@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2008 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 
 public class FunkySupers {
 	int y;
@@ -22,6 +22,7 @@ public class FunkySupers {
 
 class SubFunkySupers extends FunkySupers {
 	
+  @Override
   int funky(FunkySupers fs) {
 		SubFunkySupers.super.funky(fs);
 		SubFunkySupers.this.funky(fs);
@@ -35,4 +36,4 @@ class SubFunkySupers extends FunkySupers {
 
 //class EE { class X {} }
 //class Y extends EE.X { Y(EE e) { e.super(); } }
-// DOESNT WORK IN POLYGLOT!!!
\ No newline at end of file
+// DOESNT WORK IN POLYGLOT!!!
