@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2008 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 public class Inheritance1 {
     public static void main(String[] args) {
 	Inheritance1 ih1= new Inheritance1();
@@ -30,11 +30,13 @@ class Base {
 }
 class Derived extends Base {
     
+    @Override
     public void foo() {
 	super.foo();
     }
     
+    @Override
     public String bar(int x) {
 	return Integer.toHexString(x);
     }
-}
\ No newline at end of file
+}
