@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2008 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 public class InterfaceTest1 {
     public static void main(String[] args) {
 	InterfaceTest1 it= new InterfaceTest1();
@@ -26,6 +26,7 @@ class FooIT1 implements IFoo {
 	fValue= ch;
     }
 
+    @Override
     public char getValue() {
 	return fValue;
     }
