@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2008 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,10 +7,10 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 public class LocalClass {
     public static void main(String[] args) {
-	final Integer base = new Integer(6);
+	final Integer base = Integer.valueOf(6);
 
 	class Foo {
 	    int value;
@@ -27,7 +27,7 @@ public class LocalClass {
     }
 
     public void method() {
-	final Integer base = new Integer(6);
+	final Integer base = Integer.valueOf(6);
 
 	class Foo {
 	    int value;
