@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2008 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,18 +7,18 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 public class Monitor2 {
+  private static boolean randomIsolate() {
+    return Math.random() > .5;
+  }
+  
   int i = 0;
 
   public Monitor2() { }
 
   public void incr() { synchronized(this) { i++; } }
 
-  private static boolean test(Object o) {
-    return true;
-  }
-
   public static void main(String[] a) {
     new Monitor2().incr();
   }
