@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2008 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,13 +7,14 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 
 interface ISimpleCalls {
 	public void helloWorld();
 }
 public class SimpleCalls implements ISimpleCalls {
 	
+  @Override
   public void helloWorld() {
 		System.out.println("hello world!");
 	}
