@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 /*
  * Created on Oct 3, 2005
  */
@@ -40,6 +40,7 @@ import com.ibm.wala.classLoader.SourceFileModule;
 import com.ibm.wala.client.AbstractAnalysisEngine;
 import com.ibm.wala.ipa.callgraph.CGNode;
 import com.ibm.wala.ipa.callgraph.CallGraph;
+import com.ibm.wala.ipa.callgraph.CallGraphBuilder;
 import com.ibm.wala.ipa.callgraph.propagation.InstanceKey;
 import com.ibm.wala.ipa.callgraph.propagation.PointerAnalysis;
 import com.ibm.wala.ipa.cha.IClassHierarchy;
@@ -53,6 +54,7 @@ import com.ibm.wala.types.TypeReference;
 import com.ibm.wala.types.annotations.Annotation;
 import com.ibm.wala.util.CancelException;
 import com.ibm.wala.util.collections.HashSetFactory;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.collections.Pair;
 import com.ibm.wala.util.debug.Assertions;
 import com.ibm.wala.util.strings.Atom;
@@ -126,7 +128,7 @@ public abstract class IRTests {
   protected static class EdgeAssertions implements IRAssertion {
     public final String srcDescriptor;
 
-    public final List/* <String> */<String> tgtDescriptors = new ArrayList<String>();
+    public final List/* <String> */<String> tgtDescriptors = new ArrayList<>();
 
     public EdgeAssertions(String srcDescriptor) {
       this.srcDescriptor = srcDescriptor;
@@ -190,9 +192,7 @@ public abstract class IRTests {
         CGNode tgtNode = tgtNodes.iterator().next();
 
         boolean found = false;
-        for (Iterator<? extends CGNode> succIter = callGraph.getSuccNodes(srcNode); succIter.hasNext();) {
-          CGNode succ = succIter.next();
-
+        for (CGNode succ : Iterator2Iterable.make(callGraph.getSuccNodes(srcNode))) {
           if (tgtNode == succ) {
             found = true;
             break;
@@ -339,19 +339,23 @@ public abstract class IRTests {
   }
   
   protected String[] simpleTestEntryPoint() {
-    return new String[] { "L" + getTestName().substring(4) };
+    return new String[] { 'L' + getTestName().substring(4) };
   }
 
   protected String[] simplePkgTestEntryPoint(String pkgName) {
     return new String[] { "L" + pkgName + "/" + getTestName().substring(4) };
   }
 
-  protected abstract AbstractAnalysisEngine getAnalysisEngine(String[] mainClassDescriptors, Collection<String> sources, List<String> libs);
+  protected abstract <I extends InstanceKey> AbstractAnalysisEngine<I, CallGraphBuilder<I>, ?> getAnalysisEngine(String[] mainClassDescriptors, Collection<String> sources, List<String> libs);
 
-  public Pair<CallGraph, PointerAnalysis<InstanceKey>> runTest(Collection<String> sources, List<String> libs,
-        String[] mainClassDescriptors, List<? extends IRAssertion> ca, boolean assertReachable) throws IllegalArgumentException, CancelException, IOException {
-      AbstractAnalysisEngine engine = getAnalysisEngine(mainClassDescriptors, sources, libs);
+  public <I extends InstanceKey> Pair<CallGraph, PointerAnalysis<? extends InstanceKey>> runTest(Collection<String> sources, List<String> libs,
+        String[] mainClassDescriptors, List<? extends IRAssertion> ca, boolean assertReachable, String exclusionsFile) throws IllegalArgumentException, CancelException, IOException {
+      AbstractAnalysisEngine<I, CallGraphBuilder<I>, ?> engine = getAnalysisEngine(mainClassDescriptors, sources, libs);
 
+      if (exclusionsFile != null) {
+        engine.setExclusionsFile(exclusionsFile);
+      }
+      
       CallGraph callGraph;
         callGraph = engine.buildDefaultCallGraph();
         //System.err.println(callGraph.toString());
@@ -369,7 +373,7 @@ public abstract class IRTests {
         return Pair.make(callGraph, engine.getPointerAnalysis());
   }
 
-  protected static void dumpIR(CallGraph cg, Collection<String> sources, boolean assertReachable) throws IOException {
+  protected static void dumpIR(CallGraph cg, Collection<String> sources, boolean assertReachable) {
     Set<String> sourcePaths = HashSetFactory.make();
     for(String src : sources) {
       sourcePaths.add(src.substring(src.lastIndexOf(File.separator)+1));
@@ -378,8 +382,7 @@ public abstract class IRTests {
     Set<IMethod> unreachable = HashSetFactory.make();
     IClassHierarchy cha = cg.getClassHierarchy();
     IClassLoader sourceLoader = cha.getLoader(JavaSourceAnalysisScope.SOURCE);
-    for (Iterator iter = sourceLoader.iterateAllClasses(); iter.hasNext();) {
-      IClass clazz = (IClass) iter.next();
+    for (IClass clazz : Iterator2Iterable.make(sourceLoader.iterateAllClasses())) {
 
       System.err.println(clazz);
       if (clazz.isInterface())
@@ -389,7 +392,7 @@ public abstract class IRTests {
         if (m.isAbstract()) {
           System.err.println(m);
         } else {
-          Iterator nodeIter = cg.getNodes(m.getReference()).iterator();
+          Iterator<CGNode> nodeIter = cg.getNodes(m.getReference()).iterator();
           if (!nodeIter.hasNext()) {
             if (m instanceof AstMethod) {
               String fn = ((AstClass)m.getDeclaringClass()).getSourcePosition().getURL().getFile();
@@ -400,7 +403,7 @@ public abstract class IRTests {
             }
             continue;
           }
-          CGNode node = (CGNode) nodeIter.next();
+          CGNode node = nodeIter.next();
           System.err.println(node.getIR());
         }
       }
@@ -412,10 +415,8 @@ public abstract class IRTests {
   }
 
   /**
-   * 
    * @param srcMethodDescriptor a full method descriptor of the form ldr#type#methName#methSig example:
    *          Source#Simple1#main#([Ljava/lang/String;)V
-   * @param cha
    */
   public static MethodReference descriptorToMethodRef(String srcMethodDescriptor, IClassHierarchy cha) {
     String[] ldrTypeMeth = srcMethodDescriptor.split("\\#");
@@ -433,7 +434,7 @@ public abstract class IRTests {
 
   static TypeReference findOrCreateTypeReference(String loaderName, String typeStr, IClassHierarchy cha) {
     ClassLoaderReference clr = findLoader(loaderName, cha);
-    TypeName typeName = TypeName.string2TypeName("L" + typeStr);
+    TypeName typeName = TypeName.string2TypeName('L' + typeStr);
     TypeReference typeRef = TypeReference.findOrCreate(clr, typeName);
     return typeRef;
   }
@@ -450,14 +451,14 @@ public abstract class IRTests {
     return null;
   }
 
-  protected void populateScope(JavaSourceAnalysisEngine engine, Collection<String> sources, List<String> libs) {
+  public static void populateScope(JavaSourceAnalysisEngine<?> engine, Collection<String> sources, List<String> libs) {
     boolean foundLib = false;
     for (String lib : libs) {
       File libFile = new File(lib);
       if (libFile.exists()) {
         foundLib = true;
         try {
-          engine.addSystemModule(new JarFileModule(new JarFile(libFile)));
+          engine.addSystemModule(new JarFileModule(new JarFile(libFile, false)));
         } catch (IOException e) {
           Assert.fail(e.getMessage());
         }
