@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.java.test;
 
 import java.io.IOException;
@@ -28,7 +28,7 @@ public abstract class JLexTest extends IRTests {
   }
 
   @Test public void testJLex() throws IllegalArgumentException, CancelException, IOException {
-    runTest(singleTestSrc(), rtJar, new String[] { "LJLex/Main" }, emptyList, false);
+    runTest(singleTestSrc(), rtJar, new String[] { "LJLex/Main" }, emptyList, false, null);
   }
 
   @Override
