@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 /*
  * Created on Aug 22, 2005
  */
@@ -17,7 +17,6 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -31,6 +30,9 @@ import com.ibm.wala.cast.ir.ssa.AstIsDefinedInstruction;
 import com.ibm.wala.cast.ir.ssa.AstLexicalAccess.Access;
 import com.ibm.wala.cast.ir.ssa.AstLexicalRead;
 import com.ibm.wala.cast.ir.ssa.AstLexicalWrite;
+import com.ibm.wala.cast.ir.ssa.AstPropertyRead;
+import com.ibm.wala.cast.ir.ssa.AstPropertyWrite;
+import com.ibm.wala.cast.ir.ssa.AstYieldInstruction;
 import com.ibm.wala.cast.ir.translator.AstTranslator;
 import com.ibm.wala.cast.ir.translator.AstTranslator.AstLexicalInformation;
 import com.ibm.wala.cast.java.ssa.AstJavaInstructionFactory;
@@ -65,7 +67,7 @@ import com.ibm.wala.ipa.cha.IClassHierarchy;
 import com.ibm.wala.shrikeCT.AnnotationsReader.ConstantElementValue;
 import com.ibm.wala.shrikeCT.AnnotationsReader.ElementValue;
 import com.ibm.wala.shrikeCT.ClassConstants;
-import com.ibm.wala.ssa.SSAThrowInstruction;
+import com.ibm.wala.ssa.SSAInstruction;
 import com.ibm.wala.ssa.SymbolTable;
 import com.ibm.wala.types.ClassLoaderReference;
 import com.ibm.wala.types.Descriptor;
@@ -77,7 +79,6 @@ import com.ibm.wala.types.TypeReference;
 import com.ibm.wala.types.annotations.Annotation;
 import com.ibm.wala.util.collections.HashMapFactory;
 import com.ibm.wala.util.collections.HashSetFactory;
-import com.ibm.wala.util.config.SetOfClasses;
 import com.ibm.wala.util.debug.Assertions;
 import com.ibm.wala.util.strings.Atom;
 
@@ -93,17 +94,17 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
 
   /**
    * WALA representation of a Java class residing in a source file
-   * 
+   *
    * @author rfuhrer
    */
   public class JavaClass extends AstClass {
     protected final IClass enclosingClass;
 
-    protected final Collection superTypeNames;
+    protected final Collection<TypeName> superTypeNames;
 
     private final Collection<Annotation> annotations;
-    
-    public JavaClass(String typeName, Collection superTypeNames, CAstSourcePositionMap.Position position, Collection qualifiers,
+
+    public JavaClass(String typeName, Collection<TypeName> superTypeNames, CAstSourcePositionMap.Position position, Collection<CAstQualifier> qualifiers,
         JavaSourceLoaderImpl loader, IClass enclosingClass, Collection<Annotation> annotations) {
       super(position, TypeName.string2TypeName(typeName), loader, (short) mapToInt(qualifiers), new HashMap<Atom, IField>(), new HashMap<Selector, IMethod>());
       this.superTypeNames = superTypeNames;
@@ -124,8 +125,7 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
     @Override
     public IClass getSuperclass() {
       boolean excludedSupertype=false;
-      for (Iterator iter = superTypeNames.iterator(); iter.hasNext();) {
-        TypeName name = (TypeName) iter.next();
+      for (TypeName name : superTypeNames) {
         IClass domoType = lookupClass(name);
         if (domoType != null && !domoType.isInterface()) {
           return domoType;
@@ -144,19 +144,18 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
 /** END Custom change: Common superclass is optional */
         Assertions.UNREACHABLE("Cannot find super class for " + this + " in " + superTypeNames);
       }
-      
+
       if (excludedSupertype){
         System.err.println("Not tracking calls through excluded superclass of " + getName() + " extends " + superTypeNames);
       }
-      
+
       return null;
     }
 
     @Override
     public Collection<IClass> getDirectInterfaces() {
-      List<IClass> result = new ArrayList<IClass>();
-      for (Iterator iter = superTypeNames.iterator(); iter.hasNext();) {
-        TypeName name = (TypeName) iter.next();
+      List<IClass> result = new ArrayList<>();
+      for (TypeName name : superTypeNames) {
         IClass domoType = lookupClass(name);
         if (domoType != null && domoType.isInterface()) {
             result.add(domoType);
@@ -169,17 +168,17 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
       return result;
     }
 
-    private void addMethod(CAstEntity methodEntity, IClass owner, AbstractCFG cfg, SymbolTable symtab, boolean hasCatchBlock,
-        Map<IBasicBlock, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo) {
+    protected void addMethod(CAstEntity methodEntity, IClass owner, AbstractCFG<?, ?> cfg, SymbolTable symtab, boolean hasCatchBlock,
+        Map<IBasicBlock<SSAInstruction>, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo) {
       declaredMethods.put(Util.methodEntityToSelector(methodEntity), new ConcreteJavaMethod(methodEntity, owner, cfg, symtab,
           hasCatchBlock, caughtTypes, hasMonitorOp, lexicalInfo, debugInfo));
     }
 
-    private void addMethod(CAstEntity methodEntity, IClass owner) {
+    protected void addMethod(CAstEntity methodEntity, IClass owner) {
       declaredMethods.put(Util.methodEntityToSelector(methodEntity), new AbstractJavaMethod(methodEntity, owner));
     }
 
-    private void addField(CAstEntity fieldEntity) {
+    protected void addField(CAstEntity fieldEntity) {
       declaredFields.put(Util.fieldEntityToAtom(fieldEntity), new JavaField(fieldEntity, JavaSourceLoaderImpl.this, this, JavaSourceLoaderImpl.this.getAnnotations(fieldEntity)));
     }
 
@@ -189,21 +188,21 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
 
     @Override
     public String toString() {
-      StringBuffer sb = new StringBuffer("<src-class: " );
+      StringBuilder sb = new StringBuilder("<src-class: " );
       sb.append(getName().toString());
       if (enclosingClass != null) {
-        sb.append(" (within " + enclosingClass.getName() + ")");
+        sb.append(" (within ").append(enclosingClass.getName()).append(')');
       }
       if (annotations != null && !annotations.isEmpty()) {
         for(Annotation a : annotations) {
-          sb.append("[" + a.getType().getName().getClassName() + "]");
+          sb.append('[').append(a.getType().getName().getClassName()).append(']');
         }
       }
       return sb.toString();
     }
   }
 
-  private Collection<Annotation> getAnnotations(CAstEntity e) {
+  protected Collection<Annotation> getAnnotations(CAstEntity e) {
     Collection<CAstAnnotation> annotations = e.getAnnotations();
     if (annotations == null || annotations.isEmpty()) {
       return null;
@@ -225,14 +224,14 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
       return result;
     }
   }
-  
+
   /**
    * WALA representation of a field on a Java type that resides in a source file
-   * 
+   *
    * @author rfuhrer
    */
-  private class JavaField extends AstField {
-    private JavaField(CAstEntity fieldEntity, IClassLoader loader, IClass declaringClass, Collection<Annotation> annotations) {
+  protected class JavaField extends AstField {
+    protected JavaField(CAstEntity fieldEntity, IClassLoader loader, IClass declaringClass, Collection<Annotation> annotations) {
       super(FieldReference.findOrCreate(declaringClass.getReference(), Atom.findOrCreateUnicodeAtom(fieldEntity.getName()),
           TypeReference.findOrCreate(loader.getReference(), TypeName.string2TypeName(fieldEntity.getType().getName()))),
           fieldEntity.getQualifiers(), declaringClass, declaringClass.getClassHierarchy(), annotations);
@@ -242,16 +241,16 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
   /**
    * Generic DOMO representation of a method on a Java type that resides in a
    * source file
-   * 
+   *
    * @author rfuhrer
    */
-  private abstract class JavaEntityMethod extends AstMethod {
+  protected abstract class JavaEntityMethod extends AstMethod {
     private final TypeReference[] parameterTypes;
 
     private final TypeReference[] exceptionTypes;
 
-    public JavaEntityMethod(CAstEntity methodEntity, IClass owner, AbstractCFG cfg, SymbolTable symtab, boolean hasCatchBlock,
-        Map<IBasicBlock, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo) {
+    public JavaEntityMethod(CAstEntity methodEntity, IClass owner, AbstractCFG<?, ?> cfg, SymbolTable symtab, boolean hasCatchBlock,
+        Map<IBasicBlock<SSAInstruction>, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo) {
       super(owner, methodEntity.getQualifiers(), cfg, symtab, MethodReference.findOrCreate(owner.getReference(), Util
           .methodEntityToSelector(methodEntity)), hasCatchBlock, caughtTypes, hasMonitorOp, lexicalInfo, debugInfo, JavaSourceLoaderImpl.this.getAnnotations(methodEntity));
       this.parameterTypes = computeParameterTypes(methodEntity);
@@ -280,22 +279,22 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
       return parameterTypes[i];
     }
 
-    private TypeReference[] computeParameterTypes(CAstEntity methodEntity) {
+    protected TypeReference[] computeParameterTypes(CAstEntity methodEntity) {
       TypeReference[] types;
       CAstType.Function type = (Function) methodEntity.getType();
       int argCount = type.getArgumentTypes().size();
       if (isStatic()) {
         types = new TypeReference[argCount];
         for (int i = 0; i < argCount; i++) {
-          types[i] = TypeReference.findOrCreate(JavaSourceLoaderImpl.this.getReference(), ((CAstType) type.getArgumentTypes()
-              .get(i)).getName());
+          types[i] = TypeReference.findOrCreate(JavaSourceLoaderImpl.this.getReference(), type.getArgumentTypes()
+              .get(i).getName());
         }
       } else {
         types = new TypeReference[argCount + 1];
         types[0] = cls.getReference();
         for (int i = 0; i < argCount; i++) {
-          types[i + 1] = TypeReference.findOrCreate(JavaSourceLoaderImpl.this.getReference(), ((CAstType) type.getArgumentTypes()
-              .get(i)).getName());
+          types[i + 1] = TypeReference.findOrCreate(JavaSourceLoaderImpl.this.getReference(), type.getArgumentTypes()
+              .get(i).getName());
         }
       }
 
@@ -307,15 +306,15 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
       return exceptionTypes;
     }
 
-    private TypeReference[] computeExceptionTypes(CAstEntity methodEntity) {
+    protected TypeReference[] computeExceptionTypes(CAstEntity methodEntity) {
       CAstType.Function fType = (Function) methodEntity.getType();
-      Collection exceptionTypes = fType.getExceptionTypes();
+      Collection<CAstType> exceptionTypes = fType.getExceptionTypes();
 
       TypeReference[] result = new TypeReference[exceptionTypes.size()];
       int i = 0;
-      for (Iterator iter = exceptionTypes.iterator(); iter.hasNext(); i++) {
-        CAstType type = (CAstType) iter.next();
+      for (CAstType type : exceptionTypes) {
         result[i] = TypeReference.findOrCreate(JavaSourceLoaderImpl.this.getReference(), type.getName());
+        ++i;
       }
 
       return result;
@@ -323,17 +322,17 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
 
     @Override
     public String toString() {
-      return "<src-method: " + this.getReference() + ">";
+      return "<src-method: " + this.getReference() + '>';
     }
   }
 
   /**
    * DOMO representation of an abstract (body-less) method on a Java type that
    * resides in a source file
-   * 
+   *
    * @author rfuhrer
    */
-  private class AbstractJavaMethod extends JavaEntityMethod {
+  protected class AbstractJavaMethod extends JavaEntityMethod {
     public AbstractJavaMethod(CAstEntity methodEntity, IClass owner) {
       super(methodEntity, owner);
     }
@@ -364,12 +363,12 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
   /**
    * DOMO representation of a concrete method (which has a body) on a Java type
    * that resides in a source file
-   * 
+   *
    * @author rfuhrer
    */
   public class ConcreteJavaMethod extends JavaEntityMethod {
-    public ConcreteJavaMethod(CAstEntity methodEntity, IClass owner, AbstractCFG cfg, SymbolTable symtab, boolean hasCatchBlock,
-        Map<IBasicBlock, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo) {
+    public ConcreteJavaMethod(CAstEntity methodEntity, IClass owner, AbstractCFG<?, ?> cfg, SymbolTable symtab, boolean hasCatchBlock,
+        Map<IBasicBlock<SSAInstruction>, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo) {
       super(methodEntity, owner, cfg, symtab, hasCatchBlock, caughtTypes, hasMonitorOp, lexicalInfo, debugInfo);
     }
 
@@ -450,11 +449,9 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
     }
   }
 
-  public static int mapToInt(Collection/* <CAstQualifier> */qualifiers) {
+  public static int mapToInt(Collection<CAstQualifier> qualifiers) {
     int result = 0;
-    for (Iterator iter = qualifiers.iterator(); iter.hasNext();) {
-      CAstQualifier q = (CAstQualifier) iter.next();
-
+    for (CAstQualifier q : qualifiers) {
       if (q == CAstQualifier.PUBLIC)
         result |= ClassConstants.ACC_PUBLIC;
       if (q == CAstQualifier.PROTECTED)
@@ -485,14 +482,14 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
 
 /** BEGIN Custom change: Common superclass is optional */
   public JavaSourceLoaderImpl(boolean existsCommonSuperClass, ClassLoaderReference loaderRef, IClassLoader parent,
-      SetOfClasses exclusions, IClassHierarchy cha) throws IOException {
+      IClassHierarchy cha) {
     super(loaderRef, cha.getScope().getArrayClassLoader(), parent, cha.getScope().getExclusions(), cha);
     this.existsCommonSuperclass = existsCommonSuperClass;
   }
-  
-  public JavaSourceLoaderImpl(ClassLoaderReference loaderRef, IClassLoader parent, SetOfClasses exclusions, IClassHierarchy cha) throws IOException {
+
+  public JavaSourceLoaderImpl(ClassLoaderReference loaderRef, IClassLoader parent, IClassHierarchy cha) {
     // standard case: we have a common super class
-    this(true, loaderRef, parent, exclusions, cha);
+    this(true, loaderRef, parent, cha);
   }
 /** END Custom change: Common superclass is optional */
 
@@ -509,7 +506,7 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
 /** BEGIN Custom change: Optional deletion of fTypeMap */
   public static volatile boolean deleteTypeMapAfterInit = true;
 /** END Custom change: Optional deletion of fTypeMap */
-  
+
 
   @Override
   public void init(List<Module> modules) throws IOException {
@@ -521,8 +518,8 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
 /** END Custom change: Optional deletion of fTypeMap */
   }
 
-  public void defineFunction(CAstEntity n, IClass owner, AbstractCFG cfg, SymbolTable symtab, boolean hasCatchBlock,
-      Map<IBasicBlock, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo) {
+  public void defineFunction(CAstEntity n, IClass owner, AbstractCFG<?, ?> cfg, SymbolTable symtab, boolean hasCatchBlock,
+      Map<IBasicBlock<SSAInstruction>, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo) {
     ((JavaClass) owner).addMethod(n, owner, cfg, symtab, hasCatchBlock, caughtTypes, hasMonitorOp, lexicalInfo, debugInfo);
   }
 
@@ -534,14 +531,14 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
     ((JavaClass) owner).addField(n);
   }
 
-  private TypeName toWALATypeName(CAstType type) {
+  protected static TypeName toWALATypeName(CAstType type) {
     return TypeName.string2TypeName(type.getName());
   }
-  
+
   public IClass defineType(CAstEntity type, String typeName, CAstEntity owner) {
-    Collection<TypeName> superTypeNames = new ArrayList<TypeName>();
-    for (Iterator superTypes = type.getType().getSupertypes().iterator(); superTypes.hasNext();) {
-      superTypeNames.add(toWALATypeName(((CAstType) superTypes.next())));
+    Collection<TypeName> superTypeNames = new ArrayList<>();
+    for (CAstType superType : type.getType().getSupertypes()) {
+      superTypeNames.add(toWALATypeName(superType));
     }
 
     JavaClass javaClass = new JavaClass(typeName, superTypeNames, type.getPosition(), type.getQualifiers(), this,
@@ -550,7 +547,7 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
     if (getParent().lookupClass(javaClass.getName()) != null) {
       return null;
     }
-    
+
     fTypeMap.put(type, javaClass);
     loadedClasses.put(javaClass.getName(), javaClass);
     return javaClass;
@@ -558,9 +555,9 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
 
   @Override
   public String toString() {
-    return "Java Source Loader (classes " + loadedClasses.values() + ")";
+    return "Java Source Loader (classes " + loadedClasses.values() + ')';
   }
-  
+
   public static class InstructionFactory extends JavaInstructionFactory implements AstJavaInstructionFactory {
 
     @Override
@@ -664,13 +661,26 @@ public abstract class JavaSourceLoaderImpl extends ClassLoaderImpl {
        return new AstLexicalWrite(iindex, definer, globalName, type, rhs);
     }
 
-    public SSAThrowInstruction NonExceptingThrowInstruction(int iindex, int exception) {
-      throw new UnsupportedOperationException();
-   }    
+    @Override
+    public AstYieldInstruction YieldInstruction(int iindex, int[] rvals) {
+      return new AstYieldInstruction(iindex, rvals);
+    }
+    
+    @Override
+    public AstPropertyRead PropertyRead(int iindex, int result, int objectRef, int memberRef) {
+      assert false;
+      return null;
+    }
+
+    @Override
+    public AstPropertyWrite PropertyWrite(int iindex, int objectRef, int memberRef, int value) {
+      assert false;
+      return null;
+    }
   }
-  
-  private static final InstructionFactory insts = new InstructionFactory();
-  
+
+  protected static final InstructionFactory insts = new InstructionFactory();
+
   @Override
   public InstructionFactory getInstructionFactory() {
     return insts;
