@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,17 +7,17 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.cast.js.translator;
 
 import com.ibm.wala.cast.ir.translator.TranslatorToCAst;
 import com.ibm.wala.cast.tree.CAst;
-import com.ibm.wala.classLoader.SourceModule;
+import com.ibm.wala.classLoader.ModuleEntry;
 
 public class CAstRhinoTranslatorFactory implements JavaScriptTranslatorFactory {
 
 	@Override
-  public TranslatorToCAst make(CAst ast, SourceModule M) {
+  public TranslatorToCAst make(CAst ast, ModuleEntry M) {
 		return new CAstRhinoTranslator(M, false);
 	}
 }
