@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,10 +7,11 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.js.translator;
 
 import java.io.IOException;
+import java.io.InputStreamReader;
 import java.io.Reader;
 import java.net.URL;
 import java.util.ArrayList;
@@ -90,7 +91,6 @@ import org.mozilla.javascript.ast.XmlString;
 import org.mozilla.javascript.ast.Yield;
 
 import com.ibm.wala.cast.ir.translator.TranslatorToCAst;
-import com.ibm.wala.cast.ir.translator.TranslatorToCAst.DoLoopTranslator;
 import com.ibm.wala.cast.js.html.MappedSourceModule;
 import com.ibm.wala.cast.js.ipa.callgraph.JSSSAPropagationCallGraphBuilder;
 import com.ibm.wala.cast.js.loader.JavaScriptLoader;
@@ -108,8 +108,12 @@ import com.ibm.wala.cast.tree.CAstType;
 import com.ibm.wala.cast.tree.impl.CAstOperator;
 import com.ibm.wala.cast.tree.impl.CAstSymbolImpl;
 import com.ibm.wala.cast.tree.impl.RangePosition;
+import com.ibm.wala.cast.tree.rewrite.CAstRewriter.CopyKey;
+import com.ibm.wala.cast.tree.rewrite.CAstRewriter.RewriteContext;
+import com.ibm.wala.cast.tree.rewrite.CAstRewriterFactory;
 import com.ibm.wala.cast.tree.visit.CAstVisitor;
 import com.ibm.wala.cast.util.CAstPattern;
+import com.ibm.wala.classLoader.ModuleEntry;
 import com.ibm.wala.classLoader.SourceModule;
 import com.ibm.wala.util.collections.EmptyIterator;
 import com.ibm.wala.util.collections.HashMapFactory;
@@ -117,7 +121,7 @@ import com.ibm.wala.util.collections.HashSetFactory;
 import com.ibm.wala.util.debug.Assertions;
 import com.ibm.wala.util.warnings.Warning;
 
-public class RhinoToAstTranslator {
+public class RhinoToAstTranslator implements TranslatorToCAst {
 
   /**
    * a dummy name to use for standard function calls, only used to distinguish
@@ -155,10 +159,9 @@ public class RhinoToAstTranslator {
    */
   private static class FunctionContext extends JavaScriptTranslatorToCAst.FunctionContext<WalkContext,Node> implements WalkContext {
     FunctionContext(WalkContext parent, Node s) {
-		super(parent, s);
-	}
-
-   }
+      super(parent, s);
+    }
+  }
 
   /**
    * context used for top-level script declarations
@@ -187,29 +190,44 @@ public class RhinoToAstTranslator {
 
   private static class BreakContext extends JavaScriptTranslatorToCAst.BreakContext<WalkContext, Node> implements WalkContext {
 
+    @Override
+    public WalkContext getParent() {
+      return (WalkContext) super.getParent();
+    }
+
     BreakContext(WalkContext parent, Node breakTo, String label) {
       super(parent, breakTo, label);
     }
 
   }
 
-  private static class LoopContext extends JavaScriptTranslatorToCAst.LoopContext<WalkContext, Node> implements WalkContext {
+  private static class LoopContext extends TranslatorToCAst.LoopContext<WalkContext, Node> implements WalkContext {
 
 	LoopContext(WalkContext parent, Node breakTo, Node continueTo, String label) {
 		super(parent, breakTo, continueTo, label);
 	}
 
+  @Override
+  public WalkContext getParent() {
+    return (WalkContext) super.getParent();
   }
 
-  private static class TryCatchContext extends JavaScriptTranslatorToCAst.TryCatchContext<WalkContext, Node> implements WalkContext {
+  }
+
+  private static class TryCatchContext extends TranslatorToCAst.TryCatchContext<WalkContext, Node> implements WalkContext {
 
 	TryCatchContext(WalkContext parent, CAstNode catchNode) {
 		super(parent, catchNode);
 	}
 
+  @Override
+  public WalkContext getParent() {
+    return (WalkContext) super.getParent();
   }
 
-  private String operationReceiverName(int operationIndex) {
+  }
+
+  private static String operationReceiverName(int operationIndex) {
     return "$$destructure$rcvr" + operationIndex;
   }
 
@@ -217,7 +235,7 @@ public class RhinoToAstTranslator {
     return Ast.makeNode(CAstNode.VAR, Ast.makeConstant(operationReceiverName(operationIndex)));
   }
   
-  private String operationElementName(int operationIndex) {
+  private static String operationElementName(int operationIndex) {
     return "$$destructure$elt" + operationIndex;
   }
 
@@ -225,7 +243,7 @@ public class RhinoToAstTranslator {
     return Ast.makeNode(CAstNode.VAR, Ast.makeConstant(operationElementName(operationIndex)));
   }
 
-  private CAstNode translateOpcode(int nodeType) {
+  private static CAstNode translateOpcode(int nodeType) {
     switch (nodeType) {
     case Token.POS:
     case Token.ADD:
@@ -307,26 +325,26 @@ public class RhinoToAstTranslator {
     return makeCtorCall(value, arguments, context);
   }
 
-  private boolean isPrologueScript(WalkContext context) {
+  private static boolean isPrologueScript(WalkContext context) {
     return JavaScriptLoader.bootstrapFileNames.contains(context.script());
   }
 
-  private Node getCallTarget(FunctionCall n) {
+  private static Node getCallTarget(FunctionCall n) {
 	  return n.getTarget();
   }
   /**
    * is n a call to "primitive" within our synthetic modeling code?
    */
-  private boolean isPrimitiveCall(WalkContext context, FunctionCall n) {
+  private static boolean isPrimitiveCall(WalkContext context, FunctionCall n) {
     return isPrologueScript(context) && n.getType() == Token.CALL && getCallTarget(n).getType() == Token.NAME
         && getCallTarget(n).getString().equals("primitive");
   }
 
-  private Node getNewTarget(NewExpression n) {
+  private static Node getNewTarget(NewExpression n) {
 	  return n.getTarget();
   }
   
-  private boolean isPrimitiveCreation(WalkContext context, NewExpression n) {
+  private static boolean isPrimitiveCreation(WalkContext context, NewExpression n) {
 	  Node target = getNewTarget(n);
     return isPrologueScript(context) && n.getType() == Token.NEW && target.getType() == Token.NAME
         && target.getString().equals("Primitives");
@@ -375,7 +393,7 @@ public class RhinoToAstTranslator {
    * Used to represent a script or function in the CAst; see walkEntity().
    * 
    */
-  private static class ScriptOrFnEntity implements CAstEntity {
+  private class ScriptOrFnEntity implements CAstEntity {
     private final String[] arguments;
 
     private final String name;
@@ -391,6 +409,10 @@ public class RhinoToAstTranslator {
     private final CAstSourcePositionMap pos;
     
     private final Position entityPosition;
+
+    private final Position namePosition;
+
+    private final Position[] paramPositions;
     
     private ScriptOrFnEntity(AstNode n, Map<CAstNode, Collection<CAstEntity>> subs, CAstNode ast, CAstControlFlowMap map, CAstSourcePositionMap pos, String name) {
       this.name = name;
@@ -398,6 +420,7 @@ public class RhinoToAstTranslator {
 
       if (n instanceof FunctionNode) {
         FunctionNode f = (FunctionNode) n;
+        namePosition = makePosition(f.getFunctionName());
         f.flattenSymbolTable(false);
         int i = 0;
         arguments = new String[f.getParamCount() + 2];
@@ -406,8 +429,17 @@ public class RhinoToAstTranslator {
         for (int j = 0; j < f.getParamCount(); j++) {
           arguments[i++] = f.getParamOrVarName(j);
         }
+   
+        List<AstNode> params = f.getParams();
+        paramPositions = new Position[ params.size() ];
+        for(int pi = 0; pi < params.size(); pi++) {
+          paramPositions[pi] = makePosition(params.get(pi));
+        }
+        
       } else {
+        paramPositions = new Position[0];
         arguments = new String[0];
+        namePosition = null;
       }
       kind = (n instanceof FunctionNode) ? CAstEntity.FUNCTION_ENTITY : CAstEntity.SCRIPT_ENTITY;
       this.subs = subs;
@@ -418,7 +450,7 @@ public class RhinoToAstTranslator {
 
     @Override
     public String toString() {
-      return "<JS function " + getName() + ">";
+      return "<JS function " + getName() + '>';
     }
 
     @Override
@@ -505,10 +537,20 @@ public class RhinoToAstTranslator {
     public CAstType getType() {
       return JSAstTranslator.Any;
     }
+
+    @Override
+    public Position getPosition(int arg) {
+      return paramPositions[arg];
+    }
+
+    @Override
+    public Position getNamePosition() {
+      return namePosition;
+    }
   }
 
   private CAstEntity walkEntity(final AstNode n, List<CAstNode> body, String name, WalkContext child) {
-    CAstNode[] stmts = body.toArray(new CAstNode[body.size()]);
+    CAstNode[] stmts = body.toArray(new CAstNode[0]);
 
     // add variable / constant / function declarations, if any
     if (!child.getNameDecls().isEmpty()) {
@@ -518,7 +560,7 @@ public class RhinoToAstTranslator {
       if (child.getNameDecls().size() == 1) {
         newStmts[0] = child.getNameDecls().iterator().next();
       } else {
-        newStmts[0] = Ast.makeNode(CAstNode.BLOCK_STMT, child.getNameDecls().toArray(new CAstNode[child.getNameDecls().size()]));
+        newStmts[0] = Ast.makeNode(CAstNode.BLOCK_STMT, child.getNameDecls().toArray(new CAstNode[0]));
       }
       System.arraycopy(stmts, 0, newStmts, 1, stmts.length);
 
@@ -536,29 +578,25 @@ public class RhinoToAstTranslator {
   }
     
   private Position makePosition(AstNode n) {
-    URL url = sourceModule.getURL();
-    int line = n.getLineno(); 
-    Position pos = new RangePosition(url, line, n.getAbsolutePosition(), n.getAbsolutePosition()+n.getLength());
+    if (n != null) {
+      URL url = ((SourceModule)sourceModule).getURL();
+      int line = n.getLineno(); 
+      Position pos = new RangePosition(url, line, n.getAbsolutePosition(), n.getAbsolutePosition()+n.getLength());
 
-    if (sourceModule instanceof MappedSourceModule) {
-      Position np = ((MappedSourceModule) sourceModule).getMapping().getIncludedPosition(pos);
-      if (np != null) {
-        return np;
+      if (sourceModule instanceof MappedSourceModule) {
+        Position np = ((MappedSourceModule) sourceModule).getMapping().getIncludedPosition(pos);
+        if (np != null) {
+          return np;
+        }
       }
-    }
         
-    return pos;
+      return pos;
+    } else {
+      return null;
+    }
   }
 
-  private void pushSourcePosition(WalkContext context, CAstNode n, Position p) {
-	  if (context.pos().getPosition(n) == null && !(n.getKind()==CAstNode.FUNCTION_EXPR || n.getKind()==CAstNode.FUNCTION_STMT)) {
-	      context.pos().setPosition(n, p);
-	      for(int i = 0; i < n.getChildCount(); i++) {
-	    	  pushSourcePosition(context, n.getChild(i), p);
-	      }
-	  }
-  }
-  private CAstNode noteSourcePosition(WalkContext context, CAstNode n, AstNode p) {
+  protected CAstNode noteSourcePosition(WalkContext context, CAstNode n, AstNode p) {
     if (p.getLineno() != -1 && context.pos().getPosition(n) == null) {
       pushSourcePosition(context, n, makePosition(p));
     }
@@ -581,14 +619,14 @@ public class RhinoToAstTranslator {
     return cn;
   }
   
-  private List<Label> getLabels(AstNode node) {
+  private static List<Label> getLabels(AstNode node) {
 	  if (node instanceof LabeledStatement || ((node = node.getParent()) instanceof LabeledStatement)) {
 		  return ((LabeledStatement)node).getLabels();
 	  } else {
 		  return null;
 	  }
   }
-  private AstNode makeEmptyLabelStmt(String label) {
+  private static AstNode makeEmptyLabelStmt(String label) {
 	  Label l = new Label();
 	  l.setName(label);
 	  LabeledStatement st = new LabeledStatement();
@@ -599,7 +637,7 @@ public class RhinoToAstTranslator {
 	  return st;
   }
   
-  private WalkContext makeLoopContext(AstNode node, WalkContext arg,
+  private static WalkContext makeLoopContext(AstNode node, WalkContext arg,
 			AstNode breakStmt, AstNode contStmt) {
 	  WalkContext loopContext = arg;
 	  List<Label> labels = getLabels(node);
@@ -613,7 +651,7 @@ public class RhinoToAstTranslator {
 	  return loopContext;
   }
 
-  private WalkContext makeBreakContext(AstNode node, WalkContext arg,
+  private static WalkContext makeBreakContext(AstNode node, WalkContext arg,
       AstNode breakStmt) {
     WalkContext loopContext = arg;
     List<Label> labels = getLabels(node);
@@ -654,18 +692,18 @@ public class RhinoToAstTranslator {
 	@Override
 	public CAstNode visitArrayLiteral(ArrayLiteral node, WalkContext arg) {
 		int index = 0;
-		List<CAstNode> eltNodes = new ArrayList<CAstNode>(2 * node.getElements().size());
+		List<CAstNode> eltNodes = new ArrayList<>(2 * node.getElements().size());
     	eltNodes.add(((isPrologueScript(arg)) ? makeBuiltinNew("Array") : handleNew(arg, "Array", null)));
 		for(AstNode elt : node.getElements()) {
 			if (elt instanceof EmptyExpression) {
 				index++;
 			} else {
-				eltNodes.add(Ast.makeConstant("" + (index++)));
+				eltNodes.add(Ast.makeConstant(String.valueOf(index++)));
 				eltNodes.add(visit(elt, arg));
 			}
 		}
 		
-		CAstNode lit = Ast.makeNode(CAstNode.OBJECT_LITERAL, eltNodes.toArray(new CAstNode[eltNodes.size()]));
+		CAstNode lit = Ast.makeNode(CAstNode.OBJECT_LITERAL, eltNodes.toArray(new CAstNode[0]));
 		arg.cfg().map(node, lit);
 		return lit;
 	}
@@ -691,14 +729,14 @@ public class RhinoToAstTranslator {
 
 	@Override
 	public CAstNode visitBlock(Block node, WalkContext arg) {
-		List<CAstNode> nodes = new ArrayList<CAstNode>();
+		List<CAstNode> nodes = new ArrayList<>();
 		for(Node child : node) {
 			nodes.add(visit((AstNode)child, arg));
 		}
 		if (nodes.isEmpty()) {
 			return Ast.makeNode(CAstNode.EMPTY);
 		} else {
-			return Ast.makeNode(CAstNode.BLOCK_STMT, nodes.toArray(new CAstNode[ nodes.size() ]));
+			return Ast.makeNode(CAstNode.BLOCK_STMT, nodes.toArray(new CAstNode[0]));
 		}
 	}
 
@@ -827,87 +865,173 @@ public class RhinoToAstTranslator {
 			WalkContext arg) {
 		return visit(node.getExpression(), arg);
 	}
-
+	
 	@Override
 	public CAstNode visitForInLoop(ForInLoop node, WalkContext arg) {		
-		// set up 		
-		CAstNode object = visit(node.getIteratedObject(), arg);
-    String tempName = "for in loop temp";   
-		CAstNode[] loopHeader = new CAstNode[]{
-		    Ast.makeNode(CAstNode.DECL_STMT, Ast.makeConstant(new CAstSymbolImpl(tempName, JSAstTranslator.Any)), readName(arg, null, "$$undefined")),
-        Ast.makeNode(CAstNode.ASSIGN, Ast.makeNode(CAstNode.VAR, Ast.makeConstant(tempName)), object)
-		};
-		
-		CAstNode initNode;
-		String name;
-		AstNode var = node.getIterator();
-		assert var instanceof Name || var instanceof VariableDeclaration || var instanceof LetNode : var.getClass()  + " " + var;
-		if (var instanceof Name) {
-		  name = ((Name)var).getString();
-      initNode = 
-        Ast.makeNode(CAstNode.ASSIGN, 
-          Ast.makeNode(CAstNode.VAR, Ast.makeConstant(name)),
-          Ast.makeNode(CAstNode.EACH_ELEMENT_GET, 
-              Ast.makeNode(CAstNode.VAR, Ast.makeConstant(tempName)),
-              readName(arg, null, name)));
-		  
-		} else {
-		  VariableDeclaration decl;
-		  if (var instanceof LetNode) {
-		    decl = ((LetNode)var).getVariables();
-		  } else {
-		    decl = (VariableDeclaration)var;
-		  }
-		  assert decl.getVariables().size() == 1;
-		  VariableInitializer init = decl.getVariables().iterator().next();
+	  CAstNode loop;
+	  CAstNode get;
+	  // TODO: fix the correlation-tracking rewriters, and kill the old for..in translation
+	  if (useNewForIn) {
+	    // set up 		
+	    CAstNode object = visit(node.getIteratedObject(), arg);
+	    String tempName = "for in loop temp";   
+	    CAstNode[] loopHeader = new CAstNode[]{
+	        Ast.makeNode(CAstNode.DECL_STMT, Ast.makeConstant(new CAstSymbolImpl(tempName, JSAstTranslator.Any)), readName(arg, null, "$$undefined")),
+	        Ast.makeNode(CAstNode.ASSIGN, Ast.makeNode(CAstNode.VAR, Ast.makeConstant(tempName)), object)
+	    };
 
-      name = init.getTarget().getString();
+	    String name;
+	    AstNode var = node.getIterator();
+	    assert var instanceof Name || var instanceof VariableDeclaration || var instanceof LetNode : var.getClass()  + " " + var;
+	    if (var instanceof Name) {
+	      name = ((Name)var).getString();		  
+	    } else {
+	      VariableDeclaration decl;
+	      if (var instanceof LetNode) {
+	        decl = ((LetNode)var).getVariables();
+	      } else {
+	        decl = (VariableDeclaration)var;
+	      }
+	      assert decl.getVariables().size() == 1;
+	      VariableInitializer init = decl.getVariables().iterator().next();
 
-	    arg.addNameDecl(
-	        Ast.makeNode(CAstNode.DECL_STMT, Ast.makeConstant(new CAstSymbolImpl(name, JSAstTranslator.Any)),
-	            readName(arg, null, "$$undefined")));
-	    		  
-      initNode = 
-          Ast.makeNode(CAstNode.ASSIGN, 
-              Ast.makeNode(CAstNode.VAR, Ast.makeConstant(name)),
-		          Ast.makeNode(CAstNode.EACH_ELEMENT_GET, 
-		              Ast.makeNode(CAstNode.VAR, Ast.makeConstant(tempName)),
-		              readName(arg, null, name)));
+	      name = init.getTarget().getString();
 
-		}
-		
-		// body
-		AstNode breakStmt = makeEmptyLabelStmt("breakLabel");
-		CAstNode breakLabel = visit(breakStmt, arg);
-		AstNode contStmt = makeEmptyLabelStmt("contLabel");
-		CAstNode contLabel = visit(contStmt, arg);
-		// TODO: Figure out why this is needed to make the correlation extraction tests pass
-		// TODO: remove this silly label
-    AstNode garbageStmt = makeEmptyLabelStmt("garbageLabel");
-    CAstNode garbageLabel = visit(garbageStmt, arg);
-		WalkContext loopContext = makeLoopContext(node, arg, breakStmt, contStmt);
-		CAstNode body = Ast.makeNode(CAstNode.BLOCK_STMT,
-				initNode,
-				visit(node.getBody(), loopContext),
-				garbageLabel);
-		
-		CAstNode loop = Ast.makeNode(CAstNode.LOCAL_SCOPE,
-				Ast.makeNode(CAstNode.BLOCK_STMT,
-						loopHeader[0],
-						loopHeader[1],
-						contLabel,
-						Ast.makeNode(CAstNode.LOOP,
-								Ast.makeNode(CAstNode.BINARY_EXPR,
-								    CAstOperator.OP_NE,
-										Ast.makeConstant(null),
-				            Ast.makeNode(CAstNode.EACH_ELEMENT_GET, 
-			                  Ast.makeNode(CAstNode.VAR, Ast.makeConstant(tempName)),
-			                  readName(arg, null, name))),
-								body),
-						breakLabel));
-		arg.cfg().map(node, loop);
-		return loop;
-	}
+	      arg.addNameDecl(
+	          Ast.makeNode(CAstNode.DECL_STMT, Ast.makeConstant(new CAstSymbolImpl(name, JSAstTranslator.Any)),
+	              readName(arg, null, "$$undefined")));
+	    }
+
+	    // body
+	    AstNode breakStmt = makeEmptyLabelStmt("breakLabel");
+	    CAstNode breakLabel = visit(breakStmt, arg);
+	    AstNode contStmt = makeEmptyLabelStmt("contLabel");
+	    CAstNode contLabel = visit(contStmt, arg);
+	    // TODO: Figure out why this is needed to make the correlation extraction tests pass
+	    // TODO: remove this silly label
+	    AstNode garbageStmt = makeEmptyLabelStmt("garbageLabel");
+	    CAstNode garbageLabel = visit(garbageStmt, arg);
+	    WalkContext loopContext = makeLoopContext(node, arg, breakStmt, contStmt);
+	    CAstNode body = Ast.makeNode(CAstNode.BLOCK_STMT,
+	        //initNode,
+	        visit(node.getBody(), loopContext),
+	        garbageLabel);
+
+	    loop = Ast.makeNode(CAstNode.LOCAL_SCOPE,
+	        Ast.makeNode(CAstNode.BLOCK_STMT,
+	            loopHeader[0],
+	            loopHeader[1],
+	            contLabel,
+	            Ast.makeNode(CAstNode.LOOP,
+	                Ast.makeNode(CAstNode.BINARY_EXPR,
+	                    CAstOperator.OP_NE,
+	                    Ast.makeConstant(null),
+	                    Ast.makeNode(CAstNode.BLOCK_EXPR,
+	                        Ast.makeNode(CAstNode.ASSIGN, 
+	                            Ast.makeNode(CAstNode.VAR, Ast.makeConstant(name)),
+	                            get = Ast.makeNode(CAstNode.EACH_ELEMENT_GET,   
+	                                Ast.makeNode(CAstNode.VAR, Ast.makeConstant(tempName)),
+	                                readName(arg, null, name))),
+	                        readName(arg, null, name))),
+	                body),
+	            breakLabel));
+	    arg.cfg().map(node, loop);
+	  } else {
+	    CAstNode object = visit(node.getIteratedObject(), arg);
+	    String tempName = "for in loop temp";   
+	    CAstNode[] loopHeader = new CAstNode[]{
+	        Ast.makeNode(CAstNode.DECL_STMT, Ast.makeConstant(new CAstSymbolImpl(tempName, JSAstTranslator.Any)), readName(arg, null, "$$undefined")),
+	        Ast.makeNode(CAstNode.ASSIGN, Ast.makeNode(CAstNode.VAR, Ast.makeConstant(tempName)), object)
+	    };
+
+	    CAstNode initNode;
+	    String name;
+	    AstNode var = node.getIterator();
+	    assert var instanceof Name || var instanceof VariableDeclaration || var instanceof LetNode : var.getClass()  + " " + var;
+	    if (var instanceof Name) {
+	      name = ((Name)var).getString();
+	      initNode = 
+	          Ast.makeNode(CAstNode.ASSIGN, 
+	              Ast.makeNode(CAstNode.VAR, Ast.makeConstant(name)),
+	              get = Ast.makeNode(CAstNode.EACH_ELEMENT_GET, 
+	                  Ast.makeNode(CAstNode.VAR, Ast.makeConstant(tempName)),
+	                  readName(arg, null, name)));
+
+	    } else {
+	      VariableDeclaration decl;
+	      if (var instanceof LetNode) {
+	        decl = ((LetNode)var).getVariables();
+	      } else {
+	        decl = (VariableDeclaration)var;
+	      }
+	      assert decl.getVariables().size() == 1;
+	      VariableInitializer init = decl.getVariables().iterator().next();
+
+	      name = init.getTarget().getString();
+
+	      arg.addNameDecl(
+	          Ast.makeNode(CAstNode.DECL_STMT, Ast.makeConstant(new CAstSymbolImpl(name, JSAstTranslator.Any)),
+	              readName(arg, null, "$$undefined")));
+
+	      initNode = 
+	          Ast.makeNode(CAstNode.ASSIGN, 
+	              Ast.makeNode(CAstNode.VAR, Ast.makeConstant(name)),
+	              get = Ast.makeNode(CAstNode.EACH_ELEMENT_GET, 
+	                  Ast.makeNode(CAstNode.VAR, Ast.makeConstant(tempName)),
+	                  readName(arg, null, name)));
+
+	    }
+
+      arg.cfg().map(get, get);
+	    CAstNode ctch = arg.getCatchTarget();
+	    if (ctch != null) {
+	      arg.cfg().add(get, ctch, JavaScriptTypes.ReferenceError);
+	    } else {
+	      arg.cfg().add(get, CAstControlFlowMap.EXCEPTION_TO_EXIT, JavaScriptTypes.ReferenceError);       
+	    }
+
+	    // body
+	    AstNode breakStmt = makeEmptyLabelStmt("breakLabel");
+	    CAstNode breakLabel = visit(breakStmt, arg);
+	    AstNode contStmt = makeEmptyLabelStmt("contLabel");
+	    CAstNode contLabel = visit(contStmt, arg);
+	    // TODO: Figure out why this is needed to make the correlation extraction tests pass
+	    // TODO: remove this silly label
+	    AstNode garbageStmt = makeEmptyLabelStmt("garbageLabel");
+	    CAstNode garbageLabel = visit(garbageStmt, arg);
+	    WalkContext loopContext = makeLoopContext(node, arg, breakStmt, contStmt);
+	    CAstNode body = Ast.makeNode(CAstNode.BLOCK_STMT,
+	        initNode,
+	        visit(node.getBody(), loopContext),
+	        garbageLabel);
+
+	    loop = Ast.makeNode(CAstNode.LOCAL_SCOPE,
+	        Ast.makeNode(CAstNode.BLOCK_STMT,
+	            loopHeader[0],
+	            loopHeader[1],
+	            contLabel,
+	            Ast.makeNode(CAstNode.LOOP,
+	                Ast.makeNode(CAstNode.BINARY_EXPR,
+	                    CAstOperator.OP_NE,
+	                    Ast.makeConstant(null),
+	                    get = Ast.makeNode(CAstNode.EACH_ELEMENT_GET, 
+	                        Ast.makeNode(CAstNode.VAR, Ast.makeConstant(tempName)),
+	                        readName(arg, null, name))),
+	                body),
+	            breakLabel));
+	    arg.cfg().map(node, loop);
+	  }
+    
+    arg.cfg().map(get, get);
+    CAstNode ctch = arg.getCatchTarget();
+    if (ctch != null) {
+      arg.cfg().add(get, ctch, JavaScriptTypes.ReferenceError);
+    } else {
+      arg.cfg().add(get, CAstControlFlowMap.EXCEPTION_TO_EXIT, JavaScriptTypes.ReferenceError);       
+    }
+
+	  return loop;
+  }
 
 	@Override
 	public CAstNode visitForLoop(ForLoop node, WalkContext arg) {
@@ -991,23 +1115,23 @@ public class RhinoToAstTranslator {
 	@Override
 	public CAstNode visitFunctionNode(FunctionNode fn, WalkContext context) {
 		WalkContext child = new FunctionContext(context, fn);
-	    List<CAstNode> body = new ArrayList<CAstNode>();
+	    List<CAstNode> body = new ArrayList<>();
 	    body.add(visit(fn.getBody(), child));
 
 	    String name;
 	    Name x = fn.getFunctionName();
-	    if (x == null || x.getIdentifier() == null || "".equals(x.getIdentifier())) {
-	    	name = scriptName + "@" + fn.getAbsolutePosition();
+	    if (x == null || x.getIdentifier() == null || x.getIdentifier().isEmpty()) {
+	    	name = scriptName + '@' + fn.getAbsolutePosition();
 	    	String label = getParentName(fn);
 	    	if (label != null) {
-	    	  name = name + ":" + label;
+	    	  name = name + ':' + label;
 	    	}
 	    } else {
 	    	name = fn.getFunctionName().getIdentifier();
 	    }
 
 	    if(DEBUG)
-	      System.err.println(name + "\n" + body);
+	      System.err.println(name + '\n' + body);
 
 		CAstEntity fne = walkEntity(fn, body, name, child);
 
@@ -1113,8 +1237,9 @@ public class RhinoToAstTranslator {
     case Token.DEBUGGER: {
       return Ast.makeConstant(null);
     }
+    default:
+      throw new RuntimeException("unexpected keyword literal " + node + " (" + node.getType() + ')');
 		}
-		throw new RuntimeException("unexpected keyword literal " + node + " (" + node.getType() +")");
 	}
 
 	@Override
@@ -1234,7 +1359,7 @@ public class RhinoToAstTranslator {
 
 	@Override
 	public CAstNode visitScope(Scope node, WalkContext arg) {
-		List<CAstNode> nodes = new ArrayList<CAstNode>();
+		List<CAstNode> nodes = new ArrayList<>();
 		for(Node child : node) {
 			nodes.add(visit((AstNode)child, arg));
 		}
@@ -1243,7 +1368,7 @@ public class RhinoToAstTranslator {
 		} else {
 			return 
 				Ast.makeNode(CAstNode.LOCAL_SCOPE,
-					Ast.makeNode(CAstNode.BLOCK_STMT, nodes.toArray(new CAstNode[ nodes.size() ])));
+					Ast.makeNode(CAstNode.BLOCK_STMT, nodes.toArray(new CAstNode[0])));
 		}
 	}
 
@@ -1623,8 +1748,8 @@ public class RhinoToAstTranslator {
       if (finallyNode != null) {
         int i = 0;
         CAstNode[] finallyAsts = new CAstNode[finallyList.size()];
-        for (Iterator<Node> fns = finallyList.iterator(); fns.hasNext();) {
-          finallyAsts[i++] = walkNodes(fns.next(), context);
+        for (Node fn : finallyList) {
+          finallyAsts[i++] = walkNodes(fn, context);
         }
         finallyBlock = Ast.makeNode(CAstNode.BLOCK_STMT, finallyAsts);
       }
@@ -1634,8 +1759,8 @@ public class RhinoToAstTranslator {
         int i = 0;
         WalkContext catchChild = new CatchBlockContext(context);
         CAstNode[] catchAsts = new CAstNode[catchList.size()];
-        for (Iterator<Node> cns = catchList.iterator(); cns.hasNext();) {
-          catchAsts[i++] = walkNodes(cns.next(), catchChild);
+        for (Node cn : catchList.iterator()) {
+          catchAsts[i++] = walkNodes(cn, catchChild);
         }
         CAstNode catchBlock = Ast.makeNode(CAstNode.CATCH, Ast.makeConstant(catchChild.getCatchVar()),
             Ast.makeNode(CAstNode.BLOCK_STMT, catchAsts));
@@ -1644,8 +1769,8 @@ public class RhinoToAstTranslator {
         i = 0;
         WalkContext tryChild = new TryBlockContext(context, catchBlock);
         CAstNode[] tryAsts = new CAstNode[tryList.size()];
-        for (Iterator<Node> tns = tryList.iterator(); tns.hasNext();) {
-          tryAsts[i++] = walkNodes(tns.next(), tryChild);
+        for (Node tn : tryList) {
+          tryAsts[i++] = walkNodes(tn, tryChild);
         }
         CAstNode tryBlock = Ast.makeNode(CAstNode.BLOCK_STMT, tryAsts);
 
@@ -1659,8 +1784,8 @@ public class RhinoToAstTranslator {
       } else {
         int i = 0;
         CAstNode[] tryAsts = new CAstNode[tryList.size()];
-        for (Iterator<Node> tns = tryList.iterator(); tns.hasNext();) {
-          tryAsts[i++] = walkNodes(tns.next(), context);
+        for (Node tn : tryList) {
+          tryAsts[i++] = walkNodes(tn, context);
         }
         CAstNode tryBlock = Ast.makeNode(CAstNode.BLOCK_STMT, tryAsts);
 
@@ -2363,8 +2488,8 @@ private CAstNode[] walkChildren(final Node n, WalkContext context) {
   /**
    * parse the JavaScript code using Rhino, and then translate the resulting AST
    * to CAst
-   * @throws com.ibm.wala.cast.ir.translator.TranslatorToCAst.Error 
    */
+  @Override
   public CAstEntity translateToCAst() throws Error, IOException, com.ibm.wala.cast.ir.translator.TranslatorToCAst.Error {
     class CAstErrorReporter implements ErrorReporter {
       private Set<Warning> w = HashSetFactory.make();
@@ -2374,7 +2499,7 @@ private CAstNode[] walkChildren(final Node n, WalkContext context) {
         w.add(new Warning(Warning.SEVERE) {
           @Override
           public String getMsg() {
-            return arg0 + ": " + arg1 + "@" + arg2 + ": " + arg3;
+            return arg0 + ": " + arg1 + '@' + arg2 + ": " + arg3;
           }
         });
       }
@@ -2389,7 +2514,7 @@ private CAstNode[] walkChildren(final Node n, WalkContext context) {
       public void warning(String arg0, String arg1, int arg2, String arg3, int arg4) {
         // ignore warnings
       } 
-    };
+    }
     
     CAstErrorReporter reporter = new CAstErrorReporter();
     CompilerEnvirons compilerEnv = new CompilerEnvirons();
@@ -2411,7 +2536,7 @@ private CAstNode[] walkChildren(final Node n, WalkContext context) {
     
     final FunctionContext child = new ScriptContext(new RootContext(), top, top.getSourceName());
     TranslatingVisitor tv = new TranslatingVisitor();
-    List<CAstNode> body = new ArrayList<CAstNode>();
+    List<CAstNode> body = new ArrayList<>();
     for(Node bn : top) {
     	body.add(tv.visit((AstNode)bn, child));
     }
@@ -2423,20 +2548,32 @@ private CAstNode[] walkChildren(final Node n, WalkContext context) {
 
   private final String scriptName;
 
-  private final SourceModule sourceModule;
+  private final ModuleEntry sourceModule;
 
   final private Reader sourceReader;
 
   private int tempVarNum = 0;
 
   private final DoLoopTranslator doLoopTranslator;
+
+  private final boolean useNewForIn;
+
+  public RhinoToAstTranslator(CAst Ast, ModuleEntry m, String scriptName, boolean replicateForDoLoops) {
+    this(Ast, m, scriptName, replicateForDoLoops, false);
+  }
   
-  public RhinoToAstTranslator(CAst Ast, SourceModule M, String scriptName, boolean replicateForDoLoops) {
+  public RhinoToAstTranslator(CAst Ast, ModuleEntry m, String scriptName, boolean replicateForDoLoops, boolean useNewForIn) {
     this.Ast = Ast;
     this.scriptName = scriptName;
-    this.sourceModule = M;
-    this.sourceReader = sourceModule.getInputReader();
+    this.sourceModule = m;
+    this.sourceReader = new InputStreamReader(sourceModule.getInputStream());
     this.doLoopTranslator = new DoLoopTranslator(replicateForDoLoops, Ast);
+    this.useNewForIn = useNewForIn;
+  }
+
+  @Override
+  public <C extends RewriteContext<K>, K extends CopyKey<K>> void addRewriter(CAstRewriterFactory<C, K> factory, boolean prepend) {
+    assert false;
   }
 
 }
