@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,10 +7,9 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.js.test;
 
-import java.io.IOException;
 import java.net.URL;
 
 import org.junit.Before;
@@ -18,8 +17,7 @@ import org.junit.Test;
 
 import com.ibm.wala.cast.ipa.callgraph.CAstCallGraphUtil;
 import com.ibm.wala.cast.js.html.IHtmlParser;
-import com.ibm.wala.cast.js.html.IHtmlParserFactory;
-import com.ibm.wala.cast.js.html.WebUtil;
+import com.ibm.wala.cast.js.html.JSSourceExtractor;
 import com.ibm.wala.cast.js.ipa.callgraph.JSCFABuilder;
 import com.ibm.wala.ipa.callgraph.CallGraph;
 import com.ibm.wala.util.CancelException;
@@ -36,12 +34,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
   @Override
   @Before
   public void setUp() {
-    WebUtil.setFactory(new IHtmlParserFactory() {
-      @Override
-      public IHtmlParser getParser() {
-        return getParser();
-      }
-    });
+    JSSourceExtractor.USE_TEMP_NAME = false;
   }
   
   private static final Object[][] assertionsForPage1 = new Object[][] {
@@ -56,7 +49,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     }
   };
 
-  @Test public void testPage1() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testPage1() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/page1.html");
     CallGraph CG = JSCallGraphBuilderUtil.makeHTMLCG(url);
     verifyGraphAssertions(CG, assertionsForPage1);
@@ -67,7 +60,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     new Object[] { "page2.html", new String[] { "page2.html/__WINDOW_MAIN__" } }
   };
   
-  @Test public void testPage2() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testPage2() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/page2.html");
     CallGraph CG = JSCallGraphBuilderUtil.makeHTMLCG(url);
     verifyGraphAssertions(CG, assertionsForPage2);
@@ -84,7 +77,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     }
   };
 
-  @Test public void testCrawlPage11() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testCrawlPage11() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/crawl/page11.html");
     CallGraph CG = JSCallGraphBuilderUtil.makeHTMLCG(url);
     verifyGraphAssertions(CG, assertionsForPage11);
@@ -101,7 +94,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     }
   };
   
-  @Test public void testCrawlPage11b() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testCrawlPage11b() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/crawl/page11b.html");
     CallGraph CG = JSCallGraphBuilderUtil.makeHTMLCG(url);
     verifyGraphAssertions(CG, assertionsForPage11b);
@@ -133,7 +126,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     },
   };
 
-  @Test public void testCrawlPage12() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testCrawlPage12() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/crawl/page12.html");
     CallGraph CG = JSCallGraphBuilderUtil.makeHTMLCG(url);
     verifyGraphAssertions(CG, assertionsForPage12);
@@ -166,7 +159,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     }
   };
 
-  @Test public void testCrawlPage13() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testCrawlPage13() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/crawl/page13.html");
     CallGraph CG = JSCallGraphBuilderUtil.makeHTMLCG(url);    
     verifyGraphAssertions(CG, assertionsForPage13);
@@ -184,7 +177,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     }
   };
 
-  @Test public void testCrawlPage15() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testCrawlPage15() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/crawl/page15.html");
     CallGraph CG = JSCallGraphBuilderUtil.makeHTMLCG(url);
     verifyGraphAssertions(CG, assertionsForPage15);
@@ -202,7 +195,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     }
   };
 
-  @Test public void testCrawlPage16() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testCrawlPage16() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/crawl/page16.html");
     CallGraph CG = JSCallGraphBuilderUtil.makeHTMLCG(url);
     verifyGraphAssertions(CG, assertionsForPage16);
@@ -225,7 +218,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     }
   };
     
-  @Test public void testCrawlPage17() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testCrawlPage17() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/crawl/page17.html");
     CallGraph CG = JSCallGraphBuilderUtil.makeHTMLCG(url);
     verifyGraphAssertions(CG, assertionsForPage17);
@@ -238,19 +231,19 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     new Object[] { "apollo-example.html/__WINDOW_MAIN__/signon", new String[] { "preamble.js/DOMWindow/window_open" } }
   };
   
-  @Test public void testApolloExample() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testApolloExample() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/apollo-example.html");
     CallGraph CG = JSCallGraphBuilderUtil.makeHTMLCG(url);
     verifyGraphAssertions(CG, assertionsForApolloExample);
   }
 
-  @Test public void testNojs() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testNojs() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/nojs.html");
     // all we need is for it to finish building CG successfully.
     JSCallGraphBuilderUtil.makeHTMLCG(url);
   }
 
-  @Test public void testPage4() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testPage4() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/page4.html");
     JSCallGraphBuilderUtil.makeHTMLCG(url);
   }
@@ -265,16 +258,16 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     new Object[]{ "suffix:forall_base", "pages/collection.js", 4, 4 }
   };
     
-  @Test public void testList() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testList() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/list.html");
     JSCFABuilder builder = JSCallGraphBuilderUtil.makeHTMLCGBuilder(url);
     CallGraph CG = builder.makeCallGraph(builder.getOptions());
 //    JSCallGraphBuilderUtil.AVOID_DUMP = false;
-    CAstCallGraphUtil.dumpCG(builder.getPointerAnalysis(), CG);
+    CAstCallGraphUtil.dumpCG(builder.getCFAContextInterpreter(), builder.getPointerAnalysis(), CG);
     verifySourceAssertions(CG, sourceAssertionsForList);
   }
 
-  @Test public void testIframeTest2() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testIframeTest2() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/iframeTest2.html");
     JSCallGraphBuilderUtil.makeHTMLCG(url);
   }
@@ -288,11 +281,11 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
 
   };
 
-  @Test public void testWindowx() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testWindowx() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/windowx.html");
     JSCFABuilder builder = JSCallGraphBuilderUtil.makeHTMLCGBuilder(url);
     CallGraph CG = builder.makeCallGraph(builder.getOptions());
-    CAstCallGraphUtil.dumpCG(builder.getPointerAnalysis(), CG);
+    CAstCallGraphUtil.dumpCG(builder.getCFAContextInterpreter(), builder.getPointerAnalysis(), CG);
     verifyGraphAssertions(CG, assertionsForWindowx);
   }
 
@@ -302,11 +295,11 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     new Object[] { "windowonload.html/__WINDOW_MAIN__", new String[] { "windowonload.html/__WINDOW_MAIN__/onload_handler" } },
   };
 
-  @Test public void testWindowOnload() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testWindowOnload() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/windowonload.html");
     JSCFABuilder builder = JSCallGraphBuilderUtil.makeHTMLCGBuilder(url);
     CallGraph CG = builder.makeCallGraph(builder.getOptions());
-    CAstCallGraphUtil.dumpCG(builder.getPointerAnalysis(), CG);
+    CAstCallGraphUtil.dumpCG(builder.getCFAContextInterpreter(), builder.getPointerAnalysis(), CG);
     verifyGraphAssertions(CG, assertionsForWindowOnload);
   }
 
@@ -318,7 +311,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     new Object[] { "skeleton.html/__WINDOW_MAIN__/bad_guy", new String[] { "skeleton.html/__WINDOW_MAIN__/dollar" } },
   };
 
-  @Test public void testSkeleton() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testSkeleton() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/skeleton.html");
     CallGraph CG = JSCallGraphBuilderUtil.makeHTMLCG(url);
     verifyGraphAssertions(CG, assertionsForSkeleton);
@@ -334,7 +327,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
     new Object[] { "skeleton2.html/__WINDOW_MAIN__/bad_guy", new String[] { "skeleton2.html/__WINDOW_MAIN__/dollar" } },
   };
 
-  @Test public void testSkeleton2() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testSkeleton2() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/skeleton2.html");
     CallGraph CG = JSCallGraphBuilderUtil.makeHTMLCG(url);
     System.err.println(CG);
@@ -342,7 +335,7 @@ public abstract class TestSimplePageCallGraphShape extends TestJSCallGraphShape
   }
 
   /*
-  @Test public void testJQuery() throws IOException, IllegalArgumentException, CancelException, WalaException {
+  @Test public void testJQuery() throws IllegalArgumentException, CancelException, WalaException {
     URL url = getClass().getClassLoader().getResource("pages/jquery.html");
     CallGraph CG = Util.makeHTMLCG(url);
   }
