@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.cast.js.callgraph.fieldbased.flowgraph;
 
 import java.util.Collection;
@@ -16,7 +16,9 @@ import java.util.Map;
 import java.util.Set;
 
 import com.ibm.wala.analysis.pointers.HeapGraph;
+import com.ibm.wala.cast.ipa.callgraph.AstHeapModel;
 import com.ibm.wala.cast.ir.ssa.AstGlobalWrite;
+import com.ibm.wala.cast.ir.ssa.AstPropertyWrite;
 import com.ibm.wala.cast.js.callgraph.fieldbased.flowgraph.vertices.AbstractVertexVisitor;
 import com.ibm.wala.cast.js.callgraph.fieldbased.flowgraph.vertices.CreationSiteVertex;
 import com.ibm.wala.cast.js.callgraph.fieldbased.flowgraph.vertices.FuncVertex;
@@ -38,9 +40,9 @@ import com.ibm.wala.classLoader.IField;
 import com.ibm.wala.classLoader.IMethod;
 import com.ibm.wala.classLoader.NewSiteReference;
 import com.ibm.wala.classLoader.ProgramCounter;
-import com.ibm.wala.ipa.callgraph.AnalysisCache;
 import com.ibm.wala.ipa.callgraph.CGNode;
 import com.ibm.wala.ipa.callgraph.CallGraph;
+import com.ibm.wala.ipa.callgraph.IAnalysisCacheView;
 import com.ibm.wala.ipa.callgraph.impl.Everywhere;
 import com.ibm.wala.ipa.callgraph.propagation.FilteredPointerKey;
 import com.ibm.wala.ipa.callgraph.propagation.FilteredPointerKey.TypeFilter;
@@ -56,9 +58,10 @@ import com.ibm.wala.ssa.SSANewInstruction;
 import com.ibm.wala.types.TypeReference;
 import com.ibm.wala.util.CancelException;
 import com.ibm.wala.util.MonitorUtil.IProgressMonitor;
-import com.ibm.wala.util.Predicate;
+import com.ibm.wala.util.collections.CompoundIterator;
 import com.ibm.wala.util.collections.HashMapFactory;
 import com.ibm.wala.util.collections.HashSetFactory;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.collections.Pair;
 import com.ibm.wala.util.graph.Graph;
 import com.ibm.wala.util.graph.GraphReachability;
@@ -90,7 +93,7 @@ public class FlowGraph implements Iterable<Vertex> {
 	private GraphReachability<Vertex,FuncVertex> optimistic_closure;
 	
 	public FlowGraph() {
-		this.graph = new SlowSparseNumberedGraph<Vertex>(1);
+		this.graph = new SlowSparseNumberedGraph<>(1);
 		this.factory = new VertexFactory();
 	}
 	
@@ -102,34 +105,25 @@ public class FlowGraph implements Iterable<Vertex> {
 		optimistic_closure = computeClosure(graph, monitor, FuncVertex.class);
 	}
 	
-	private <T> GraphReachability<Vertex, T> computeClosure(NumberedGraph<Vertex> graph, IProgressMonitor monitor, final Class<?> type) throws CancelException {
+	private static <T> GraphReachability<Vertex, T> computeClosure(NumberedGraph<Vertex> graph, IProgressMonitor monitor, final Class<?> type) throws CancelException {
 		// prune flowgraph by taking out 'unknown' vertex
-		Graph<Vertex> pruned_flowgraph = GraphSlicer.prune(graph, new Predicate<Vertex>() {
-			@Override
-			public boolean test(Vertex t) {
-				return t.accept(new AbstractVertexVisitor<Boolean>() {
-					@Override
-					public Boolean visitVertex(Vertex vertex) {
-						return true;
-					}
-					
-					@Override
-					public Boolean visitUnknownVertex(UnknownVertex unknownVertex) {
-						return false;
-					}
-				});
-			}
-		});
+		Graph<Vertex> pruned_flowgraph = GraphSlicer.prune(graph, t -> t.accept(new AbstractVertexVisitor<Boolean>() {
+    	@Override
+    	public Boolean visitVertex() {
+    		return true;
+    	}
+    	
+    	@Override
+    	public Boolean visitUnknownVertex(UnknownVertex unknownVertex) {
+    		return false;
+    	}
+    }));
 		
 		// compute transitive closure
 		GraphReachability<Vertex, T> optimistic_closure = 
-		    new GraphReachability<Vertex,T>(
-		      new InvertedGraph<Vertex>(pruned_flowgraph),
-		      new Predicate<Vertex>() {
-		        @Override public boolean test(Vertex o) {
-		          return type.isInstance(o);
-		        } 
-		      }
+		    new GraphReachability<>(
+		      new InvertedGraph<>(pruned_flowgraph),
+		      type::isInstance
 		    );
 		
 		optimistic_closure.solve(monitor);
@@ -142,7 +136,7 @@ public class FlowGraph implements Iterable<Vertex> {
 	}
 	
 	/**
-	 * Adds an edge from vertex <code>from</code> to vertex <code>to</code>, adding the vertices
+	 * Adds an edge from vertex {@code from} to vertex {@code to}, adding the vertices
 	 * to the graph if they are not in there yet.
 	 */
 	public void addEdge(Vertex from, Vertex to) {
@@ -158,7 +152,7 @@ public class FlowGraph implements Iterable<Vertex> {
 	}
 
 	/**
-	 * Computes the set of vertices that may reach <code>dest</code> along paths not containing an
+	 * Computes the set of vertices that may reach {@code dest} along paths not containing an
 	 * {@link UnknownVertex}.
 	 */
 	public OrdinalSet<FuncVertex> getReachingSet(Vertex dest, IProgressMonitor monitor) throws CancelException {
@@ -178,16 +172,16 @@ public class FlowGraph implements Iterable<Vertex> {
     return graph.iterator();
   }
   
-  public PointerAnalysis<ObjectVertex> getPointerAnalysis(final CallGraph cg, final AnalysisCache cache, final IProgressMonitor monitor) throws CancelException {
+  public PointerAnalysis<ObjectVertex> getPointerAnalysis(final CallGraph cg, final IAnalysisCacheView cache, final IProgressMonitor monitor) throws CancelException {
     return new PointerAnalysis<ObjectVertex>() {
       
       private final Map<Pair<PrototypeField,ObjectVertex>,PrototypeFieldVertex> proto = HashMapFactory.make();
       
       private GraphReachability<Vertex,ObjectVertex> pointerAnalysis = computeClosure(graph, monitor, ObjectVertex.class);
 
-      private final ExtensionGraph<Vertex> dataflow = new ExtensionGraph<Vertex>(graph);
+      private final ExtensionGraph<Vertex> dataflow = new ExtensionGraph<>(graph);
 
-      protected IR getIR(final AnalysisCache cache, FuncVertex func) {
+      protected IR getIR(final IAnalysisCacheView cache, FuncVertex func) {
         return cache.getIR(func.getConcreteType().getMethod(AstMethodReference.fnSelector));
       }
 
@@ -202,16 +196,14 @@ public class FlowGraph implements Iterable<Vertex> {
       {
         PropVertex proto = factory.makePropVertex("prototype");
         if (graph.containsNode(proto)) {
-          for(Iterator<Vertex> ps = graph.getPredNodes(proto); ps.hasNext(); ) {
-            Vertex p = ps.next();
+          for(Vertex p : Iterator2Iterable.make(graph.getPredNodes(proto))) {
             if (p instanceof VarVertex) {
               int rval = ((VarVertex) p).getValueNumber();
               FuncVertex func = ((VarVertex) p).getFunction();
               DefUse du = cache.getDefUse(getIR(cache, func));
-              for(Iterator<SSAInstruction> insts = du.getUses(rval); insts.hasNext(); ) {
-                SSAInstruction inst = insts.next();
+              for(SSAInstruction inst : Iterator2Iterable.make(du.getUses(rval))) {
                 if (inst instanceof JavaScriptPropertyWrite) {
-                  int obj = ((JavaScriptPropertyWrite) inst).getObjectRef();
+                  int obj = ((AstPropertyWrite) inst).getObjectRef();
                   VarVertex object = factory.makeVarVertex(func, obj);
                   for(ObjectVertex o : getPointsToSet(object)) {
                     PrototypeFieldVertex prototype = get(PrototypeField.prototype, o);
@@ -283,13 +275,15 @@ public class FlowGraph implements Iterable<Vertex> {
 
       @Override
       public Iterable<PointerKey> getPointerKeys() {
-        // TODO Auto-generated method stub
-        return null;
+        return () -> new CompoundIterator<>(factory.getArgVertices().iterator(),
+            new CompoundIterator<>(factory.getRetVertices().iterator(), 
+                new CompoundIterator<PointerKey>(factory.getVarVertices().iterator(),
+                    factory.getPropVertices().iterator())));
       }
-
+      
       @Override
       public HeapModel getHeapModel() {
-        return new HeapModel() {
+        return new AstHeapModel() {
           
           @Override
           public PointerKey getPointerKeyForLocal(CGNode node, int valueNumber) {
@@ -387,6 +381,30 @@ public class FlowGraph implements Iterable<Vertex> {
           public IClassHierarchy getClassHierarchy() {
             assert false;
             return null;
+          }
+
+          @Override
+          public PointerKey getPointerKeyForArrayLength(InstanceKey I) {
+            // TODO Auto-generated method stub
+            return null;
+          }
+
+          @Override
+          public Iterator<PointerKey> getPointerKeysForReflectedFieldRead(InstanceKey I, InstanceKey F) {
+            // TODO Auto-generated method stub
+            return null;
+          }
+
+          @Override
+          public Iterator<PointerKey> getPointerKeysForReflectedFieldWrite(InstanceKey I, InstanceKey F) {
+            // TODO Auto-generated method stub
+            return null;
+          }
+
+          @Override
+          public PointerKey getPointerKeyForObjectCatalog(InstanceKey I) {
+            // TODO Auto-generated method stub
+            return null;
           }        
         };
       }
@@ -400,6 +418,8 @@ public class FlowGraph implements Iterable<Vertex> {
           final PointerAnalysis<ObjectVertex> pa = this;
           class FieldBasedHeapGraph extends SlowSparseNumberedGraph<Object> implements HeapGraph<ObjectVertex> {
 
+            private static final long serialVersionUID = -3544629644808422215L;
+
             private <X> X ensureNode(X n) {
               if (!containsNode(n)) {
                 addNode(n);
@@ -432,16 +452,14 @@ public class FlowGraph implements Iterable<Vertex> {
               for(PropVertex property : factory.getPropVertices()) {
 
                 // edges from objects to properties assigned to them
-                for(Iterator<Vertex> ps = dataflow.getPredNodes(property); ps.hasNext(); ) {
-                  Vertex p = ps.next();
+                for(Vertex p : Iterator2Iterable.make(dataflow.getPredNodes(property))) {
                   if (p instanceof VarVertex) {
                     int rval = ((VarVertex) p).getValueNumber();
                     FuncVertex func = ((VarVertex) p).getFunction();
                     DefUse du = cache.getDefUse(getIR(cache, func));
-                    for(Iterator<SSAInstruction> insts = du.getUses(rval); insts.hasNext(); ) {
-                      SSAInstruction inst = insts.next();
+                    for(SSAInstruction inst : Iterator2Iterable.make(du.getUses(rval))) {
                       if (inst instanceof JavaScriptPropertyWrite) {
-                        int obj = ((JavaScriptPropertyWrite) inst).getObjectRef();
+                        int obj = ((AstPropertyWrite) inst).getObjectRef();
                         VarVertex object = factory.makeVarVertex(func, obj);
                         for(ObjectVertex o : getPointsToSet(object)) {
                           addEdge(ensureNode(o), ensureNode(propertyKey(property.getPropName(), o)));
@@ -482,8 +500,7 @@ public class FlowGraph implements Iterable<Vertex> {
               // prototype dataflow for object creations
               for(CreationSiteVertex cs : factory.creationSites()) {
                 if (cg.getNode(cs.getMethod(), Everywhere.EVERYWHERE) != null) {
-                for(Iterator<Pair<CGNode, NewSiteReference>> sites = cs.getCreationSites(cg); sites.hasNext(); ) {
-                  Pair<CGNode, NewSiteReference> site = sites.next();
+                for(Pair<CGNode, NewSiteReference> site : Iterator2Iterable.make(cs.getCreationSites(cg))) {
                   IR ir = site.fst.getIR();
                   SSAInstruction creation = ir.getInstructions()[ site.snd.getProgramCounter() ];
                   if (creation instanceof JavaScriptInvoke) {
@@ -513,11 +530,7 @@ public class FlowGraph implements Iterable<Vertex> {
 
             @Override
             public Collection<Object> getReachableInstances(Set<Object> roots) {
-              return DFS.getReachableNodes(this, roots, new Predicate<Object>() {
-                @Override public boolean test(Object o) {
-                  return o instanceof ObjectVertex;
-                } 
-              });
+              return DFS.getReachableNodes(this, roots, ObjectVertex.class::isInstance);
             }
 
             @Override
