@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2012 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,9 +7,11 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.js.callgraph.fieldbased.flowgraph.vertices;
 
+import com.ibm.wala.ipa.callgraph.propagation.PointerKey;
+
 
 /**
  * A return vertex represents the 'arguments' array of a given function.
@@ -17,7 +19,7 @@ package com.ibm.wala.cast.js.callgraph.fieldbased.flowgraph.vertices;
  * @author Julian Dolby (dolby@us.ibm.com)
  *
  */
-public class ArgVertex extends Vertex {
+public class ArgVertex extends Vertex implements PointerKey {
 	private final FuncVertex func;
 
 	ArgVertex(FuncVertex func) {
@@ -35,6 +37,6 @@ public class ArgVertex extends Vertex {
 	
 	@Override
 	public String toString() {
-	  return "Args(" + func + ")";
+	  return "Args(" + func + ')';
 	}
 }
