@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2012 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.js.callgraph.fieldbased.flowgraph.vertices;
 
 /**
@@ -37,6 +37,6 @@ public class LexicalVarVertex extends Vertex {
 	
 	@Override
 	public String toString() {
-		return "LexVar(" + definer.substring(definer.lastIndexOf('/')+1) + ", " + name + ")";
+		return "LexVar(" + definer.substring(definer.lastIndexOf('/')+1) + ", " + name + ')';
 	}
 }
