@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2012 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.js.callgraph.fieldbased.flowgraph.vertices;
 
 
@@ -17,7 +17,7 @@ package com.ibm.wala.cast.js.callgraph.fieldbased.flowgraph.vertices;
  * 
  * <p>
  * Numbering of positional parameters is 1-based, with parameter 0 being the
- * <code>this</code> value.
+ * {@code this} value.
  * </p>
  * 
  * <p>
@@ -53,6 +53,6 @@ public class ParamVertex extends Vertex {
 	
 	@Override
 	public String toString() {
-	  return "Param(" + func + ", " + index + ")";
+	  return "Param(" + func + ", " + index + ')';
 	}
 }
