@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.cast.js.html;
 
 import java.util.ArrayList;
@@ -16,7 +16,7 @@ import java.util.List;
 import com.ibm.wala.cast.tree.CAstSourcePositionMap.Position;
 
 public class CompositeFileMapping implements FileMapping {
-  private final List<FileMapping> mappings = new ArrayList<FileMapping>(2);
+  private final List<FileMapping> mappings = new ArrayList<>(2);
     
   public CompositeFileMapping(FileMapping a, FileMapping b) {
     addMapping(a);
