@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.js.ipa.callgraph;
 
 import java.io.UnsupportedEncodingException;
@@ -20,6 +20,7 @@ import com.ibm.wala.cast.ipa.callgraph.GlobalObjectKey;
 import com.ibm.wala.cast.ir.ssa.AstGlobalRead;
 import com.ibm.wala.cast.ir.ssa.AstGlobalWrite;
 import com.ibm.wala.cast.ir.ssa.AstIsDefinedInstruction;
+import com.ibm.wala.cast.ir.ssa.CAstUnaryOp;
 import com.ibm.wala.cast.ir.ssa.EachElementHasNextInstruction;
 import com.ibm.wala.cast.js.analysis.typeInference.JSTypeInference;
 import com.ibm.wala.cast.js.ipa.callgraph.JSSSAPropagationCallGraphBuilder.JSPointerAnalysisImpl.JSImplicitPointsToSetVisitor;
@@ -27,8 +28,6 @@ import com.ibm.wala.cast.js.ssa.JSInstructionVisitor;
 import com.ibm.wala.cast.js.ssa.JavaScriptCheckReference;
 import com.ibm.wala.cast.js.ssa.JavaScriptInstanceOf;
 import com.ibm.wala.cast.js.ssa.JavaScriptInvoke;
-import com.ibm.wala.cast.js.ssa.JavaScriptPropertyRead;
-import com.ibm.wala.cast.js.ssa.JavaScriptPropertyWrite;
 import com.ibm.wala.cast.js.ssa.JavaScriptTypeOfInstruction;
 import com.ibm.wala.cast.js.ssa.JavaScriptWithRegion;
 import com.ibm.wala.cast.js.ssa.PrototypeLookup;
@@ -43,10 +42,11 @@ import com.ibm.wala.classLoader.IMethod;
 import com.ibm.wala.classLoader.Language;
 import com.ibm.wala.fixpoint.AbstractOperator;
 import com.ibm.wala.fixpoint.UnaryOperator;
-import com.ibm.wala.ipa.callgraph.AnalysisCache;
 import com.ibm.wala.ipa.callgraph.AnalysisOptions;
 import com.ibm.wala.ipa.callgraph.CGNode;
 import com.ibm.wala.ipa.callgraph.CallGraph;
+import com.ibm.wala.ipa.callgraph.IAnalysisCacheView;
+import com.ibm.wala.ipa.callgraph.impl.AbstractRootMethod;
 import com.ibm.wala.ipa.callgraph.impl.ExplicitCallGraph;
 import com.ibm.wala.ipa.callgraph.propagation.AbstractFieldPointerKey;
 import com.ibm.wala.ipa.callgraph.propagation.ConcreteTypeKey;
@@ -67,6 +67,7 @@ import com.ibm.wala.shrikeBT.BinaryOpInstruction;
 import com.ibm.wala.shrikeBT.IUnaryOpInstruction;
 import com.ibm.wala.ssa.DefUse;
 import com.ibm.wala.ssa.IR;
+import com.ibm.wala.ssa.IRView;
 import com.ibm.wala.ssa.SSAAbstractBinaryInstruction;
 import com.ibm.wala.ssa.SSAAbstractInvokeInstruction;
 import com.ibm.wala.ssa.SSABinaryOpInstruction;
@@ -81,6 +82,8 @@ import com.ibm.wala.util.MonitorUtil;
 import com.ibm.wala.util.collections.HashSetFactory;
 import com.ibm.wala.util.intset.IntSet;
 import com.ibm.wala.util.intset.IntSetAction;
+import com.ibm.wala.util.intset.IntSetUtil;
+import com.ibm.wala.util.intset.MutableIntSet;
 import com.ibm.wala.util.intset.MutableMapping;
 import com.ibm.wala.util.intset.MutableSparseIntSet;
 import com.ibm.wala.util.intset.OrdinalSet;
@@ -99,10 +102,11 @@ import com.ibm.wala.util.strings.Atom;
  * {@link JSImplicitPointsToSetVisitor#visitAstGlobalRead(AstGlobalRead)}.
  * Finally, we need to represent direct flow of the global object to handle
  * receiver argument semantics (see
- * {@link org.mozilla.javascript.RhinoToAstTranslator}). To do so, we create a
+ * {@link com.ibm.wala.cast.js.translator.RhinoToAstTranslator}). To do so, we create a
  * reference to a global named {@link #GLOBAL_OBJ_VAR_NAME}, which is handled
  * specially in {@link JSConstraintVisitor#visitAstGlobalRead(AstGlobalRead)}.
  */
+@SuppressWarnings({"javadoc", "JavadocReference"})
 public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraphBuilder {
 
   public static final boolean DEBUG_LEXICAL = false;
@@ -146,9 +150,9 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
     this.scriptBaseURL = url;
   }
 
-  protected JSSSAPropagationCallGraphBuilder(IClassHierarchy cha, AnalysisOptions options, AnalysisCache cache,
+  protected JSSSAPropagationCallGraphBuilder(AbstractRootMethod abstractRootMethod, AnalysisOptions options, IAnalysisCacheView cache,
       PointerKeyFactory pointerKeyFactory) {
-    super(cha, options, cache, pointerKeyFactory);
+    super(abstractRootMethod, options, cache, pointerKeyFactory);
     globalObject = new GlobalObjectKey(cha.lookupClass(JavaScriptTypes.Root));
   }
 
@@ -213,8 +217,8 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
     return getPointerKeyForInstanceField(getGlobalObject(JavaScriptTypes.jsName), f);
   }
   @Override
-  protected ExplicitCallGraph createEmptyCallGraph(IClassHierarchy cha, AnalysisOptions options) {
-    return new JSCallGraph(cha, options, getAnalysisCache());
+  protected ExplicitCallGraph createEmptyCallGraph(IMethod fakeRootClass, AnalysisOptions options) {
+    return new JSCallGraph(fakeRootClass, options, getAnalysisCache());
   }
 
   protected TypeInference makeTypeInference(IR ir, IClassHierarchy cha) {
@@ -237,7 +241,7 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
   }
 
   @Override
-  protected void addAssignmentsForCatchPointerKey(PointerKey exceptionVar, Set catchClasses, PointerKey e) {
+  protected void addAssignmentsForCatchPointerKey(PointerKey exceptionVar, Set<IClass> catchClasses, PointerKey e) {
     system.newConstraint(exceptionVar, assignOperator, e);
   }
 
@@ -256,16 +260,6 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
       bingo = true;
     }
 
-    @Override
-    public void visitJavaScriptPropertyRead(JavaScriptPropertyRead instruction) {
-      bingo = true;
-    }
-
-    @Override
-    public void visitJavaScriptPropertyWrite(JavaScriptPropertyWrite instruction) {
-      bingo = true;
-    }
-
     @Override
     public void visitTypeOf(JavaScriptTypeOfInstruction inst) {
       bingo = true;
@@ -301,7 +295,7 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
   protected InterestingVisitor makeInterestingVisitor(CGNode node, int vn) {
     return new JSInterestingVisitor(vn);
   }
-
+  
   // ///////////////////////////////////////////////////////////////////////////
   //
   // specialized pointer analysis
@@ -332,16 +326,6 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
 
       }
 
-      @Override
-      public void visitJavaScriptPropertyRead(JavaScriptPropertyRead instruction) {
-
-      }
-
-      @Override
-      public void visitJavaScriptPropertyWrite(JavaScriptPropertyWrite instruction) {
-
-      }
-
       @Override
       public void visitJavaScriptInstanceOf(JavaScriptInstanceOf instruction) {
 
@@ -368,13 +352,13 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
         InstanceKey globalObj = ((AstSSAPropagationCallGraphBuilder) jsAnalysis.builder).getGlobalObject(JavaScriptTypes.jsName);
         PointerKey fkey = analysis.getHeapModel().getPointerKeyForInstanceField(globalObj, f);
         if (fkey != null) {
-          OrdinalSet pointees = analysis.getPointsToSet(fkey);
+          OrdinalSet<InstanceKey> pointees = analysis.getPointsToSet(fkey);
           IntSet set = pointees.getBackingSet();
           if (set != null) {
             S.addAll(set);
           }
         }
-        pointsToSet = new OrdinalSet<InstanceKey>(S, analysis.getInstanceKeyMapping());
+        pointsToSet = new OrdinalSet<>(S, analysis.getInstanceKeyMapping());
       }
 
       @Override
@@ -385,13 +369,13 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
       public void visitPrototypeLookup(PrototypeLookup instruction) {
       }
 
-    };
+    }
 
     @Override
     protected ImplicitPointsToSetVisitor makeImplicitPointsToVisitor(LocalPointerKey lpk) {
       return new JSImplicitPointsToSetVisitor(this, lpk);
     }
-  };
+  }
 
   @Override
   protected PropagationSystem makeSystem(AnalysisOptions options) {
@@ -444,6 +428,8 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
     public void visitUnaryOp(SSAUnaryOpInstruction inst) {
       if (inst.getOpcode() == IUnaryOpInstruction.Operator.NEG) {
         addLvalTypeKeyConstraint(inst, JavaScriptTypes.Boolean);
+      } else if (inst.getOpcode() == CAstUnaryOp.MINUS) {
+        addLvalTypeKeyConstraint(inst, JavaScriptTypes.Number);        
       }
     }
 
@@ -521,8 +507,8 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
       if (contentsAreInvariant(symbolTable, du, rval)) {
         system.recordImplicitPointsToSet(rvalKey);
         InstanceKey[] ik = getInvariantContents(rval);
-        for (int i = 0; i < ik.length; i++) {
-          system.newConstraint(p, ik[i]);
+        for (InstanceKey element : ik) {
+          system.newConstraint(p, element);
         }
       } else {
         system.newConstraint(p, assignOperator, rvalKey);
@@ -535,41 +521,6 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
       handleBinaryOp(instruction, node, symbolTable, du);
     }
 
-    @Override
-    public void visitJavaScriptPropertyRead(JavaScriptPropertyRead instruction) {
-      if (AstSSAPropagationCallGraphBuilder.DEBUG_PROPERTIES) {
-        Position instructionPosition = getInstructionPosition(instruction);
-        if (instructionPosition != null) {
-          System.err.println("processing read instruction " + instruction + ", position " + instructionPosition);
-        }
-      }
-      newFieldRead(node, instruction.getUse(0), instruction.getUse(1), instruction.getDef(0));
-    }
-
-    private Position getInstructionPosition(SSAInstruction instruction) {
-      IMethod method = node.getMethod();
-      if (method instanceof AstMethod) {
-        SSAInstruction[] instructions = ir.getInstructions();
-        for (int ind = basicBlock.getFirstInstructionIndex(); ind <= basicBlock.getLastInstructionIndex(); ind++) {
-          if (instruction.equals(instructions[ind])) {
-            return ((AstMethod) method).getSourcePosition(ind);
-          }
-        }
-      }
-      return null;
-    }
-
-    @Override
-    public void visitJavaScriptPropertyWrite(JavaScriptPropertyWrite instruction) {
-      if (AstSSAPropagationCallGraphBuilder.DEBUG_PROPERTIES) {
-        Position instructionPosition = getInstructionPosition(instruction);
-        if (instructionPosition != null) {
-          System.err.println("processing write instruction " + instruction + ", position " + instructionPosition);
-        }
-      }
-      newFieldWrite(node, instruction.getUse(0), instruction.getUse(1), instruction.getUse(2));
-    }
-
     @Override
     public void visitJavaScriptInvoke(JavaScriptInvoke instruction) {
       if (instruction.getDeclaredTarget().equals(JavaScriptMethods.dispatchReference)) {
@@ -594,27 +545,27 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
               private AbstractFieldPointerKey getProperty() { return fieldKey; }
               private CGNode getNode() { return node; }
               
+              private MutableIntSet previous = IntSetUtil.make();
+              
               @Override
               public byte evaluate(PointsToSetVariable lhs, PointsToSetVariable ptrs) {
                 if (ptrs.getValue() != null) {
-                  ptrs.getValue().foreach(new IntSetAction() {
-                    @Override
-                    public void act(int x) {
-                      final InstanceKey functionObj = system.getInstanceKey(x);
-                      visitInvokeInternal(instruction, new DefaultInvariantComputer() {
-                        @Override
-                        public InstanceKey[][] computeInvariantParameters(SSAAbstractInvokeInstruction call) {
-                          InstanceKey[][] x = super.computeInvariantParameters(call);
-                          if (x == null) {
-                            x = new InstanceKey[call.getNumberOfUses()][];
-                          }
-                          x[0] = new InstanceKey[]{ functionObj };
-                          x[1] = new InstanceKey[]{ receiverType };
-                          return x;
+                  ptrs.getValue().foreachExcluding(previous, x -> {
+                    final InstanceKey functionObj = system.getInstanceKey(x);
+                    visitInvokeInternal(instruction, new DefaultInvariantComputer() {
+                      @Override
+                      public InstanceKey[][] computeInvariantParameters(SSAAbstractInvokeInstruction call) {
+                        InstanceKey[][] x = super.computeInvariantParameters(call);
+                        if (x == null) {
+                          x = new InstanceKey[call.getNumberOfUses()][];
                         }
-                      });
-                    } 
+                        x[0] = new InstanceKey[]{ functionObj };
+                        x[1] = new InstanceKey[]{ receiverType };
+                        return x;
+                      }
+                    });
                   });
+                  previous.addAll(ptrs.getValue());
                 }
                 return NOT_CHANGED;
               }
@@ -634,13 +585,13 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
               public String toString() {
                 return "sub-dispatch for " + instruction + ": " + receiverType + ", " + fieldKey;
               } 
-            };
+            }
           
             system.newSideEffect(new FieldValueDispatch(), fieldKey);
         }
         @Override
         public void dump(AbstractFieldPointerKey fieldKey, boolean constObj, boolean constProp) {
-          System.err.println("dispatch to " + receiverType + "." + fieldKey + " for " + instruction);
+          System.err.println("dispatch to " + receiverType + '.' + fieldKey + " for " + instruction);
         }
       };
 
@@ -663,11 +614,13 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
       if (contentsAreInvariant(symbolTable, du, receiverVn)) {
           system.recordImplicitPointsToSet(receiverKey);
           InstanceKey[] ik = getInvariantContents(receiverVn);
-          for (int i = 0; i < ik.length; i++) {
-            handleJavascriptDispatch(instruction, ik[i]);
+          for (InstanceKey element : ik) {
+            handleJavascriptDispatch(instruction, element);
           }
       } else {
         class ReceiverForDispatchOp extends UnaryOperator<PointsToSetVariable> {
+          MutableIntSet previous = IntSetUtil.make();
+          
           private JavaScriptInvoke getInstruction() {
             return instruction;
           }
@@ -675,18 +628,16 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
           @Override
           public byte evaluate(PointsToSetVariable lhs, PointsToSetVariable rhs) {
             if (rhs.getValue() != null) {
-              rhs.getValue().foreach(new IntSetAction() {
-                @Override
-                public void act(int x) {
-                  try {
-                    MonitorUtil.throwExceptionIfCanceled(getBuilder().monitor);
-                  } catch (CancelException e) {
-                    throw new CancelRuntimeException(e);
-                  }
-                  InstanceKey ik = system.getInstanceKey(x);
-                  handleJavascriptDispatch(instruction, ik);
+              rhs.getValue().foreachExcluding(previous, x -> {
+                try {
+                  MonitorUtil.throwExceptionIfCanceled(getBuilder().monitor);
+                } catch (CancelException e) {
+                  throw new CancelRuntimeException(e);
                 }
+                InstanceKey ik = system.getInstanceKey(x);
+                handleJavascriptDispatch(instruction, ik);
               });
+              previous.addAll(rhs.getValue());
             }
             return NOT_CHANGED;
           }
@@ -767,14 +718,9 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
               return new InstanceKey[0];
             } else {
               final Set<InstanceKey> temp = HashSetFactory.make();
-              v.getValue().foreach(new IntSetAction() {
-                @Override
-                public void act(int keyIndex) {
-                  temp.add(system.getInstanceKey(keyIndex));
-                }
-              });
+              v.getValue().foreach(keyIndex -> temp.add(system.getInstanceKey(keyIndex)));
 
-              return temp.toArray(new InstanceKey[temp.size()]);
+              return temp.toArray(new InstanceKey[0]);
             }
           }
         }
@@ -785,12 +731,7 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
 
         private boolean addKey(InstanceKey k) {
           int n = system.findOrCreateIndexForInstanceKey(k);
-          if (!lv.contains(n)) {
-            lv.add(n);
-            return true;
-          } else {
-            return false;
-          }
+          return lv.add(n);
         }
 
         @Override
@@ -802,17 +743,17 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
           InstanceKey[] iks2 = getInstancesArray(arg2);
 
           if ((instruction.getOperator() == BinaryOpInstruction.Operator.ADD) && (getOptions().getTraceStringConstants())) {
-            for (int i = 0; i < iks1.length; i++) {
-              if (isStringConstant(iks1[i])) {
-                for (int j = 0; j < iks2.length; j++) {
-                  if (isStringConstant(iks2[j])) {
+            for (InstanceKey element : iks1) {
+              if (isStringConstant(element)) {
+                for (InstanceKey element2 : iks2) {
+                  if (isStringConstant(element2)) {
                     try {
                       MonitorUtil.throwExceptionIfCanceled(builder.monitor);
                     } catch (CancelException e) {
                       throw new CancelRuntimeException(e);
                     }
-                    String v1 = (String) ((ConstantKey) iks1[i]).getValue();
-                    String v2 = (String) ((ConstantKey) iks2[j]).getValue();
+                    String v1 = (String) ((ConstantKey<?>) element).getValue();
+                    String v2 = (String) ((ConstantKey<?>) element2).getValue();
                     if (v1.indexOf(v2) == -1 && v2.indexOf(v1) == -1) {
                       InstanceKey lvalKey = getInstanceKeyForConstant(v1 + v2);
                       if (addKey(lvalKey)) {
@@ -834,20 +775,39 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
           }
 
           if (doDefault) {
-              for (int i = 0; i < iks1.length; i++) {
-                for (int j = 0; j < iks2.length; j++) {
+              for (InstanceKey element : iks1) {
+                for (InstanceKey element2 : iks2) {
                   try {
                     MonitorUtil.throwExceptionIfCanceled(builder.monitor);
                   } catch (CancelException e) {
                     throw new CancelRuntimeException(e);
                   }
-                  if (handleBinaryOperatorArgs(iks1[i], iks2[j])) {
+                  if (handleBinaryOperatorArgs(element, element2)) {
                     changed = CHANGED;
                   }
                 }
               }
           }
           
+          if (iks1 == null || iks1.length == 0 || iks2 == null || iks2.length == 0) {
+            if (iks1 != null) {
+              for(InstanceKey ik : iks1) {
+                if (addKey(ik)) {
+                  changed = CHANGED;
+                }
+              }
+            }
+            if (iks2 != null) {
+              for(InstanceKey ik : iks2) {
+                if (addKey(ik)) {
+                  changed = CHANGED;
+                }
+              }
+            }
+            
+            System.err.println(instruction);
+          }
+          
           return changed;
         }
         
@@ -994,12 +954,14 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
     processCallingConstraintsInternal(this, caller, instruction, target, constParams, uniqueCatchKey);
   }
 
+  @SuppressWarnings("unused")
   public static void processCallingConstraintsInternal(AstSSAPropagationCallGraphBuilder builder, CGNode caller, SSAAbstractInvokeInstruction instruction, CGNode target,
       InstanceKey[][] constParams, PointerKey uniqueCatchKey) {
-    IR sourceIR = builder.getCFAContextInterpreter().getIR(caller);
+        
+    IRView sourceIR = builder.getCFAContextInterpreter().getIRView(caller);
     SymbolTable sourceST = sourceIR.getSymbolTable();
 
-    IR targetIR = builder.getCFAContextInterpreter().getIR(target);
+    IRView targetIR = builder.getCFAContextInterpreter().getIRView(target);
     SymbolTable targetST = targetIR.getSymbolTable();
 
     JSConstraintVisitor targetVisitor = null;
@@ -1016,7 +978,7 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
     }
 
     int paramCount = targetST.getParameterValueNumbers().length;
-    int argCount = instruction.getNumberOfParameters();
+    int argCount = instruction.getNumberOfPositionalParameters();
     
     // the first two arguments are the function object and the receiver, neither of which
     // should become part of the arguments array
@@ -1024,7 +986,7 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
 
     // pass actual arguments to formals in the normal way
     for (int i = 0; i < Math.min(paramCount, argCount); i++) {
-      InstanceKey[] fn = new InstanceKey[] { builder.getInstanceKeyForConstant(JavaScriptTypes.String, ""+(i-num_pseudoargs)) };
+      InstanceKey[] fn = new InstanceKey[] { builder.getInstanceKeyForConstant(JavaScriptTypes.String, String.valueOf(i - num_pseudoargs)) };
       PointerKey F = builder.getTargetPointerKey(target, i);
 
       if (constParams != null && constParams[i] != null) {
@@ -1050,7 +1012,7 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
     if (paramCount < argCount) {
       if (av != -1) {
         for (int i = paramCount; i < argCount; i++) {
-          InstanceKey[] fn = new InstanceKey[] { builder.getInstanceKeyForConstant(JavaScriptTypes.String, ""+(i-num_pseudoargs)) };
+          InstanceKey[] fn = new InstanceKey[] { builder.getInstanceKeyForConstant(JavaScriptTypes.String, String.valueOf(i - num_pseudoargs)) };
           if (constParams != null && constParams[i] != null && i >= num_pseudoargs) {
               targetVisitor.newFieldWrite(target, av, fn, constParams[i]);
           } else if(i >= num_pseudoargs) {
@@ -1068,8 +1030,8 @@ public class JSSSAPropagationCallGraphBuilder extends AstSSAPropagationCallGraph
       InstanceKey[] nullkeys = builder.getInvariantContents(sourceST, sourceDU, caller, nullvn, builder);
       for (int i = argCount; i < paramCount; i++) {
         PointerKey F = builder.getPointerKeyForLocal(target, targetST.getParameter(i));
-        for (int k = 0; k < nullkeys.length; k++) {
-          builder.getSystem().newConstraint(F, nullkeys[k]);
+        for (InstanceKey nullkey : nullkeys) {
+          builder.getSystem().newConstraint(F, nullkey);
         }
       }
     }
