@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2011 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 
 package com.ibm.wala.cast.js.ipa.callgraph.correlations.extraction;
 
@@ -31,6 +31,7 @@ import static com.ibm.wala.cast.tree.CAstNode.TRY;
 import static com.ibm.wala.cast.tree.CAstNode.VAR;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.LinkedList;
@@ -83,11 +84,11 @@ import com.ibm.wala.util.debug.UnimplementedError;
  * 
  * <p>There are four issues to be considered here.</p>
  * <ul>
- * <li><b>References to <code>this</code></b>: 
- *   <p>If the code to extract contains references to <code>this</code>, these references have to be 
+ * <li><b>References to {@code this}</b>:
+ *   <p>If the code to extract contains references to {@code this}, these references have to be
  *   rewritten; otherwise they would refer to the global object in the transformed code.</p>
- *   <p>We do this by giving the extracted function an extra parameter <code>thi$</code>, and rewriting
- *   <code>this</code> to <code>thi$</code> within the extracted code.</p>
+ *   <p>We do this by giving the extracted function an extra parameter {@code thi$}, and rewriting
+ *   {@code this} to {@code thi$} within the extracted code.</p>
  *   <p>For instance,</p>
  *   <pre>
  *   Object.prototype.extend = function(src) {
@@ -111,23 +112,23 @@ import com.ibm.wala.util.debug.UnimplementedError;
  *   <p>This is already taken care of by the translation from Rhino's AST to CAst.</p>
  *   <p>Optionally, the policy can request that one local variable of the surrounding function be turned into 
  *   a local variable of the extracted closure. The rewriter checks that this is possible: the code to extract
- *   must not contain function calls or <code>new</code> expressions, and it must not contain <code>break</code>,
- *   <code>continue</code>, or <code>return</code> statements. The former requirement prevents a called function
+ *   must not contain function calls or {@code new} expressions, and it must not contain {@code break},
+ *   {@code continue}, or {@code return} statements. The former requirement prevents a called function
  *   from observing a different value of the local variable than before. The latter requirement is necessary
  *   because the final value of the localised variable needs to be returned and assigned to its counterpart in
  *   the surrounding function; since non-local jumps are encoded by special return values (see next item),
  *   this would no longer be possible.</p>
  * </li>
- * <li><b><code>break</code>, <code>continue</code>, <code>return</code></b>:
- *   <p>A <code>break</code> or <code>continue</code> statement within the extracted loop body that refers
- *   to the loop itself or an enclosing loop would become invalid in the transformed code. A <code>return</code>
+ * <li><b>{@code break}, {@code continue}, {@code return}</b>:
+ *   <p>A {@code break} or {@code continue} statement within the extracted loop body that refers
+ *   to the loop itself or an enclosing loop would become invalid in the transformed code. A {@code return}
  *   statement would no longer return from the enclosing function, but instead from the extracted function.</p>
- *   <p>We transform all three statements into <code>return</code> statements returning an object literal with a
- *   property <code>type</code> indicating whether this is a 'goto' (i.e., <code>break</code> or <code>return</code>)
+ *   <p>We transform all three statements into {@code return} statements returning an object literal with a
+ *   property {@code type} indicating whether this is a 'goto' (i.e., {@code break} or {@code return})
  *   or a 'return'. In the former case, the 'target' property contains an integer identifying the jump target; in
  *   the latter case, the 'value' property contains the value to return.</p>
  *   <p>The return value of the extracted function is then examined to determine whether it completed normally
- *   (i.e., returned <code>undefined</code>), or whether it returned an object indicating special control flow.</p>
+ *   (i.e., returned {@code undefined}), or whether it returned an object indicating special control flow.</p>
  *   <p>For example, consider this code from MooTools:</p>
  *   <pre>
  *   for(var style in Element.ShortStyles) {
@@ -162,7 +163,7 @@ import com.ibm.wala.util.debug.UnimplementedError;
  *     }
  *   }
  *   </pre>
- *   <p>Note that at the CAst level, <code>break</code> and <code>continue</code> are represented as <code>goto</code>
+ *   <p>Note that at the CAst level, {@code break} and {@code continue} are represented as {@code goto}
  *   statements, which simplifies the translation somewhat. The numerical encoding of jump targets does not matter
  *   as long as the extracted function and the fixup code agree on which number represents which label.</p>
  * </li>
@@ -179,7 +180,7 @@ import com.ibm.wala.util.debug.UnimplementedError;
  *
  */
 public class ClosureExtractor extends CAstRewriterExt {
-  private LinkedList<ExtractionPolicy> policies = new LinkedList<ExtractionPolicy>();
+  private LinkedList<ExtractionPolicy> policies = new LinkedList<>();
   private final ExtractionPolicyFactory policyFactory;
   
   private static final boolean LOCALISE = true;
@@ -200,7 +201,7 @@ public class ClosureExtractor extends CAstRewriterExt {
   }
   
   @Override
-  protected void leaveEntity(CAstEntity entity) {
+  protected void leaveEntity() {
     policies.pop();
   }
 
@@ -210,7 +211,7 @@ public class ClosureExtractor extends CAstRewriterExt {
     case OPERATOR:
       return root;
     case CONSTANT:
-      return copyConstant(root, cfg, context, nodeMap);
+      return copyConstant(root, context, nodeMap);
     case BLOCK_STMT:
       return copyBlock(root, cfg, context, nodeMap);
     case RETURN: 
@@ -225,7 +226,7 @@ public class ClosureExtractor extends CAstRewriterExt {
   }
 
   /* Constants are not affected by the rewriting, they are just copied. */
-  private CAstNode copyConstant(CAstNode root, CAstControlFlowMap cfg, NodePos context, Map<Pair<CAstNode, NoKey>, CAstNode> nodeMap) {
+  private CAstNode copyConstant(CAstNode root, NodePos context, Map<Pair<CAstNode, NoKey>, CAstNode> nodeMap) {
     CAstNode newNode = Ast.makeConstant(root.getValue());
     nodeMap.put(Pair.make(root, context.key()), newNode);
     return newNode;
@@ -237,14 +238,13 @@ public class ClosureExtractor extends CAstRewriterExt {
     if(regions == null || usesArguments(root)) {
       return copyNode(root, cfg, context, nodeMap);
     } else {
-      ArrayList<CAstNode> copied_children = new ArrayList<CAstNode>();
+      ArrayList<CAstNode> copied_children = new ArrayList<>();
       int next_child = 0;
       // code in between regions is handled by invoking copyNodes, the regions themselves by extractRegion
       for(ExtractionRegion region : regions) {
         for(;next_child<region.getStart();++next_child)
           copied_children.add(copyNodes(root.getChild(next_child), cfg, new ChildPos(root, next_child, context), nodeMap));
-        for(CAstNode stmt : extractRegion(root, cfg, new ExtractionPos(root, region, context), nodeMap))
-          copied_children.add(stmt);
+        copied_children.addAll(extractRegion(root, cfg, new ExtractionPos(root, region, context), nodeMap));
         next_child = region.getEnd();
       }
       for(;next_child<root.getChildCount();++next_child)
@@ -306,7 +306,7 @@ public class ClosureExtractor extends CAstRewriterExt {
           Ast.makeConstant("type"),
           Ast.makeConstant("goto"),
           Ast.makeConstant("target"),
-          Ast.makeConstant(((double)label)+"")),
+          Ast.makeConstant(String.valueOf((double) label))),
           getCurrentEntity().getControlFlow());
 
       addNode(returnLit, getCurrentEntity().getControlFlow());
@@ -445,8 +445,8 @@ public class ClosureExtractor extends CAstRewriterExt {
      * 
      * The whole thing is then wrapped into a block.
      */
-    ArrayList<CAstNode> prologue = new ArrayList<CAstNode>();
-    ArrayList<CAstNode> fun_body_stmts = new ArrayList<CAstNode>();
+    ArrayList<CAstNode> prologue = new ArrayList<>();
+    ArrayList<CAstNode> fun_body_stmts = new ArrayList<>();
 
     // if we are extracting a block, unwrap it
     if(extractingBlock) {
@@ -464,18 +464,14 @@ public class ClosureExtractor extends CAstRewriterExt {
           CAstNode[] before = new CAstNode[tler.getStartInner()];
           for(i=0;i<tler.getStartInner();++i)
             before[i] = copyNodes(start.getChild(i), cfg, context, nodeMap);
-          for(int x = 0; x < before.length; x++) {
-            prologue.add(before[x]);
-          }
+          prologue.addAll(Arrays.asList(before));
           if(i+1 == start.getChildCount()) {
             fun_body_stmts.add(addSpuriousExnFlow(start.getChild(i), cfg));            
           } else {
             CAstNode[] after = new CAstNode[start.getChildCount()-i];
             for(int j=0;j+i<start.getChildCount();++j)
               after[j] = addSpuriousExnFlow(start.getChild(j+i), cfg);
-            for(int x = 0; x < after.length; x++) {
-              fun_body_stmts.add(after[x]);
-            }
+            fun_body_stmts.addAll(Arrays.asList(after));
           }
           for(i=context.getStart()+1;i<context.getEnd();++i)
             fun_body_stmts.add(root.getChild(i));
@@ -562,6 +558,10 @@ public class ClosureExtractor extends CAstRewriterExt {
       public CAstNodeTypeMap newTypes() { return theTypes; }
       @Override
       public Map<CAstNode, Collection<CAstEntity>> newChildren() { return theChildren; }
+      @Override
+      public CAstNode[] newDefaults() {
+        return null;
+      }
     };
     new_entity.setRewrite(rw);
 
@@ -588,7 +588,7 @@ public class ClosureExtractor extends CAstRewriterExt {
      * a null pointer exception on the call; these are infeasible, but we add them anyway to get the same AST 
      * as with a manual extraction.
      */
-    List<CAstNode> args = new ArrayList<CAstNode>();
+    List<CAstNode> args = new ArrayList<>();
     CAstNode funExpr = Ast.makeNode(FUNCTION_EXPR, Ast.makeConstant(new_entity));
     args.add(funExpr);
     context.setCallSite(funExpr);
@@ -609,7 +609,7 @@ public class ClosureExtractor extends CAstRewriterExt {
     addExnFlow(call, null, entity, context);
 
     // if the extracted code contains jumps, we need to insert some fix-up code
-    List<CAstNode> stmts = new ArrayList<CAstNode>(prologue);
+    List<CAstNode> stmts = new ArrayList<>(prologue);
     if(context.containsJump()) {
       CAstNode decl = Ast.makeNode(ASSIGN,
           addExnFlow(makeVarRef("re$"), JavaScriptTypes.ReferenceError, entity, context),
@@ -666,7 +666,7 @@ public class ClosureExtractor extends CAstRewriterExt {
     return stmts;
   }
   
-  private CAstNode addSpuriousExnFlow(CAstNode node, CAstControlFlowMap cfg) {
+  private static CAstNode addSpuriousExnFlow(CAstNode node, CAstControlFlowMap cfg) {
     CAstControlFlowRecorder flow = (CAstControlFlowRecorder)cfg;
     if(node.getKind() == ASSIGN) {
       if(node.getChild(0).getKind() == VAR) {
@@ -704,7 +704,7 @@ public class ClosureExtractor extends CAstRewriterExt {
           addExnFlow(Ast.makeNode(OBJECT_REF,
               addExnFlow(makeVarRef("re$"), JavaScriptTypes.ReferenceError, entity, context),
               Ast.makeConstant("target")), JavaScriptTypes.TypeError, entity, context),
-          Ast.makeConstant((double)labeller.getLabel(goto_target.snd)+""));
+          Ast.makeConstant(String.valueOf((double) labeller.getLabel(goto_target.snd))));
       CAstNode then_branch;
       if(goto_target.fst != null)
         then_branch = Ast.makeNode(GOTO, Ast.makeConstant(goto_target.fst));
@@ -816,6 +816,8 @@ public class ClosureExtractor extends CAstRewriterExt {
     case CAstNode.CALL:
     case CAstNode.NEW:
       return false;
+    default:
+      // fall through to generic handlers below
     }
     for(int i=0;i<node.getChildCount();++i)
       if(!noJumpsAndNoCalls(node.getChild(i)))
