@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2011 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 
 package com.ibm.wala.cast.js.ipa.callgraph.correlations.extraction;
 
@@ -22,7 +22,7 @@ import com.ibm.wala.cast.tree.CAstNode;
  *
  */
 public class NodeLabeller {
-	private ArrayList<CAstNode> nodes = new ArrayList<CAstNode>();
+	private ArrayList<CAstNode> nodes = new ArrayList<>();
 	
 	/**
 	 * Adds a node to the mapping if it is not present yet.
