@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2014 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,30 +7,36 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 
 package com.ibm.wala.cast.js.ipa.summaries;
 
-import java.io.File;
-import java.io.FileWriter;
 import java.io.IOException;
+import java.io.InputStream;
+import java.io.Reader;
+import java.io.StringReader;
+import java.net.MalformedURLException;
+import java.net.URL;
+import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 
 import com.ibm.wala.cast.js.ipa.callgraph.JSCallGraphUtil;
-import com.ibm.wala.cast.js.loader.JSCallSiteReference;
 import com.ibm.wala.cast.js.loader.JavaScriptLoader;
 import com.ibm.wala.cast.js.ssa.JSInstructionFactory;
 import com.ibm.wala.cast.js.types.JavaScriptMethods;
 import com.ibm.wala.cast.js.types.JavaScriptTypes;
+import com.ibm.wala.cast.loader.DynamicCallSiteReference;
 import com.ibm.wala.cast.types.AstMethodReference;
 import com.ibm.wala.classLoader.CallSiteReference;
 import com.ibm.wala.classLoader.IClass;
 import com.ibm.wala.classLoader.IMethod;
+import com.ibm.wala.classLoader.Module;
+import com.ibm.wala.classLoader.ModuleEntry;
 import com.ibm.wala.classLoader.NewSiteReference;
+import com.ibm.wala.classLoader.SourceModule;
 import com.ibm.wala.ipa.cha.IClassHierarchy;
 import com.ibm.wala.ipa.summaries.MethodSummary;
-import com.ibm.wala.shrikeBT.IConditionalBranchInstruction.IOperator;
 import com.ibm.wala.shrikeBT.IConditionalBranchInstruction.Operator;
 import com.ibm.wala.ssa.ConstantValue;
 import com.ibm.wala.ssa.IR;
@@ -40,6 +46,7 @@ import com.ibm.wala.types.MethodReference;
 import com.ibm.wala.types.TypeName;
 import com.ibm.wala.types.TypeReference;
 import com.ibm.wala.util.collections.HashMapFactory;
+import com.ibm.wala.util.collections.NonNullSingletonIterator;
 import com.ibm.wala.util.collections.Pair;
 
 public class JavaScriptConstructorFunctions {
@@ -68,7 +75,7 @@ public class JavaScriptConstructorFunctions {
 
     @Override
     public String toString() {
-      return "<ctor for " + getReference().getDeclaringClass() + toStringExtra + ">";
+      return "<ctor for " + getReference().getDeclaringClass() + toStringExtra + '>';
     }
     
     public IClass constructedType() {
@@ -81,7 +88,7 @@ public class JavaScriptConstructorFunctions {
     return m;
   }
 
-  private IMethod makeNullaryValueConstructor(IClass cls, Object value) {
+  private static IMethod makeNullaryValueConstructor(IClass cls, Object value) {
     JSInstructionFactory insts = (JSInstructionFactory)cls.getClassLoader().getInstructionFactory();
     MethodReference ref = JavaScriptMethods.makeCtorReference(cls.getReference());
     JavaScriptSummary S = new JavaScriptSummary(ref, 1);
@@ -95,8 +102,12 @@ public class JavaScriptConstructorFunctions {
     //S.addStatement(insts.PutInstruction(5, 4, "__proto__"));
     S.getNextProgramCounter();
     
-    S.addConstant(new Integer(8), new ConstantValue(value));
+    S.addConstant(Integer.valueOf(8), new ConstantValue(value));
     S.addStatement(insts.PutInstruction(S.getNumberOfStatements(), 5, 8, "$value"));
+    if (value instanceof String) {
+      S.addConstant(9, new ConstantValue(0));
+      S.addStatement(insts.PutInstruction(S.getNumberOfStatements(), 5, 9, "length"));
+    }
     S.getNextProgramCounter();
     
     S.addStatement(insts.ReturnInstruction(S.getNumberOfStatements(), 5, false));
@@ -107,7 +118,7 @@ public class JavaScriptConstructorFunctions {
     return new JavaScriptConstructor(ref, S, cls, cls);
   }
 
-  private IMethod makeUnaryValueConstructor(IClass cls) {
+  private static IMethod makeUnaryValueConstructor(IClass cls) {
     JSInstructionFactory insts = (JSInstructionFactory)cls.getClassLoader().getInstructionFactory();
    MethodReference ref = JavaScriptMethods.makeCtorReference(cls.getReference());
     JavaScriptSummary S = new JavaScriptSummary(ref, 2);
@@ -135,7 +146,7 @@ public class JavaScriptConstructorFunctions {
   private IMethod makeValueConstructor(IClass cls, int nargs, Object value) {
     if (nargs == 0 || nargs == 1) {
 
-      Object key = Pair.make(cls, new Integer(nargs));
+      Object key = Pair.make(cls, Integer.valueOf(nargs));
       if (constructors.containsKey(key))
         return constructors.get(key);
 
@@ -186,7 +197,7 @@ public class JavaScriptConstructorFunctions {
   private IMethod makeObjectConstructor(IClass cls, int nargs) {
     if (nargs == 0 || nargs == 1) {
 
-      Object key = Pair.make(cls, new Integer(nargs));
+      Object key = Pair.make(cls, Integer.valueOf(nargs));
       if (constructors.containsKey(key))
         return constructors.get(key);
 
@@ -202,7 +213,7 @@ public class JavaScriptConstructorFunctions {
   private IMethod makeObjectCall(IClass cls, int nargs) {
     assert nargs == 0;
 
-    Object key = Pair.make(cls, new Integer(nargs));
+    Object key = Pair.make(cls, Integer.valueOf(nargs));
     if (constructors.containsKey(key))
       return constructors.get(key);
 
@@ -240,7 +251,7 @@ public class JavaScriptConstructorFunctions {
     MethodReference ref = JavaScriptMethods.makeCtorReference(JavaScriptTypes.Array);
     JavaScriptSummary S = new JavaScriptSummary(ref, nargs + 1);
 
-    S.addConstant(new Integer(nargs + 3), new ConstantValue("prototype"));
+    S.addConstant(Integer.valueOf(nargs + 3), new ConstantValue("prototype"));
     S.addStatement(insts.PropertyRead(S.getNumberOfStatements(), nargs + 4, 1, nargs + 3));
     S.getNextProgramCounter();
     
@@ -252,13 +263,13 @@ public class JavaScriptConstructorFunctions {
     //S.addStatement(insts.PutInstruction(nargs + 5, nargs + 4, "__proto__"));
     S.getNextProgramCounter();
     
-    S.addConstant(new Integer(nargs + 7), new ConstantValue(nargs));
+    S.addConstant(Integer.valueOf(nargs + 7), new ConstantValue(nargs));
     S.addStatement(insts.PutInstruction(S.getNumberOfStatements(), nargs + 5, nargs + 7, "length"));
     S.getNextProgramCounter();
     
     int vn = nargs + 9;
     for (int i = 0; i < nargs; i++, vn += 2) {
-      S.addConstant(new Integer(vn), new ConstantValue(i));
+      S.addConstant(Integer.valueOf(vn), new ConstantValue(i));
       S.addStatement(insts.PropertyWrite(S.getNumberOfStatements(), nargs + 5, vn, i + 1));
       S.getNextProgramCounter();
       }
@@ -272,7 +283,7 @@ public class JavaScriptConstructorFunctions {
   }
 
   private IMethod makeArrayConstructor(IClass cls, int nargs) {
-    Object key = Pair.make(cls, new Integer(nargs));
+    Object key = Pair.make(cls, Integer.valueOf(nargs));
     if (constructors.containsKey(key))
       return constructors.get(key);
 
@@ -285,7 +296,12 @@ public class JavaScriptConstructorFunctions {
     MethodReference ref = AstMethodReference.fnReference(JavaScriptTypes.String);
     JavaScriptSummary S = new JavaScriptSummary(ref, 1);
 
-    S.addConstant(new Integer(2), new ConstantValue(""));
+    S.addConstant(Integer.valueOf(2), new ConstantValue(""));
+
+    S.addConstant(Integer.valueOf(3), new ConstantValue(0));
+    S.addStatement(insts.PutInstruction(S.getNumberOfStatements(), 2, 3, "length"));
+    S.getNextProgramCounter();
+
     S.addStatement(insts.ReturnInstruction(S.getNumberOfStatements(), 2, false));
     S.getNextProgramCounter();
     
@@ -300,7 +316,7 @@ public class JavaScriptConstructorFunctions {
     S.addStatement(insts.GetInstruction(S.getNumberOfStatements(), 4, 2, "toString"));
     S.getNextProgramCounter();
     
-    CallSiteReference cs = new JSCallSiteReference(S.getNextProgramCounter());
+    CallSiteReference cs = new DynamicCallSiteReference(JavaScriptTypes.CodeBody, S.getNextProgramCounter());
     S.addStatement(insts.Invoke(S.getNumberOfStatements(), 4, 5, new int[] { 2 }, 6, cs));
 
     S.addStatement(insts.ReturnInstruction(S.getNumberOfStatements(), 5, false));
@@ -312,7 +328,7 @@ public class JavaScriptConstructorFunctions {
   private IMethod makeStringCall(IClass cls, int nargs) {
     assert nargs == 0 || nargs == 1;
 
-    Object key = Pair.make(cls, new Integer(nargs));
+    Object key = Pair.make(cls, Integer.valueOf(nargs));
     if (constructors.containsKey(key))
       return constructors.get(key);
 
@@ -325,7 +341,7 @@ public class JavaScriptConstructorFunctions {
     MethodReference ref = AstMethodReference.fnReference(JavaScriptTypes.Number);
     JavaScriptSummary S = new JavaScriptSummary(ref, 1);
 
-    S.addConstant(new Integer(2), new ConstantValue(0.0));
+    S.addConstant(Integer.valueOf(2), new ConstantValue(0.0));
     S.addStatement(insts.ReturnInstruction(S.getNumberOfStatements(), 2, false));
     S.getNextProgramCounter();
     
@@ -340,7 +356,7 @@ public class JavaScriptConstructorFunctions {
     S.addStatement(insts.GetInstruction(S.getNumberOfStatements(), 4, 2, "toNumber"));
     S.getNextProgramCounter();
     
-    CallSiteReference cs = new JSCallSiteReference(S.getNextProgramCounter());
+    CallSiteReference cs = new DynamicCallSiteReference(JavaScriptTypes.CodeBody, S.getNextProgramCounter());
     S.addStatement(insts.Invoke(S.getNumberOfStatements(), 4, 5, new int[] { 2 }, 6, cs));
 
     S.addStatement(insts.ReturnInstruction(S.getNumberOfStatements(), 5, false));
@@ -352,7 +368,7 @@ public class JavaScriptConstructorFunctions {
   private IMethod makeNumberCall(IClass cls, int nargs) {
     assert nargs == 0 || nargs == 1;
 
-    Object key = Pair.make(cls, new Integer(nargs));
+    Object key = Pair.make(cls, Integer.valueOf(nargs));
     if (constructors.containsKey(key))
       return constructors.get(key);
 
@@ -393,7 +409,7 @@ public class JavaScriptConstructorFunctions {
     //S.addConstant(8, new ConstantValue("__proto__"));
 
     if (receiver != cls)
-      return record(tableKey, new JavaScriptConstructor(ref, S, receiver, cls, "(" + cls.getReference().getName() + ")"));
+      return record(tableKey, new JavaScriptConstructor(ref, S, receiver, cls, "(" + cls.getReference().getName() + ')'));
     else
       return record(tableKey, new JavaScriptConstructor(ref, S, receiver, cls));
   }
@@ -403,73 +419,142 @@ public class JavaScriptConstructorFunctions {
   private IMethod makeFunctionConstructor(IR callerIR, SSAAbstractInvokeInstruction callStmt, IClass cls, int nargs) {
     SymbolTable ST = callerIR.getSymbolTable();
 
-    if (nargs == 0) {
-      return makeFunctionConstructor(cls, cls);
-    } else if (nargs == 1) {
-      if (ST.isStringConstant(callStmt.getUse(1))) {
-        TypeReference ref = TypeReference.findOrCreate(JavaScriptTypes.jsLoader, TypeName.string2TypeName(ST
-            .getStringValue(callStmt.getUse(1))));
+    switch (nargs) {
+      case 0:
+        return makeFunctionConstructor(cls, cls);
+      case 1:
+        if (ST.isStringConstant(callStmt.getUse(1))) {
+          TypeReference ref = TypeReference.findOrCreate(JavaScriptTypes.jsLoader, TypeName.string2TypeName(ST
+              .getStringValue(callStmt.getUse(1))));
 
-        IClass cls2 = cha.lookupClass(ref);
-        if (cls2 != null) {
-          return makeFunctionConstructor(cls, cls2);
-        }
-      }
-
-      return makeFunctionConstructor(cls, cls);
-    } else {
-      assert nargs > 1;
-      JavaScriptLoader cl = (JavaScriptLoader) cha.getLoader(JavaScriptTypes.jsLoader);
-
-      for (int i = 1; i < callStmt.getNumberOfUses(); i++)
-        if (!ST.isStringConstant(callStmt.getUse(i)))
-          return makeFunctionConstructor(cls, cls);
-
-      StringBuffer fun = new StringBuffer("function _fromctor (");
-      for (int j = 1; j < callStmt.getNumberOfUses() - 1; j++) {
-        if (j != 1)
-          fun.append(",");
-        fun.append(ST.getStringValue(callStmt.getUse(j)));
-      }
-
-      fun.append(") {");
-      fun.append(ST.getStringValue(callStmt.getUse(callStmt.getNumberOfUses() - 1)));
-      fun.append("}");
-
-      try {
-        String fileName = "ctor$" + ++ctorCount;
-        File f = new File(System.getProperty("java.io.tmpdir") + File.separator + fileName);
-        FileWriter FO = new FileWriter(f);
-        FO.write(fun.toString());
-        FO.close();
-        
-        Set<String> fnNames = JSCallGraphUtil.loadAdditionalFile(cha, cl, fileName, f.toURI().toURL());
-        IClass fcls = null;
-        for(String nm : fnNames) {
-          if (nm.endsWith("_fromctor")) {
-            fcls = cl.lookupClass(nm, cha);
+          IClass cls2 = cha.lookupClass(ref);
+          if (cls2 != null) {
+            return makeFunctionConstructor(cls, cls2);
           }
         }
 
-        assert fcls != null : "cannot find class for " + fileName + " in " + f;
-        
-        f.delete();
+        return makeFunctionConstructor(cls, cls);
+      default:
+        assert nargs > 1;
+        JavaScriptLoader cl = (JavaScriptLoader) cha.getLoader(JavaScriptTypes.jsLoader);
+
+        for (int i = 1; i < callStmt.getNumberOfUses(); i++)
+          if (!ST.isStringConstant(callStmt.getUse(i)))
+            return makeFunctionConstructor(cls, cls);
+
+        final StringBuilder fun = new StringBuilder("function _fromctor (");
+        for (int j = 1; j < callStmt.getNumberOfUses() - 1; j++) {
+          if (j != 1)
+            fun.append(',');
+          fun.append(ST.getStringValue(callStmt.getUse(j)));
+        }
+
+        fun.append(") {");
+        fun.append(ST.getStringValue(callStmt.getUse(callStmt.getNumberOfUses() - 1)));
+        fun.append('}');
+
+        try {
+          final String fileName = "ctor$" + ++ctorCount;
+          ModuleEntry ME = new SourceModule() {
+
+            @Override
+            public String getName() {
+              return fileName;
+            }
+
+            @Override
+            public boolean isClassFile() {
+              return false;
+            }
+
+            @Override
+            public boolean isSourceFile() {
+              return true;
+            }
+
+            @Override
+            public InputStream getInputStream() {
+              return new InputStream() {
+                private int i = 0;
+
+                @Override
+                public int read() throws IOException {
+                  if (i >= fun.length()) {
+                    return -1;
+                  } else {
+                    return fun.codePointAt(i++);
+                  }
+                }
+
+              };
+            }
+
+            @Override
+            public boolean isModuleFile() {
+              return false;
+            }
+
+            @Override
+            public Module asModule() {
+              return null;
+            }
+
+            @Override
+            public String getClassName() {
+              return fileName;
+            }
+
+            @Override
+            public Module getContainer() {
+              return null;
+            }
+
+            @Override
+            public Iterator<? extends ModuleEntry> getEntries() {
+              return new NonNullSingletonIterator<ModuleEntry>(this);
+            }
+
+            @Override
+            public Reader getInputReader() {
+              return new StringReader(fun.toString());
+            }
+
+            @Override
+            public URL getURL() {
+              try {
+                return new URL("file://" + fileName);
+              } catch (MalformedURLException e) {
+                assert false;
+                return null;
+              }
+            }
+
+          };
+
+          Set<String> fnNames = JSCallGraphUtil.loadAdditionalFile(cha, cl, ME);
+          IClass fcls = null;
+          for (String nm : fnNames) {
+            if (nm.endsWith("_fromctor")) {
+              fcls = cl.lookupClass(nm, cha);
+            }
+          }
+
+          assert fcls != null : "cannot find class for " + fileName;
 
-        if (fcls != null)
           return makeFunctionConstructor(cls, fcls);
 
-      } catch (IOException e) {
+        } catch (IOException e) {
 
-      }
+        }
 
-      return makeFunctionConstructor(cls, cls);
+        return makeFunctionConstructor(cls, cls);
     }
   }
 
  
   private IMethod makeFunctionObjectConstructor(IClass cls, int nargs) {
     JSInstructionFactory insts = (JSInstructionFactory)cls.getClassLoader().getInstructionFactory();
-   Object key = Pair.make(cls, new Integer(nargs));
+   Object key = Pair.make(cls, Integer.valueOf(nargs));
     if (constructors.containsKey(key))
       return constructors.get(key);
     
@@ -486,7 +571,7 @@ public class JavaScriptConstructorFunctions {
     S.addStatement(insts.SetPrototype(S.getNumberOfStatements(), nargs + 5, nargs + 4));
     S.getNextProgramCounter();
     
-    CallSiteReference cs = new JSCallSiteReference(S.getNextProgramCounter());
+    CallSiteReference cs = new DynamicCallSiteReference(JavaScriptTypes.CodeBody, S.getNextProgramCounter());
     int[] args = new int[nargs + 1];
     args[0] = nargs + 5;
     for (int i = 0; i < nargs; i++)
@@ -518,7 +603,7 @@ public class JavaScriptConstructorFunctions {
       assert nargs == 1;
       return makeValueConstructor(receiver, nargs, null);
     } else if (receiver.getReference().equals(JavaScriptTypes.NumberObject))
-      return makeValueConstructor(receiver, nargs, new Integer(0));
+      return makeValueConstructor(receiver, nargs, Integer.valueOf(0));
     else if (receiver.getReference().equals(JavaScriptTypes.Function))
       return makeFunctionConstructor(callerIR, callStmt, receiver, nargs);
     else if (cha.isSubclassOf(receiver, cha.lookupClass(JavaScriptTypes.CodeBody)))
