@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.js.loader;
 
 import java.io.UnsupportedEncodingException;
@@ -26,14 +26,19 @@ import com.ibm.wala.cast.ir.ssa.AstIsDefinedInstruction;
 import com.ibm.wala.cast.ir.ssa.AstLexicalAccess.Access;
 import com.ibm.wala.cast.ir.ssa.AstLexicalRead;
 import com.ibm.wala.cast.ir.ssa.AstLexicalWrite;
+import com.ibm.wala.cast.ir.ssa.AstPropertyRead;
+import com.ibm.wala.cast.ir.ssa.AstPropertyWrite;
+import com.ibm.wala.cast.ir.ssa.AstYieldInstruction;
 import com.ibm.wala.cast.ir.ssa.EachElementGetInstruction;
 import com.ibm.wala.cast.ir.ssa.EachElementHasNextInstruction;
-import com.ibm.wala.cast.ir.translator.AstTranslator;
 import com.ibm.wala.cast.ir.translator.AstTranslator.AstLexicalInformation;
 import com.ibm.wala.cast.ir.translator.AstTranslator.WalkContext;
 import com.ibm.wala.cast.ir.translator.TranslatorToCAst;
 import com.ibm.wala.cast.ir.translator.TranslatorToIR;
 import com.ibm.wala.cast.js.analysis.typeInference.JSPrimitiveType;
+import com.ibm.wala.cast.js.ipa.callgraph.JSCallGraph.JSFakeRoot;
+import com.ibm.wala.cast.js.ipa.modref.JavaScriptModRef;
+import com.ibm.wala.cast.js.ipa.modref.JavaScriptModRef.JavaScriptRefVisitor;
 import com.ibm.wala.cast.js.ssa.JSInstructionFactory;
 import com.ibm.wala.cast.js.ssa.JavaScriptCheckReference;
 import com.ibm.wala.cast.js.ssa.JavaScriptInstanceOf;
@@ -47,31 +52,34 @@ import com.ibm.wala.cast.js.ssa.SetPrototype;
 import com.ibm.wala.cast.js.translator.JSAstTranslator;
 import com.ibm.wala.cast.js.translator.JavaScriptTranslatorFactory;
 import com.ibm.wala.cast.js.types.JavaScriptTypes;
-import com.ibm.wala.cast.loader.AstClass;
-import com.ibm.wala.cast.loader.AstDynamicPropertyClass;
-import com.ibm.wala.cast.loader.AstFunctionClass;
-import com.ibm.wala.cast.loader.AstMethod;
 import com.ibm.wala.cast.loader.AstMethod.DebuggingInformation;
-import com.ibm.wala.cast.loader.AstMethod.Retranslatable;
 import com.ibm.wala.cast.loader.CAstAbstractModuleLoader;
 import com.ibm.wala.cast.tree.CAst;
 import com.ibm.wala.cast.tree.CAstEntity;
 import com.ibm.wala.cast.tree.CAstQualifier;
 import com.ibm.wala.cast.tree.CAstSourcePositionMap;
 import com.ibm.wala.cast.tree.rewrite.CAstRewriterFactory;
-import com.ibm.wala.cast.types.AstMethodReference;
+import com.ibm.wala.cast.types.AstTypeReference;
 import com.ibm.wala.cfg.AbstractCFG;
 import com.ibm.wala.cfg.IBasicBlock;
 import com.ibm.wala.classLoader.CallSiteReference;
 import com.ibm.wala.classLoader.IClass;
-import com.ibm.wala.classLoader.IClassLoader;
-import com.ibm.wala.classLoader.IField;
 import com.ibm.wala.classLoader.IMethod;
 import com.ibm.wala.classLoader.Language;
 import com.ibm.wala.classLoader.LanguageImpl;
+import com.ibm.wala.classLoader.ModuleEntry;
 import com.ibm.wala.classLoader.NewSiteReference;
-import com.ibm.wala.classLoader.SourceModule;
+import com.ibm.wala.ipa.callgraph.AnalysisOptions;
+import com.ibm.wala.ipa.callgraph.CGNode;
+import com.ibm.wala.ipa.callgraph.IAnalysisCacheView;
+import com.ibm.wala.ipa.callgraph.impl.AbstractRootMethod;
+import com.ibm.wala.ipa.callgraph.propagation.InstanceKey;
+import com.ibm.wala.ipa.callgraph.propagation.PointerAnalysis;
+import com.ibm.wala.ipa.callgraph.propagation.PointerKey;
 import com.ibm.wala.ipa.cha.IClassHierarchy;
+import com.ibm.wala.ipa.modref.ExtendedHeapModel;
+import com.ibm.wala.ipa.modref.ModRef.ModVisitor;
+import com.ibm.wala.ipa.modref.ModRef.RefVisitor;
 import com.ibm.wala.shrikeBT.IBinaryOpInstruction.IOperator;
 import com.ibm.wala.shrikeBT.IComparisonInstruction.Operator;
 import com.ibm.wala.shrikeCT.BootstrapMethodsReader.BootstrapMethod;
@@ -109,10 +117,8 @@ import com.ibm.wala.ssa.SymbolTable;
 import com.ibm.wala.types.ClassLoaderReference;
 import com.ibm.wala.types.FieldReference;
 import com.ibm.wala.types.MethodReference;
-import com.ibm.wala.types.Selector;
 import com.ibm.wala.types.TypeName;
 import com.ibm.wala.types.TypeReference;
-import com.ibm.wala.types.annotations.Annotation;
 import com.ibm.wala.util.collections.HashSetFactory;
 import com.ibm.wala.util.debug.Assertions;
 import com.ibm.wala.util.strings.Atom;
@@ -145,7 +151,7 @@ public class JavaScriptLoader extends CAstAbstractModuleLoader {
       if (o == null) {
         return JavaScriptTypes.Null;
       } else {
-        Class c = o.getClass();
+        Class<?> c = o.getClass();
         if (c == Boolean.class) {
           return JavaScriptTypes.Boolean;
         } else if (c == String.class) {
@@ -206,6 +212,11 @@ public class JavaScriptLoader extends CAstAbstractModuleLoader {
       throw new UnsupportedOperationException("JavaScript does not permit explicit pointers");
     }
 
+    @Override
+    public boolean methodsHaveDeclaredParameterTypes() {
+      return false;
+    }
+
     @Override
     public JSInstructionFactory instructionFactory() {
       return new JSInstructionFactory() {
@@ -242,12 +253,12 @@ public class JavaScriptLoader extends CAstAbstractModuleLoader {
         }
 
         @Override
-        public JavaScriptPropertyRead PropertyRead(int iindex, int result, int objectRef, int memberRef) {
+        public AstPropertyRead PropertyRead(int iindex, int result, int objectRef, int memberRef) {
           return new JavaScriptPropertyRead(iindex, result, objectRef, memberRef);
         }
 
         @Override
-        public JavaScriptPropertyWrite PropertyWrite(int iindex, int objectRef, int memberRef, int value) {
+        public AstPropertyWrite PropertyWrite(int iindex, int objectRef, int memberRef, int value) {
           return new JavaScriptPropertyWrite(iindex, objectRef, memberRef, value);
         }
 
@@ -298,6 +309,11 @@ public class JavaScriptLoader extends CAstAbstractModuleLoader {
           return new AstEchoInstruction(iindex, rvals);
         }
 
+        @Override
+        public AstYieldInstruction YieldInstruction(int iindex, int[] rvals) {
+          return new AstYieldInstruction(iindex, rvals);
+        }
+
         @Override
         public AstGlobalRead GlobalRead(int iindex, int lhs, FieldReference global) {
           return new AstGlobalRead(iindex, lhs, global);
@@ -648,7 +664,6 @@ public class JavaScriptLoader extends CAstAbstractModuleLoader {
       return JavaScriptTypes.String;
     }
 
-    @SuppressWarnings("static-access")
     @Override
     public PrimitiveType getPrimitive(TypeReference reference) {
       return PrimitiveType.getPrimitive(reference);
@@ -664,126 +679,39 @@ public class JavaScriptLoader extends CAstAbstractModuleLoader {
       return false;
     }
 
+    @Override
+    public AbstractRootMethod getFakeRootMethod(IClassHierarchy cha, AnalysisOptions options, IAnalysisCacheView cache) {
+      return new JSFakeRoot(cha, options, cache);
+    }
+
+    @Override
+    public <T extends InstanceKey> RefVisitor<T, ? extends ExtendedHeapModel> makeRefVisitor(CGNode n,
+        Collection<PointerKey> result, PointerAnalysis<T> pa, ExtendedHeapModel h) {
+      return new JavaScriptRefVisitor<>(n, result, pa, h);
+    }
+
+    @Override
+    public <T extends InstanceKey> ModVisitor<T, ? extends ExtendedHeapModel> makeModVisitor(CGNode n, Collection<PointerKey> result,
+        PointerAnalysis<T> pa, ExtendedHeapModel h, boolean ignoreAllocHeapDefs) {
+      return new JavaScriptModRef.JavaScriptModVisitor<>(n, result, h, pa);
+    }
+
   };
 
-  private static final Map<Selector, IMethod> emptyMap1 = Collections.emptyMap();
-
-  private static final Map<Atom, IField> emptyMap2 = Collections.emptyMap();
-
   private final JavaScriptTranslatorFactory translatorFactory;
   
-  private final CAstRewriterFactory preprocessor;
+  private final CAstRewriterFactory<?, ?> preprocessor;
   
   public JavaScriptLoader(IClassHierarchy cha, JavaScriptTranslatorFactory translatorFactory) {
     this(cha, translatorFactory, null);
   }
 
-  public JavaScriptLoader(IClassHierarchy cha, JavaScriptTranslatorFactory translatorFactory, CAstRewriterFactory preprocessor) {
+  public JavaScriptLoader(IClassHierarchy cha, JavaScriptTranslatorFactory translatorFactory, CAstRewriterFactory<?, ?> preprocessor) {
     super(cha);
     this.translatorFactory = translatorFactory;
     this.preprocessor = preprocessor;
   }
 
-  class JavaScriptClass extends AstClass {
-    private IClass superClass;
-
-    private JavaScriptClass(IClassLoader loader, TypeReference classRef, TypeReference superRef,
-        CAstSourcePositionMap.Position sourcePosition) {
-      super(sourcePosition, classRef.getName(), loader, (short) 0, emptyMap2, emptyMap1);
-      types.put(classRef.getName(), this);
-      superClass = superRef == null ? null : loader.lookupClass(superRef.getName());
-    }
-
-    @Override
-    public IClassHierarchy getClassHierarchy() {
-      return cha;
-    }
-
-    @Override
-    public String toString() {
-      return "JS:" + getReference().toString();
-    }
-
-    @Override
-    public Collection<IClass> getDirectInterfaces() {
-      return Collections.emptySet();
-    }
-
-    @Override
-    public IClass getSuperclass() {
-      return superClass;
-    }
-
-    @Override
-    public Collection<Annotation> getAnnotations() {
-      return Collections.emptySet();
-    }
-  }
-
-  class JavaScriptRootClass extends AstDynamicPropertyClass {
-
-    private JavaScriptRootClass(IClassLoader loader, CAstSourcePositionMap.Position sourcePosition) {
-      super(sourcePosition, JavaScriptTypes.Root.getName(), loader, (short) 0, emptyMap1, JavaScriptTypes.Root);
-
-      types.put(JavaScriptTypes.Root.getName(), this);
-    }
-
-    @Override
-    public IClassHierarchy getClassHierarchy() {
-      return cha;
-    }
-
-    @Override
-    public String toString() {
-      return "JS Root:" + getReference().toString();
-    }
-
-    @Override
-    public Collection<IClass> getDirectInterfaces() {
-      return Collections.emptySet();
-    }
-
-    @Override
-    public IClass getSuperclass() {
-      return null;
-    }
-    
-    @Override
-    public Collection<Annotation> getAnnotations() {
-      return Collections.emptySet();
-    }
-  }
-
-  class JavaScriptCodeBody extends AstFunctionClass {
-    private final WalkContext translationContext;
-    private final CAstEntity entity;
-    
-    public JavaScriptCodeBody(TypeReference codeName, TypeReference parent, IClassLoader loader,
-        CAstSourcePositionMap.Position sourcePosition, CAstEntity entity, WalkContext context) {
-      super(codeName, parent, loader, sourcePosition);
-      types.put(codeName.getName(), this);
-      this.translationContext = context;
-      this.entity = entity;
-    }
-
-    @Override
-    public IClassHierarchy getClassHierarchy() {
-      return cha;
-    }
-    
-    private IMethod setCodeBody(JavaScriptMethodObject codeBody) {
-      this.functionBody = codeBody;
-      codeBody.entity = entity;
-      codeBody.translationContext = translationContext;
-      return codeBody;
-    }
-    
-    @Override
-    public Collection<Annotation> getAnnotations() {
-      return Collections.emptySet();
-    }
-  }
-
   private static final Set<CAstQualifier> functionQualifiers;
 
   static {
@@ -792,113 +720,8 @@ public class JavaScriptLoader extends CAstAbstractModuleLoader {
     functionQualifiers.add(CAstQualifier.FINAL);
   }
 
-  public class JavaScriptMethodObject extends AstMethod implements Retranslatable {
-    private WalkContext translationContext;
-    private CAstEntity entity;
-
-    JavaScriptMethodObject(IClass cls, AbstractCFG cfg, SymbolTable symtab, boolean hasCatchBlock,
-        Map<IBasicBlock, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo) {
-      super(cls, functionQualifiers, cfg, symtab, AstMethodReference.fnReference(cls.getReference()), hasCatchBlock, caughtTypes,
-          hasMonitorOp, lexicalInfo, debugInfo, null);
-
-      // force creation of these constants by calling the getter methods
-      symtab.getNullConstant();
-    }
-
-    
-    @Override
-    public CAstEntity getEntity() {
-      return entity;
-    }
-
-
-    @Override
-    public void retranslate(AstTranslator xlator) {
-      xlator.translate(entity, translationContext);
-    }
-
-    @Override
-    public IClassHierarchy getClassHierarchy() {
-      return cha;
-    }
-
-    @Override
-    public String toString() {
-      return "<Code body of " + cls + ">";
-    }
-
-    @Override
-    public TypeReference[] getDeclaredExceptions() {
-      return null;
-    }
-
-    @Override
-    public LexicalParent[] getParents() {
-      if (lexicalInfo() == null)
-        return new LexicalParent[0];
-
-      final String[] parents = lexicalInfo().getScopingParents();
-
-      if (parents == null)
-        return new LexicalParent[0];
-
-      LexicalParent result[] = new LexicalParent[parents.length];
-
-      for (int i = 0; i < parents.length; i++) {
-        final int hack = i;
-        final AstMethod method = (AstMethod) lookupClass(parents[i], cha).getMethod(AstMethodReference.fnSelector);
-        result[i] = new LexicalParent() {
-          @Override
-          public String getName() {
-            return parents[hack];
-          }
-
-          @Override
-          public AstMethod getMethod() {
-            return method;
-          }
-        };
-
-        if (AstTranslator.DEBUG_LEXICAL) {
-          System.err.println(("parent " + result[i].getName() + " is " + result[i].getMethod()));
-        }
-      }
-
-      return result;
-    }
-
-    @Override
-    public String getLocalVariableName(int bcIndex, int localNumber) {
-      return null;
-    }
-
-    @Override
-    public boolean hasLocalVariableTable() {
-      return false;
-    }
-
-    public int getMaxLocals() {
-      Assertions.UNREACHABLE();
-      return -1;
-    }
-
-    public int getMaxStackHeight() {
-      Assertions.UNREACHABLE();
-      return -1;
-    }
-
-    @Override
-    public TypeReference getParameterType(int i) {
-      if (i == 0) {
-        return getDeclaringClass().getReference();
-      } else {
-        return JavaScriptTypes.Root;
-      }
-    }
-  }
-
   public IClass makeCodeBodyType(String name, TypeReference P, CAstSourcePositionMap.Position sourcePosition, CAstEntity entity, WalkContext context) {
-    return new JavaScriptCodeBody(TypeReference.findOrCreate(JavaScriptTypes.jsLoader, TypeName.string2TypeName(name)), P, this,
+    return new DynamicCodeBody(TypeReference.findOrCreate(JavaScriptTypes.jsLoader, TypeName.string2TypeName(name)), P, this,
         sourcePosition, entity, context);
   }
 
@@ -910,61 +733,61 @@ public class JavaScriptLoader extends CAstAbstractModuleLoader {
     return makeCodeBodyType(name, JavaScriptTypes.Script, pos, entity, context);
   }
 
-  public IMethod defineCodeBodyCode(String clsName, AbstractCFG cfg, SymbolTable symtab, boolean hasCatchBlock,
-      Map<IBasicBlock, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo) {
-    JavaScriptCodeBody C = (JavaScriptCodeBody) lookupClass(clsName, cha);
+  public IMethod defineCodeBodyCode(String clsName, AbstractCFG<?, ?> cfg, SymbolTable symtab, boolean hasCatchBlock,
+      Map<IBasicBlock<SSAInstruction>, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo) {
+    DynamicCodeBody C = (DynamicCodeBody) lookupClass(clsName, cha);
     assert C != null : clsName;
     return C.setCodeBody(makeCodeBodyCode(cfg, symtab, hasCatchBlock, caughtTypes, hasMonitorOp, lexicalInfo, debugInfo, C));
   }
 
-  public JavaScriptMethodObject makeCodeBodyCode(AbstractCFG cfg, SymbolTable symtab, boolean hasCatchBlock,
-      Map<IBasicBlock, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo,
+  public DynamicMethodObject makeCodeBodyCode(AbstractCFG<?, ?> cfg, SymbolTable symtab, boolean hasCatchBlock,
+      Map<IBasicBlock<SSAInstruction>, TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation lexicalInfo, DebuggingInformation debugInfo,
       IClass C) {
-    return new JavaScriptMethodObject(C, cfg, symtab, hasCatchBlock, caughtTypes, hasMonitorOp, lexicalInfo,
+    return new DynamicMethodObject(C, functionQualifiers, cfg, symtab, hasCatchBlock, caughtTypes, hasMonitorOp, lexicalInfo,
         debugInfo);
   }
 
-  final JavaScriptRootClass ROOT = new JavaScriptRootClass(this, null);
+  final CoreClass ROOT = new CoreClass(AstTypeReference.rootTypeName, null, this, null);
 
-  final JavaScriptClass UNDEFINED = new JavaScriptClass(this, JavaScriptTypes.Undefined, JavaScriptTypes.Root, null);
+  final CoreClass UNDEFINED = new CoreClass(JavaScriptTypes.Undefined.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass PRIMITIVES = new JavaScriptClass(this, JavaScriptTypes.Primitives, JavaScriptTypes.Root, null);
+  final CoreClass PRIMITIVES = new CoreClass(JavaScriptTypes.Primitives.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass FAKEROOT = new JavaScriptClass(this, JavaScriptTypes.FakeRoot, JavaScriptTypes.Root, null);
+  final CoreClass FAKEROOT = new CoreClass(JavaScriptTypes.FakeRoot.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass STRING = new JavaScriptClass(this, JavaScriptTypes.String, JavaScriptTypes.Root, null);
+  final CoreClass STRING = new CoreClass(JavaScriptTypes.String.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass NULL = new JavaScriptClass(this, JavaScriptTypes.Null, JavaScriptTypes.Root, null);
+  final CoreClass NULL = new CoreClass(JavaScriptTypes.Null.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass ARRAY = new JavaScriptClass(this, JavaScriptTypes.Array, JavaScriptTypes.Root, null);
+  final CoreClass ARRAY = new CoreClass(JavaScriptTypes.Array.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass OBJECT = new JavaScriptClass(this, JavaScriptTypes.Object, JavaScriptTypes.Root, null);
+  final CoreClass OBJECT = new CoreClass(JavaScriptTypes.Object.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass TYPE_ERROR = new JavaScriptClass(this, JavaScriptTypes.TypeError, JavaScriptTypes.Root, null);
+  final CoreClass TYPE_ERROR = new CoreClass(JavaScriptTypes.TypeError.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass CODE_BODY = new JavaScriptClass(this, JavaScriptTypes.CodeBody, JavaScriptTypes.Root, null);
+  final CoreClass CODE_BODY = new CoreClass(JavaScriptTypes.CodeBody.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass FUNCTION = new JavaScriptClass(this, JavaScriptTypes.Function, JavaScriptTypes.CodeBody, null);
+  final CoreClass FUNCTION = new CoreClass(JavaScriptTypes.Function.getName(), JavaScriptTypes.CodeBody.getName(), this, null);
 
-  final JavaScriptClass SCRIPT = new JavaScriptClass(this, JavaScriptTypes.Script, JavaScriptTypes.CodeBody, null);
+  final CoreClass SCRIPT = new CoreClass(JavaScriptTypes.Script.getName(), JavaScriptTypes.CodeBody.getName(), this, null);
 
-  final JavaScriptClass BOOLEAN = new JavaScriptClass(this, JavaScriptTypes.Boolean, JavaScriptTypes.Root, null);
+  final CoreClass BOOLEAN = new CoreClass(JavaScriptTypes.Boolean.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass NUMBER = new JavaScriptClass(this, JavaScriptTypes.Number, JavaScriptTypes.Root, null);
+  final CoreClass NUMBER = new CoreClass(JavaScriptTypes.Number.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass DATE = new JavaScriptClass(this, JavaScriptTypes.Date, JavaScriptTypes.Root, null);
+  final CoreClass DATE = new CoreClass(JavaScriptTypes.Date.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass REGEXP = new JavaScriptClass(this, JavaScriptTypes.RegExp, JavaScriptTypes.Root, null);
+  final CoreClass REGEXP = new CoreClass(JavaScriptTypes.RegExp.getName(), JavaScriptTypes.Root.getName(), this, null);
 
-  final JavaScriptClass BOOLEAN_OBJECT = new JavaScriptClass(this, JavaScriptTypes.BooleanObject, JavaScriptTypes.Object, null);
+  final CoreClass BOOLEAN_OBJECT = new CoreClass(JavaScriptTypes.BooleanObject.getName(), JavaScriptTypes.Object.getName(), this, null);
 
-  final JavaScriptClass NUMBER_OBJECT = new JavaScriptClass(this, JavaScriptTypes.NumberObject, JavaScriptTypes.Object, null);
+  final CoreClass NUMBER_OBJECT = new CoreClass(JavaScriptTypes.NumberObject.getName(), JavaScriptTypes.Object.getName(), this, null);
 
-  final JavaScriptClass DATE_OBJECT = new JavaScriptClass(this, JavaScriptTypes.DateObject, JavaScriptTypes.Object, null);
+  final CoreClass DATE_OBJECT = new CoreClass(JavaScriptTypes.DateObject.getName(), JavaScriptTypes.Object.getName(), this, null);
 
-  final JavaScriptClass REGEXP_OBJECT = new JavaScriptClass(this, JavaScriptTypes.RegExpObject, JavaScriptTypes.Object, null);
+  final CoreClass REGEXP_OBJECT = new CoreClass(JavaScriptTypes.RegExpObject.getName(), JavaScriptTypes.Object.getName(), this, null);
 
-  final JavaScriptClass STRING_OBJECT = new JavaScriptClass(this, JavaScriptTypes.StringObject, JavaScriptTypes.Object, null);
+  final CoreClass STRING_OBJECT = new CoreClass(JavaScriptTypes.StringObject.getName(), JavaScriptTypes.Object.getName(), this, null);
 
   @Override
   public Language getLanguage() {
@@ -1006,9 +829,8 @@ public class JavaScriptLoader extends CAstAbstractModuleLoader {
     bootstrapFileNames.add(prologueFileName);
   }
 
-  @SuppressWarnings("unchecked")
   @Override
-  protected TranslatorToCAst getTranslatorToCAst(final CAst ast, SourceModule module) {
+  protected TranslatorToCAst getTranslatorToCAst(final CAst ast, ModuleEntry module) {
     TranslatorToCAst translator = translatorFactory.make(ast, module);
     if(preprocessor != null)
       translator.addRewriter(preprocessor, true);
