@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.js.ssa;
 
 import com.ibm.wala.cast.ir.ssa.AstInstructionVisitor;
@@ -17,11 +17,7 @@ public interface JSInstructionVisitor extends AstInstructionVisitor {
   public void visitJavaScriptInvoke(JavaScriptInvoke instruction);
     
   public void visitTypeOf(JavaScriptTypeOfInstruction instruction);
-    
-  public void visitJavaScriptPropertyRead(JavaScriptPropertyRead instruction);
-  
-  public void visitJavaScriptPropertyWrite(JavaScriptPropertyWrite instruction);
-  
+      
   public void visitJavaScriptInstanceOf(JavaScriptInstanceOf instruction);
   
   public void visitWithRegion(JavaScriptWithRegion instruction);
