@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.js.translator;
 
 import java.util.Collection;
@@ -16,16 +16,17 @@ import java.util.Map;
 import java.util.Set;
 
 import com.ibm.wala.cast.ir.translator.AstTranslator;
-import com.ibm.wala.cast.js.loader.JSCallSiteReference;
 import com.ibm.wala.cast.js.loader.JavaScriptLoader;
 import com.ibm.wala.cast.js.ssa.JSInstructionFactory;
 import com.ibm.wala.cast.js.ssa.JavaScriptInstanceOf;
 import com.ibm.wala.cast.js.ssa.PrototypeLookup;
 import com.ibm.wala.cast.js.types.JavaScriptMethods;
 import com.ibm.wala.cast.js.types.JavaScriptTypes;
+import com.ibm.wala.cast.loader.DynamicCallSiteReference;
 import com.ibm.wala.cast.loader.AstMethod.DebuggingInformation;
 import com.ibm.wala.cast.tree.CAstEntity;
 import com.ibm.wala.cast.tree.CAstNode;
+import com.ibm.wala.cast.tree.CAstSourcePositionMap.Position;
 import com.ibm.wala.cast.tree.CAstSymbol;
 import com.ibm.wala.cast.tree.CAstType;
 import com.ibm.wala.cast.tree.impl.CAstSymbolImpl;
@@ -54,7 +55,7 @@ public class JSAstTranslator extends AstTranslator {
     super(loader);
   }
 
-  private boolean isPrologueScript(WalkContext context) {
+  private static boolean isPrologueScript(WalkContext context) {
     return JavaScriptLoader.bootstrapFileNames.contains( context.getModule().getName() );
   }
 
@@ -152,24 +153,24 @@ public class JSAstTranslator extends AstTranslator {
     if (f.getKind() == CAstEntity.SCRIPT_ENTITY)
       return f.getName();
     else
-      return parent.getName() + "/" + f.getName();
+      return parent.getName() + '/' + f.getName();
   }
 
   @Override
   protected void declareFunction(CAstEntity N, WalkContext context) {
     String fnName = composeEntityName(context, N);
     if (N.getKind() == CAstEntity.SCRIPT_ENTITY) {
-      ((JavaScriptLoader) loader).defineScriptType("L" + fnName, N.getPosition(), N, context);
+      ((JavaScriptLoader) loader).defineScriptType('L' + fnName, N.getPosition(), N, context);
     } else if (N.getKind() == CAstEntity.FUNCTION_ENTITY) {
-      ((JavaScriptLoader) loader).defineFunctionType("L" + fnName, N.getPosition(), N, context);
+      ((JavaScriptLoader) loader).defineFunctionType('L' + fnName, N.getPosition(), N, context);
     } else {
       Assertions.UNREACHABLE();
     }
   }
 
   @Override
-  protected void defineFunction(CAstEntity N, WalkContext definingContext, AbstractCFG cfg, SymbolTable symtab,
-      boolean hasCatchBlock, Map<IBasicBlock,TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation LI,
+  protected void defineFunction(CAstEntity N, WalkContext definingContext, AbstractCFG<SSAInstruction, ? extends IBasicBlock<SSAInstruction>> cfg, SymbolTable symtab,
+      boolean hasCatchBlock, Map<IBasicBlock<SSAInstruction>,TypeReference[]> caughtTypes, boolean hasMonitorOp, AstLexicalInformation LI,
       DebuggingInformation debugInfo) {
     if (DEBUG)
       System.err.println(("\n\nAdding code for " + N));
@@ -178,7 +179,7 @@ public class JSAstTranslator extends AstTranslator {
     if (DEBUG)
       System.err.println(cfg);
  
-    ((JavaScriptLoader) loader).defineCodeBodyCode("L" + fnName, cfg, symtab, hasCatchBlock, caughtTypes, hasMonitorOp, LI,
+    ((JavaScriptLoader) loader).defineCodeBodyCode('L' + fnName, cfg, symtab, hasCatchBlock, caughtTypes, hasMonitorOp, LI,
         debugInfo);
   }
 
@@ -196,7 +197,7 @@ public class JSAstTranslator extends AstTranslator {
 
     context.cfg().addInstruction(
         ((JSInstructionFactory) insts).Invoke(context.cfg().getCurrentInstruction(), receiver, result, arguments, exception, 
-            new JSCallSiteReference(ref, context.cfg().getCurrentInstruction())));
+            new DynamicCallSiteReference(ref, context.cfg().getCurrentInstruction())));
 
     context.cfg().addPreNode(call, context.getUnwindState());
 
@@ -221,12 +222,12 @@ public class JSAstTranslator extends AstTranslator {
 
   @Override
   protected void doMaterializeFunction(CAstNode n, WalkContext context, int result, int exception, CAstEntity fn) {
-    int nm = context.currentScope().getConstantValue("L" + composeEntityName(context, fn));
+    int nm = context.currentScope().getConstantValue('L' + composeEntityName(context, fn));
     // "Function" is the name we use to model the constructor of function values
     int tmp = super.doGlobalRead(n, context, "Function", JavaScriptTypes.Function);
     context.cfg().addInstruction(
       ((JSInstructionFactory)insts).Invoke(context.cfg().getCurrentInstruction(), tmp, result, new int[]{ nm }, exception,
-        new JSCallSiteReference(JavaScriptMethods.ctorReference, context.cfg().getCurrentInstruction())));
+        new DynamicCallSiteReference(JavaScriptMethods.ctorReference, context.cfg().getCurrentInstruction())));
   }
 
   @Override
@@ -318,66 +319,76 @@ public class JSAstTranslator extends AstTranslator {
   protected void doPrimitive(int resultVal, WalkContext context, CAstNode primitiveCall) {
     try {
       String name = (String) primitiveCall.getChild(0).getValue();
-      if (name.equals("GlobalNaN")) {
-	context.cfg().addInstruction(
-	    ((JSInstructionFactory)insts).AssignInstruction(context.cfg().getCurrentInstruction(), 
-	    resultVal, context.currentScope().getConstantValue(new Float(Float.NaN))));
-      } else if (name.equals("GlobalInfinity")) {
-        context.cfg().addInstruction(
-            ((JSInstructionFactory)insts).AssignInstruction(context.cfg().getCurrentInstruction(), 
-            resultVal, context.currentScope().getConstantValue(new Float(Float.POSITIVE_INFINITY))));
-      } else if (name.equals("MathE")) {
-        context.cfg().addInstruction(
-            ((JSInstructionFactory)insts).AssignInstruction(context.cfg().getCurrentInstruction(), 
-            resultVal, context.currentScope().getConstantValue(new Double(Math.E))));
-      } else if (name.equals("MathPI")) {
-        context.cfg().addInstruction(
-            ((JSInstructionFactory)insts).AssignInstruction(context.cfg().getCurrentInstruction(), 
-            resultVal, context.currentScope().getConstantValue(new Double(Math.PI))));
-      } else if (name.equals("MathSQRT1_2")) {
-        context.cfg().addInstruction(
-            ((JSInstructionFactory)insts).AssignInstruction(context.cfg().getCurrentInstruction(), 
-            resultVal, context.currentScope().getConstantValue(new Double(Math.sqrt(.5)))));
-      } else if (name.equals("MathSQRT2")) {
-        context.cfg().addInstruction(
-            ((JSInstructionFactory)insts).AssignInstruction(context.cfg().getCurrentInstruction(), 
-            resultVal, context.currentScope().getConstantValue(new Double(Math.sqrt(2)))));
-      } else if (name.equals("MathLN2")) {
-        context.cfg().addInstruction(
-            ((JSInstructionFactory)insts).AssignInstruction(context.cfg().getCurrentInstruction(), 
-            resultVal, context.currentScope().getConstantValue(new Double(Math.log(2)))));
-      } else if (name.equals("MathLN10")) {
-        context.cfg().addInstruction(
-            ((JSInstructionFactory)insts).AssignInstruction(context.cfg().getCurrentInstruction(), 
-            resultVal, context.currentScope().getConstantValue(new Double(Math.log(10)))));
-      } else if (name.equals("NewObject")) {
-        doNewObject(context, null, resultVal, "Object", null);
-
-      } else if (name.equals("NewArray")) {
-        doNewObject(context, null, resultVal, "Array", null);
-
-      } else if (name.equals("NewString")) {
-        doPrimitiveNew(context, resultVal, "String");
-
-      } else if (name.equals("NewNumber")) {
-        doPrimitiveNew(context, resultVal, "Number");
-
-      } else if (name.equals("NewRegExp")) {
-        doPrimitiveNew(context, resultVal, "RegExp");
-
-      } else if (name.equals("NewFunction")) {
-        doNewObject(context, null, resultVal, "Function", null);
-
-      } else if (name.equals("NewUndefined")) {
-        doNewObject(context, null, resultVal, "Undefined", null);
-
-      } else {
-	context.cfg().addInstruction(
-	    ((JSInstructionFactory)insts).AssignInstruction(context.cfg().getCurrentInstruction(), 
-            resultVal, context.currentScope().getConstantValue( null )));
+      switch (name) {
+        case "GlobalNaN":
+          context.cfg().addInstruction(
+                  ((JSInstructionFactory) insts).AssignInstruction(context.cfg().getCurrentInstruction(),
+                          resultVal, context.currentScope().getConstantValue(Float.valueOf(Float.NaN))));
+          break;
+        case "GlobalInfinity":
+          context.cfg().addInstruction(
+                  ((JSInstructionFactory) insts).AssignInstruction(context.cfg().getCurrentInstruction(),
+                          resultVal, context.currentScope().getConstantValue(Float.valueOf(Float.POSITIVE_INFINITY))));
+          break;
+        case "MathE":
+          context.cfg().addInstruction(
+                  ((JSInstructionFactory) insts).AssignInstruction(context.cfg().getCurrentInstruction(),
+                          resultVal, context.currentScope().getConstantValue(Double.valueOf(Math.E))));
+          break;
+        case "MathPI":
+          context.cfg().addInstruction(
+                  ((JSInstructionFactory) insts).AssignInstruction(context.cfg().getCurrentInstruction(),
+                          resultVal, context.currentScope().getConstantValue(Double.valueOf(Math.PI))));
+          break;
+        case "MathSQRT1_2":
+          context.cfg().addInstruction(
+                  ((JSInstructionFactory) insts).AssignInstruction(context.cfg().getCurrentInstruction(),
+                          resultVal, context.currentScope().getConstantValue(Double.valueOf(Math.sqrt(.5)))));
+          break;
+        case "MathSQRT2":
+          context.cfg().addInstruction(
+                  ((JSInstructionFactory) insts).AssignInstruction(context.cfg().getCurrentInstruction(),
+                          resultVal, context.currentScope().getConstantValue(Double.valueOf(Math.sqrt(2)))));
+          break;
+        case "MathLN2":
+          context.cfg().addInstruction(
+                  ((JSInstructionFactory) insts).AssignInstruction(context.cfg().getCurrentInstruction(),
+                          resultVal, context.currentScope().getConstantValue(Double.valueOf(Math.log(2)))));
+          break;
+        case "MathLN10":
+          context.cfg().addInstruction(
+                  ((JSInstructionFactory) insts).AssignInstruction(context.cfg().getCurrentInstruction(),
+                          resultVal, context.currentScope().getConstantValue(Double.valueOf(Math.log(10)))));
+          break;
+        case "NewObject":
+          doNewObject(context, null, resultVal, "Object", null);
+          break;
+        case "NewArray":
+          doNewObject(context, null, resultVal, "Array", null);
+          break;
+        case "NewString":
+          doPrimitiveNew(context, resultVal, "String");
+          break;
+        case "NewNumber":
+          doPrimitiveNew(context, resultVal, "Number");
+          break;
+        case "NewRegExp":
+          doPrimitiveNew(context, resultVal, "RegExp");
+          break;
+        case "NewFunction":
+          doNewObject(context, null, resultVal, "Function", null);
+          break;
+        case "NewUndefined":
+          doNewObject(context, null, resultVal, "Undefined", null);
+          break;
+        default:
+          context.cfg().addInstruction(
+                  ((JSInstructionFactory) insts).AssignInstruction(context.cfg().getCurrentInstruction(),
+                          resultVal, context.currentScope().getConstantValue(null)));
+          break;
       }
     } catch (ClassCastException e) {
-      throw new RuntimeException("Cannot translate primitive " + primitiveCall.getChild(0).getValue());
+      throw new RuntimeException("Cannot translate primitive " + primitiveCall.getChild(0).getValue(), e);
     }
   }
 
@@ -470,7 +481,7 @@ public class JSAstTranslator extends AstTranslator {
     }
 
     @Override
-    public Collection getSupertypes() {
+    public Collection<CAstType> getSupertypes() {
       return Collections.EMPTY_SET;
     }
   };
@@ -485,4 +496,17 @@ public class JSAstTranslator extends AstTranslator {
     return Any;
   }
 
+  @Override
+  protected Position[] getParameterPositions(CAstEntity e) {
+    if (e.getKind() == CAstEntity.SCRIPT_ENTITY) {
+      return new Position[0];
+    } else {
+      Position[] ps = new Position[ e.getArgumentCount() ];
+      for(int i = 2; i < e.getArgumentCount(); i++) {
+        ps[i] = e.getPosition(i-2);
+      }
+      return ps;
+    }
+  }
+
 }
