@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,12 +7,12 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.js.translator;
 
 import com.ibm.wala.cast.ir.translator.TranslatorToCAst;
 import com.ibm.wala.cast.tree.CAst;
-import com.ibm.wala.classLoader.SourceModule;
+import com.ibm.wala.classLoader.ModuleEntry;
 
 /**
  * Factory interface for creating translators that generate the CAst for some
@@ -21,6 +21,6 @@ import com.ibm.wala.classLoader.SourceModule;
  */
 public interface JavaScriptTranslatorFactory {
 
-  TranslatorToCAst make(CAst ast, SourceModule M);
+  TranslatorToCAst make(CAst ast, ModuleEntry M);
 
 }
