@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/bin/bash -eu
 
 if (uname | grep -i "cygwin"); then
 	# This should be the default for most of cases;
@@ -8,5 +8,9 @@ if (uname | grep -i "cygwin"); then
 	
 	cmd.exe /c "call \"$MSVC\\vcvarsall.bat\" $ARCH && make"
 else
-	make
+	make --quiet
 fi
+
+# Local variables:
+# eval: (smie-config-local '((8 :after "else" 2) (8 :elem basic 2)))
+# End:
