@@ -3,15 +3,10 @@
 
 #include "CAstWrapper.h"
 #include "Exceptions.h"
-#include "com_ibm_wala_cast_ir_translator_NativeBridge.h"
 
-extern "C" {
+bool CAstWrapper::initialized = false;
 
-JNIEXPORT void JNICALL 
-Java_com_ibm_wala_cast_ir_translator_NativeBridge_initialize(
-  JNIEnv *env, 
-  jclass cls)
-{
+void CAstWrapper::initialize(JNIEnv *env) {
   TRY(exp, env)
 
   jclass CAstNode = env->FindClass( "com/ibm/wala/cast/tree/CAstNode" );
@@ -38,4 +33,3 @@ Java_com_ibm_wala_cast_ir_translator_NativeBridge_initialize(
   CATCH()
 }
 
-}
