@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.ipa.callgraph;
 
 import com.ibm.wala.ipa.callgraph.propagation.AbstractPointerKey;
@@ -35,7 +35,7 @@ public class AstGlobalPointerKey extends AbstractPointerKey {
 
   @Override
   public String toString() {
-    return "[global: " + globalName + "]";
+    return "[global: " + globalName + ']';
   }
 }
     
