@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.ipa.callgraph;
 
 import java.io.UTFDataFormatException;
@@ -22,26 +22,29 @@ import com.ibm.wala.cast.ir.ssa.AstAssertInstruction;
 import com.ibm.wala.cast.ir.ssa.AstEchoInstruction;
 import com.ibm.wala.cast.ir.ssa.AstGlobalRead;
 import com.ibm.wala.cast.ir.ssa.AstGlobalWrite;
-import com.ibm.wala.cast.ir.ssa.AstIRFactory.AstIR;
+import com.ibm.wala.cast.ir.ssa.AstIRFactory;
 import com.ibm.wala.cast.ir.ssa.AstInstructionVisitor;
 import com.ibm.wala.cast.ir.ssa.AstIsDefinedInstruction;
-import com.ibm.wala.cast.ir.ssa.AstLexicalAccess;
 import com.ibm.wala.cast.ir.ssa.AstLexicalAccess.Access;
 import com.ibm.wala.cast.ir.ssa.AstLexicalRead;
 import com.ibm.wala.cast.ir.ssa.AstLexicalWrite;
+import com.ibm.wala.cast.ir.ssa.AstPropertyRead;
+import com.ibm.wala.cast.ir.ssa.AstPropertyWrite;
 import com.ibm.wala.cast.ir.ssa.EachElementGetInstruction;
 import com.ibm.wala.cast.ir.ssa.EachElementHasNextInstruction;
 import com.ibm.wala.cast.ir.translator.AstTranslator;
 import com.ibm.wala.cast.loader.AstMethod;
 import com.ibm.wala.cast.loader.AstMethod.LexicalInformation;
+import com.ibm.wala.cast.tree.CAstSourcePositionMap.Position;
 import com.ibm.wala.classLoader.IClass;
+import com.ibm.wala.classLoader.IMethod;
 import com.ibm.wala.fixpoint.AbstractOperator;
 import com.ibm.wala.fixpoint.IntSetVariable;
 import com.ibm.wala.fixpoint.UnaryOperator;
-import com.ibm.wala.ipa.callgraph.AnalysisCache;
 import com.ibm.wala.ipa.callgraph.AnalysisOptions;
 import com.ibm.wala.ipa.callgraph.CGNode;
 import com.ibm.wala.ipa.callgraph.CallGraph;
+import com.ibm.wala.ipa.callgraph.IAnalysisCacheView;
 import com.ibm.wala.ipa.callgraph.impl.ExplicitCallGraph;
 import com.ibm.wala.ipa.callgraph.propagation.AbstractFieldPointerKey;
 import com.ibm.wala.ipa.callgraph.propagation.HeapModel;
@@ -63,14 +66,15 @@ import com.ibm.wala.ipa.callgraph.propagation.cfa.DelegatingSSAContextInterprete
 import com.ibm.wala.ipa.cha.IClassHierarchy;
 import com.ibm.wala.ipa.modref.ArrayLengthKey;
 import com.ibm.wala.ssa.DefUse;
-import com.ibm.wala.ssa.IR;
+import com.ibm.wala.ssa.IRView;
+import com.ibm.wala.ssa.SSAInstruction;
 import com.ibm.wala.ssa.SSAPutInstruction;
 import com.ibm.wala.ssa.SymbolTable;
 import com.ibm.wala.util.collections.HashSetFactory;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.collections.Pair;
 import com.ibm.wala.util.debug.Assertions;
 import com.ibm.wala.util.intset.IntSet;
-import com.ibm.wala.util.intset.IntSetAction;
 import com.ibm.wala.util.intset.IntSetUtil;
 import com.ibm.wala.util.intset.MutableIntSet;
 import com.ibm.wala.util.intset.MutableMapping;
@@ -102,6 +106,7 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
    * each language can specify whether a particular field name should be stored
    * in object catalogs or not. By default, always return false.
    */
+  @SuppressWarnings("unused")
   protected boolean isUncataloguedField(IClass type, String fieldName) {
     return false;
   }
@@ -115,9 +120,9 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
   
   public abstract GlobalObjectKey getGlobalObject(Atom language);
 
-  protected AstSSAPropagationCallGraphBuilder(IClassHierarchy cha, AnalysisOptions options, AnalysisCache cache,
+  protected AstSSAPropagationCallGraphBuilder(IMethod fakeRootClass, AnalysisOptions options, IAnalysisCacheView cache,
       PointerKeyFactory pointerKeyFactory) {
-    super(cha, options, cache, pointerKeyFactory);
+    super(fakeRootClass, options, cache, pointerKeyFactory);
   }
 
   public SSAContextInterpreter makeDefaultContextInterpreters(SSAContextInterpreter appContextInterpreter, AnalysisOptions options,
@@ -195,6 +200,16 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
         super(analysis, lpk);
       }
 
+      @Override
+      public void visitPropertyRead(AstPropertyRead instruction) {
+
+      }
+
+      @Override
+      public void visitPropertyWrite(AstPropertyWrite instruction) {
+
+      }
+
       @Override
       public void visitAstLexicalRead(AstLexicalRead instruction) {
 
@@ -240,7 +255,7 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
 
       }
     }
-  };
+  }
 
   // /////////////////////////////////////////////////////////////////////////
   //
@@ -249,8 +264,8 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
   // /////////////////////////////////////////////////////////////////////////
 
   @Override
-  protected ExplicitCallGraph createEmptyCallGraph(IClassHierarchy cha, AnalysisOptions options) {
-    return new AstCallGraph(cha, options, getAnalysisCache());
+  protected ExplicitCallGraph createEmptyCallGraph(IMethod fakeRootClass, AnalysisOptions options) {
+    return new AstCallGraph(fakeRootClass, options, getAnalysisCache());
   }
 
   public static class AstInterestingVisitor extends InterestingVisitor implements AstInstructionVisitor {
@@ -259,6 +274,16 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
       super(vn);
     }
 
+    @Override
+    public void visitPropertyRead(AstPropertyRead instruction) {
+      bingo = true;
+    }
+
+    @Override
+    public void visitPropertyWrite(AstPropertyWrite instruction) {
+      bingo = true;
+    }
+
     @Override
     public void visitAstLexicalRead(AstLexicalRead instruction) {
       bingo = true;
@@ -314,7 +339,7 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
   public boolean hasNoInterestingUses(CGNode node, int vn, DefUse du) {
     if (node.getMethod() instanceof AstMethod) {
       // uses in nested functions are interesting
-      IntSet uses = ((AstIR) node.getIR()).lexicalInfo().getAllExposedUses();
+      IntSet uses = ((AstIRFactory.AstIR) node.getIR()).lexicalInfo().getAllExposedUses();
       if (uses.contains(vn)) {
         return false;
       }
@@ -357,8 +382,8 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
       return ((AstPointerKeyFactory) getBuilder().getPointerKeyFactory()).getPointerKeysForReflectedFieldWrite(I, F);
     }
 
-    private void visitLexical(AstLexicalAccess instruction, final LexicalOperator op) {
-      op.doLexicalPointerKeys(false);
+    private static void visitLexical(final LexicalOperator op) {
+      op.doLexicalPointerKeys();
       // I have no idea what the code below does, but commenting it out doesn't
       // break any regression tests. --MS
       // if (! checkLexicalInstruction(instruction)) {
@@ -366,26 +391,56 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
       // }
     }
 
+    @Override
+    public void visitPropertyRead(AstPropertyRead instruction) {
+      if (AstSSAPropagationCallGraphBuilder.DEBUG_PROPERTIES) {
+        Position instructionPosition = getInstructionPosition(instruction);
+        if (instructionPosition != null) {
+          System.err.println("processing read instruction " + instruction + ", position " + instructionPosition);
+        }
+      }
+      newFieldRead(node, instruction.getUse(0), instruction.getUse(1), instruction.getDef(0));
+    }
+
+    private Position getInstructionPosition(SSAInstruction instruction) {
+      IMethod method = node.getMethod();
+      if (method instanceof AstMethod) {
+        return ((AstMethod) method).getSourcePosition(instruction.iindex);
+      }
+      return null;
+    }
+
+    @Override
+    public void visitPropertyWrite(AstPropertyWrite instruction) {
+      if (AstSSAPropagationCallGraphBuilder.DEBUG_PROPERTIES) {
+        Position instructionPosition = getInstructionPosition(instruction);
+        if (instructionPosition != null) {
+          System.err.println("processing write instruction " + instruction + ", position " + instructionPosition);
+        }
+      }
+      newFieldWrite(node, instruction.getUse(0), instruction.getUse(1), instruction.getUse(2));
+    }
 
 
     @Override
     public void visitAstLexicalRead(AstLexicalRead instruction) {
-      visitLexical(instruction, new LexicalOperator((AstCGNode) node, instruction.getAccesses(), true) {
+      visitLexical(new LexicalOperator((AstCGNode) node, instruction.getAccesses(), true) {
         @Override
         protected void action(PointerKey lexicalKey, int vn) {
           PointerKey lval = getPointerKeyForLocal(vn);
           if (lexicalKey instanceof LocalPointerKey) {
             CGNode lnode = ((LocalPointerKey) lexicalKey).getNode();
             int lvn = ((LocalPointerKey) lexicalKey).getValueNumber();
-            IR lir = getBuilder().getCFAContextInterpreter().getIR(lnode);
+            IRView lir = getBuilder().getCFAContextInterpreter().getIRView(lnode);
             SymbolTable lsymtab = lir.getSymbolTable();
-            DefUse ldu = getAnalysisCache().getSSACache().findOrCreateDU(lir, lnode.getContext());
+            DefUse ldu = getBuilder().getCFAContextInterpreter().getDU(lnode);
+            // DefUse ldu = getAnalysisCache().getDefUse(lir);
             if (contentsAreInvariant(lsymtab, ldu, lvn)) {
               InstanceKey[] ik = getInvariantContents(lsymtab, ldu, lnode, lvn);
               system.recordImplicitPointsToSet(lexicalKey);
-              for (int i = 0; i < ik.length; i++) {
-                system.findOrCreateIndexForInstanceKey(ik[i]);
-                system.newConstraint(lval, ik[i]);
+              for (InstanceKey element : ik) {
+                system.findOrCreateIndexForInstanceKey(element);
+                system.newConstraint(lval, element);
               }
 
               return;
@@ -399,16 +454,16 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
 
     @Override
     public void visitAstLexicalWrite(AstLexicalWrite instruction) {
-      visitLexical(instruction, new LexicalOperator((AstCGNode) node, instruction.getAccesses(), false) {
+      visitLexical(new LexicalOperator((AstCGNode) node, instruction.getAccesses(), false) {
         @Override
         protected void action(PointerKey lexicalKey, int vn) {
           PointerKey rval = getPointerKeyForLocal(vn);
           if (contentsAreInvariant(symbolTable, du, vn)) {
             InstanceKey[] ik = getInvariantContents(vn);
             system.recordImplicitPointsToSet(rval);
-            for (int i = 0; i < ik.length; i++) {
-              system.findOrCreateIndexForInstanceKey(ik[i]);
-              system.newConstraint(lexicalKey, ik[i]);
+            for (InstanceKey element : ik) {
+              system.findOrCreateIndexForInstanceKey(element);
+              system.newConstraint(lexicalKey, element);
             }
           } else {
             system.newConstraint(lexicalKey, assignOperator, rval);
@@ -470,17 +525,14 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
         system.newSideEffect(new UnaryOperator<PointsToSetVariable>() {
           @Override
           public byte evaluate(PointsToSetVariable lhs, PointsToSetVariable rhs) {
-            final IntSetVariable objects = rhs;
+            final IntSetVariable<?> objects = rhs;
             if (objects.getValue() != null) {
-              objects.getValue().foreach(new IntSetAction() {
-                @Override
-                public void act(int optr) {
-                  InstanceKey object = system.getInstanceKey(optr);
-                  if (!getBuilder().isUncataloguedField(object.getConcreteType(), hack)) {
-                    PointerKey cat = getPointerKeyForObjectCatalog(object);
-                    if (cat != null) {
-                      system.newConstraint(cat, fieldNameKeys[0]);
-                    }
+              objects.getValue().foreach(optr -> {
+                InstanceKey object = system.getInstanceKey(optr);
+                if (!getBuilder().isUncataloguedField(object.getConcreteType(), hack)) {
+                  PointerKey cat = getPointerKeyForObjectCatalog(object);
+                  if (cat != null) {
+                    system.newConstraint(cat, fieldNameKeys[0]);
                   }
                 }
               });
@@ -526,8 +578,8 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
 
       if (contentsAreInvariant(symbolTable, du, rval)) {
         InstanceKey objects[] = getInvariantContents(rval);
-        for (int i = 0; i < objects.length; i++) {
-          PointerKey catalog = getPointerKeyForObjectCatalog(objects[i]);
+        for (InstanceKey object : objects) {
+          PointerKey catalog = getPointerKeyForObjectCatalog(object);
           system.newConstraint(lk, assignOperator, catalog);
         }
       }
@@ -536,16 +588,13 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
         system.newSideEffect(new UnaryOperator<PointsToSetVariable>() {
           @Override
           public byte evaluate(PointsToSetVariable lhs, PointsToSetVariable rhs) {
-            final IntSetVariable objects = rhs;
+            final IntSetVariable<?> objects = rhs;
             if (objects.getValue() != null) {
-              objects.getValue().foreach(new IntSetAction() {
-                @Override
-                public void act(int optr) {
-                  InstanceKey object = system.getInstanceKey(optr);
-                  PointerKey objCatalog = getPointerKeyForObjectCatalog(object);
-                  if (objCatalog != null) {
-                    system.newConstraint(lk, assignOperator, objCatalog);
-                  }
+              objects.getValue().foreach(optr -> {
+                InstanceKey object = system.getInstanceKey(optr);
+                PointerKey objCatalog = getPointerKeyForObjectCatalog(object);
+                if (objCatalog != null) {
+                  system.newConstraint(lk, assignOperator, objCatalog);
                 }
               });
             }
@@ -612,16 +661,16 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
        * perform the necessary {@link #action(PointerKey, int)}s for the
        * accesses. For each access, we determine the possible {@link CGNode}s
        * corresponding to its definer (see
-       * {@link AstConstraintVisitor#getLexicalDefiners(CGNode, String)). Handle
+       * {@link AstConstraintVisitor#getLexicalDefiners(CGNode, Pair)}). Handle
        * using
        * {@link AstConstraintVisitor#handleRootLexicalReference(String, String, CGNode)}
        * .
        */
-      private void doLexicalPointerKeys(boolean funargsOnly) {
-        for (int i = 0; i < accesses.length; i++) {
-          final String name = accesses[i].variableName;
-          final String definer = accesses[i].variableDefiner;
-          final int vn = accesses[i].valueNumber;
+      private void doLexicalPointerKeys() {
+        for (Access accesse : accesses) {
+          final String name = accesse.variableName;
+          final String definer = accesse.variableDefiner;
+          final int vn = accesse.valueNumber;
 
           if (AstTranslator.DEBUG_LEXICAL)
             System.err.println(("looking up lexical parent " + definer));
@@ -639,7 +688,7 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
 
       @Override
       public byte evaluate(PointsToSetVariable lhs, PointsToSetVariable rhs) {
-        doLexicalPointerKeys(true);
+        doLexicalPointerKeys();
         return NOT_CHANGED;
       }
 
@@ -700,15 +749,15 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
         final Set<CGNode> result = HashSetFactory.make();
         PointerKey F = getBuilder().getPointerKeyForLocal(opNode, 1);
 
-        IR ir = getBuilder().getCFAContextInterpreter().getIR(opNode);
+        IRView ir = getBuilder().getCFAContextInterpreter().getIRView(opNode);
         SymbolTable symtab = ir.getSymbolTable();
         DefUse du = getBuilder().getCFAContextInterpreter().getDU(opNode);
         if (contentsAreInvariant(symtab, du, 1)) {
           system.recordImplicitPointsToSet(F);
           final InstanceKey[] functionKeys = getInvariantContents(symtab, du, opNode, 1);
-          for (int f = 0; f < functionKeys.length; f++) {
-            system.findOrCreateIndexForInstanceKey(functionKeys[f]);
-            ScopeMappingInstanceKey K = (ScopeMappingInstanceKey) functionKeys[f];
+          for (InstanceKey functionKey : functionKeys) {
+            system.findOrCreateIndexForInstanceKey(functionKey);
+            ScopeMappingInstanceKey K = (ScopeMappingInstanceKey) functionKey;
             Iterator<CGNode> x = K.getFunargNodes(definer);
             while (x.hasNext()) {
               result.add(x.next());
@@ -717,19 +766,16 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
         } else {
           PointsToSetVariable FV = system.findOrCreatePointsToSet(F);
           if (FV.getValue() != null) {
-            FV.getValue().foreach(new IntSetAction() {
-              @Override
-              public void act(int ptr) {
-                InstanceKey iKey = system.getInstanceKey(ptr);
-                if (iKey instanceof ScopeMappingInstanceKey) {
-                  ScopeMappingInstanceKey K = (ScopeMappingInstanceKey) iKey;
-                  Iterator<CGNode> x = K.getFunargNodes(definer);
-                  while (x.hasNext()) {
-                    result.add(x.next());
-                  }
-                } else {
-                  Assertions.UNREACHABLE("unexpected instance key " + iKey);
+            FV.getValue().foreach(ptr -> {
+              InstanceKey iKey = system.getInstanceKey(ptr);
+              if (iKey instanceof ScopeMappingInstanceKey) {
+                ScopeMappingInstanceKey K = (ScopeMappingInstanceKey) iKey;
+                Iterator<CGNode> x = K.getFunargNodes(definer);
+                while (x.hasNext()) {
+                  result.add(x.next());
                 }
+              } else {
+                //Assertions.UNREACHABLE("unexpected instance key " + iKey);
               }
             });
           }
@@ -739,13 +785,6 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
       }
     }
 
-    private boolean isEqual(Object a, Object b) {
-      if (a == null)
-        return b == null;
-      else
-        return a.equals(b);
-    }
-
     private Set<PointerKey> discoveredUpwardFunargs = HashSetFactory.make();
 
     /**
@@ -755,13 +794,13 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
     private void addUpwardFunargConstraints(PointerKey lhs, String name, String definer, CGNode definingNode) {
       discoveredUpwardFunargs.add(lhs);
 
-      LexicalInformation LI = ((AstIR) definingNode.getIR()).lexicalInfo();
-      Pair[] names = LI.getExposedNames();
+      LexicalInformation LI = ((AstIRFactory.AstIR) definingNode.getIR()).lexicalInfo();
+      Pair<String, String>[] names = LI.getExposedNames();
       for (int i = 0; i < names.length; i++) {
         if (name.equals(names[i].fst) && definer.equals(names[i].snd)) {
           int vn = LI.getExitExposedUses()[i];
           if (vn > 0) {
-            IR ir = getBuilder().getCFAContextInterpreter().getIR(definingNode);
+            IRView ir = getBuilder().getCFAContextInterpreter().getIRView(definingNode);
             DefUse du = getBuilder().getCFAContextInterpreter().getDU(definingNode);
             SymbolTable st = ir.getSymbolTable();
 
@@ -770,9 +809,9 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
             if (contentsAreInvariant(st, du, vn)) {
               system.recordImplicitPointsToSet(rhs);
               final InstanceKey[] objs = getInvariantContents(st, du, definingNode, vn);
-              for (int f = 0; f < objs.length; f++) {
-                system.findOrCreateIndexForInstanceKey(objs[f]);
-                system.newConstraint(lhs, objs[f]);
+              for (InstanceKey obj : objs) {
+                system.findOrCreateIndexForInstanceKey(obj);
+                system.newConstraint(lhs, obj);
               }
             } else {
               system.newConstraint(lhs, assignOperator, rhs);
@@ -821,7 +860,7 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
 
           @Override
           public String toString() {
-            return "[upward:" + getName() + ":" + definingNode + "]";
+            return "[upward:" + getName() + ':' + definingNode + ']';
           }
         }
 
@@ -851,7 +890,7 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
 
     private void newFieldOperation(CGNode opNode, final int objVn, final int fieldsVn, final boolean isLoadOperation,
         final ReflectedFieldAction action) {
-      IR ir = getBuilder().getCFAContextInterpreter().getIR(opNode);
+      IRView ir = getBuilder().getCFAContextInterpreter().getIRView(opNode);
       SymbolTable symtab = ir.getSymbolTable();
       DefUse du = getBuilder().getCFAContextInterpreter().getDU(opNode);
       PointerKey objKey = getBuilder().getPointerKeyForLocal(opNode, objVn);
@@ -860,15 +899,15 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
       // log field access
       if (DEBUG_PROPERTIES) {
         if (isLoadOperation)
-          System.err.print(("adding read of " + objKey + "." + fieldKey + ":"));
+          System.err.print(("adding read of " + objKey + '.' + fieldKey + ':'));
         else
-          System.err.print(("adding write of " + objKey + "." + fieldKey + ":"));
+          System.err.print(("adding write of " + objKey + '.' + fieldKey + ':'));
 
         if (contentsAreInvariant(symtab, du, objVn)) {
           System.err.print(" constant obj:");
           InstanceKey[] x = getInvariantContents(symtab, du, opNode, objVn);
-          for (int i = 0; i < x.length; i++) {
-            System.err.print((x[i].toString() + " "));
+          for (InstanceKey element : x) {
+            System.err.print((element.toString() + ' '));
           }
         } else {
           System.err.print((" obj:" + system.findOrCreatePointsToSet(objKey)));
@@ -877,8 +916,8 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
         if (contentsAreInvariant(symtab, du, fieldsVn)) {
           System.err.print(" constant prop:");
           InstanceKey[] x = getInvariantContents(symtab, du, opNode, fieldsVn);
-          for (int i = 0; i < x.length; i++) {
-            System.err.print((x[i].toString() + " "));
+          for (InstanceKey element : x) {
+            System.err.print((element.toString() + ' '));
           }
         } else {
           System.err.print((" props:" + system.findOrCreatePointsToSet(fieldKey)));
@@ -890,14 +929,14 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
       // make sure instance keys get mapped for PointerAnalysisImpl
       if (contentsAreInvariant(symtab, du, objVn)) {
         InstanceKey[] x = getInvariantContents(symtab, du, opNode, objVn);
-        for (int i = 0; i < x.length; i++) {
-          system.findOrCreateIndexForInstanceKey(x[i]);
+        for (InstanceKey element : x) {
+          system.findOrCreateIndexForInstanceKey(element);
         }
       }
       if (contentsAreInvariant(symtab, du, fieldsVn)) {
         InstanceKey[] x = getInvariantContents(symtab, du, opNode, fieldsVn);
-        for (int i = 0; i < x.length; i++) {
-          system.findOrCreateIndexForInstanceKey(x[i]);
+        for (InstanceKey element : x) {
+          system.findOrCreateIndexForInstanceKey(element);
         }
       }
 
@@ -935,7 +974,7 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
 
     protected void newFieldOperationFieldConstant(CGNode opNode, final boolean isLoadOperation, final ReflectedFieldAction action,
         final int objVn, final InstanceKey[] fieldsKeys) {
-      IR ir = getBuilder().getCFAContextInterpreter().getIR(opNode);
+      IRView ir = getBuilder().getCFAContextInterpreter().getIRView(opNode);
       SymbolTable symtab = ir.getSymbolTable();
       DefUse du = getBuilder().getCFAContextInterpreter().getDU(opNode);
       PointerKey objKey = getBuilder().getPointerKeyForLocal(opNode, objVn);
@@ -960,37 +999,31 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
 
         @Override
         public byte evaluate(PointsToSetVariable lhs, final PointsToSetVariable[] rhs) {
-          final IntSetVariable receivers = rhs[0];
-          final IntSetVariable fields = rhs[1];
+          final IntSetVariable<?> receivers = rhs[0];
+          final IntSetVariable<?> fields = rhs[1];
           if (receivers.getValue() != null && fields.getValue() != null) {
-            receivers.getValue().foreach(new IntSetAction() {
-              @Override
-              public void act(final int rptr) {
-                final InstanceKey receiver = system.getInstanceKey(rptr);
+            receivers.getValue().foreach(rptr -> {
+              final InstanceKey receiver = system.getInstanceKey(rptr);
 
-                if (!isLoadOperation) {
-                  PointerKey cat = getPointerKeyForObjectCatalog(receiver);
-                  if (cat != null) {
-                    system.newConstraint(cat, assignOperator, fieldKey);
+              if (!isLoadOperation) {
+                PointerKey cat = getPointerKeyForObjectCatalog(receiver);
+                if (cat != null) {
+                  system.newConstraint(cat, assignOperator, fieldKey);
+                }
+              }
+
+              fields.getValue().foreach(fptr -> {
+                if (!doneField.contains(fptr) || !doneReceiver.contains(rptr)) {
+                  InstanceKey field = system.getInstanceKey(fptr);
+                  for (PointerKey pkey : Iterator2Iterable.make(isLoadOperation ? getPointerKeysForReflectedFieldRead(receiver, field)
+                      : getPointerKeysForReflectedFieldWrite(receiver, field))) {
+                    AbstractFieldPointerKey key = (AbstractFieldPointerKey) pkey;
+                    if (DEBUG_PROPERTIES)
+                      action.dump(key, false, false);
+                    action.action(key);
                   }
                 }
-
-                fields.getValue().foreach(new IntSetAction() {
-                  @Override
-                  public void act(int fptr) {
-                    if (!doneField.contains(fptr) || !doneReceiver.contains(rptr)) {
-                      InstanceKey field = system.getInstanceKey(fptr);
-                      for (Iterator keys = isLoadOperation ? getPointerKeysForReflectedFieldRead(receiver, field)
-                          : getPointerKeysForReflectedFieldWrite(receiver, field); keys.hasNext();) {
-                        AbstractFieldPointerKey key = (AbstractFieldPointerKey) keys.next();
-                        if (DEBUG_PROPERTIES)
-                          action.dump(key, false, false);
-                        action.action(key);
-                      }
-                    }
-                  }
-                });
-              }
+              });
             });
             doneReceiver.addAll(receivers.getValue());
             doneField.addAll(fields.getValue());
@@ -1021,31 +1054,28 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
       system.newSideEffect(new UnaryOperator<PointsToSetVariable>() {
         @Override
         public byte evaluate(PointsToSetVariable lhs, PointsToSetVariable rhs) {
-          final IntSetVariable objects = rhs;
+          final IntSetVariable<?> objects = rhs;
           if (objects.getValue() != null) {
-            objects.getValue().foreach(new IntSetAction() {
-              @Override
-              public void act(int optr) {
-                InstanceKey object = system.getInstanceKey(optr);
-                PointerKey objCatalog = getPointerKeyForObjectCatalog(object);
-                for (int f = 0; f < fieldsKeys.length; f++) {
-                  if (isLoadOperation) {
-                    for (Iterator keys = getPointerKeysForReflectedFieldRead(object, fieldsKeys[f]); keys.hasNext();) {
-                      AbstractFieldPointerKey key = (AbstractFieldPointerKey) keys.next();
-                      if (DEBUG_PROPERTIES)
-                        action.dump(key, true, false);
-                      action.action(key);
-                    }
-                  } else {
-                    if (objCatalog != null) {
-                      system.newConstraint(objCatalog, fieldsKeys[f]);
-                    }
-                    for (Iterator keys = getPointerKeysForReflectedFieldWrite(object, fieldsKeys[f]); keys.hasNext();) {
-                      AbstractFieldPointerKey key = (AbstractFieldPointerKey) keys.next();
-                      if (DEBUG_PROPERTIES)
-                        action.dump(key, true, false);
-                      action.action(key);
-                    }
+            objects.getValue().foreach(optr -> {
+              InstanceKey object = system.getInstanceKey(optr);
+              PointerKey objCatalog = getPointerKeyForObjectCatalog(object);
+              for (InstanceKey fieldsKey : fieldsKeys) {
+                if (isLoadOperation) {
+                  for (PointerKey pkey : Iterator2Iterable.make(getPointerKeysForReflectedFieldRead(object, fieldsKey))) {
+                    AbstractFieldPointerKey key = (AbstractFieldPointerKey) pkey;
+                    if (DEBUG_PROPERTIES)
+                      action.dump(key, true, false);
+                    action.action(key);
+                  }
+                } else {
+                  if (objCatalog != null) {
+                    system.newConstraint(objCatalog, fieldsKey);
+                  }
+                  for (PointerKey pkey : Iterator2Iterable.make(getPointerKeysForReflectedFieldWrite(object, fieldsKey))) {
+                    AbstractFieldPointerKey key = (AbstractFieldPointerKey) pkey;
+                    if (DEBUG_PROPERTIES)
+                      action.dump(key, true, false);
+                    action.action(key);
                   }
                 }
               }
@@ -1074,8 +1104,8 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
     protected void newFieldOperationOnlyObjectConstant(final boolean isLoadOperation, final ReflectedFieldAction action,
         final PointerKey fieldKey, final InstanceKey[] objKeys) {
       if (!isLoadOperation) {
-        for (int o = 0; o < objKeys.length; o++) {
-          PointerKey objCatalog = getPointerKeyForObjectCatalog(objKeys[o]);
+        for (InstanceKey objKey : objKeys) {
+          PointerKey objCatalog = getPointerKeyForObjectCatalog(objKey);
           if (objCatalog != null) {
             system.newConstraint(objCatalog, assignOperator, fieldKey);
           }
@@ -1085,20 +1115,17 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
       system.newSideEffect(new UnaryOperator<PointsToSetVariable>() {
         @Override
         public byte evaluate(PointsToSetVariable lhs, PointsToSetVariable rhs) {
-          final IntSetVariable fields = rhs;
+          final IntSetVariable<?> fields = rhs;
           if (fields.getValue() != null) {
-            fields.getValue().foreach(new IntSetAction() {
-              @Override
-              public void act(int fptr) {
-                InstanceKey field = system.getInstanceKey(fptr);
-                for (int o = 0; o < objKeys.length; o++) {
-                  for (Iterator keys = isLoadOperation ? getPointerKeysForReflectedFieldRead(objKeys[o], field)
-                      : getPointerKeysForReflectedFieldWrite(objKeys[o], field); keys.hasNext();) {
-                    AbstractFieldPointerKey key = (AbstractFieldPointerKey) keys.next();
-                    if (DEBUG_PROPERTIES)
-                      action.dump(key, false, true);
-                    action.action(key);
-                  }
+            fields.getValue().foreach(fptr -> {
+              InstanceKey field = system.getInstanceKey(fptr);
+              for (InstanceKey objKey : objKeys) {
+                for (PointerKey pkey : Iterator2Iterable.make(isLoadOperation ? getPointerKeysForReflectedFieldRead(objKey, field)
+                    : getPointerKeysForReflectedFieldWrite(objKey, field))) {
+                  AbstractFieldPointerKey key = (AbstractFieldPointerKey) pkey;
+                  if (DEBUG_PROPERTIES)
+                    action.dump(key, false, true);
+                  action.action(key);
                 }
               }
             });
@@ -1125,22 +1152,22 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
 
     protected void newFieldOperationObjectAndFieldConstant(final boolean isLoadOperation, final ReflectedFieldAction action,
         final InstanceKey[] objKeys, InstanceKey[] fieldsKeys) {
-      for (int o = 0; o < objKeys.length; o++) {
-        PointerKey objCatalog = getPointerKeyForObjectCatalog(objKeys[o]);
-        for (int f = 0; f < fieldsKeys.length; f++) {
+      for (InstanceKey objKey : objKeys) {
+        PointerKey objCatalog = getPointerKeyForObjectCatalog(objKey);
+        for (InstanceKey fieldsKey : fieldsKeys) {
           if (isLoadOperation) {
-            for (Iterator keys = getPointerKeysForReflectedFieldRead(objKeys[o], fieldsKeys[f]); keys.hasNext();) {
-              AbstractFieldPointerKey key = (AbstractFieldPointerKey) keys.next();
+            for (PointerKey pkey : Iterator2Iterable.make(getPointerKeysForReflectedFieldRead(objKey, fieldsKey))) {
+              AbstractFieldPointerKey key = (AbstractFieldPointerKey) pkey;
               if (DEBUG_PROPERTIES)
                 action.dump(key, true, true);
               action.action(key);
             }
           } else {
             if (objCatalog != null) {
-              system.newConstraint(objCatalog, fieldsKeys[f]);
+              system.newConstraint(objCatalog, fieldsKey);
             }
-            for (Iterator keys = getPointerKeysForReflectedFieldWrite(objKeys[o], fieldsKeys[f]); keys.hasNext();) {
-              AbstractFieldPointerKey key = (AbstractFieldPointerKey) keys.next();
+            for (PointerKey pkey : Iterator2Iterable.make(getPointerKeysForReflectedFieldWrite(objKey, fieldsKey))) {
+              AbstractFieldPointerKey key = (AbstractFieldPointerKey) pkey;
               if (DEBUG_PROPERTIES)
                 action.dump(key, true, true);
               action.action(key);
@@ -1151,7 +1178,7 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
     }
 
     public void newFieldWrite(CGNode opNode, int objVn, int fieldsVn, int rhsVn) {
-      IR ir = getBuilder().getCFAContextInterpreter().getIR(opNode);
+      IRView ir = getBuilder().getCFAContextInterpreter().getIRView(opNode);
       SymbolTable symtab = ir.getSymbolTable();
       DefUse du = getBuilder().getCFAContextInterpreter().getDU(opNode);
       PointerKey rhsKey = getBuilder().getPointerKeyForLocal(opNode, rhsVn);
@@ -1172,18 +1199,18 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
 
       @Override
       public void dump(AbstractFieldPointerKey fieldKey, boolean constObj, boolean constProp) {
-        System.err.println(("writing fixed rvals to " + fieldKey + " " + constObj + ", " + constProp));
-        for (int i = 0; i < rhsFixedValues.length; i++) {
-          System.err.println(("writing " + rhsFixedValues[i]));
+        System.err.println(("writing fixed rvals to " + fieldKey + ' ' + constObj + ", " + constProp));
+        for (InstanceKey rhsFixedValue : rhsFixedValues) {
+          System.err.println(("writing " + rhsFixedValue));
         }
       }
 
       @Override
       public void action(AbstractFieldPointerKey fieldKey) {
         if (!representsNullType(fieldKey.getInstanceKey())) {
-          for (int i = 0; i < rhsFixedValues.length; i++) {
-            system.findOrCreateIndexForInstanceKey(rhsFixedValues[i]);
-            system.newConstraint(fieldKey, rhsFixedValues[i]);
+          for (InstanceKey rhsFixedValue : rhsFixedValues) {
+            system.findOrCreateIndexForInstanceKey(rhsFixedValue);
+            system.newConstraint(fieldKey, rhsFixedValue);
           }
         }
       }
@@ -1206,7 +1233,7 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
 
       @Override
       public void dump(AbstractFieldPointerKey fieldKey, boolean constObj, boolean constProp) {
-        System.err.println(("write " + rhs + " to " + fieldKey + " " + constObj + ", " + constProp));
+        System.err.println(("write " + rhs + " to " + fieldKey + ' ' + constObj + ", " + constProp));
       }
 
       @Override
@@ -1215,7 +1242,7 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
           system.newConstraint(fieldKey, assignOperator, rhs);
         }
       }
-    };
+    }
 
     public void newFieldWrite(CGNode opNode, int objVn, int fieldsVn, final PointerKey rhs) {
       newFieldOperation(opNode, objVn, fieldsVn, false, new NormalWriter(rhs));
@@ -1233,7 +1260,7 @@ public abstract class AstSSAPropagationCallGraphBuilder extends SSAPropagationCa
       newFieldOperation(opNode, objVn, fieldsVn, true, new ReflectedFieldAction() {
         @Override
         public void dump(AbstractFieldPointerKey fieldKey, boolean constObj, boolean constProp) {
-          System.err.println(("read " + lhs + " from " + fieldKey + " " + constObj + ", " + constProp));
+          System.err.println(("read " + lhs + " from " + fieldKey + ' ' + constObj + ", " + constProp));
         }
 
         @Override
