@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.cast.ipa.callgraph;
 
 import java.util.Iterator;
@@ -23,8 +23,9 @@ import com.ibm.wala.util.collections.Pair;
 /**
  * Represents the JavaScript global object.  
  * 
- * @see JSSSAPropagationCallGraphBuilder
+ * @see com.ibm.wala.cast.js.ipa.callgraph.JSSSAPropagationCallGraphBuilder
  */
+@SuppressWarnings({"javadoc", "JavadocReference"})
 public class GlobalObjectKey implements InstanceKey {
 
   private final IClass concreteType;
