@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 package com.ibm.wala.cast.ir.ssa;
 
 import com.ibm.wala.ssa.SSAInstruction;
@@ -17,6 +17,16 @@ public abstract class AstAbstractInstructionVisitor
     implements AstInstructionVisitor 
 {
 
+  @Override
+  public void visitPropertyRead(AstPropertyRead instruction) {
+    
+  }
+
+  @Override
+  public void visitPropertyWrite(AstPropertyWrite instruction) {
+    
+  }
+
   @Override
   public void visitAstLexicalRead(AstLexicalRead instruction) {
 
