@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2014 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 
 /**
  * 
@@ -19,7 +19,7 @@ import java.util.Collection;
 import com.ibm.wala.cast.tree.CAstQualifier;
 import com.ibm.wala.cast.tree.CAstType;
 
-public class AbstractClassEntity extends AbstractDataEntity {
+public abstract class AbstractClassEntity extends AbstractDataEntity {
   private final CAstType.Class type;
 
   public AbstractClassEntity(CAstType.Class type) {
@@ -50,4 +50,4 @@ public class AbstractClassEntity extends AbstractDataEntity {
   public Collection<CAstQualifier> getQualifiers() {
     return type.getQualifiers();
   }
-}
\ No newline at end of file
+}
