@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2014 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 
 /**
  * 
@@ -21,7 +21,7 @@ import java.util.Set;
 import com.ibm.wala.cast.tree.CAstQualifier;
 import com.ibm.wala.cast.tree.CAstType;
 
-public class AbstractGlobalEntity extends AbstractDataEntity {
+public abstract class AbstractGlobalEntity extends AbstractDataEntity {
   private final String name;
 
   private final Set<CAstQualifier> modifiers;
@@ -31,7 +31,7 @@ public class AbstractGlobalEntity extends AbstractDataEntity {
   public AbstractGlobalEntity(String name, CAstType type, Set<CAstQualifier> modifiers) {
     this.name = name;
     this.type = type;
-    this.modifiers = new HashSet<CAstQualifier>();
+    this.modifiers = new HashSet<>();
     if (modifiers != null) {
       this.modifiers.addAll(modifiers);
     }
@@ -42,7 +42,7 @@ public class AbstractGlobalEntity extends AbstractDataEntity {
     if (type == null) {
       return "global " + name;
     } else {
-      return "global " + name + ":" + type;
+      return "global " + name + ':' + type;
     }
   }
 
