@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 /*
  * Created on Aug 31, 2005
  */
@@ -15,13 +15,13 @@ package com.ibm.wala.cast.tree;
 
 import java.util.Iterator;
 
-public interface CAstTypeDictionary/*<ASTType>*/ extends Iterable {
+public interface CAstTypeDictionary/*<ASTType>*/ extends Iterable<CAstType> {
 
   CAstType getCAstTypeFor(Object/*ASTType*/ type);
 
   CAstReference resolveReference(CAstReference ref);
 
   @Override
-  Iterator iterator();
+  Iterator<CAstType> iterator();
 
 }
