@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 /*
  * Created on Sep 21, 2005
  */
@@ -21,21 +21,20 @@ import com.ibm.wala.cast.tree.CAstType;
 import com.ibm.wala.cast.tree.CAstTypeDictionary;
 import com.ibm.wala.util.collections.HashMapFactory;
 
-public class CAstTypeDictionaryImpl implements CAstTypeDictionary {
-  protected final Map fMap = HashMapFactory.make();
+public class CAstTypeDictionaryImpl<A> implements CAstTypeDictionary {
+  protected final Map<A, CAstType> fMap = HashMapFactory.make();
 
   @Override
-  public CAstType getCAstTypeFor(Object/*ASTType*/ astType) {
-      return (CAstType) fMap.get(astType);
+  public CAstType getCAstTypeFor(Object astType) {
+      return fMap.get(astType);
   }
 
-  @SuppressWarnings("unchecked")
-  public void map(Object/*ASTType*/ astType, CAstType castType) {
+  public void map(A astType, CAstType castType) {
     fMap.put(astType, castType);
   }
 
   @Override
-  public Iterator iterator() {
+  public Iterator<CAstType> iterator() {
     return fMap.values().iterator();
   }
 
