@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2011 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 
 package com.ibm.wala.cast.tree.pattern;
 
@@ -26,9 +26,7 @@ public class NodeOfKind implements NodePattern {
 	
 	public NodeOfKind(int kind, NodePattern... children) {
 		this.kind = kind;
-		this.children = new NodePattern[children.length];
-		for(int i=0;i<children.length;++i)
-			this.children[i] = children[i];
+		this.children = children.clone();
 	}
 	
 	/* (non-Javadoc)
@@ -43,4 +41,4 @@ public class NodeOfKind implements NodePattern {
 				return false;
 		return true;
 	}
-}
\ No newline at end of file
+}
