@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2008 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,14 +7,14 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package annotations;
 
 public @interface AnnotationWithParams {
 
   String strParam() default "strdef";
   int intParam() default 0;
-  Class klassParam() default Object.class;
+  Class<?> klassParam() default Object.class;
   AnnotationEnum enumParam() default AnnotationEnum.VAL2;
   String[] strArrParam() default {"foo","baz"};
   int[] intArrParam() default {3,4};
