@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,13 +7,13 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package classConstant;
 
 class ClassConstant {
 
   public static void main(String args[]) {
-    Class x = ClassConstant.class;
+    Class<ClassConstant> x = ClassConstant.class;
     x.hashCode();
   }
 
