@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2007 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,13 +7,13 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package cornerCases;
 
 public class AliasNames {
 
   public static void foo(String[] a) {
     @SuppressWarnings("unused")
-    String s = a[0].toString();
+    String s = a[0];
   }
 }
