@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2009 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package cornerCases;
 
 import java.io.BufferedInputStream;
@@ -17,6 +17,7 @@ import java.io.InputStream;
 
 public class TryFinally {
   
+  @SuppressWarnings("resource")
   public void test1(InputStream i1, InputStream i2) throws IOException {
     BufferedInputStream in = new BufferedInputStream(i1);
     try {
