@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2007 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package cornerCases;
 
 import sun.java2d.FontSupport;
@@ -18,6 +18,7 @@ import sun.java2d.FontSupport;
  * When analyzed with J2EEClassHierarchy exclusions, the superinterface
  * FontSupport should not be found because we exclude sun.java2d.*
  */
+@SuppressWarnings("restriction")
 public interface YuckyInterface extends FontSupport {
 
 
