@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package reflection;
 
 import java.lang.reflect.InvocationTargetException;
@@ -20,7 +20,7 @@ import java.lang.reflect.Modifier;
 public class Reflect14 {
   public static void main(String[] args) throws ClassNotFoundException, IllegalArgumentException, InstantiationException,
       IllegalAccessException, InvocationTargetException, SecurityException, NoSuchMethodException {
-    Class c = Class.forName("reflection.Helper");
+    Class<?> c = Class.forName("reflection.Helper");
     Method[] ms = c.getMethods();
     for (Method m : ms) {
       int mods = m.getModifiers();
