@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package reflection;
 
 import java.lang.reflect.Constructor;
@@ -17,12 +17,13 @@ import java.lang.reflect.InvocationTargetException;
  * Test of Class.getConstructors().
  */
 public class Reflect15 {
+  @SuppressWarnings("null")
   public static void main(String[] args) throws ClassNotFoundException, IllegalArgumentException, InstantiationException,
       IllegalAccessException, InvocationTargetException {
-    Class c = Class.forName("reflection.Helper");
-    Constructor[] ctors = c.getConstructors();
+    Class<?> c = Class.forName("reflection.Helper");
+    Constructor<?>[] ctors = c.getConstructors();
     Helper h = null;
-    for (Constructor ctor : ctors) {
+    for (Constructor<?> ctor : ctors) {
       if (ctor.getParameterTypes().length == 2) {
         h = (Helper) ctor.newInstance(new Object[] {new Object(), new Object()});
       }
