@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package reflection;
 
 import java.lang.reflect.InvocationTargetException;
@@ -22,8 +22,8 @@ public class Reflect20 {
       NoSuchMethodException, IllegalAccessException, InstantiationException,
       IllegalArgumentException, InvocationTargetException {
     Class<?> helperClass = Class.forName("reflection.Helper");
-    Class objectClass = Class.forName("java.lang.Object");
-    Class[] paramArrayTypes = new Class[]{objectClass, objectClass};
+    Class<?> objectClass = Class.forName("java.lang.Object");
+    Class<?>[] paramArrayTypes = new Class[]{objectClass, objectClass};
     Method m = helperClass.getMethod("o", paramArrayTypes);
     Object helperObject = helperClass.newInstance();
     Object[] paramArrayObjects = new Object[]{new Object(), new Object()};
