@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package reflection;
 
 import java.util.Hashtable;
@@ -15,13 +15,13 @@ import java.util.Hashtable;
 public class Reflect3 {
 
   public static void main(String[] args) throws ClassNotFoundException, IllegalAccessException, InstantiationException {
-    Class c = Class.forName("java.util.Properties");
-    Hashtable h = (Hashtable) c.newInstance();
+    Class<?> c = Class.forName("java.util.Properties");
+    Hashtable<Object, Object> h = (Hashtable<Object, Object>) c.newInstance();
     System.out.println(h.toString());
   }
   
   @SuppressWarnings("unused")
-  private static class Hash extends Hashtable {
+  private static class Hash extends Hashtable<Object, Object> {
     
   }
 }
