@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package reflection;
 
 import java.io.FilePermission;
@@ -15,7 +15,7 @@ import java.io.FilePermission;
 public class Reflect4 {
 
   public static void main(String[] args) throws IllegalAccessException, InstantiationException, ClassNotFoundException {
-    Class c = Class.forName("java.io.FilePermission");
+    Class<?> c = Class.forName("java.io.FilePermission");
     FilePermission h = (FilePermission) c.newInstance();
     System.out.println(h.toString());
   }
