@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package reflection;
 
 import java.lang.reflect.Constructor;
@@ -19,8 +19,8 @@ import java.lang.reflect.InvocationTargetException;
 public class Reflect8 {
   public static void main(String[] args) throws ClassNotFoundException, IllegalArgumentException, InstantiationException,
       IllegalAccessException, InvocationTargetException {
-    Class c = Class.forName("java.lang.Integer");
-    Constructor[] ctors = c.getConstructors();
+    Class<?> c = Class.forName("java.lang.Integer");
+    Constructor<?>[] ctors = c.getConstructors();
     Integer i = (Integer) ctors[0].newInstance(new Integer(1));
     i.toString();
   }
