@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2007 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package slice;
 
 import java.util.Vector;
@@ -20,7 +20,7 @@ public class Slice6 {
     messages = new Vector<Integer>();
     messages.add(5);
 
-    int message = (Integer) messages.elementAt(0);
+    int message = messages.elementAt(0);
 
     sendMessage(message);
   }
