@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2008 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,13 +7,14 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package staticInit;
 
 public class TestStaticInitOrder {
 
   private static class A {
 
+    @SuppressWarnings("unused")
     static int f;
     
     static {
@@ -26,6 +27,7 @@ public class TestStaticInitOrder {
   }
 
   private static class B {
+    @SuppressWarnings("unused")
     static int b;
     
     static {
@@ -39,6 +41,7 @@ public class TestStaticInitOrder {
   
   private static class C extends B {
     
+    @SuppressWarnings("unused")
     static int c = 5;
     
     public static void dostuff() {
