@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,22 +7,21 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package string;
 
 public class SimpleStringOps {
 
   private static void whatever(String s) {
-    StringBuffer sb = new StringBuffer();
-    sb.append(s.substring(5));
-    sb.append(" and other garbage");
-    System.out.println(sb.toString());
+    System.out.println(s.substring(5) + " and other garbage");
   }
   
   public static void main(String[] args) {
     if (args.length > 0) {
+      @SuppressWarnings("NonConstantStringShouldBeStringBuffer")
       String s = args[0];
       for(int i = 1; i < args.length; i++) {
+        //noinspection StringConcatenationInLoop
         s = s + args[i];
       }
       
