@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2014 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 
 /*
  * Licensed Materials - Property of IBM
@@ -38,7 +38,7 @@ public final class TwoLevelVectorTest extends WalaTestCase {
   // --- Test cases
   
   @Test public void testCase1() {
-    final TwoLevelVector<Integer> tlVector = new TwoLevelVector<Integer>();
+    final TwoLevelVector<Integer> tlVector = new TwoLevelVector<>();
     tlVector.iterator();
     tlVector.set(2147483647, 56);
     Assert.assertNotNull(tlVector.iterator());
