@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.analysis.reflection;
 
 import java.util.ArrayList;
@@ -32,10 +32,10 @@ import com.ibm.wala.classLoader.IClass;
 import com.ibm.wala.classLoader.IMethod;
 import com.ibm.wala.classLoader.NewSiteReference;
 import com.ibm.wala.classLoader.SyntheticMethod;
-import com.ibm.wala.ipa.callgraph.AnalysisCache;
 import com.ibm.wala.ipa.callgraph.AnalysisOptions;
 import com.ibm.wala.ipa.callgraph.CGNode;
 import com.ibm.wala.ipa.callgraph.Context;
+import com.ibm.wala.ipa.callgraph.IAnalysisCacheView;
 import com.ibm.wala.ipa.cha.IClassHierarchy;
 import com.ibm.wala.ipa.summaries.SummarizedMethod;
 import com.ibm.wala.ipa.summaries.SyntheticIR;
@@ -44,6 +44,7 @@ import com.ibm.wala.shrikeCT.InvalidClassFileException;
 import com.ibm.wala.ssa.ConstantValue;
 import com.ibm.wala.ssa.DefUse;
 import com.ibm.wala.ssa.IR;
+import com.ibm.wala.ssa.IRView;
 import com.ibm.wala.ssa.ISSABasicBlock;
 import com.ibm.wala.ssa.SSAInstruction;
 import com.ibm.wala.ssa.SSAInstructionFactory;
@@ -56,6 +57,7 @@ import com.ibm.wala.types.MethodReference;
 import com.ibm.wala.types.TypeReference;
 import com.ibm.wala.util.collections.HashMapFactory;
 import com.ibm.wala.util.collections.HashSetFactory;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.debug.Assertions;
 import com.ibm.wala.util.warnings.Warnings;
 
@@ -65,7 +67,7 @@ import com.ibm.wala.util.warnings.Warnings;
 public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
 
   /**
-   * A Map from CallerSiteContext -> Set <TypeReference>represents the types a factory method might create in a particular context
+   * A Map from CallerSiteContext -&gt; Set &lt;TypeReference&gt;represents the types a factory method might create in a particular context
    */
   private final Map<Context, Set<TypeReference>> map = HashMapFactory.make();
 
@@ -77,9 +79,9 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
   /**
    * @param options governing analysis options
    */
-  public FactoryBypassInterpreter(AnalysisOptions options, AnalysisCache cache) {
+  public FactoryBypassInterpreter(AnalysisOptions options, IAnalysisCacheView iAnalysisCacheView) {
     this.options = options;
-    this.cache = cache;
+    this.cache = iAnalysisCacheView;
   }
 
   @Override
@@ -91,7 +93,12 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
       System.err.println("generating IR for " + node);
     }
     SpecializedFactoryMethod m = findOrCreateSpecializedFactoryMethod(node);
-    return cache.getSSACache().findOrCreateIR(m, node.getContext(), options.getSSAOptions());
+    return cache.getIR(m, node.getContext());
+  }
+
+  @Override
+  public IRView getIRView(CGNode node) {
+    return getIR(node);
   }
 
   private Set<TypeReference> getTypesForContext(Context context) {
@@ -134,7 +141,7 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
     if (node == null) {
       throw new IllegalArgumentException("node is null");
     }
-    if (node.getMethod().isSynthetic()) {
+    if (node.getMethod().isWalaSynthetic()) {
       SyntheticMethod s = (SyntheticMethod) node.getMethod();
       if (s.isFactoryMethod()) {
         return getTypesForContext(node.getContext()) != null;
@@ -151,8 +158,8 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
     }
     SpecializedFactoryMethod m = findOrCreateSpecializedFactoryMethod(node);
     HashSet<NewSiteReference> result = HashSetFactory.make(5);
-    for (Iterator<SSAInstruction> it = m.getAllocationStatements().iterator(); it.hasNext();) {
-      SSANewInstruction s = (SSANewInstruction) it.next();
+    for (SSAInstruction ssaInstruction : m.getAllocationStatements()) {
+      SSANewInstruction s = (SSANewInstruction) ssaInstruction;
       result.add(s.getNewSite());
     }
     return result.iterator();
@@ -194,16 +201,15 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
       types = HashSetFactory.make(2);
       map.put(context, types);
     }
-    if (types.contains(type)) {
+    if (!types.add(type)) {
       return false;
     } else {
-      types.add(type);
       // update any extant synthetic method
       SpecializedFactoryMethod m = syntheticMethodCache.get(context);
       if (m != null) {
         TypeAbstraction T = typeRef2TypeAbstraction(cha, type);
         m.addStatementsForTypeAbstraction(T);
-        cache.getSSACache().invalidate(m, context);
+        cache.invalidate(m, context);
       }
       return true;
     }
@@ -257,14 +263,14 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
   private SpecializedFactoryMethod findOrCreateSpecializedFactoryMethod(CGNode node) {
     SpecializedFactoryMethod m = syntheticMethodCache.get(node.getContext());
     if (m == null) {
-      Set types = getTypesForContext(node.getContext());
+      Set<TypeReference> types = getTypesForContext(node.getContext());
       m = new SpecializedFactoryMethod((SummarizedMethod) node.getMethod(), node.getContext(), types);
       syntheticMethodCache.put(node.getContext(), m);
     }
     return m;
   }
 
-  public Set getCaughtExceptions(CGNode node) {
+  public Set<TypeReference> getCaughtExceptions(CGNode node) {
     if (node == null) {
       throw new IllegalArgumentException("node is null");
     }
@@ -306,7 +312,7 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
     }
   }
 
-  public Iterator iterateCastTypes(CGNode node) {
+  public Iterator<TypeReference> iterateCastTypes(CGNode node) {
     if (node == null) {
       throw new IllegalArgumentException("node is null");
     }
@@ -333,8 +339,8 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
     if (node == null) {
       throw new IllegalArgumentException("node is null");
     }
-    SpecializedFactoryMethod m = findOrCreateSpecializedFactoryMethod(node);
-    return cache.getSSACache().findOrCreateDU(m, node.getContext(), options.getSSAOptions());
+    // SpecializedFactoryMethod m = findOrCreateSpecializedFactoryMethod(node);
+    return cache.getDefUse(getIR(node));
   }
 
   protected class SpecializedFactoryMethod extends SpecializedMethod {
@@ -342,7 +348,7 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
     /**
      * List of synthetic invoke instructions we model for this specialized instance.
      */
-    final private ArrayList<SSAInstruction> calls = new ArrayList<SSAInstruction>();
+    final private ArrayList<SSAInstruction> calls = new ArrayList<>();
 
     /**
      * The method being modelled
@@ -372,7 +378,7 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
       }
     }
 
-    protected SpecializedFactoryMethod(final SummarizedMethod m, Context context, final Set S) {
+    protected SpecializedFactoryMethod(final SummarizedMethod m, Context context, final Set<TypeReference> S) {
       super(m, m.getDeclaringClass(), m.isStatic(), true);
 
       this.context = context;
@@ -387,8 +393,7 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
       // add original statements from the method summary
       nextLocal = addOriginalStatements(m);
 
-      for (Iterator it = S.iterator(); it.hasNext();) {
-        TypeReference type = (TypeReference) it.next();
+      for (TypeReference type : S) {
         TypeAbstraction T = typeRef2TypeAbstraction(m.getClassHierarchy(), type);
         addStatementsForTypeAbstraction(T);
       }
@@ -422,7 +427,7 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
           if (((ConeType) T).isInterface()) {
             Set<IClass> implementors = T.getType().getClassHierarchy().getImplementors(ref);
             if (DEBUG) {
-              System.err.println(("Implementors for " + T + " " + implementors));
+              System.err.println(("Implementors for " + T + ' ' + implementors));
             }
             if (implementors.isEmpty()) {
               if (DEBUG) {
@@ -438,7 +443,7 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
           } else {
             Collection<IClass> subclasses = T.getType().getClassHierarchy().computeSubClasses(ref);
             if (DEBUG) {
-              System.err.println(("Subclasses for " + T + " " + subclasses));
+              System.err.println(("Subclasses for " + T + ' ' + subclasses));
             }
             if (subclasses.isEmpty()) {
               if (DEBUG) {
@@ -476,8 +481,6 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
 
     /**
      * Set up a method summary which allocates and returns an instance of concrete type T.
-     * 
-     * @param T
      */
     private void addStatementsForConcreteType(final TypeReference T) {
       int alloc = addStatementsForConcreteSimpleType(T);
@@ -500,8 +503,7 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
       SSAInstruction[] original = m.getStatements(options.getSSAOptions());
       // local value number 1 is "this", so the next free value number is 2
       int nextLocal = 2;
-      for (int i = 0; i < original.length; i++) {
-        SSAInstruction s = original[i];
+      for (SSAInstruction s : original) {
         allInstructions.add(s);
         if (s instanceof SSAInvokeInstruction) {
           calls.add(s);
@@ -531,8 +533,7 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
         allInstructions.add(r);
       }
 
-      for (; it.hasNext();) {
-        IClass klass = it.next();
+      for (IClass klass : Iterator2Iterable.make(it)) {
         TypeReference T = klass.getReference();
         if (klass.isAbstract() || klass.isInterface() || typesAllocated.contains(T)) {
           continue;
@@ -597,8 +598,8 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
     public SSAInstruction[] getStatements() {
       SSAInstruction[] result = new SSAInstruction[allInstructions.size()];
       int i = 0;
-      for (Iterator<SSAInstruction> it = allInstructions.iterator(); it.hasNext();) {
-        result[i++] = it.next();
+      for (SSAInstruction ssaInstruction : allInstructions) {
+        result[i++] = ssaInstruction;
       }
       return result;
     }
@@ -628,7 +629,7 @@ public class FactoryBypassInterpreter extends AbstractReflectionInterpreter {
       Map<Integer, ConstantValue> constants = null;
       if (valueNumberForConstantOne > -1) {
         constants = HashMapFactory.make(1);
-        constants.put(new Integer(valueNumberForConstantOne), new ConstantValue(new Integer(1)));
+        constants.put(Integer.valueOf(valueNumberForConstantOne), new ConstantValue(Integer.valueOf(1)));
       }
 
       return new SyntheticIR(this, context, new InducedCFG(instrs, this, context), instrs, options, constants);
