@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.analysis.typeInference;
 
 import java.util.Collection;
@@ -51,6 +51,7 @@ import com.ibm.wala.types.TypeReference;
 import com.ibm.wala.util.CancelException;
 import com.ibm.wala.util.CancelRuntimeException;
 import com.ibm.wala.util.MonitorUtil.IProgressMonitor;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.debug.Assertions;
 
 /**
@@ -149,7 +150,7 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
       TypeReference t = ir.getParameterType(i);
 
       if (DEBUG) {
-        System.err.println("parameter " + parameterValueNumbers[i] + " " + t);
+        System.err.println("parameter " + parameterValueNumbers[i] + ' ' + t);
       }
 
       if (t.isReferenceType()) {
@@ -178,8 +179,7 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
       }
     }
 
-    for (Iterator<SSAInstruction> it = ir.iterateNormalInstructions(); it.hasNext();) {
-      SSAInstruction s = it.next();
+    for (SSAInstruction s : Iterator2Iterable.make(ir.iterateNormalInstructions())) {
       if (s instanceof SSAAbstractInvokeInstruction) {
         SSAAbstractInvokeInstruction call = (SSAAbstractInvokeInstruction) s;
         TypeVariable v = getVariable(call.getException());
@@ -217,8 +217,7 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
             x = new TypeReference[]{ language.getThrowableType() };
           }
           if (x != null) {
-            for (int i = 0; i < x.length; i++) {
-              TypeReference tx = x[i];
+            for (TypeReference tx : x) {
               IClass tc = cha.lookupClass(tx);
               if (tc != null) {
                 v.setType(v.getType().meet(new ConeType(tc)));
@@ -267,7 +266,7 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
       return "delared type := " + type;
     }
 
-    public boolean isNullary() {
+    public static boolean isNullary() {
       return true;
     }
 
@@ -299,8 +298,8 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
     public byte evaluate(TypeVariable lhs, TypeVariable[] rhs) {
 
       if (DEBUG) {
-        System.err.print("PhiOperator.meet " + lhs + " ");
-        for (IVariable v : rhs) {
+        System.err.print("PhiOperator.meet " + lhs + ' ');
+        for (IVariable<?> v : rhs) {
           System.err.print(v + " ");
         }
         System.err.println();
@@ -308,9 +307,8 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
 
       TypeAbstraction lhsType = lhs.getType();
       TypeAbstraction meet = TypeAbstraction.TOP;
-      for (int i = 0; i < rhs.length; i++) {
-        if (rhs[i] != null && rhs[i].getType() != null) {
-          TypeVariable r = rhs[i];
+      for (TypeVariable r : rhs) {
+        if (r != null && r.getType() != null) {
           meet = meet.meet(r.getType());
         }
       }
@@ -386,9 +384,8 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
     public byte evaluate(TypeVariable lhs, TypeVariable[] rhs) {
       TypeAbstraction lhsType = lhs.getType();
       TypeAbstraction meet = TypeAbstraction.TOP;
-      for (int i = 0; i < rhs.length; i++) {
-        if (rhs[i] != null  && rhs[i].getType() != null) {
-          TypeVariable r = rhs[i];
+      for (TypeVariable r : rhs) {
+        if (r != null  && r.getType() != null) {
           meet = meet.meet(r.getType());
         }
       }
@@ -523,7 +520,7 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
       if (!doPrimitives) {
         result = null;
       } else {
-        result = new DeclaredTypeOperator(language.getPrimitive(language.getConstantType(new Integer(1))));
+        result = new DeclaredTypeOperator(language.getPrimitive(language.getConstantType(Integer.valueOf(1))));
       }
     }
 
@@ -625,7 +622,7 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
     @Override
     public void visitComparison(SSAComparisonInstruction instruction) {
       if (doPrimitives) {
-        result = new DeclaredTypeOperator(language.getPrimitive(language.getConstantType(new Integer(0))));
+        result = new DeclaredTypeOperator(language.getPrimitive(language.getConstantType(Integer.valueOf(0))));
       }
     }
 
@@ -668,8 +665,8 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
 
     private TypeAbstraction meetDeclaredExceptionTypes(SSAGetCaughtExceptionInstruction s) {
       ExceptionHandlerBasicBlock bb = (ExceptionHandlerBasicBlock) ir.getControlFlowGraph().getNode(s.getBasicBlockNumber());
-      Iterator it = bb.getCaughtExceptionTypes();
-      TypeReference t = (TypeReference) it.next();
+      Iterator<TypeReference> it = bb.getCaughtExceptionTypes();
+      TypeReference t = it.next();
       IClass klass = cha.lookupClass(t);
       TypeAbstraction result = null;
       if (klass == null) {
@@ -680,7 +677,7 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
         result = new ConeType(klass);
       }
       while (it.hasNext()) {
-        t = (TypeReference) it.next();
+        t = it.next();
         IClass tClass = cha.lookupClass(t);
         if (tClass == null) {
           result = BOTTOM;
@@ -723,12 +720,12 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
     }
   }
 
-  public class TypeVarFactory implements VariableFactory {
+  public class TypeVarFactory implements VariableFactory<TypeVariable> {
 
     @Override
-    public IVariable makeVariable(int valueNumber) {
-      SymbolTable st = ir.getSymbolTable();
+    public TypeVariable makeVariable(int valueNumber) {
       if (doPrimitives) {
+        SymbolTable st = ir.getSymbolTable();
         if (st.isConstant(valueNumber)) {
           if (st.isBooleanConstant(valueNumber)) {
             return new TypeVariable(language.getPrimitive(language.getConstantType(Boolean.TRUE)));
@@ -752,8 +749,9 @@ public class TypeInference extends SSAInference<TypeVariable> implements FixedPo
     if (valueNumber < 0) {
       throw new IllegalArgumentException("bad value number " + valueNumber);
     }
-    assert getVariable(valueNumber) != null : "null variable for value number " + valueNumber;
-    return getVariable(valueNumber).getType();
+    TypeVariable variable = getVariable(valueNumber);
+    assert variable != null : "null variable for value number " + valueNumber;
+    return variable.getType();
   }
 
   public TypeAbstraction getConstantType(int valueNumber) {
