@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.cfg;
 
 import java.util.ArrayList;
@@ -18,11 +18,12 @@ import java.util.List;
 
 import com.ibm.wala.classLoader.IMethod;
 import com.ibm.wala.shrikeBT.Constants;
-import com.ibm.wala.util.Predicate;
 import com.ibm.wala.util.collections.CompoundIterator;
 import com.ibm.wala.util.collections.EmptyIterator;
+import com.ibm.wala.util.collections.FilterIterator;
 import com.ibm.wala.util.collections.HashSetFactory;
 import com.ibm.wala.util.collections.Iterator2Collection;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.collections.IteratorPlusOne;
 import com.ibm.wala.util.collections.IteratorPlusTwo;
 import com.ibm.wala.util.collections.NonNullSingletonIterator;
@@ -42,7 +43,7 @@ import com.ibm.wala.util.intset.SimpleIntVector;
 /**
  * Common functionality for {@link ControlFlowGraph} implementations.
  */
-public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements ControlFlowGraph<I, T>, Constants {
+public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements ControlFlowGraph<I, T>, MinimalCFG<T>, Constants {
 
   /**
    * The method this AbstractCFG represents
@@ -52,25 +53,25 @@ public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements Contro
   /**
    * An object to track nodes in this cfg
    */
-  final private DelegatingNumberedNodeManager<T> nodeManager = new DelegatingNumberedNodeManager<T>();
+  final private DelegatingNumberedNodeManager<T> nodeManager = new DelegatingNumberedNodeManager<>();
 
   /**
    * An object to track most normal edges in this cfg
    */
-  final private SparseNumberedEdgeManager<T> normalEdgeManager = new SparseNumberedEdgeManager<T>(nodeManager, 2,
+  final private SparseNumberedEdgeManager<T> normalEdgeManager = new SparseNumberedEdgeManager<>(nodeManager, 2,
       BasicNaturalRelation.SIMPLE);
 
   /**
    * An object to track not-to-exit exceptional edges in this cfg
    */
-  final private SparseNumberedEdgeManager<T> exceptionalEdgeManager = new SparseNumberedEdgeManager<T>(nodeManager, 0,
+  final private SparseNumberedEdgeManager<T> exceptionalEdgeManager = new SparseNumberedEdgeManager<>(nodeManager, 0,
       BasicNaturalRelation.SIMPLE);
 
   /**
    * An object to track not-to-exit exceptional edges in this cfg, indexed by block number. exceptionalEdges[i] is a list of block
    * numbers that are non-exit exceptional successors of block i, in order of increasing "catch scope".
    */
-  final private SimpleVector<SimpleIntVector> exceptionalSuccessors = new SimpleVector<SimpleIntVector>();
+  final private SimpleVector<SimpleIntVector> exceptionalSuccessors = new SimpleVector<>();
 
   /**
    * Which basic blocks have a normal edge to exit()?
@@ -227,13 +228,10 @@ public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements Contro
       throw new IllegalArgumentException("N is null");
     }
     if (N.equals(exit())) {
-      return Predicate.filter(iterator(), new Predicate<T>() {
-        @Override
-        public boolean test(T o) {
-          int i = getNumber(o);
-          return normalToExit.get(i) || exceptionalToExit.get(i);
-        }
-      }).iterator();
+      return new FilterIterator<>(iterator(), o -> {
+        int i = getNumber(o);
+        return normalToExit.get(i) || exceptionalToExit.get(i);
+      });
     } else {
       int number = getNumber(N);
       boolean normalIn = getNumberOfNormalIn(N) > 0;
@@ -308,9 +306,9 @@ public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements Contro
   public Iterator<T> getSuccNodes(T N) {
     int number = getNumber(N);
     if (normalToExit.get(number) && exceptionalToExit.get(number)) {
-      return new CompoundIterator<T>(iterateNormalSuccessorsWithoutExit(number), iterateExceptionalSuccessors(number));
+      return new CompoundIterator<>(iterateNormalSuccessorsWithoutExit(number), iterateExceptionalSuccessors(number));
     } else {
-      return new CompoundIterator<T>(iterateNormalSuccessors(number), iterateExceptionalSuccessors(number));
+      return new CompoundIterator<>(iterateNormalSuccessors(number), iterateExceptionalSuccessors(number));
     }
   }
 
@@ -320,7 +318,7 @@ public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements Contro
    */
   private Iterator<T> iterateExceptionalSuccessors(int number) {
     if (exceptionalEdgeManager.hasAnySuccessor(number)) {
-      List<T> result = new ArrayList<T>();
+      List<T> result = new ArrayList<>();
       SimpleIntVector v = exceptionalSuccessors.get(number);
       for (int i = 0; i <= v.getMaxIndex(); i++) {
         result.add(getNode(v.get(i)));
@@ -331,7 +329,7 @@ public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements Contro
       return result.iterator();
     } else {
       if (exceptionalToExit.get(number)) {
-        return new NonNullSingletonIterator<T>(exit());
+        return new NonNullSingletonIterator<>(exit());
       } else {
         return EmptyIterator.instance();
       }
@@ -340,13 +338,10 @@ public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements Contro
 
   Iterator<T> iterateExceptionalPredecessors(T N) {
     if (N.equals(exit())) {
-      return Predicate.filter(iterator(), new Predicate<T>() {
-        @Override
-        public boolean test(T o) {
-          int i = getNumber(o);
-          return exceptionalToExit.get(i);
-        }
-      }).iterator();
+      return new FilterIterator<>(iterator(), o -> {
+        int i = getNumber(o);
+        return exceptionalToExit.get(i);
+      });
     } else {
       return exceptionalEdgeManager.getPredNodes(N);
     }
@@ -354,13 +349,10 @@ public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements Contro
 
   Iterator<T> iterateNormalPredecessors(T N) {
     if (N.equals(exit())) {
-      return Predicate.filter(iterator(), new Predicate<T>() {
-        @Override
-        public boolean test(T o) {
-          int i = getNumber(o);
-          return normalToExit.get(i);
-        }
-      }).iterator();
+      return new FilterIterator<>(iterator(), o -> {
+        int i = getNumber(o);
+        return normalToExit.get(i);
+      });
     } else {
       int number = getNumber(N);
       if (number > 0 && fallThru.get(number - 1)) {
@@ -374,7 +366,7 @@ public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements Contro
   private Iterator<T> iterateNormalSuccessors(int number) {
     if (fallThru.get(number)) {
       if (normalToExit.get(number)) {
-        return new IteratorPlusTwo<T>(normalEdgeManager.getSuccNodes(number), getNode(number + 1), exit());
+        return new IteratorPlusTwo<>(normalEdgeManager.getSuccNodes(number), getNode(number + 1), exit());
       } else {
         return IteratorPlusOne.make(normalEdgeManager.getSuccNodes(number), getNode(number + 1));
       }
@@ -395,9 +387,6 @@ public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements Contro
     }
   }
 
-  /**
-   * @param n
-   */
   @Override
   public void addNode(T n) {
     nodeManager.addNode(n);
@@ -545,14 +534,13 @@ public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements Contro
 
   @Override
   public String toString() {
-    StringBuffer s = new StringBuffer("");
-    for (Iterator<T> it = iterator(); it.hasNext();) {
-      T bb = it.next();
-      s.append("BB").append(getNumber(bb)).append("\n");
+    StringBuilder s = new StringBuilder();
+    for (T bb : this) {
+      s.append("BB").append(getNumber(bb)).append('\n');
 
       Iterator<T> succNodes = getSuccNodes(bb);
       while (succNodes.hasNext()) {
-        s.append("    -> BB").append(getNumber(succNodes.next())).append("\n");
+        s.append("    -> BB").append(getNumber(succNodes.next())).append('\n');
       }
     }
     return s.toString();
@@ -601,9 +589,9 @@ public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements Contro
     if (b == null) {
       throw new IllegalArgumentException("b is null");
     }
-    List<T> result = new ArrayList<T>();
-    for (Iterator<T> it = iterateExceptionalSuccessors(b.getNumber()); it.hasNext();) {
-      result.add(it.next());
+    List<T> result = new ArrayList<>();
+    for (T s : Iterator2Iterable.make(iterateExceptionalSuccessors(b.getNumber()))) {
+      result.add(s);
     }
     return result;
   }
@@ -624,7 +612,7 @@ public abstract class AbstractCFG<I, T extends IBasicBlock<I>> implements Contro
    */
   @Override
   public Iterator<T> iterateNodes(IntSet s) {
-    return new NumberedNodeIterator<T>(s, this);
+    return new NumberedNodeIterator<>(s, this);
   }
 
   @Override
