@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.cfg;
 
 import java.util.ArrayList;
@@ -53,7 +53,7 @@ public class InducedCFG extends AbstractCFG<SSAInstruction, InducedCFG.BasicBloc
   private static final boolean DEBUG = false;
 
   /**
-   * A partial map from Instruction -> BasicBlock
+   * A partial map from Instruction -&gt; BasicBlock
    */
   private final BasicBlock[] i2block;
 
@@ -120,8 +120,7 @@ public class InducedCFG extends AbstractCFG<SSAInstruction, InducedCFG.BasicBloc
    * Compute outgoing edges in the control flow graph.
    */
   private void computeEdges() {
-    for (Iterator it = iterator(); it.hasNext();) {
-      BasicBlock b = (BasicBlock) it.next();
+    for (BasicBlock b : this) {
       if (b.equals(exit()))
         continue;
       b.computeOutgoingEdges();
@@ -129,7 +128,7 @@ public class InducedCFG extends AbstractCFG<SSAInstruction, InducedCFG.BasicBloc
     clearPis(getInstructions());
   }
 
-  private void clearPis(SSAInstruction[] instructions) {
+  private static void clearPis(SSAInstruction[] instructions) {
     for (int i = 0; i < instructions.length; i++) {
       if (instructions[i] instanceof SSAPiInstruction) {
         instructions[i] = null;
@@ -216,7 +215,7 @@ public class InducedCFG extends AbstractCFG<SSAInstruction, InducedCFG.BasicBloc
   /**
    * set to null any slots in the array with phi instructions
    */
-  private void clearPhis(SSAInstruction[] instructions) {
+  private static void clearPhis(SSAInstruction[] instructions) {
     for (int i = 0; i < instructions.length; i++) {
       if (instructions[i] instanceof SSAPhiInstruction) {
         instructions[i] = null;
@@ -394,7 +393,7 @@ public class InducedCFG extends AbstractCFG<SSAInstruction, InducedCFG.BasicBloc
 
     public void addPhi(SSAPhiInstruction phiInstruction) {
       if (phis == null) {
-        phis = new ArrayList<SSAPhiInstruction>(1);
+        phis = new ArrayList<>(1);
       }
       phis.add(phiInstruction);
     }
@@ -407,7 +406,7 @@ public class InducedCFG extends AbstractCFG<SSAInstruction, InducedCFG.BasicBloc
 
     public void addPi(SSAPiInstruction piInstruction) {
       if (pis == null) {
-        pis = new ArrayList<SSAPiInstruction>(1);
+        pis = new ArrayList<>(1);
       }
       pis.add(piInstruction);
     }
@@ -471,8 +470,7 @@ public class InducedCFG extends AbstractCFG<SSAInstruction, InducedCFG.BasicBloc
           int tgtNd = getIndexFromIIndex(tgt);  // index in instructions-array
           BasicBlock target = null;
 
-          for (Iterator it = InducedCFG.this.iterator(); it.hasNext();) {
-            final BasicBlock candid = (BasicBlock) it.next();
+          for (BasicBlock candid : InducedCFG.this) {
             if (candid.getFirstInstructionIndex() == tgtNd) {
               target = candid;
               break;
@@ -480,7 +478,7 @@ public class InducedCFG extends AbstractCFG<SSAInstruction, InducedCFG.BasicBloc
           }
 
           if (target == null) {
-            System.err.println("Error retreiving the Node with IIndex " + tgt + " (in array at " + tgtNd + ")");
+            System.err.println("Error retreiving the Node with IIndex " + tgt + " (in array at " + tgtNd + ')');
             System.err.println("The associated Instruction " + instructions[tgtNd] + " does not start a basic block");
             assert(false); // It will fail anyway
           }
@@ -616,23 +614,22 @@ public class InducedCFG extends AbstractCFG<SSAInstruction, InducedCFG.BasicBloc
 
     @Override
     public Iterator<SSAInstruction> iterator() {
-      return new ArrayIterator<SSAInstruction>(getInstructions(), getFirstInstructionIndex(), getLastInstructionIndex());
+      return new ArrayIterator<>(getInstructions(), getFirstInstructionIndex(), getLastInstructionIndex());
     }
   }
 
   @Override
   public String toString() {
-    StringBuffer s = new StringBuffer("");
-    for (Iterator it = iterator(); it.hasNext();) {
-      BasicBlock bb = (BasicBlock) it.next();
-      s.append("BB").append(getNumber(bb)).append("\n");
+    StringBuilder s = new StringBuilder();
+    for (BasicBlock bb : this) {
+      s.append("BB").append(getNumber(bb)).append('\n');
       for (int j = bb.getFirstInstructionIndex(); j <= bb.getLastInstructionIndex(); j++) {
-        s.append("  ").append(j).append("  ").append(getInstructions()[j]).append("\n");
+        s.append("  ").append(j).append("  ").append(getInstructions()[j]).append('\n');
       }
 
       Iterator<BasicBlock> succNodes = getSuccNodes(bb);
       while (succNodes.hasNext()) {
-        s.append("    -> BB").append(getNumber(succNodes.next())).append("\n");
+        s.append("    -> BB").append(getNumber(succNodes.next())).append('\n');
       }
     }
     return s.toString();
@@ -646,7 +643,7 @@ public class InducedCFG extends AbstractCFG<SSAInstruction, InducedCFG.BasicBloc
   @Override
   public int getProgramCounter(int index) {
     if (getInstructions().length <= index) {
-      throw new IllegalArgumentException("invalid index " + index + " " + getInstructions().length);
+      throw new IllegalArgumentException("invalid index " + index + ' ' + getInstructions().length);
     }
     if (getInstructions()[index] instanceof SSAInvokeInstruction) {
       return ((SSAInvokeInstruction) getInstructions()[index]).getCallSite().getProgramCounter();
@@ -697,8 +694,7 @@ public class InducedCFG extends AbstractCFG<SSAInstruction, InducedCFG.BasicBloc
 
   public Collection<SSAPhiInstruction> getAllPhiInstructions() {
     Collection<SSAPhiInstruction> result = HashSetFactory.make();
-    for (Iterator<BasicBlock> it = iterator(); it.hasNext();) {
-      BasicBlock b = it.next();
+    for (BasicBlock b : this) {
       result.addAll(b.getPhis());
     }
     return result;
