@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.cfg;
 
 import java.util.ArrayList;
@@ -47,7 +47,7 @@ public class ShrikeCFG extends AbstractCFG<IInstruction, ShrikeCFG.BasicBlock> i
 
   private int[] instruction2Block;
 
-  private final IBytecodeMethod method;
+  private final IBytecodeMethod<IInstruction> method;
 
   /**
    * Cache this here for efficiency
@@ -59,11 +59,11 @@ public class ShrikeCFG extends AbstractCFG<IInstruction, ShrikeCFG.BasicBlock> i
    */
   final private Set<ExceptionHandler> exceptionHandlers = HashSetFactory.make(10);
 
-  public static ShrikeCFG make(IBytecodeMethod m) {
+  public static ShrikeCFG make(IBytecodeMethod<IInstruction> m) {
     return new ShrikeCFG(m);
   }
     
-  private ShrikeCFG(IBytecodeMethod method) throws IllegalArgumentException {
+  private ShrikeCFG(IBytecodeMethod<IInstruction> method) throws IllegalArgumentException {
     super(method);
     if (method == null) {
       throw new IllegalArgumentException("method cannot be null");
@@ -81,7 +81,7 @@ public class ShrikeCFG extends AbstractCFG<IInstruction, ShrikeCFG.BasicBlock> i
   }
   
   @Override
-  public IBytecodeMethod getMethod() {
+  public IBytecodeMethod<IInstruction> getMethod() {
     return method;
   }
 
@@ -111,8 +111,7 @@ public class ShrikeCFG extends AbstractCFG<IInstruction, ShrikeCFG.BasicBlock> i
    */
   private void computeI2BMapping() {
     instruction2Block = new int[getInstructions().length];
-    for (Iterator it = iterator(); it.hasNext();) {
-      final BasicBlock b = (BasicBlock) it.next();
+    for (BasicBlock b : this) {
       for (int j = b.getFirstInstructionIndex(); j <= b.getLastInstructionIndex(); j++) {
         instruction2Block[j] = getNumber(b);
       }
@@ -123,8 +122,7 @@ public class ShrikeCFG extends AbstractCFG<IInstruction, ShrikeCFG.BasicBlock> i
    * Compute outgoing edges in the control flow graph.
    */
   private void computeEdges() {
-    for (Iterator it = iterator(); it.hasNext();) {
-      BasicBlock b = (BasicBlock) it.next();
+    for (BasicBlock b : this) {
       if (b.equals(exit())) {
         continue;
       } else if (b.equals(entry())) {
@@ -238,8 +236,8 @@ public class ShrikeCFG extends AbstractCFG<IInstruction, ShrikeCFG.BasicBlock> i
 
       IInstruction last = getInstructions()[getLastInstructionIndex()];
       int[] targets = last.getBranchTargets();
-      for (int i = 0; i < targets.length; i++) {
-        BasicBlock b = getBlockForInstruction(targets[i]);
+      for (int target : targets) {
+        BasicBlock b = getBlockForInstruction(target);
         addNormalEdgeTo(b);
       }
       addExceptionalEdges(last);
@@ -291,6 +289,10 @@ public class ShrikeCFG extends AbstractCFG<IInstruction, ShrikeCFG.BasicBlock> i
                 e.printStackTrace();
                 Assertions.UNREACHABLE();
               }
+              IMethod mTarget = cha.resolveMethod(target);
+              if (mTarget == null) {
+                goToAllHandlers = true;
+              }
             }
           }
         }
@@ -306,11 +308,11 @@ public class ShrikeCFG extends AbstractCFG<IInstruction, ShrikeCFG.BasicBlock> i
           // this var gets set to false if goToAllHandlers is true but some enclosing exception handler catches all
           // exceptions.  in such a case, we need not add an exceptional edge to the method exit
           boolean needEdgeToExitForAllHandlers = true;
-          for (int j = 0; j < hs.length; j++) {
+          for (ExceptionHandler element : hs) {
             if (DEBUG) {
-              System.err.println(" handler " + hs[j]);
+              System.err.println(" handler " + element);
             }
-            BasicBlock b = getBlockForInstruction(hs[j].getHandler());
+            BasicBlock b = getBlockForInstruction(element.getHandler());
             if (DEBUG) {
               System.err.println(" target " + b);
             }
@@ -321,20 +323,26 @@ public class ShrikeCFG extends AbstractCFG<IInstruction, ShrikeCFG.BasicBlock> i
               }
               addExceptionalEdgeTo(b);
               // if the handler catches all exceptions, we don't need to add an edge to the exit or any other handlers
-              if (hs[j].getCatchClass() == null) {
+              if (element.getCatchClass() == null) {
                 needEdgeToExitForAllHandlers = false;
                 break;
               }
             } else {
               TypeReference caughtException = null;
-              if (hs[j].getCatchClass() != null) {
-                ClassLoaderReference loader = ShrikeCFG.this.getMethod().getDeclaringClass().getReference().getClassLoader();
-                caughtException = ShrikeUtil.makeTypeReference(loader, hs[j].getCatchClass());
+              if (element.getCatchClass() != null) {
+                ClassLoaderReference loader = 
+                    element.getCatchClassLoader() == null?
+                    ShrikeCFG.this.getMethod().getDeclaringClass().getReference().getClassLoader():
+                    (ClassLoaderReference)element.getCatchClassLoader();
+                caughtException = ShrikeUtil.makeTypeReference(loader, element.getCatchClass());
                 if (DEBUG) {
                   System.err.println(" caughtException " + caughtException);
                 }
                 IClass caughtClass = cha.lookupClass(caughtException);
-                if (caughtClass == null) {
+                if (DEBUG) {
+                  System.err.println(" caughtException class " + caughtClass);
+                }
+               if (caughtClass == null) {
                   // conservatively add the edge, and raise a warning
                   addExceptionalEdgeTo(b);
                   Warnings.add(FailedExceptionResolutionWarning.create(caughtException));
@@ -351,14 +359,14 @@ public class ShrikeCFG extends AbstractCFG<IInstruction, ShrikeCFG.BasicBlock> i
                 if (!exceptionTypes.isEmpty()) {
                   addExceptionalEdgeTo(b);
                   exceptionTypes.clear();
-                  caughtException = null;
+                  assert caughtException == null;
                 }
               }
               if (caughtException != null) {
                 IClass caughtClass = cha.lookupClass(caughtException);
                 // the set "caught" should be the set of exceptions that MUST
                 // have been caught by the handlers in scope
-                ArrayList<TypeReference> caught = new ArrayList<TypeReference>(exceptionTypes.size());
+                ArrayList<TypeReference> caught = new ArrayList<>(exceptionTypes.size());
                 // check if we should add an edge to the catch block.
                 for (TypeReference t : exceptionTypes) {
                   if (t != null) {
@@ -443,7 +451,7 @@ public class ShrikeCFG extends AbstractCFG<IInstruction, ShrikeCFG.BasicBlock> i
 
     @Override
     public String toString() {
-      return "BB[Shrike]" + getNumber() + " - " + method.getDeclaringClass().getReference().getName() + "." + method.getName();
+      return "BB[Shrike]" + getNumber() + " - " + method.getDeclaringClass().getReference().getName() + '.' + method.getName();
     }
 
     /*
@@ -491,23 +499,22 @@ public class ShrikeCFG extends AbstractCFG<IInstruction, ShrikeCFG.BasicBlock> i
 
     @Override
     public Iterator<IInstruction> iterator() {
-      return new ArrayIterator<IInstruction>(getInstructions(), getFirstInstructionIndex(), getLastInstructionIndex());
+      return new ArrayIterator<>(getInstructions(), getFirstInstructionIndex(), getLastInstructionIndex());
     }
   }
 
   @Override
   public String toString() {
-    StringBuffer s = new StringBuffer("");
-    for (Iterator it = iterator(); it.hasNext();) {
-      BasicBlock bb = (BasicBlock) it.next();
-      s.append("BB").append(getNumber(bb)).append("\n");
+    StringBuilder s = new StringBuilder();
+    for (BasicBlock bb : this) {
+      s.append("BB").append(getNumber(bb)).append('\n');
       for (int j = bb.getFirstInstructionIndex(); j <= bb.getLastInstructionIndex(); j++) {
-        s.append("  ").append(j).append("  ").append(getInstructions()[j]).append("\n");
+        s.append("  ").append(j).append("  ").append(getInstructions()[j]).append('\n');
       }
 
       Iterator<BasicBlock> succNodes = getSuccNodes(bb);
       while (succNodes.hasNext()) {
-        s.append("    -> BB").append(getNumber(succNodes.next())).append("\n");
+        s.append("    -> BB").append(getNumber(succNodes.next())).append('\n');
       }
     }
     return s.toString();
