@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2014 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,10 +7,11 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 
 package com.ibm.wala.cfg.exc.intra;
 
+import java.util.ArrayList;
 import com.ibm.wala.cfg.ControlFlowGraph;
 import com.ibm.wala.cfg.Util;
 import com.ibm.wala.dataflow.graph.AbstractMeetOperator;
@@ -47,9 +48,10 @@ import com.ibm.wala.ssa.SSAThrowInstruction;
 import com.ibm.wala.ssa.SSAUnaryOpInstruction;
 import com.ibm.wala.ssa.SymbolTable;
 import com.ibm.wala.ssa.analysis.IExplodedBasicBlock;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 
 /**
- * @author Juergen Graf <graf@kit.edu>
+ * @author Juergen Graf &lt;graf@kit.edu&gt;
  *
  */
 class NullPointerTransferFunctionProvider<T extends ISSABasicBlock> implements ITransferFunctionProvider<T, NullPointerState> {
@@ -90,6 +92,7 @@ class NullPointerTransferFunctionProvider<T extends ISSABasicBlock> implements I
   public UnaryOperator<NullPointerState> getEdgeTransferFunction(T src, T dst) {
     SSAInstruction instr = getRelevantInstruction(src);
     
+    assert !(instr instanceof SSAPhiInstruction);
     if (instr != null && cfg.hasEdge(src, dst)) {
       instr.visit(visitor);
       if (visitor.noIdentity) {
@@ -133,8 +136,20 @@ class NullPointerTransferFunctionProvider<T extends ISSABasicBlock> implements I
    * @see com.ibm.wala.dataflow.graph.ITransferFunctionProvider#getNodeTransferFunction(java.lang.Object)
    */
   @Override
-  public UnaryOperator<NullPointerState> getNodeTransferFunction(T node) {
-    throw new UnsupportedOperationException("We do not have such a thing dude!");
+  public UnaryOperator<NullPointerState> getNodeTransferFunction(final T node) {
+    final ArrayList<UnaryOperator<NullPointerState>> phiTransferFunctions = new ArrayList<>(1);
+    for (SSAPhiInstruction phi : Iterator2Iterable.make(node.iteratePhis())) {
+      int[] uses = new int[phi.getNumberOfUses()];
+      for (int i = 0; i < uses.length; i++) {
+        uses[i] = phi.getUse(i);
+      }
+      phiTransferFunctions.add(NullPointerState.phiValueMeetFunction(phi.getDef(), uses));
+    }
+    if (phiTransferFunctions.size() > 0) {
+      return NullPointerState.phisFunction(phiTransferFunctions);
+    } else {
+      return NullPointerState.identityFunction();
+    }
   }
 
   /* (non-Javadoc)
@@ -150,7 +165,7 @@ class NullPointerTransferFunctionProvider<T extends ISSABasicBlock> implements I
    */
   @Override
   public boolean hasNodeTransferFunctions() {
-    return false;
+    return true;
   }
   
   private static class TransferFunctionSSAVisitor implements IVisitor {
