@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2007 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.classLoader;
 
 import java.io.Reader;
@@ -22,6 +22,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import com.ibm.wala.ipa.cha.ClassHierarchy;
 import com.ibm.wala.ipa.cha.ClassHierarchyWarning;
 import com.ibm.wala.ipa.cha.IClassHierarchy;
 import com.ibm.wala.shrikeCT.InvalidClassFileException;
@@ -31,6 +32,7 @@ import com.ibm.wala.types.Selector;
 import com.ibm.wala.types.TypeName;
 import com.ibm.wala.types.TypeReference;
 import com.ibm.wala.types.annotations.Annotation;
+import com.ibm.wala.types.annotations.TypeAnnotation;
 import com.ibm.wala.types.generics.TypeSignature;
 import com.ibm.wala.util.collections.BimodalMap;
 import com.ibm.wala.util.collections.HashMapFactory;
@@ -295,17 +297,26 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
       computeSuperclass();
     }
     if (superClass == null && !getReference().equals(TypeReference.JavaLangObject)) {
-      throw new IllegalStateException("No superclass found for " + this + " Superclass name " + superName);
+      // TODO MissingSuperClassHandling.Phantom needs to be implemented
+      if (cha instanceof ClassHierarchy && ((ClassHierarchy) cha).getSuperClassHandling().equals(ClassHierarchy.MissingSuperClassHandling.ROOT)) {
+        superClass = loader.lookupClass(loader.getLanguage().getRootType().getName());
+      } else
+        throw new NoSuperclassFoundException("No superclass found for " + this + " Superclass name " + superName);
     }
     return superClass;
   }
 
+  public TypeName getSuperName() {
+    return TypeName.findOrCreate(superName);
+  }
+
+
   /*
    * @see com.ibm.wala.classLoader.IClass#getAllFields()
    */
   @Override
   public Collection<IField> getAllFields() {
-    Collection<IField> result = new LinkedList<IField>();
+    Collection<IField> result = new LinkedList<>();
     result.addAll(getAllInstanceFields());
     result.addAll(getAllStaticFields());
     return result;
@@ -358,7 +369,7 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
    */
   @Override
   public Collection<IField> getAllInstanceFields() {
-    Collection<IField> result = new LinkedList<IField>(getDeclaredInstanceFields());
+    Collection<IField> result = new LinkedList<>(getDeclaredInstanceFields());
     IClass s = getSuperclass();
     while (s != null) {
       result.addAll(s.getDeclaredInstanceFields());
@@ -372,7 +383,7 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
    */
   @Override
   public Collection<IField> getAllStaticFields() {
-    Collection<IField> result = new LinkedList<IField>(getDeclaredStaticFields());
+    Collection<IField> result = new LinkedList<>(getDeclaredStaticFields());
     IClass s = getSuperclass();
     while (s != null) {
       result.addAll(s.getDeclaredStaticFields());
@@ -386,22 +397,21 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
    */
   @Override
   public Collection<IMethod> getAllMethods() {
-    Collection<IMethod> result = new LinkedList<IMethod>();
-    Iterator<IMethod> declaredMethods = getDeclaredMethods().iterator();
-    while (declaredMethods.hasNext()) {
-      result.add(declaredMethods.next());
-    }
+    Collection<IMethod> result = new LinkedList<>(getDeclaredMethods());
     if (isInterface()) {
       for (IClass i : getDirectInterfaces()) {
         result.addAll(i.getAllMethods());
       }
+    } else {
+      // for non-interfaces, add default methods inherited from interfaces #219.
+      for (IClass i : this.getAllImplementedInterfaces())
+          for (IMethod m : i.getDeclaredMethods())
+              if (!m.isAbstract())
+                  result.add(m);
     }
     IClass s = getSuperclass();
     while (s != null) {
-      Iterator<IMethod> superDeclaredMethods = s.getDeclaredMethods().iterator();
-      while (superDeclaredMethods.hasNext()) {
-        result.add(superDeclaredMethods.next());
-      }
+      result.addAll(s.getDeclaredMethods());
       s = s.getSuperclass();
     }
     return result;
@@ -446,13 +456,14 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
     }
 
     // check parent, caching if found
-    if (!selector.equals(MethodReference.clinitSelector) && !selector.equals(MethodReference.initSelector)) {
+    if (!selector.equals(MethodReference.clinitSelector) 
+        && !selector.getName().equals(MethodReference.initAtom)) {
       IClass superclass = getSuperclass();
       if (superclass != null) {
         IMethod inherit = superclass.getMethod(selector);
         if (inherit != null) {
           if (inheritCache == null) {
-            inheritCache = new BimodalMap<Selector, IMethod>(5);
+            inheritCache = new BimodalMap<>(5);
           }
           inheritCache.put(selector, inherit);
           return inherit;
@@ -466,7 +477,7 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
       for(IMethod m : iface.getDeclaredMethods()) {
         if (!m.isAbstract() && m.getSelector().equals(selector)) {          
           if (inheritCache == null) {
-            inheritCache = new BimodalMap<Selector, IMethod>(5);
+            inheritCache = new BimodalMap<>(5);
           }
           inheritCache.put(selector, m);
 
@@ -477,7 +488,7 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
     
     // no method found
     if (inheritCache == null) {
-      inheritCache = new BimodalMap<Selector, IMethod>(5);
+      inheritCache = new BimodalMap<>(5);
     }
     inheritCache.put(selector, null);
     return null;
@@ -496,8 +507,7 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
   protected Collection<IClass> computeAllInterfacesAsCollection() {
     Collection<? extends IClass> c = getDirectInterfaces();
     Set<IClass> result = HashSetFactory.make();
-    for (Iterator<? extends IClass> it = c.iterator(); it.hasNext();) {
-      IClass klass = it.next();
+    for (IClass klass : c) {
       if (klass.isInterface()) {
         result.add(klass);
       } else {
@@ -530,9 +540,8 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
    *         classes can not be loaded
    */
   private Collection<IClass> array2IClassSet(ImmutableByteArray[] interfaces) {
-    ArrayList<IClass> result = new ArrayList<IClass>(interfaces.length);
-    for (int i = 0; i < interfaces.length; i++) {
-      ImmutableByteArray name = interfaces[i];
+    ArrayList<IClass> result = new ArrayList<>(interfaces.length);
+    for (ImmutableByteArray name : interfaces) {
       IClass klass = null;
       klass = loader.lookupClass(TypeName.findOrCreate(name));
       if (klass == null) {
@@ -546,20 +555,20 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
 
   protected List<IField> findDeclaredField(Atom name) {
     
-    List<IField> result = new ArrayList<IField>(1);
+    List<IField> result = new ArrayList<>(1);
     
     if (instanceFields != null) {
-      for (int i = 0; i < instanceFields.length; i++) {
-        if (instanceFields[i].getName() == name) {
-          result.add(instanceFields[i]);
+      for (IField instanceField : instanceFields) {
+        if (instanceField.getName() == name) {
+          result.add(instanceField);
         }
       }
     }
 
     if (staticFields != null) {
-      for (int i = 0; i < staticFields.length; i++) {
-        if (staticFields[i].getName() == name) {
-          result.add(staticFields[i]);
+      for (IField staticField : staticFields) {
+        if (staticField.getName() == name) {
+          result.add(staticField);
         }
       }
     }
@@ -568,7 +577,7 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
   }
 
   protected void addFieldToList(List<FieldImpl> L, Atom name, ImmutableByteArray fieldType, int accessFlags,
-      Collection<Annotation> annotations, TypeSignature sig) {
+      Collection<Annotation> annotations, Collection<TypeAnnotation> typeAnnotations, TypeSignature sig) {
     TypeName T = null;
     if (fieldType.get(fieldType.length() - 1) == ';') {
       T = TypeName.findOrCreate(fieldType, 0, fieldType.length() - 1);
@@ -577,7 +586,7 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
     }
     TypeReference type = TypeReference.findOrCreate(getClassLoader().getReference(), T);
     FieldReference fr = FieldReference.findOrCreate(getReference(), name, type);
-    FieldImpl f = new FieldImpl(this, fr, accessFlags, annotations, sig);
+    FieldImpl f = new FieldImpl(this, fr, accessFlags, annotations, typeAnnotations, sig);
     L.add(f);
   }
 
@@ -594,10 +603,9 @@ public abstract class BytecodeClass<T extends IClassLoader> implements IClass {
           if (methods.length > 5) {
             tmpMethodMap = HashMapFactory.make(methods.length);
           } else {
-            tmpMethodMap= new SmallMap<Selector, IMethod>();
+            tmpMethodMap= new SmallMap<>();
           }
-          for (int i = 0; i < methods.length; i++) {
-            IMethod m = methods[i];
+          for (IMethod m : methods) {
             tmpMethodMap.put(m.getReference().getSelector(), m);
           }
           
