@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.classLoader;
 
 import java.io.BufferedInputStream;
@@ -25,7 +25,6 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.TreeSet;
 import java.util.jar.JarEntry;
 import java.util.jar.JarInputStream;
 
@@ -35,10 +34,8 @@ import com.ibm.wala.shrikeCT.InvalidClassFileException;
 import com.ibm.wala.ssa.SSAInstructionFactory;
 import com.ibm.wala.types.ClassLoaderReference;
 import com.ibm.wala.types.TypeName;
-import com.ibm.wala.util.collections.HashCodeComparator;
 import com.ibm.wala.util.collections.HashMapFactory;
 import com.ibm.wala.util.collections.HashSetFactory;
-import com.ibm.wala.util.collections.Iterator2Collection;
 import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.config.SetOfClasses;
 import com.ibm.wala.util.io.FileProvider;
@@ -96,6 +93,7 @@ public class ClassLoaderImpl implements IClassLoader {
    * @param parent parent loader for delegation
    * @param exclusions set of classes to exclude from loading
    */
+  @SuppressWarnings("unused")
   public ClassLoaderImpl(ClassLoaderReference loader, ArrayClassLoader arrayClassLoader, IClassLoader parent,
       SetOfClasses exclusions, IClassHierarchy cha) {
 
@@ -119,18 +117,14 @@ public class ClassLoaderImpl implements IClassLoader {
    * 
    * @param M the module
    * @return the Set of source files in the module
-   * @throws IOException
    */
+  @SuppressWarnings("unused")
   private Set<ModuleEntry> getSourceFiles(Module M) throws IOException {
     if (DEBUG_LEVEL > 0) {
       System.err.println("Get source files for " + M);
     }
-    TreeSet<ModuleEntry> sortedEntries = new TreeSet<ModuleEntry>(HashCodeComparator.instance());
-    sortedEntries.addAll(Iterator2Collection.toSet(M.getEntries()));
-
     HashSet<ModuleEntry> result = HashSetFactory.make();
-    for (Iterator it = sortedEntries.iterator(); it.hasNext();) {
-      ModuleEntry entry = (ModuleEntry) it.next();
+    for (ModuleEntry entry : Iterator2Iterable.make(M.getEntries())) {
       if (DEBUG_LEVEL > 0) {
         System.err.println("consider entry for source information: " + entry);
       }
@@ -151,17 +145,14 @@ public class ClassLoaderImpl implements IClassLoader {
    * 
    * @param M the module
    * @return the Set of class Files in the module
-   * @throws IOException
    */
+  @SuppressWarnings("unused")
   private Set<ModuleEntry> getClassFiles(Module M) throws IOException {
     if (DEBUG_LEVEL > 0) {
       System.err.println("Get class files for " + M);
     }
-    TreeSet<ModuleEntry> sortedEntries = new TreeSet<ModuleEntry>(HashCodeComparator.instance());
-    sortedEntries.addAll(Iterator2Collection.toSet(M.getEntries()));
     HashSet<ModuleEntry> result = HashSetFactory.make();
-    for (Iterator it = sortedEntries.iterator(); it.hasNext();) {
-      ModuleEntry entry = (ModuleEntry) it.next();
+    for (ModuleEntry entry : Iterator2Iterable.make(M.getEntries())) {
       if (DEBUG_LEVEL > 0) {
         System.err.println("ClassLoaderImpl.getClassFiles:Got entry: " + entry);
       }
@@ -186,20 +177,8 @@ public class ClassLoaderImpl implements IClassLoader {
   /**
    * Remove from s any class file module entries which already are in t
    */
-  private void removeClassFiles(Set<ModuleEntry> s, Set<ModuleEntry> t) {
-    Set<String> old = HashSetFactory.make();
-    for (Iterator<ModuleEntry> it = t.iterator(); it.hasNext();) {
-      ModuleEntry m = it.next();
-      old.add(m.getClassName());
-    }
-    HashSet<ModuleEntry> toRemove = HashSetFactory.make();
-    for (Iterator<ModuleEntry> it = s.iterator(); it.hasNext();) {
-      ModuleEntry m = it.next();
-      if (old.contains(m.getClassName())) {
-        toRemove.add(m);
-      }
-    }
-    s.removeAll(toRemove);
+  private static void removeClassFiles(Set<ModuleEntry> s, Set<ModuleEntry> t) {
+    s.removeAll(t);
   }
 
   /**
@@ -246,13 +225,14 @@ public class ClassLoaderImpl implements IClassLoader {
   /**
    * Set up the set of classes loaded by this object.
    */
+  @SuppressWarnings("unused")
   private void loadAllClasses(Collection<ModuleEntry> moduleEntries, Map<String, Object> fileContents) {
-    for (Iterator<ModuleEntry> it = moduleEntries.iterator(); it.hasNext();) {
-      ModuleEntry entry = it.next();
+    for (ModuleEntry entry : moduleEntries) {
       if (!entry.isClassFile()) {
         continue;
       }
 
+      @SuppressWarnings("NonConstantStringShouldBeStringBuffer")
       String className = entry.getClassName().replace('.', '/');
 
       if (DEBUG_LEVEL > 0) {
@@ -268,7 +248,7 @@ public class ClassLoaderImpl implements IClassLoader {
 
       ShrikeClassReaderHandle entryReader = new ShrikeClassReaderHandle(entry);
 
-      className = "L" + className;
+      className = 'L' + className;
       if (DEBUG_LEVEL > 0) {
         System.err.println("Load class " + className);
       }
@@ -294,7 +274,7 @@ public class ClassLoaderImpl implements IClassLoader {
             // so we can null out and re-read class file contents
             loadedClasses.put(T, new ShrikeClass(entryReader, this, cha));
             if (DEBUG_LEVEL > 1) {
-              System.err.println("put " + T + " ");
+              System.err.println("put " + T + ' ');
             }
           } else {
             Warnings.add(InvalidClassFile.create(className));
@@ -320,11 +300,10 @@ public class ClassLoaderImpl implements IClassLoader {
       return null;
     }
     Map<String, Object> result = HashMapFactory.make();
-    try {
-      JarInputStream s = new JarInputStream(new ByteArrayInputStream(jarFileContents));
+    try (final JarInputStream s = new JarInputStream(new ByteArrayInputStream(jarFileContents), false)) {
       JarEntry entry = null;
       while ((entry = s.getNextJarEntry()) != null) {
-        byte[] entryBytes = getEntryBytes(entry, entrySizesForFile.get(entry.getName()), s);
+        byte[] entryBytes = getEntryBytes(entrySizesForFile.get(entry.getName()), s);
         if (entryBytes == null) {
           return null;
         }
@@ -334,9 +313,10 @@ public class ClassLoaderImpl implements IClassLoader {
           if (nestedResult == null) {
             return null;
           }
-          for (String entryName : nestedResult.keySet()) {
+          for (Map.Entry<String, Object> nestedEntry : nestedResult.entrySet()) {
+            final String entryName = nestedEntry.getKey();
             if (!result.containsKey(entryName)) {
-              result.put(entryName, nestedResult.get(entryName));
+              result.put(entryName, nestedEntry.getValue());
             }
           }
         } else if (FileSuffixes.isClassFile(name) || FileSuffixes.isSourceFile(name)) {
@@ -349,7 +329,7 @@ public class ClassLoaderImpl implements IClassLoader {
     return result;
   }
 
-  private byte[] getEntryBytes(JarEntry entry, Long size, InputStream is) throws IOException {
+  private static byte[] getEntryBytes(Long size, InputStream is) throws IOException {
     if (size == null) {
       return null;
     }
@@ -414,12 +394,12 @@ public class ClassLoaderImpl implements IClassLoader {
   /**
    * Set up mapping from type name to Module Entry
    */
+  @SuppressWarnings("unused")
   protected void loadAllSources(Set<ModuleEntry> sourceModules) {
-    for (Iterator<ModuleEntry> it = sourceModules.iterator(); it.hasNext();) {
-      ModuleEntry entry = it.next();
+    for (ModuleEntry entry : sourceModules) {
       String className = entry.getClassName().replace('.', '/');
       className = className.replace(File.separatorChar, '/');
-      className = "L" + ((className.startsWith("/")) ? className.substring(1) : className);
+      className = 'L' + ((className.startsWith("/")) ? className.substring(1) : className);
       TypeName T = TypeName.string2TypeName(className);
 
       // Note: entry.getClassName() may not return the correct class name, for example, 
@@ -454,7 +434,7 @@ public class ClassLoaderImpl implements IClassLoader {
         // look at substrings starting after '/' characters, in the hope
         // that we find a known class name
         while (className.indexOf('/') > 0) {
-          className = "L" + className.substring(className.indexOf('/') + 1, className.length());
+          className = 'L' + className.substring(className.indexOf('/') + 1);
           TypeName T2 = TypeName.string2TypeName(className);
           if (loadedClasses.get(T2) != null) {
             if (DEBUG_LEVEL > 0) {
@@ -482,6 +462,7 @@ public class ClassLoaderImpl implements IClassLoader {
    * 
    * @throws IllegalArgumentException if modules is null
    */
+  @SuppressWarnings("unused")
   @Override
   public void init(List<Module> modules) throws IOException {
 
@@ -492,8 +473,7 @@ public class ClassLoaderImpl implements IClassLoader {
     // module are loaded according to the given order (same as in Java VM)
     Set<ModuleEntry> classModuleEntries = HashSetFactory.make();
     Set<ModuleEntry> sourceModuleEntries = HashSetFactory.make();
-    for (Iterator<Module> it = modules.iterator(); it.hasNext();) {
-      Module archive = it.next();
+    for (Module archive : modules) {
       if (DEBUG_LEVEL > 0) {
         System.err.println("add archive: " + archive);
       }
@@ -527,14 +507,8 @@ public class ClassLoaderImpl implements IClassLoader {
       }
       loadAllClasses(classFiles, allClassAndSourceFileContents);
       loadAllSources(sourceFiles);
-      for (Iterator<ModuleEntry> it2 = classFiles.iterator(); it2.hasNext();) {
-        ModuleEntry file = it2.next();
-        classModuleEntries.add(file);
-      }
-      for (Iterator<ModuleEntry> it2 = sourceFiles.iterator(); it2.hasNext();) {
-        ModuleEntry file = it2.next();
-        sourceModuleEntries.add(file);
-      }
+      classModuleEntries.addAll(classFiles);
+      sourceModuleEntries.addAll(sourceFiles);
     }
   }
 
@@ -558,7 +532,7 @@ public class ClassLoaderImpl implements IClassLoader {
   /**
    * get the contents of a jar file. if any IO exceptions occur, catch and return null.
    */
-  private void getJarFileContents(JarFileModule archive) {
+  private static void getJarFileContents(JarFileModule archive) {
     String jarFileName = archive.getJarFile().getName();
     InputStream s = null;
     try {
@@ -594,6 +568,7 @@ public class ClassLoaderImpl implements IClassLoader {
   /*
    * @see com.ibm.wala.classLoader.IClassLoader#lookupClass(com.ibm.wala.types.TypeName)
    */
+  @SuppressWarnings("unused")
   @Override
   public IClass lookupClass(TypeName className) {
     if (className == null) {
@@ -658,8 +633,7 @@ public class ClassLoaderImpl implements IClassLoader {
   @Override
   public int getNumberOfMethods() {
     int result = 0;
-    for (Iterator<IClass> it = iterateAllClasses(); it.hasNext();) {
-      IClass klass = it.next();
+    for (IClass klass : Iterator2Iterable.make(iterateAllClasses())) {
       result += klass.getDeclaredMethods().size();
     }
     return result;
@@ -704,14 +678,9 @@ public class ClassLoaderImpl implements IClassLoader {
     if (toRemove == null) {
       throw new IllegalArgumentException("toRemove is null");
     }
-    for (Iterator<IClass> it = toRemove.iterator(); it.hasNext();) {
-      IClass klass = it.next();
-      if (DEBUG_LEVEL > 0) {
-        System.err.println("removing " + klass.getName());
-      }
-      loadedClasses.remove(klass.getName());
-      sourceMap.remove(klass.getName());
-    }
+    toRemove.stream().map(IClass::getName)
+            .peek(loadedClasses::remove)
+            .forEach(sourceMap::remove);
   }
 
   @Override
