@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.classLoader;
 
 import java.lang.ref.SoftReference;
@@ -145,69 +145,84 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
     }
     if (result == null) {
       result = computeBCInfo();
-      bcInfo = new SoftReference<BytecodeInfo>(result);
+      bcInfo = new SoftReference<>(result);
     }
     return result;
   }
 
   /**
    * Return the program counter (bytecode index) for a particular Shrike instruction index.
-   * 
-   * @throws InvalidClassFileException
    */
   public int getBytecodeIndex(int instructionIndex) throws InvalidClassFileException {
     return getBCInfo().pcMap[instructionIndex];
   }
 
   /**
-   * Return the number of Shrike instructions for this method.
+   * Return the Shrike instruction index for a particular valid program counter (bytecode index), or -1 if 
+   * the Shrike instriction index could not be determined. 
    * 
-   * @throws InvalidClassFileException
+   * This ShrikeBTMethod must not be native.
+   */
+  public int getInstructionIndex(int bcIndex) throws InvalidClassFileException {
+    if (isNative()) {
+      throw new UnsupportedOperationException("getInstructionIndex(int bcIndex) is only supported for non-native bytecode");
+    }
+
+    final BytecodeInfo info = getBCInfo();
+    if (info.decoder.containsSubroutines()) return -1;
+
+    final int[] pcMap = info.pcMap;
+    assert isSorted(pcMap);
+
+    int iindex = Arrays.binarySearch(pcMap, bcIndex);
+    if (iindex < 0) return -1;
+
+    // Unfortunately, pcMap is not always *strictly* sorted: given bcIndex, there may be multiple adjacent indices
+    // i,j such that pcMap[i] == bcIndex == pcMap[j]. We pick the least such index.
+    while (iindex > 0 && pcMap[iindex - 1] == bcIndex) iindex--;
+    return iindex;
+  }
+
+  private static boolean isSorted(int[] a) {
+    for (int i = 0; i < a.length - 1; i++) {
+      if (a[i+1] < a[i]) return false;
+    }
+    return true;
+  }
+
+  /**
+   * Return the number of Shrike instructions for this method.
    */
   public int getNumShrikeInstructions() throws InvalidClassFileException {
     return getBCInfo().pcMap.length;
   }
 
-  /**
-   * @throws InvalidClassFileException
-   */
   public Collection<CallSiteReference> getCallSites() throws InvalidClassFileException {
-    Collection<CallSiteReference> empty = Collections.emptySet();
-    if (isNative()) {
-      return empty;
-    }
-    return (getBCInfo().callSites == null) ? empty : Collections.unmodifiableCollection(Arrays.asList(getBCInfo().callSites));
+    return isNative() || getBCInfo().callSites == null
+            ? Collections.emptySet()
+            : Collections.unmodifiableCollection(Arrays.asList(getBCInfo().callSites));
   }
 
-  /**
-   * @throws InvalidClassFileException
-   */
   Collection<NewSiteReference> getNewSites() throws InvalidClassFileException {
-    Collection<NewSiteReference> empty = Collections.emptySet();
-    if (isNative()) {
-      return empty;
-    }
-
-    return (getBCInfo().newSites == null) ? empty : Collections.unmodifiableCollection(Arrays.asList(getBCInfo().newSites));
+    return (isNative() || getBCInfo().newSites == null)
+            ? Collections.emptySet()
+            : Collections.unmodifiableCollection(Arrays.asList(getBCInfo().newSites));
   }
 
   /**
-   * @return Set <TypeReference>, the exceptions that statements in this method may throw,
-   * @throws InvalidClassFileException
+   * @return {@link Set}&lt;{@link TypeReference}&gt;, the exceptions that statements in this method may throw,
    */
   public Collection<TypeReference> getImplicitExceptionTypes() throws InvalidClassFileException {
     if (isNative()) {
       return Collections.emptySet();
     }
-    return (getBCInfo().implicitExceptions == null) ? Arrays.asList(new TypeReference[0]) : Arrays
+    return (getBCInfo().implicitExceptions == null) ? Collections.emptyList() : Arrays
         .asList(getBCInfo().implicitExceptions);
   }
 
   /**
    * Do a cheap pass over the bytecodes to collect some mapping information. Some methods require this as a pre-req to accessing
    * ShrikeCT information.
-   * 
-   * @throws InvalidClassFileException
    */
   private BytecodeInfo computeBCInfo() throws InvalidClassFileException {
     BytecodeInfo result = new BytecodeInfo();
@@ -229,7 +244,6 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
 
   /**
    * @return true iff this method has a monitorenter or monitorexit
-   * @throws InvalidClassFileException
    */
   public boolean hasMonitorOp() throws InvalidClassFileException {
     if (isNative()) {
@@ -240,7 +254,6 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
 
   /**
    * @return Set of FieldReference
-   * @throws InvalidClassFileException
    */
   public Iterator<FieldReference> getFieldsWritten() throws InvalidClassFileException {
     if (isNative()) {
@@ -256,7 +269,6 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
 
   /**
    * @return Iterator of FieldReference
-   * @throws InvalidClassFileException
    */
   public Iterator<FieldReference> getFieldsRead() throws InvalidClassFileException {
     if (isNative()) {
@@ -272,9 +284,8 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
 
   /**
    * @return Iterator of TypeReference
-   * @throws InvalidClassFileException
    */
-  public Iterator getArraysRead() throws InvalidClassFileException {
+  public Iterator<TypeReference> getArraysRead() throws InvalidClassFileException {
     if (isNative()) {
       return EmptyIterator.instance();
     }
@@ -283,7 +294,6 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
 
   /**
    * @return Iterator of TypeReference
-   * @throws InvalidClassFileException
    */
   public Iterator<TypeReference> getArraysWritten() throws InvalidClassFileException {
     if (isNative()) {
@@ -299,9 +309,8 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
 
   /**
    * @return Iterator of TypeReference
-   * @throws InvalidClassFileException
    */
-  public Iterator getCastTypes() throws InvalidClassFileException {
+  public Iterator<TypeReference> getCastTypes() throws InvalidClassFileException {
     if (isNative()) {
       return EmptyIterator.instance();
     }
@@ -406,7 +415,10 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
   }
 
   @Override
-  public boolean isSynthetic() {
+  public boolean isSynthetic() { return ((getModifiers() & Constants.ACC_SYNTHETIC) != 0); }
+
+  @Override
+  public boolean isWalaSynthetic() {
     return false;
   }
 
@@ -424,8 +436,6 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
 
   /**
    * Walk through the bytecodes and collect trivial information.
-   * 
-   * @throws InvalidClassFileException
    */
   protected abstract void processDebugInfo(BytecodeInfo bcInfo) throws InvalidClassFileException;
 
@@ -461,75 +471,69 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
     copyVisitorSetsToArrays(simpleVisitor, info);
   }
 
-  private void copyVisitorSetsToArrays(SimpleVisitor simpleVisitor, BytecodeInfo info) {
+  private static void copyVisitorSetsToArrays(SimpleVisitor simpleVisitor, BytecodeInfo info) {
     info.newSites = new NewSiteReference[simpleVisitor.newSites.size()];
     int i = 0;
-    for (Iterator<NewSiteReference> it = simpleVisitor.newSites.iterator(); it.hasNext();) {
-      info.newSites[i++] = it.next();
+    for (NewSiteReference newSiteReference : simpleVisitor.newSites) {
+      info.newSites[i++] = newSiteReference;
     }
 
     info.fieldsRead = new FieldReference[simpleVisitor.fieldsRead.size()];
     i = 0;
-    for (Iterator<FieldReference> it = simpleVisitor.fieldsRead.iterator(); it.hasNext();) {
-      info.fieldsRead[i++] = it.next();
+    for (FieldReference fieldReference : simpleVisitor.fieldsRead) {
+      info.fieldsRead[i++] = fieldReference;
     }
 
     info.fieldsRead = new FieldReference[simpleVisitor.fieldsRead.size()];
     i = 0;
-    for (Iterator<FieldReference> it = simpleVisitor.fieldsRead.iterator(); it.hasNext();) {
-      info.fieldsRead[i++] = it.next();
+    for (FieldReference fieldReference : simpleVisitor.fieldsRead) {
+      info.fieldsRead[i++] = fieldReference;
     }
 
     info.fieldsWritten = new FieldReference[simpleVisitor.fieldsWritten.size()];
     i = 0;
-    for (Iterator<FieldReference> it = simpleVisitor.fieldsWritten.iterator(); it.hasNext();) {
-      info.fieldsWritten[i++] = it.next();
+    for (FieldReference fieldReference : simpleVisitor.fieldsWritten) {
+      info.fieldsWritten[i++] = fieldReference;
     }
 
     info.callSites = new CallSiteReference[simpleVisitor.callSites.size()];
     i = 0;
-    for (Iterator<CallSiteReference> it = simpleVisitor.callSites.iterator(); it.hasNext();) {
-      info.callSites[i++] = it.next();
+    for (CallSiteReference callSiteReference : simpleVisitor.callSites) {
+      info.callSites[i++] = callSiteReference;
     }
 
     info.arraysRead = new TypeReference[simpleVisitor.arraysRead.size()];
     i = 0;
-    for (Iterator<TypeReference> it = simpleVisitor.arraysRead.iterator(); it.hasNext();) {
-      info.arraysRead[i++] = it.next();
+    for (TypeReference typeReference : simpleVisitor.arraysRead) {
+      info.arraysRead[i++] = typeReference;
     }
 
     info.arraysWritten = new TypeReference[simpleVisitor.arraysWritten.size()];
     i = 0;
-    for (Iterator<TypeReference> it = simpleVisitor.arraysWritten.iterator(); it.hasNext();) {
-      info.arraysWritten[i++] = it.next();
+    for (TypeReference typeReference : simpleVisitor.arraysWritten) {
+      info.arraysWritten[i++] = typeReference;
     }
 
     info.implicitExceptions = new TypeReference[simpleVisitor.implicitExceptions.size()];
     i = 0;
-    for (Iterator it = simpleVisitor.implicitExceptions.iterator(); it.hasNext();) {
-      info.implicitExceptions[i++] = (TypeReference) it.next();
+    for (TypeReference typeReference : simpleVisitor.implicitExceptions) {
+      info.implicitExceptions[i++] = typeReference;
     }
 
     info.castTypes = new TypeReference[simpleVisitor.castTypes.size()];
     i = 0;
-    for (Iterator<TypeReference> it = simpleVisitor.castTypes.iterator(); it.hasNext();) {
-      info.castTypes[i++] = it.next();
+    for (TypeReference typeReference : simpleVisitor.castTypes) {
+      info.castTypes[i++] = typeReference;
     }
 
     info.hasMonitorOp = simpleVisitor.hasMonitorOp;
   }
 
-  /**
-   * @see java.lang.Object#toString()
-   */
   @Override
   public String toString() {
     return getReference().toString();
   }
 
-  /**
-   * @see java.lang.Object#equals(Object)
-   */
   @Override
   public boolean equals(Object obj) {
     // instanceof is OK because this class is final.
@@ -542,9 +546,6 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
     }
   }
 
-  /**
-   * @see java.lang.Object#hashCode()
-   */
   @Override
   public int hashCode() {
     return 9661 * getReference().hashCode();
@@ -606,7 +607,7 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
       instructionIndex = i;
     }
 
-    public int getProgramCounter() throws InvalidClassFileException {
+    public int getProgramCounter() {
       return info.pcMap[instructionIndex];
     }
 
@@ -619,12 +620,7 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
     public void visitNew(NewInstruction instruction) {
       ClassLoaderReference loader = getReference().getDeclaringClass().getClassLoader();
       TypeReference t = ShrikeUtil.makeTypeReference(loader, instruction.getType());
-      try {
-        newSites.add(NewSiteReference.make(getProgramCounter(), t));
-      } catch (InvalidClassFileException e) {
-        e.printStackTrace();
-        Assertions.UNREACHABLE();
-      }
+      newSites.add(NewSiteReference.make(getProgramCounter(), t));
     }
 
     @Override
@@ -649,12 +645,7 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
       MethodReference m = MethodReference.findOrCreate(loader.getLanguage(), loader.getReference(), instruction.getClassType(),
           instruction.getMethodName(), instruction.getMethodSignature());
       int programCounter = 0;
-      try {
-        programCounter = getProgramCounter();
-      } catch (InvalidClassFileException e) {
-        e.printStackTrace();
-        Assertions.UNREACHABLE();
-      }
+      programCounter = getProgramCounter();
       CallSiteReference site = null;
       site = CallSiteReference.make(programCounter, m, instruction.getInvocationCode());
       callSites.add(site);
@@ -740,10 +731,6 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
 
   /**
    * Clients should not modify the returned array. TODO: clone to avoid the problem?
-   * 
-   * @throws InvalidClassFileException
-   * 
-   * @see com.ibm.wala.classLoader.IMethod#getDeclaredExceptions()
    */
   @Override
   public TypeReference[] getDeclaredExceptions() throws InvalidClassFileException {
@@ -766,7 +753,7 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
 
       TypeReference[] result = new TypeReference[strings.length];
       for (int i = 0; i < result.length; i++) {
-        result[i] = TypeReference.findOrCreate(loader, TypeName.findOrCreate(ImmutableByteArray.make("L" + strings[i])));
+        result[i] = TypeReference.findOrCreate(loader, TypeName.findOrCreate(ImmutableByteArray.make('L' + strings[i])));
       }
       return result;
     } catch (InvalidClassFileException e) {
@@ -779,6 +766,7 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
   /*
    * @see com.ibm.wala.classLoader.IMethod#getSourcePosition(int)
    */
+  @Override
   public SourcePosition getSourcePosition(int bcIndex) throws InvalidClassFileException {
     return (getBCInfo().positionMap == null) ? null : getBCInfo().positionMap[bcIndex];
   }
@@ -786,6 +774,7 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
   /*
    * @see com.ibm.wala.classLoader.IMethod#getParameterSourcePosition(int)
    */
+  @Override
   public SourcePosition getParameterSourcePosition(int paramNum) throws InvalidClassFileException {
     return (getBCInfo().paramPositionMap == null) ? null : getBCInfo().paramPositionMap[paramNum];
   }
@@ -804,8 +793,7 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
   }
 
   /**
-   * @return Set <TypeReference>
-   * @throws InvalidClassFileException
+   * @return {@link Set}&lt;{@link TypeReference}&gt;
    */
   public Set<TypeReference> getCaughtExceptionTypes() throws InvalidClassFileException {
 
@@ -815,9 +803,9 @@ public abstract class ShrikeBTMethod implements IMethod, BytecodeConstants {
     }
     HashSet<TypeReference> result = HashSetFactory.make(10);
     ClassLoaderReference loader = getReference().getDeclaringClass().getClassLoader();
-    for (int i = 0; i < handlers.length; i++) {
-      for (int j = 0; j < handlers[i].length; j++) {
-        TypeReference t = ShrikeUtil.makeTypeReference(loader, handlers[i][j].getCatchClass());
+    for (ExceptionHandler[] handler : handlers) {
+      for (ExceptionHandler element : handler) {
+        TypeReference t = ShrikeUtil.makeTypeReference(loader, element.getCatchClass());
         if (t == null) {
           t = TypeReference.JavaLangThrowable;
         }
