@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,14 +7,13 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.dataflow.IFDS;
 
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Comparator;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
@@ -30,6 +29,7 @@ import com.ibm.wala.util.collections.HashMapFactory;
 import com.ibm.wala.util.collections.HashSetFactory;
 import com.ibm.wala.util.collections.Heap;
 import com.ibm.wala.util.collections.Iterator2Collection;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.collections.MapUtil;
 import com.ibm.wala.util.collections.ToStringComparator;
 import com.ibm.wala.util.heapTrace.HeapTracer;
@@ -52,7 +52,7 @@ import com.ibm.wala.util.ref.ReferenceCleanser;
  * <li>it stores summary edges at each callee instead of at each call site.
  * </ul>
  * <p>
- * 
+ *
  * @param <T> type of node in the supergraph
  * @param <P> type of a procedure (like a box in an RSM)
  * @param <F> type of factoids propagated when solving this problem
@@ -110,24 +110,24 @@ public class TabulationSolver<T, P, F> {
   private final TabulationProblem<T, P, F> problem;
 
   /**
-   * A map from Object (entry node in supergraph) -> LocalPathEdges.
-   * 
-   * Logically, this represents a set of edges (s_p,d_i) -> (n, d_j). The data structure is chosen to attempt to save space over
+   * A map from Object (entry node in supergraph) -&gt; LocalPathEdges.
+   *
+   * Logically, this represents a set of edges (s_p,d_i) -&gt; (n, d_j). The data structure is chosen to attempt to save space over
    * representing each edge explicitly.
    */
   final private Map<T, LocalPathEdges> pathEdges = HashMapFactory.make();
 
   /**
-   * A map from Object (entry node in supergraph) -> CallFlowEdges.
-   * 
-   * Logically, this represents a set of edges (c,d_i) -> (s_p, d_j). The data structure is chosen to attempt to save space over
+   * A map from Object (entry node in supergraph) -&gt; CallFlowEdges.
+   *
+   * Logically, this represents a set of edges (c,d_i) -&gt; (s_p, d_j). The data structure is chosen to attempt to save space over
    * representing each edge explicitly.
    */
   final private Map<T, CallFlowEdges> callFlowEdges = HashMapFactory.make();
 
   /**
-   * A map from Object (procedure) -> LocalSummaryEdges.
-   * 
+   * A map from Object (procedure) -&gt; LocalSummaryEdges.
+   *
    */
   final protected Map<P, LocalSummaryEdges> summaryEdges = HashMapFactory.make();
 
@@ -152,7 +152,7 @@ public class TabulationSolver<T, P, F> {
   protected final IProgressMonitor progressMonitor;
 
   /**
-   * the path edge currently being processed in the main loop of {@link #forwardTabulateSLRPs()}; <code>null</code> if
+   * the path edge currently being processed in the main loop of {@link #forwardTabulateSLRPs()}; {@code null} if
    * {@link #forwardTabulateSLRPs()} is not currently running. Note that if we are applying a summary edge in
    * {@link #processExit(PathEdge)}, curPathEdge is modified to be the path edge terminating at the call node in the caller, to
    * match the behavior in {@link #processCall(PathEdge)}.
@@ -161,7 +161,7 @@ public class TabulationSolver<T, P, F> {
 
   /**
    * the summary edge currently being applied in {@link #processCall(PathEdge)} or {@link #processExit(PathEdge)}, or
-   * <code>null</code> if summary edges are not currently being processed.
+   * {@code null} if summary edges are not currently being processed.
    */
   private PathEdge<T> curSummaryEdge;
 
@@ -191,12 +191,12 @@ public class TabulationSolver<T, P, F> {
    * @throws IllegalArgumentException if p is null
    */
   public static <T, P, F> TabulationSolver<T, P, F> make(TabulationProblem<T, P, F> p) {
-    return new TabulationSolver<T, P, F>(p, null);
+    return new TabulationSolver<>(p, null);
   }
 
   /**
    * Solve the dataflow problem.
-   * 
+   *
    * @return a representation of the result
    */
   public TabulationResult<T, P, F> solve() throws CancelException {
@@ -238,9 +238,8 @@ public class TabulationSolver<T, P, F> {
 
   /**
    * See POPL 95 paper for this algorithm, Figure 3
-   * 
-   * @throws CancelException
    */
+  @SuppressWarnings("unused")
   private void forwardTabulateSLRPs() throws CancelException {
     assert curPathEdge == null : "curPathEdge should not be non-null here";
     if (worklist == null) {
@@ -293,7 +292,7 @@ public class TabulationSolver<T, P, F> {
   /**
    * For some reason (either a bug in our code that defeats soft references, or a bad policy in the GC), leaving soft reference
    * caches to clear themselves out doesn't work. Help it out.
-   * 
+   *
    * It's unfortunate that this method exits.
    */
   protected void tendToSoftCaches() {
@@ -305,7 +304,7 @@ public class TabulationSolver<T, P, F> {
   }
 
   /**
-   * 
+   *
    */
   protected final void performVerboseAction() {
     verboseCounter++;
@@ -323,15 +322,13 @@ public class TabulationSolver<T, P, F> {
 
   /**
    * Handle lines [33-37] of the algorithm
-   * 
-   * @param edge
    */
+  @SuppressWarnings("unused")
   private void processNormal(final PathEdge<T> edge) {
     if (DEBUG_LEVEL > 0) {
       System.err.println("process normal: " + edge);
     }
-    for (Iterator<? extends T> it = supergraph.getSuccNodes(edge.target); it.hasNext();) {
-      final T m = it.next();
+    for (T m : Iterator2Iterable.make(supergraph.getSuccNodes(edge.target))) {
       if (DEBUG_LEVEL > 0) {
         System.err.println("normal successor: " + m);
       }
@@ -341,11 +338,9 @@ public class TabulationSolver<T, P, F> {
         System.err.println(" reached: " + D3);
       }
       if (D3 != null) {
-        D3.foreach(new IntSetAction() {
-          @Override
-          public void act(int d3) {
-            propagate(edge.entry, edge.d1, m, d3);
-          }
+        D3.foreach(d3 -> {
+          newNormalExplodedEdge(edge, m, d3);
+          propagate(edge.entry, edge.d1, m, d3);
         });
       }
     }
@@ -353,10 +348,11 @@ public class TabulationSolver<T, P, F> {
 
   /**
    * Handle lines [21 - 32] of the algorithm, propagating information from an exit node.
-   * 
+   *
    * Note that we've changed the way we record summary edges. Summary edges are now associated with a callee (s_p,exit), where the
    * original algorithm used a call, return pair in the caller.
    */
+  @SuppressWarnings("unused")
   protected void processExit(final PathEdge<T> edge) {
     if (DEBUG_LEVEL > 0) {
       System.err.println("process exit: " + edge);
@@ -390,14 +386,14 @@ public class TabulationSolver<T, P, F> {
 
   /**
    * Propagate information for an "exit" edge to the appropriate return sites
-   * 
-   * [23] for each d5 s.t. <s_p,d2> -> <returnSite(c),d5> ..
-   * 
+   *
+   * [23] for each d5 s.t. {@literal <s_p,d2> -> <returnSite(c),d5>} ..
+   *
    * @param edge the edge being processed
-   * @param succ numbers of the nodes that are successors of edge.n (the return block in the callee) in the call graph.
    * @param c a call site of edge.s_p
-   * @param D4 set of d1 s.t. <c, d1> -> <edge.s_p, edge.d2> was recorded as call flow
+   * @param D4 set of d1 s.t. {@literal <c, d1> -> <edge.s_p, edge.d2>} was recorded as call flow
    */
+  @SuppressWarnings("unused")
   private void propagateToReturnSites(final PathEdge<T> edge, final T c, final IntSet D4) {
     P proc = supergraph.getProcOf(c);
     final T[] entries = supergraph.getEntriesForProcedure(proc);
@@ -407,10 +403,9 @@ public class TabulationSolver<T, P, F> {
     // note that we might have different summary edges for each
     // potential return site, and different flow functions from this
     // exit block to each return site.
-    for (Iterator<? extends T> retSites = supergraph.getReturnSites(c, supergraph.getProcOf(edge.target)); retSites.hasNext();) {
-      final T retSite = retSites.next();
+    for (T retSite : Iterator2Iterable.make(supergraph.getReturnSites(c, supergraph.getProcOf(edge.target)))) {
       if (DEBUG_LEVEL > 1) {
-        System.err.println("candidate return site: " + retSite + " " + supergraph.getNumber(retSite));
+        System.err.println("candidate return site: " + retSite + ' ' + supergraph.getNumber(retSite));
       }
       // note: since we might have multiple exit nodes for the callee, (to handle exceptional returns)
       // not every return site might be valid for this exit node (edge.n).
@@ -432,12 +427,7 @@ public class TabulationSolver<T, P, F> {
           System.err.println("D4" + D4);
           System.err.println("D5 " + D5);
         }
-        IntSetAction action = new IntSetAction() {
-          @Override
-          public void act(final int d4) {
-            propToReturnSite(c, entries, retSite, d4, D5);
-          }
-        };
+        IntSetAction action = d4 -> propToReturnSite(c, entries, retSite, d4, D5, edge);
         D4.foreach(action);
       }
     }
@@ -445,41 +435,40 @@ public class TabulationSolver<T, P, F> {
 
   /**
    * Propagate information for an "exit" edge to a caller return site
-   * 
-   * [23] for each d5 s.t. <s_p,d2> -> <returnSite(c),d5> ..
-   * 
+   *
+   * [23] for each d5 s.t. {@literal <s_p,d2> -> <returnSite(c),d5>} ..
+   *
    * @param edge the edge being processed
    * @param c a call site of edge.s_p
-   * @param D4 set of d1 s.t. <c, d1> -> <edge.s_p, edge.d2> was recorded as call flow
+   * @param D4 set of d1 s.t. {@literal <c, d1> -> <edge.s_p, edge.d2>} was recorded as call flow
    * @param entries the blocks in the supergraph that are entries for the procedure of c
    * @param retSite the return site being propagated to
    * @param retf the flow function
    */
-  private void propagateToReturnSiteWithBinaryFlowFunction(final PathEdge edge, final T c, final IntSet D4, final T[] entries,
+  private void propagateToReturnSiteWithBinaryFlowFunction(final PathEdge<T> edge, final T c, final IntSet D4, final T[] entries,
       final T retSite, final IFlowFunction retf) {
-    D4.foreach(new IntSetAction() {
-      @Override
-      public void act(final int d4) {
-        final IntSet D5 = computeBinaryFlow(d4, edge.d2, (IBinaryReturnFlowFunction) retf);
-        propToReturnSite(c, entries, retSite, d4, D5);
-      }
-
+    D4.foreach(d4 -> {
+      final IntSet D5 = computeBinaryFlow(d4, edge.d2, (IBinaryReturnFlowFunction) retf);
+      propToReturnSite(c, entries, retSite, d4, D5, edge);
     });
   }
 
   /**
    * Propagate information to a particular return site.
-   * 
+   *
    * @param c the corresponding call site
    * @param entries entry nodes in the caller
    * @param retSite the return site
-   * @param d4 a fact s.t. <c, d4> -> <callee, d2> was recorded as call flow and <callee, d2> is the source of the summary edge
-   *          being applied
+   * @param d4 a fact s.t. {@literal <c, d4> -> <callee, d2>} was
+   *          recorded as call flow and {@literal <callee, d2>} is the
+   *          source of the summary edge being applied
    * @param D5 facts to propagate to return site
+   * @param edge the path edge ending at the exit site of the callee
    */
-  private void propToReturnSite(final T c, final T[] entries, final T retSite, final int d4, final IntSet D5) {
+  private void propToReturnSite(final T c, final T[] entries, final T retSite, final int d4, final IntSet D5, final PathEdge<T> edge) {
     if (D5 != null) {
       D5.foreach(new IntSetAction() {
+        @SuppressWarnings("unused")
         @Override
         public void act(final int d5) {
           // [26 - 28]
@@ -490,8 +479,7 @@ public class TabulationSolver<T, P, F> {
           // with respect to one s_profOf(c), we have to propagate
           // for each
           // potential entry node s_p /in s_procof(c)
-          for (int i = 0; i < entries.length; i++) {
-            final T s_p = entries[i];
+          for (final T s_p : entries) {
             if (DEBUG_LEVEL > 1) {
               System.err.println(" do entry " + s_p);
             }
@@ -500,13 +488,11 @@ public class TabulationSolver<T, P, F> {
               System.err.println("D3" + D3);
             }
             if (D3 != null) {
-              D3.foreach(new IntSetAction() {
-                @Override
-                public void act(int d3) {
-                  // set curPathEdge to be consistent with its setting in processCall() when applying a summary edge
-                  curPathEdge = PathEdge.createPathEdge(s_p, d3, c, d4);
-                  propagate(s_p, d3, retSite, d5);
-                }
+              D3.foreach(d3 -> {
+                // set curPathEdge to be consistent with its setting in processCall() when applying a summary edge
+                curPathEdge = PathEdge.createPathEdge(s_p, d3, c, d4);
+                newSummaryEdge(curPathEdge, edge, retSite, d5);
+                propagate(s_p, d3, retSite, d5);
               });
             }
           }
@@ -516,10 +502,8 @@ public class TabulationSolver<T, P, F> {
   }
 
   /**
-   * @param s_p
-   * @param n
    * @param d2 note that s_p must be an entry for procof(n)
-   * @return set of d1 s.t. <s_p, d1> -> <n, d2> is a path edge, or null if none found
+   * @return set of d1 s.t. {@literal <s_p, d1> -> <n, d2>} is a path edge, or null if none found
    */
   protected IntSet getInversePathEdges(T s_p, T n, int d2) {
     int number = supergraph.getLocalBlockNumber(n);
@@ -533,6 +517,7 @@ public class TabulationSolver<T, P, F> {
   /**
    * Handle lines [14 - 19] of the algorithm, propagating information into and across a call site.
    */
+  @SuppressWarnings("unused")
   protected void processCall(final PathEdge<T> edge) {
     if (DEBUG_LEVEL > 0) {
       System.err.println("process call: " + edge);
@@ -543,20 +528,18 @@ public class TabulationSolver<T, P, F> {
 
     Collection<T> allReturnSites = HashSetFactory.make();
     // populate allReturnSites with return sites for missing calls.
-    for (Iterator<? extends T> it = supergraph.getReturnSites(edge.target, null); it.hasNext();) {
-      allReturnSites.add(it.next());
+    for (T retSite : Iterator2Iterable.make(supergraph.getReturnSites(edge.target, null))) {
+      allReturnSites.add(retSite);
     }
     // [14 - 16]
     boolean hasCallee = false;
-    for (Iterator<? extends T> it = supergraph.getCalledNodes(edge.target); it.hasNext();) {
+    for (T callee : Iterator2Iterable.make(supergraph.getCalledNodes(edge.target))) {
       hasCallee = true;
-      final T callee = it.next();
       processParticularCallee(edge, c, allReturnSites, callee);
     }
     // special logic: in backwards problems, a "call" node can have
     // "normal" successors as well. deal with these.
-    for (Iterator<? extends T> it = supergraph.getNormalSuccessors(edge.target); it.hasNext();) {
-      final T m = it.next();
+    for (T m : Iterator2Iterable.make(supergraph.getNormalSuccessors(edge.target))) {
       if (DEBUG_LEVEL > 0) {
         System.err.println("normal successor: " + m);
       }
@@ -566,11 +549,9 @@ public class TabulationSolver<T, P, F> {
         System.err.println("normal successor reached: " + D3);
       }
       if (D3 != null) {
-        D3.foreach(new IntSetAction() {
-          @Override
-          public void act(int d3) {
-            propagate(edge.entry, edge.d1, m, d3);
-          }
+        D3.foreach(d3 -> {
+          newNormalExplodedEdge(edge, m, d3);
+          propagate(edge.entry, edge.d1, m, d3);
         });
       }
     }
@@ -592,13 +573,11 @@ public class TabulationSolver<T, P, F> {
         System.err.println("reached: " + reached);
       }
       if (reached != null) {
-        reached.foreach(new IntSetAction() {
-          @Override
-          public void act(int x) {
-            assert x >= 0;
-            assert edge.d1 >= 0;
-            propagate(edge.entry, edge.d1, returnSite, x);
-          }
+        reached.foreach(x -> {
+          assert x >= 0;
+          assert edge.d1 >= 0;
+          newNormalExplodedEdge(edge, returnSite, x);
+          propagate(edge.entry, edge.d1, returnSite, x);
         });
       }
     }
@@ -606,12 +585,13 @@ public class TabulationSolver<T, P, F> {
 
   /**
    * handle a particular callee for some call node.
-   * 
+   *
    * @param edge the path edge being processed
    * @param callNodeNum the number of the call node in the supergraph
    * @param allReturnSites a set collecting return sites for the call. This set is mutated with the return sites for this callee.
    * @param calleeEntry the entry node of the callee in question
    */
+  @SuppressWarnings("unused")
   protected void processParticularCallee(final PathEdge<T> edge, final int callNodeNum, Collection<T> allReturnSites, final T calleeEntry) {
     if (DEBUG_LEVEL > 0) {
       System.err.println(" process callee: " + calleeEntry);
@@ -645,66 +625,56 @@ public class TabulationSolver<T, P, F> {
       final CallFlowEdges callFlow = findOrCreateCallFlowEdges(calleeEntry);
       final int s_p_num = supergraph.getLocalBlockNumber(calleeEntry);
 
-      reached.foreach(new IntSetAction() {
-        @Override
-        public void act(final int d1) {
-          // we get reuse if we _don't_ propagate a new fact to the callee entry
-          final boolean gotReuse = !propagate(calleeEntry, d1, calleeEntry, d1);
-          recordCall(edge.target, calleeEntry, d1, gotReuse);
-          // cache the fact that we've flowed <c, d2> -> <callee, d1> by a
-          // call flow
-          callFlow.addCallEdge(callNodeNum, edge.d2, d1);
-          // handle summary edges now as well. this is different from the PoPL
-          // 95 paper.
-          if (summaries != null) {
-            // for each exit from the callee
-            P p = supergraph.getProcOf(calleeEntry);
-            T[] exits = supergraph.getExitsForProcedure(p);
-            for (int e = 0; e < exits.length; e++) {
-              final T exit = exits[e];
-              if (DEBUG_LEVEL > 0) {
-                assert supergraph.containsNode(exit);
-              }
-              int x_num = supergraph.getLocalBlockNumber(exit);
-              // reachedBySummary := {d2} s.t. <callee,d1> -> <exit,d2>
-              // was recorded as a summary edge
-              IntSet reachedBySummary = summaries.getSummaryEdges(s_p_num, x_num, d1);
-              if (reachedBySummary != null) {
-                for (final T returnSite : returnSitesForCallee) {
-                  // if "exit" is a valid exit from the callee to the return
-                  // site being processed
-                  if (supergraph.hasEdge(exit, returnSite)) {
-                    final IFlowFunction retf = flowFunctionMap.getReturnFlowFunction(edge.target, exit, returnSite);
-                    reachedBySummary.foreach(new IntSetAction() {
-                      @Override
-                      public void act(int d2) {
-                        assert curSummaryEdge == null : "curSummaryEdge should be null here";
-                        curSummaryEdge = PathEdge.createPathEdge(calleeEntry, d1, exit, d2);
-                        if (retf instanceof IBinaryReturnFlowFunction) {
-                          final IntSet D5 = computeBinaryFlow(edge.d2, d2, (IBinaryReturnFlowFunction) retf);
-                          if (D5 != null) {
-                            D5.foreach(new IntSetAction() {
-                              @Override
-                              public void act(int d5) {
-                                propagate(edge.entry, edge.d1, returnSite, d5);
-                              }
-                            });
-                          }
-                        } else {
-                          final IntSet D5 = computeFlow(d2, (IUnaryFlowFunction) retf);
-                          if (D5 != null) {
-                            D5.foreach(new IntSetAction() {
-                              @Override
-                              public void act(int d5) {
-                                propagate(edge.entry, edge.d1, returnSite, d5);
-                              }
-                            });
-                          }
-                        }
-                        curSummaryEdge = null;
+      reached.foreach(d1 -> {
+        // we get reuse if we _don't_ propagate a new fact to the callee entry
+        final boolean gotReuse = !propagate(calleeEntry, d1, calleeEntry, d1);
+        recordCall(edge.target, calleeEntry, d1, gotReuse);
+        newCallExplodedEdge(edge, calleeEntry, d1);
+        // cache the fact that we've flowed <c, d2> -> <callee, d1> by a
+        // call flow
+        callFlow.addCallEdge(callNodeNum, edge.d2, d1);
+        // handle summary edges now as well. this is different from the PoPL
+        // 95 paper.
+        if (summaries != null) {
+          // for each exit from the callee
+          P p = supergraph.getProcOf(calleeEntry);
+          T[] exits = supergraph.getExitsForProcedure(p);
+          for (final T exit : exits) {
+            if (DEBUG_LEVEL > 0) {
+              assert supergraph.containsNode(exit);
+            }
+            int x_num = supergraph.getLocalBlockNumber(exit);
+            // reachedBySummary := {d2} s.t. <callee,d1> -> <exit,d2>
+            // was recorded as a summary edge
+            IntSet reachedBySummary = summaries.getSummaryEdges(s_p_num, x_num, d1);
+            if (reachedBySummary != null) {
+              for (final T returnSite : returnSitesForCallee) {
+                // if "exit" is a valid exit from the callee to the return
+                // site being processed
+                if (supergraph.hasEdge(exit, returnSite)) {
+                  final IFlowFunction retf = flowFunctionMap.getReturnFlowFunction(edge.target, exit, returnSite);
+                  reachedBySummary.foreach(d2 -> {
+                    assert curSummaryEdge == null : "curSummaryEdge should be null here";
+                    curSummaryEdge = PathEdge.createPathEdge(calleeEntry, d1, exit, d2);
+                    if (retf instanceof IBinaryReturnFlowFunction) {
+                      final IntSet D51 = computeBinaryFlow(edge.d2, d2, (IBinaryReturnFlowFunction) retf);
+                      if (D51 != null) {
+                        D51.foreach(d5 -> {
+                          newSummaryEdge(edge, curSummaryEdge, returnSite, d5);
+                          propagate(edge.entry, edge.d1, returnSite, d5);
+                        });
                       }
-                    });
-                  }
+                    } else {
+                      final IntSet D52 = computeFlow(d2, (IUnaryFlowFunction) retf);
+                      if (D52 != null) {
+                        D52.foreach(d5 -> {
+                          newSummaryEdge(edge, curSummaryEdge, returnSite, d5);
+                          propagate(edge.entry, edge.d1, returnSite, d5);
+                        });
+                      }
+                    }
+                    curSummaryEdge = null;
+                  });
                 }
               }
             }
@@ -716,19 +686,19 @@ public class TabulationSolver<T, P, F> {
 
   /**
    * invoked when a callee is processed with a particular entry fact
-   * 
-   * @param callNode
-   * @param callee
+   *
    * @param d1 the entry fact
    * @param gotReuse whether existing summary edges were applied
    */
+  @SuppressWarnings("unused")
   protected void recordCall(T callNode, T callee, int d1, boolean gotReuse) {
   }
 
   /**
    * @return f(call_d, exit_d);
-   * 
+   *
    */
+  @SuppressWarnings("unused")
   protected IntSet computeBinaryFlow(int call_d, int exit_d, IBinaryReturnFlowFunction f) {
     if (DEBUG_LEVEL > 0) {
       System.err.println("got binary flow function " + f);
@@ -739,8 +709,9 @@ public class TabulationSolver<T, P, F> {
 
   /**
    * @return f(d1)
-   * 
+   *
    */
+  @SuppressWarnings("unused")
   protected IntSet computeFlow(int d1, IUnaryFlowFunction f) {
     if (DEBUG_LEVEL > 0) {
       System.err.println("got flow function " + f);
@@ -766,7 +737,7 @@ public class TabulationSolver<T, P, F> {
     return worklist.take();
   }
 
-  private PathEdge peekFromWorkList() {
+  private PathEdge<T> peekFromWorkList() {
     // horrible. don't use in performance-critical
     assert worklist != null;
     PathEdge<T> result = worklist.take();
@@ -775,14 +746,15 @@ public class TabulationSolver<T, P, F> {
   }
 
   /**
-   * Propagate the fact <s_p,i> -> <n, j> has arisen as a path edge. Returns <code>true</code> iff the path edge was not previously
+   * Propagate the fact &lt;s_p,i&gt; -&gt; &lt;n, j&gt; has arisen as a path edge. Returns &lt;code&gt;true&lt;/code&gt; iff the path edge was not previously
    * observed.
-   * 
+   *
    * @param s_p entry block
    * @param i dataflow fact on entry
    * @param n reached block
    * @param j dataflow fact reached
    */
+  @SuppressWarnings("unused")
   protected boolean propagate(T s_p, int i, T n, int j) {
     int number = supergraph.getLocalBlockNumber(n);
     if (number < 0) {
@@ -797,7 +769,7 @@ public class TabulationSolver<T, P, F> {
 
     if (!pLocal.contains(i, number, j)) {
       if (DEBUG_LEVEL > 0) {
-        System.err.println("propagate " + s_p + "  " + i + " " + number + " " + j);
+        System.err.println("propagate " + s_p + "  " + i + ' ' + number + ' ' + j);
       }
       pLocal.addPathEdge(i, number, j);
       addToWorkList(s_p, i, n, j);
@@ -811,11 +783,11 @@ public class TabulationSolver<T, P, F> {
   }
 
   /**
-   * Merging: suppose we're doing propagate <s_p,i> -> <n,j> but we already have path edges <s_p,i> -> <n, x>, <s_p,i> -> <n,y>, and
-   * <s_p,i> -><n, z>.
-   * 
-   * let \alpha be the merge function. then instead of <s_p,i> -> <n,j>, we propagate <s_p,i> -> <n, \alpha(j,x,y,z) > !!!
-   * 
+   * Merging: suppose we're doing propagate &lt;s_p,i&gt; -&gt; &lt;n,j&gt; but we already have path edges &lt;s_p,i&gt; -&gt; &lt;n, x&gt;, &lt;s_p,i&gt; -&gt; &lt;n,y&gt;, and
+   * &lt;s_p,i&gt; -&gt;&lt;n, z&gt;.
+   *
+   * let \alpha be the merge function. then instead of &lt;s_p,i&gt; -&gt; &lt;n,j&gt;, we propagate &lt;s_p,i&gt; -&gt; &lt;n, \alpha(j,x,y,z) &gt; !!!
+   *
    * return -1 if no fact should be propagated
    */
   private int merge(T s_p, int i, T n, int j) {
@@ -840,6 +812,7 @@ public class TabulationSolver<T, P, F> {
     }
   }
 
+  @SuppressWarnings("unused")
   protected void addToWorkList(T s_p, int i, T n, int j) {
     if (worklist == null) {
       worklist = makeWorklist();
@@ -883,7 +856,7 @@ public class TabulationSolver<T, P, F> {
 
   /**
    * get the bitvector of facts that hold at the entry to a given node
-   * 
+   *
    * @return IntSet representing the bitvector
    */
   public IntSet getResult(T node) {
@@ -898,15 +871,15 @@ public class TabulationSolver<T, P, F> {
     	for (PathEdge<T> seed : pSeeds) {
     		allEntries.add(seed.entry);
     	}
-    }    
+    }
 
     for (T entry : allEntries){
     	LocalPathEdges lp = pathEdges.get(entry);
     	if (lp != null) {
     		result.addAll(lp.getReachable(n));
     	}
-    }    	
-    
+    }
+
     return result;
   }
 
@@ -914,7 +887,7 @@ public class TabulationSolver<T, P, F> {
 
     /**
      * get the bitvector of facts that hold at the entry to a given node
-     * 
+     *
      * @return IntSet representing the bitvector
      */
     @Override
@@ -925,37 +898,31 @@ public class TabulationSolver<T, P, F> {
     @Override
     public String toString() {
 
-      StringBuffer result = new StringBuffer();
-      TreeMap<Object, TreeSet<T>> map = new TreeMap<Object, TreeSet<T>>(ToStringComparator.instance());
+      StringBuilder result = new StringBuilder();
+      TreeMap<Object, TreeSet<T>> map = new TreeMap<>(ToStringComparator.instance());
 
-      Comparator<Object> c = new Comparator<Object>() {
-        @Override
-        public int compare(Object o1, Object o2) {
-          if (!(o1 instanceof IBasicBlock)) {
-            return -1;
-          }
-          IBasicBlock bb1 = (IBasicBlock) o1;
-          IBasicBlock bb2 = (IBasicBlock) o2;
-          return bb1.getNumber() - bb2.getNumber();
+      Comparator<Object> c = (o1, o2) -> {
+        if (!(o1 instanceof IBasicBlock)) {
+          return -1;
         }
+        IBasicBlock<?> bb1 = (IBasicBlock<?>) o1;
+        IBasicBlock<?> bb2 = (IBasicBlock<?>) o2;
+        return bb1.getNumber() - bb2.getNumber();
       };
-      for (Iterator<? extends T> it = supergraph.iterator(); it.hasNext();) {
-        T n = it.next();
+      for (T n : supergraph) {
         P proc = supergraph.getProcOf(n);
         TreeSet<T> s = map.get(proc);
         if (s == null) {
-          s = new TreeSet<T>(c);
+          s = new TreeSet<>(c);
           map.put(proc, s);
         }
         s.add(n);
       }
 
-      for (Iterator<Map.Entry<Object, TreeSet<T>>> it = map.entrySet().iterator(); it.hasNext();) {
-        Map.Entry<Object, TreeSet<T>> e = it.next();
+      for (Entry<Object, TreeSet<T>> e : map.entrySet()) {
         Set<T> s = e.getValue();
-        for (Iterator<T> it2 = s.iterator(); it2.hasNext();) {
-          T o = it2.next();
-          result.append(o + " : " + getResult(o) + "\n");
+        for (T o : s) {
+          result.append(o).append(" : ").append(getResult(o)).append('\n');
         }
       }
       return result.toString();
@@ -988,10 +955,7 @@ public class TabulationSolver<T, P, F> {
     }
 
     /**
-     * @param n1
-     * @param d1
-     * @param n2
-     * @return set of d2 s.t. (n1,d1) -> (n2,d2) is recorded as a summary edge, or null if none found
+     * @return set of d2 s.t. (n1,d1) -&gt; (n2,d2) is recorded as a summary edge, or null if none found
      */
     @Override
     public IntSet getSummaryTargets(T n1, int d1, T n2) {
@@ -1031,9 +995,10 @@ public class TabulationSolver<T, P, F> {
   }
 
   /**
-   * @return set of d1 s.t. (n1,d1) -> (n2,d2) is recorded as a summary edge, or null if none found
+   * @return set of d1 s.t. (n1,d1) -&gt; (n2,d2) is recorded as a summary edge, or null if none found
    * @throws UnsupportedOperationException unconditionally
    */
+  @SuppressWarnings("unused")
   public IntSet getSummarySources(T n2, int d2, T n1) throws UnsupportedOperationException {
     throw new UnsupportedOperationException("not currently supported.  be careful");
     // LocalSummaryEdges summaries = summaryEdges.get(supergraph.getProcOf(n1));
@@ -1064,4 +1029,41 @@ public class TabulationSolver<T, P, F> {
   protected PathEdge<T> getCurSummaryEdge() {
     return curSummaryEdge;
   }
+
+  /**
+   * Indicates that due to a path edge &lt;s_p, d1&gt; -&gt; &lt;n, d2&gt; (the 'edge'
+   * parameter) and a normal flow function application, a new path edge &lt;s_p,
+   * d1&gt; -&gt; &lt;m, d3&gt; was created. To be overridden in subclasses. We also use
+   * this function to record call-to-return flow.
+   *
+   */
+  @SuppressWarnings("unused")
+  protected void newNormalExplodedEdge(PathEdge<T> edge, T m, int d3) {
+
+  }
+
+  /**
+   * Indicates that due to a path edge 'edge' &lt;s_p, d1&gt; -&gt; &lt;n, d2&gt; and
+   * application of a call flow function, a new path edge &lt;calleeEntry, d3&gt; -&gt;
+   * &lt;calleeEntry, d3&gt; was created. To be overridden in subclasses.
+   *
+   */
+  @SuppressWarnings("unused")
+  protected void newCallExplodedEdge(PathEdge<T> edge, T calleeEntry, int d3) {
+
+  }
+
+  /**
+   * Combines [25] and [26-28]. In the caller we have a path edge
+   * 'edgeToCallSite' &lt;s_c, d3&gt; -&gt; &lt;c, d4&gt;, where c is the call site. In the
+   * callee, we have path edge 'calleeSummaryEdge' &lt;s_p, d1&gt; -&gt; &lt;e_p, d2&gt;. Of
+   * course, there is a call edge &lt;c, d4&gt; -&gt; &lt;s_p, d1&gt;. Finally, we have a
+   * return edge &lt;e_p, d2&gt; -&gt; &lt;returnSite, d5&gt;.
+   */
+  @SuppressWarnings("unused")
+  protected void newSummaryEdge(PathEdge<T> edgeToCallSite, PathEdge<T> calleeSummaryEdge, T returnSite, int d5) {
+
+  }
+
+
 }
