@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -75,12 +75,14 @@ import com.ibm.wala.ssa.SSAArrayLoadInstruction;
 import com.ibm.wala.ssa.SSAArrayStoreInstruction;
 import com.ibm.wala.ssa.SSAGetInstruction;
 import com.ibm.wala.ssa.SSAInstruction;
+import com.ibm.wala.ssa.SSAInvokeInstruction;
 import com.ibm.wala.ssa.SSANewInstruction;
 import com.ibm.wala.ssa.SSAPutInstruction;
 import com.ibm.wala.ssa.SymbolTable;
 import com.ibm.wala.types.TypeReference;
 import com.ibm.wala.util.collections.EmptyIterator;
 import com.ibm.wala.util.collections.HashMapFactory;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.collections.MapUtil;
 import com.ibm.wala.util.collections.Pair;
 import com.ibm.wala.util.debug.Assertions;
@@ -112,25 +114,26 @@ public abstract class AbstractFlowGraph extends SlowSparseNumberedLabeledGraph<O
   };
 
   /**
-   * Map: LocalPointerKey -> SSAInvokeInstruction. If we have (x, foo()), that means that x was def'fed by the return value from the
+   * Map: LocalPointerKey -&gt; SSAInvokeInstruction. If we have (x, foo()), that means that x was def'fed by the return value from the
    * call to foo()
    */
   protected final Map<PointerKey, SSAAbstractInvokeInstruction> callDefs = HashMapFactory.make();
 
   /**
-   * Map: {@link LocalPointerKey} -> Set<{@link SSAInvokeInstruction}>. If we have (x, foo()), that means x was passed as a
-   * parameter to the call to foo(). The parameter position is not represented and must be recovered.
+   * Map: {@link LocalPointerKey} -&gt; {@link Set}&lt;{@link SSAInvokeInstruction}&gt;.
+   * If we have (x, foo()), that means x was passed as a parameter to the call to foo().
+   * The parameter position is not represented and must be recovered.
    */
   protected final Map<PointerKey, Set<SSAAbstractInvokeInstruction>> callParams = HashMapFactory.make();
 
   /**
-   * Map: LocalPointerKey -> CGNode. If we have (x, foo), then x is a parameter of method foo. For now, we have to re-discover the
+   * Map: LocalPointerKey -&gt; CGNode. If we have (x, foo), then x is a parameter of method foo. For now, we have to re-discover the
    * parameter position. TODO this should just be a set; we can get the CGNode from the {@link LocalPointerKey}
    */
   protected final Map<PointerKey, CGNode> params = HashMapFactory.make();
 
   /**
-   * Map: {@link LocalPointerKey} -> {@link CGNode}. If we have (x, foo), then x is a return value of method foo. Must re-discover
+   * Map: {@link LocalPointerKey} -&gt; {@link CGNode}. If we have (x, foo), then x is a return value of method foo. Must re-discover
    * if x is normal or exceptional return value.
    */
   protected final Map<PointerKey, CGNode> returns = HashMapFactory.make();
@@ -157,10 +160,9 @@ public abstract class AbstractFlowGraph extends SlowSparseNumberedLabeledGraph<O
    */
   @Override
   public void visitSuccs(Object node, IFlowLabelVisitor v) {
-    for (Iterator<? extends IFlowLabel> succLabelIter = getSuccLabels(node); succLabelIter.hasNext();) {
-      final IFlowLabel label = succLabelIter.next();
-      for (Iterator<? extends Object> succNodeIter = getSuccNodes(node, label); succNodeIter.hasNext();) {
-        label.visit(v, succNodeIter.next());
+    for (final IFlowLabel label : Iterator2Iterable.make(getSuccLabels(node))) {
+      for (Object succNode : Iterator2Iterable.make(getSuccNodes(node, label))) {
+        label.visit(v, succNode);
       }
     }
   }
@@ -171,22 +173,18 @@ public abstract class AbstractFlowGraph extends SlowSparseNumberedLabeledGraph<O
    */
   @Override
   public void visitPreds(Object node, IFlowLabelVisitor v) {
-    for (Iterator<? extends IFlowLabel> predLabelIter = getPredLabels(node); predLabelIter.hasNext();) {
-      final IFlowLabel label = predLabelIter.next();
-      for (Iterator<? extends Object> predNodeIter = getPredNodes(node, label); predNodeIter.hasNext();) {
-        label.visit(v, predNodeIter.next());
+    for (final IFlowLabel label : Iterator2Iterable.make(getPredLabels(node))) {
+      for (Object predNode : Iterator2Iterable.make(getPredNodes(node, label))) {
+        label.visit(v, predNode);
       }
     }
   }
 
   /**
    * For each invocation in the method, add nodes for actual parameters and return values
-   * 
-   * @param node
    */
   protected void addNodesForInvocations(CGNode node, IR ir) {
-    for (Iterator<CallSiteReference> iter = ir.iterateCallSites(); iter.hasNext();) {
-      CallSiteReference site = iter.next();
+    for (CallSiteReference site : Iterator2Iterable.make(ir.iterateCallSites())) {
       SSAAbstractInvokeInstruction[] calls = ir.getCalls(site);
       for (SSAAbstractInvokeInstruction invokeInstr : calls) {
         for (int i = 0; i < invokeInstr.getNumberOfUses(); i++) {
@@ -269,7 +267,7 @@ public abstract class AbstractFlowGraph extends SlowSparseNumberedLabeledGraph<O
     for (MemoryAccess a : writes) {
       addSubgraphForNode(a.getNode());
     }
-    ArrayList<PointerKey> written = new ArrayList<PointerKey>();
+    ArrayList<PointerKey> written = new ArrayList<>();
     for (MemoryAccess a : writes) {
       IR ir = a.getNode().getIR();
       SSAPutInstruction s = (SSAPutInstruction) ir.getInstructions()[a.getInstructionIndex()];
@@ -330,7 +328,7 @@ public abstract class AbstractFlowGraph extends SlowSparseNumberedLabeledGraph<O
     for (MemoryAccess a : reads) {
       addSubgraphForNode(a.getNode());
     }
-    ArrayList<PointerKey> readInto = new ArrayList<PointerKey>();
+    ArrayList<PointerKey> readInto = new ArrayList<>();
     for (MemoryAccess a : reads) {
       IR ir = a.getNode().getIR();
       SSAGetInstruction s = (SSAGetInstruction) ir.getInstructions()[a.getInstructionIndex()];
@@ -353,7 +351,7 @@ public abstract class AbstractFlowGraph extends SlowSparseNumberedLabeledGraph<O
     for (MemoryAccess a : arrayWrites) {
       addSubgraphForNode(a.getNode());
     }
-    ArrayList<PointerKey> written = new ArrayList<PointerKey>();
+    ArrayList<PointerKey> written = new ArrayList<>();
     for (MemoryAccess a : arrayWrites) {
       final CGNode node = a.getNode();
       IR ir = node.getIR();
@@ -383,13 +381,11 @@ public abstract class AbstractFlowGraph extends SlowSparseNumberedLabeledGraph<O
   protected Iterator<PointerKey> getArrayReads(PointerKey arrayRef) {
     arrayRef = convertPointerKeyToHeapModel(arrayRef, mam.getHeapModel());
     Collection<MemoryAccess> arrayReads = mam.getArrayReads(arrayRef);
-    for (Iterator<MemoryAccess> it = arrayReads.iterator(); it.hasNext();) {
-      MemoryAccess a = it.next();
+    for (MemoryAccess a : arrayReads) {
       addSubgraphForNode(a.getNode());
     }
-    ArrayList<PointerKey> read = new ArrayList<PointerKey>();
-    for (Iterator<MemoryAccess> it = arrayReads.iterator(); it.hasNext();) {
-      MemoryAccess a = it.next();
+    ArrayList<PointerKey> read = new ArrayList<>();
+    for (MemoryAccess a : arrayReads) {
       IR ir = a.getNode().getIR();
       SSAArrayLoadInstruction s = (SSAArrayLoadInstruction) ir.getInstructions()[a.getInstructionIndex()];
       if (s == null) {
@@ -428,8 +424,7 @@ public abstract class AbstractFlowGraph extends SlowSparseNumberedLabeledGraph<O
    */
   protected void addExceptionDefConstraints(IR ir, CGNode node, List<ProgramCounter> peis, PointerKey exceptionVar,
       Set<IClass> catchClasses) {
-    for (Iterator<ProgramCounter> it = peis.iterator(); it.hasNext();) {
-      ProgramCounter peiLoc = it.next();
+    for (ProgramCounter peiLoc : peis) {
       SSAInstruction pei = ir.getPEI(peiLoc);
 
       if (pei instanceof SSAAbstractInvokeInstruction) {
@@ -452,8 +447,7 @@ public abstract class AbstractFlowGraph extends SlowSparseNumberedLabeledGraph<O
       // the pei, but just instance keys
       Collection<TypeReference> types = pei.getExceptionTypes();
       if (types != null) {
-        for (Iterator<TypeReference> it2 = types.iterator(); it2.hasNext();) {
-          TypeReference type = it2.next();
+        for (TypeReference type : types) {
           if (type != null) {
             InstanceKey ik = heapModel.getInstanceKeyForPEI(node, peiLoc, type);
             if (ik == null) {
