@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2007 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 
 package com.ibm.wala.demandpa.flowgraph;
 
@@ -21,7 +21,6 @@ import java.util.Set;
 import com.ibm.wala.analysis.typeInference.TypeAbstraction;
 import com.ibm.wala.analysis.typeInference.TypeInference;
 import com.ibm.wala.cfg.ControlFlowGraph;
-import com.ibm.wala.cfg.IBasicBlock;
 import com.ibm.wala.classLoader.CallSiteReference;
 import com.ibm.wala.classLoader.IClass;
 import com.ibm.wala.classLoader.IField;
@@ -65,6 +64,7 @@ import com.ibm.wala.types.FieldReference;
 import com.ibm.wala.types.TypeReference;
 import com.ibm.wala.util.collections.HashMapFactory;
 import com.ibm.wala.util.collections.HashSetFactory;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.debug.Assertions;
 import com.ibm.wala.util.debug.UnimplementedError;
 import com.ibm.wala.util.graph.impl.SlowSparseNumberedGraph;
@@ -80,13 +80,13 @@ import com.ibm.wala.util.ref.ReferenceCleanser;
  * 
  * The edges represent
  * <ul>
- * <li>flow from local -> local representing assignment (i.e. phi,pi)
- * <li>flow from instancekey -> local for news
- * <li>flow from formal -> actual parameter
- * <li>flow from return value -> local
+ * <li>flow from local -&gt; local representing assignment (i.e. phi,pi)
+ * <li>flow from instancekey -&gt; local for news
+ * <li>flow from formal -&gt; actual parameter
+ * <li>flow from return value -&gt; local
  * <li>match edges
- * <li>local -> local edges representing loads/stores (e.g. x = y.f will have a edge x->y, labelled with f) for a getstatic x = Y.f,
- * we have an edge from x -> Y.f.
+ * <li>local -&gt; local edges representing loads/stores (e.g. x = y.f will have a edge x-&gt;y, labelled with f) for a getstatic x = Y.f,
+ * we have an edge from x -&gt; Y.f.
  * </ul>
  * 
  * N.B: Edges go OPPOSITE the flow of values.
@@ -95,6 +95,8 @@ import com.ibm.wala.util.ref.ReferenceCleanser;
  */
 public class SimpleDemandPointerFlowGraph extends SlowSparseNumberedGraph<Object> {
 
+  private static final long serialVersionUID = 5208052568163692029L;
+
   private final static boolean DEBUG = false;
 
   /**
@@ -116,20 +118,20 @@ public class SimpleDemandPointerFlowGraph extends SlowSparseNumberedGraph<Object
   final BitVectorIntSet cgNodesVisited = new BitVectorIntSet();
 
   /**
-   * Map: LocalPointerKey -> IField. if we have (x,f), that means x was def'fed by a getfield on f.
+   * Map: LocalPointerKey -&gt; IField. if we have (x,f), that means x was def'fed by a getfield on f.
    */
   final Map<PointerKey, IField> getFieldDefs = HashMapFactory.make();
 
   final Collection<PointerKey> arrayDefs = HashSetFactory.make();
 
   /**
-   * Map: LocalPointerKey -> SSAInvokeInstruction. If we have (x, foo()), that means that x was def'fed by the return value from a
+   * Map: LocalPointerKey -&gt; SSAInvokeInstruction. If we have (x, foo()), that means that x was def'fed by the return value from a
    * call to foo()
    */
   final Map<PointerKey, SSAInvokeInstruction> callDefs = HashMapFactory.make();
 
   /**
-   * Map: LocalPointerKey -> CGNode. If we have (x, foo), then x is a parameter of method foo. For now, we have to re-discover the
+   * Map: LocalPointerKey -&gt; CGNode. If we have (x, foo), then x is a parameter of method foo. For now, we have to re-discover the
    * parameter position.
    */
   final Map<PointerKey, CGNode> params = HashMapFactory.make();
@@ -156,8 +158,6 @@ public class SimpleDemandPointerFlowGraph extends SlowSparseNumberedGraph<Object
 
   /**
    * add nodes for parameters and return values
-   * 
-   * @param node
    */
   private void addNodesForParameters(CGNode node) {
     // TODO Auto-generated method stub
@@ -299,12 +299,10 @@ public class SimpleDemandPointerFlowGraph extends SlowSparseNumberedGraph<Object
       // as the argument
       addSubgraphForNode(caller);
       IR ir = caller.getIR();
-      for (Iterator<CallSiteReference> iterator = ir.iterateCallSites(); iterator.hasNext();) {
-        CallSiteReference call = iterator.next();
+      for (CallSiteReference call : Iterator2Iterable.make(ir.iterateCallSites())) {
         if (cg.getPossibleTargets(caller, call).contains(node)) {
           SSAAbstractInvokeInstruction[] callInstrs = ir.getCalls(call);
-          for (int i = 0; i < callInstrs.length; i++) {
-            SSAAbstractInvokeInstruction callInstr = callInstrs[i];
+          for (SSAAbstractInvokeInstruction callInstr : callInstrs) {
             PointerKey actualPk = heapModel.getPointerKeyForLocal(caller, callInstr.getUse(paramPos));
             assert containsNode(actualPk);
             assert containsNode(pk);
@@ -481,8 +479,7 @@ public class SimpleDemandPointerFlowGraph extends SlowSparseNumberedGraph<Object
     v.setBasicBlock(b);
 
     // visit each instruction in the basic block.
-    for (Iterator<SSAInstruction> it = b.iterator(); it.hasNext();) {
-      SSAInstruction s = it.next();
+    for (SSAInstruction s : b) {
       if (s != null) {
         s.visit(v);
       }
@@ -494,8 +491,7 @@ public class SimpleDemandPointerFlowGraph extends SlowSparseNumberedGraph<Object
   private void addPhiConstraints(CGNode node, ControlFlowGraph<SSAInstruction, ISSABasicBlock> cfg, ISSABasicBlock b) {
 
     // visit each phi instruction in each successor block
-    for (Iterator<? extends IBasicBlock> sbs = cfg.getSuccNodes(b); sbs.hasNext();) {
-      ISSABasicBlock sb = (ISSABasicBlock) sbs.next();
+    for (ISSABasicBlock sb : Iterator2Iterable.make(cfg.getSuccNodes(b))) {
       if (sb.isExitBlock()) {
         // an optimization based on invariant that exit blocks should have no
         // phis.
@@ -503,14 +499,14 @@ public class SimpleDemandPointerFlowGraph extends SlowSparseNumberedGraph<Object
       }
       int n = 0;
       // set n to be whichPred(this, sb);
-      for (Iterator<? extends IBasicBlock> back = cfg.getPredNodes(sb); back.hasNext(); n++) {
-        if (back.next() == b) {
+      for (ISSABasicBlock back : Iterator2Iterable.make(cfg.getPredNodes(sb))) {
+        if (back == b) {
           break;
         }
+        ++n;
       }
       assert n < cfg.getPredNodeCount(sb);
-      for (Iterator<SSAPhiInstruction> phis = sb.iteratePhis(); phis.hasNext();) {
-        SSAPhiInstruction phi = phis.next();
+      for (SSAPhiInstruction phi : Iterator2Iterable.make(sb.iteratePhis())) {
         if (phi == null) {
           continue;
         }
@@ -531,7 +527,7 @@ public class SimpleDemandPointerFlowGraph extends SlowSparseNumberedGraph<Object
     return new StatementVisitor(node, ir, du);
   }
 
-  private void debugPrintIR(IR ir) {
+  private static void debugPrintIR(IR ir) {
     if (DEBUG) {
       if (ir == null) {
         System.err.println("\n   No statements\n");
@@ -746,7 +742,7 @@ public class SimpleDemandPointerFlowGraph extends SlowSparseNumberedGraph<Object
 
       PointerKey result = heapModel.getFilteredPointerKeyForLocal(node, 
           instruction.getResult(), 
-          new FilteredPointerKey.MultipleClassesFilter(types.toArray(new IClass[ types.size() ])) );
+          new FilteredPointerKey.MultipleClassesFilter(types.toArray(new IClass[0])) );
         
       PointerKey value = heapModel.getPointerKeyForLocal(node, instruction.getVal());
       // TODO actually use the cast type
@@ -1314,4 +1310,4 @@ public class SimpleDemandPointerFlowGraph extends SlowSparseNumberedGraph<Object
   // }
   // }
 
-}
\ No newline at end of file
+}
