@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,16 +7,17 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.callgraph;
 
 import java.io.File;
+import java.io.IOException;
+import java.io.InputStream;
 import java.io.NotSerializableException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
@@ -30,6 +31,7 @@ import com.ibm.wala.classLoader.BinaryDirectoryTreeModule;
 import com.ibm.wala.classLoader.ClassFileModule;
 import com.ibm.wala.classLoader.IClassLoader;
 import com.ibm.wala.classLoader.JarFileModule;
+import com.ibm.wala.classLoader.JarStreamModule;
 import com.ibm.wala.classLoader.Language;
 import com.ibm.wala.classLoader.Module;
 import com.ibm.wala.classLoader.SourceDirectoryTreeModule;
@@ -40,12 +42,14 @@ import com.ibm.wala.types.Descriptor;
 import com.ibm.wala.types.MethodReference;
 import com.ibm.wala.types.TypeName;
 import com.ibm.wala.types.TypeReference;
-import com.ibm.wala.util.PlatformUtil;
+import com.ibm.wala.util.collections.FilterIterator;
 import com.ibm.wala.util.collections.HashMapFactory;
 import com.ibm.wala.util.collections.HashSetFactory;
+import com.ibm.wala.util.collections.MapIterator;
 import com.ibm.wala.util.collections.MapUtil;
 import com.ibm.wala.util.config.SetOfClasses;
 import com.ibm.wala.util.debug.Assertions;
+import com.ibm.wala.util.io.RtJar;
 import com.ibm.wala.util.strings.Atom;
 import com.ibm.wala.util.strings.ImmutableByteArray;
 
@@ -54,7 +58,7 @@ import com.ibm.wala.util.strings.ImmutableByteArray;
  * 
  * The analysis scope is partitioned by class loader. There are three pre-defined class loader scopes:
  * <ul>
- * <li>Primordial (for <code>rt.jar</code>, the core classes)
+ * <li>Primordial (for {@code rt.jar}, the core classes)
  * <li>Extension (for extension libraries in $JRE/lib/ext)
  * <li>Application (for the classes of the application)
  * </ul>
@@ -117,7 +121,7 @@ public class AnalysisScope {
    */
   private SetOfClasses exclusions;
 
-  final protected LinkedHashMap<Atom, ClassLoaderReference> loadersByName = new LinkedHashMap<Atom, ClassLoaderReference>();
+  public final LinkedHashMap<Atom, ClassLoaderReference> loadersByName = new LinkedHashMap<>();
 
   /**
    * Special class loader for array instances
@@ -130,7 +134,7 @@ public class AnalysisScope {
 
   protected AnalysisScope(Collection<? extends Language> languages) {
     super();
-    this.languages = new HashMap<Atom, Language>();
+    this.languages = new HashMap<>();
     for (Language l : languages) {
       this.languages.put(l.getName(), l);
     }
@@ -203,16 +207,28 @@ public class AnalysisScope {
 
   /**
    * Add a class file to the scope for a loader
-   * @throws InvalidClassFileException 
    */
   public void addClassFileToScope(ClassLoaderReference loader, File file) throws IllegalArgumentException, InvalidClassFileException {
     List<Module> s = MapUtil.findOrCreateList(moduleMap, loader);
     s.add(new ClassFileModule(file, null));
   }
 
+  /**
+   * Add a jar file to the scope via an {@link InputStream}.  NOTE: The InputStream should *not*
+   * be a {@link java.util.jar.JarInputStream}; it should be a regular {@link InputStream} for
+   * the raw bytes of the jar file.
+   *
+   */
+  public void addInputStreamForJarToScope(ClassLoaderReference loader, InputStream stream) throws
+      IOException {
+    MapUtil.findOrCreateList(moduleMap, loader).add(new JarStreamModule(stream));
+  }
+
+
   /**
    * Add a jar file to the scope for a loader
    */
+  @SuppressWarnings("unused")
   public void addToScope(ClassLoaderReference loader, JarFile file) {
     List<Module> s = MapUtil.findOrCreateList(moduleMap, loader);
     if (DEBUG_LEVEL > 0) {
@@ -224,6 +240,7 @@ public class AnalysisScope {
   /**
    * Add a module to the scope for a loader
    */
+  @SuppressWarnings("unused")
   public void addToScope(ClassLoaderReference loader, Module m) {
     if (m == null) {
       throw new IllegalArgumentException("null m");
@@ -252,6 +269,7 @@ public class AnalysisScope {
   /**
    * Add a module file to the scope for a loader. The classes in the added jar file will override classes added to the scope so far.
    */
+  @SuppressWarnings("unused")
   public void addToScopeHead(ClassLoaderReference loader, Module m) {
     if (m == null) {
       throw new IllegalArgumentException("null m");
@@ -264,7 +282,7 @@ public class AnalysisScope {
   }
 
   /**
-   * @return the ClassLoaderReference specified by <code>name</code>.
+   * @return the ClassLoaderReference specified by {@code name}.
    * @throws IllegalArgumentException if name is null
    */
   public ClassLoaderReference getLoader(Atom name) throws IllegalArgumentException {
@@ -319,18 +337,18 @@ public class AnalysisScope {
 
   @Override
   public String toString() {
-    StringBuffer result = new StringBuffer();
+    StringBuilder result = new StringBuilder();
     for (ClassLoaderReference loader : loadersByName.values()) {
       result.append(loader.getName());
-      result.append("\n");
+      result.append('\n');
       for (Module m : getModules(loader)) {
-        result.append(" ");
+        result.append(' ');
         result.append(m);
-        result.append("\n");
+        result.append('\n');
       }
     }
     result.append(getExclusionString());
-    result.append("\n");
+    result.append('\n');
     return result.toString();
   }
 
@@ -371,31 +389,16 @@ public class AnalysisScope {
    * @return the rt.jar (1.4) or core.jar (1.5) file, or null if not found.
    */
   private JarFile getRtJar() {
-    for (Iterator MS = getModules(getPrimordialLoader()).iterator(); MS.hasNext();) {
-      Module M = (Module) MS.next();
-      if (M instanceof JarFileModule) {
-        JarFile JF = ((JarFileModule) M).getJarFile();
-        if (JF.getName().endsWith(File.separator + "rt.jar")) {
-          return JF;
-        }
-        if (JF.getName().endsWith(File.separator + "core.jar")) {
-          return JF;
-        }
-        // hack for Mac
-        if (PlatformUtil.onMacOSX() && JF.getName().endsWith(File.separator + "classes.jar")) {
-          return JF;
-        }
-      }
-    }
-    return null;
+    return RtJar.getRtJar(
+        new MapIterator<Module,JarFile>(
+            new FilterIterator<>(getModules(getPrimordialLoader()).iterator(), JarFileModule.class::isInstance), M -> ((JarFileModule) M).getJarFile()));
   }
 
   public String getJavaLibraryVersion() throws IllegalStateException {
-    JarFile rtJar = getRtJar();
-    if (rtJar == null) {
-      throw new IllegalStateException("cannot find runtime libraries");
-    }
-    try {
+    try (final JarFile rtJar = getRtJar()) {
+      if (rtJar == null) {
+        throw new IllegalStateException("cannot find runtime libraries");
+      }
       Manifest man = rtJar.getManifest();
       assert man != null : "runtime library has no manifest!";
       String result = man.getMainAttributes().getValue("Specification-Version");
@@ -435,7 +438,6 @@ public class AnalysisScope {
    * Creates a "serializable" version of the analysis scope.
    * 
    * @return a "serializable" version of the analysis scope.
-   * @throws NotSerializableException
    */
   public ShallowAnalysisScope toShallowAnalysisScope() throws NotSerializableException {
 
@@ -445,7 +447,7 @@ public class AnalysisScope {
     // Note: 'arrayClassLoader' object will be built from scratch in remote process
 
     // represent modules map as a set of strings (corresponding to analysis scope file lines.
-    List<String> moduleLines = new ArrayList<String>();
+    List<String> moduleLines = new ArrayList<>();
     for (Map.Entry<ClassLoaderReference, List<Module>> e : moduleMap.entrySet()) {
       ClassLoaderReference lrReference = e.getKey();
       String moduleLdr = lrReference.getName().toString();
@@ -478,7 +480,7 @@ public class AnalysisScope {
     }
 
     // represent loaderImplByRef map as set of strings
-    List<String> ldrImplLines = new ArrayList<String>();
+    List<String> ldrImplLines = new ArrayList<>();
     for (Map.Entry<ClassLoaderReference, String> e : loaderImplByRef.entrySet()) {
       ClassLoaderReference lrReference = e.getKey();
       String ldrName = lrReference.getName().toString();
