@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,18 +7,19 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.callgraph;
 
 
 import com.ibm.wala.ipa.callgraph.propagation.InstanceKey;
 import com.ibm.wala.ipa.callgraph.propagation.PointerAnalysis;
+import com.ibm.wala.ipa.cha.IClassHierarchy;
 import com.ibm.wala.util.MonitorUtil.IProgressMonitor;
 
 /**
  * Basic interface for an object that can build a call graph.
  */
-public interface CallGraphBuilder {
+public interface CallGraphBuilder<I extends InstanceKey> {
   /**
    * Build a call graph.
    * 
@@ -31,11 +32,13 @@ public interface CallGraphBuilder {
   /**
    * @return the Pointer Analysis information computed as a side-effect of call graph construction.
    */
-  public PointerAnalysis<InstanceKey> getPointerAnalysis();
+  public PointerAnalysis<I> getPointerAnalysis();
 
   /**
    * @return A cache of various analysis artifacts used during call graph construction.
    */
-  public AnalysisCache getAnalysisCache();
+  public IAnalysisCacheView getAnalysisCache();
 
+  public IClassHierarchy getClassHierarchy();
+  
 }
