@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 
 package com.ibm.wala.ipa.callgraph;
 
@@ -27,8 +27,8 @@ public interface ContextItem {
       return v;
     }
 
-    public static <T> Value make(T v) {
-      return new Value<T>(v);
+    public static <T> Value<T> make(T v) {
+      return new Value<>(v);
     }
 
     @Override
@@ -44,7 +44,7 @@ public interface ContextItem {
         return false;
       if (getClass() != obj.getClass())
         return false;
-      Value other = (Value) obj;
+      Value<?> other = (Value<?>) obj;
       if (v == null) {
         if (other.v != null)
           return false;
