@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2007 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,12 +7,13 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.callgraph.cha;
 
 import java.util.Iterator;
 
 import com.ibm.wala.classLoader.CallSiteReference;
+import com.ibm.wala.classLoader.NewSiteReference;
 import com.ibm.wala.ipa.callgraph.CGNode;
 
 public interface CHAContextInterpreter {
@@ -27,4 +28,5 @@ public interface CHAContextInterpreter {
    */
   public abstract Iterator<CallSiteReference> iterateCallSites(CGNode node);
 
+  Iterator<NewSiteReference> iterateNewSites(CGNode node);
 }
