@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2007 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,13 +7,14 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.callgraph.cha;
 
 import java.util.Iterator;
 
 import com.ibm.wala.classLoader.CallSiteReference;
 import com.ibm.wala.classLoader.CodeScanner;
+import com.ibm.wala.classLoader.NewSiteReference;
 import com.ibm.wala.ipa.callgraph.CGNode;
 import com.ibm.wala.shrikeCT.InvalidClassFileException;
 import com.ibm.wala.util.debug.Assertions;
@@ -39,4 +40,16 @@ public class ContextInsensitiveCHAContextInterpreter implements CHAContextInterp
     }
   }
 
+  @Override
+  public Iterator<NewSiteReference> iterateNewSites(CGNode node) {
+    if (node == null) {
+      throw new IllegalArgumentException("node is null");
+    }
+    try {
+      return CodeScanner.getNewSites(node.getMethod()).iterator();
+    } catch (InvalidClassFileException e) {
+      throw new RuntimeException(e);
+    }
+  }
+
 }
