@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 
 package com.ibm.wala.ipa.callgraph.impl;
 
@@ -31,11 +31,11 @@ public class ComposedEntrypoints implements Iterable<Entrypoint> {
     if (B == null) {
       throw new IllegalArgumentException("B is null");
     }
-    for (Iterator<Entrypoint> it = A.iterator(); it.hasNext(); ) {
-      entrypoints.add(it.next());
+    for (Entrypoint entrypoint : A) {
+      entrypoints.add(entrypoint);
     }
-    for (Iterator<Entrypoint> it = B.iterator(); it.hasNext(); ) {
-      entrypoints.add(it.next());
+    for (Entrypoint entrypoint : B) {
+      entrypoints.add(entrypoint);
     }
   }
 
