@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,12 +7,13 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.callgraph.impl;
 
 import java.io.BufferedInputStream;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
+import java.io.IOException;
 import java.io.InputStream;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -20,14 +21,16 @@ import java.util.Set;
 
 import com.ibm.wala.classLoader.IClass;
 import com.ibm.wala.classLoader.IMethod;
-import com.ibm.wala.ipa.callgraph.AnalysisCache;
+import com.ibm.wala.classLoader.Language;
 import com.ibm.wala.ipa.callgraph.AnalysisOptions;
 import com.ibm.wala.ipa.callgraph.AnalysisScope;
 import com.ibm.wala.ipa.callgraph.CallGraphBuilder;
 import com.ibm.wala.ipa.callgraph.ClassTargetSelector;
 import com.ibm.wala.ipa.callgraph.ContextSelector;
 import com.ibm.wala.ipa.callgraph.Entrypoint;
+import com.ibm.wala.ipa.callgraph.IAnalysisCacheView;
 import com.ibm.wala.ipa.callgraph.MethodTargetSelector;
+import com.ibm.wala.ipa.callgraph.propagation.InstanceKey;
 import com.ibm.wala.ipa.callgraph.propagation.SSAContextInterpreter;
 import com.ibm.wala.ipa.callgraph.propagation.SSAPropagationCallGraphBuilder;
 import com.ibm.wala.ipa.callgraph.propagation.cfa.ZeroXCFABuilder;
@@ -104,10 +107,13 @@ public class Util {
       throw new IllegalArgumentException("cha cannot be null");
     }
 
-    InputStream s = cl.getResourceAsStream(xmlFile);
-    XMLMethodSummaryReader summary = new XMLMethodSummaryReader(s, scope);
-
-    addBypassLogic(options, scope, cl, summary, cha);
+    try (final InputStream s = cl.getResourceAsStream(xmlFile)) {
+      XMLMethodSummaryReader summary = new XMLMethodSummaryReader(s, scope);
+      addBypassLogic(options, scope, cl, summary, cha);
+    } catch (IOException e) {
+      System.err.println("Could not close XML method summary reader: " + e.getLocalizedMessage());
+      e.printStackTrace();
+    }
   }
 
   public static void addBypassLogic(AnalysisOptions options, AnalysisScope scope, ClassLoader cl, XMLMethodSummaryReader summary,
@@ -135,8 +141,6 @@ public class Util {
   }
   
   /**
-   * @param scope
-   * @param cha
    * @return set of all eligible Main classes in the class hierarchy
    * @throws IllegalArgumentException if scope is null
    */
@@ -163,12 +167,7 @@ public class Util {
         }
       }
     }
-    return new Iterable<Entrypoint>() {
-      @Override
-      public Iterator<Entrypoint> iterator() {
-        return result.iterator();
-      }
-    };
+    return result::iterator;
   }
 
   /**
@@ -189,7 +188,7 @@ public class Util {
   /**
    * @return Entrypoints for a set of J2SE Main classes
    * @throws IllegalArgumentException if classNames == null
-   * @throws IllegalArgumentException if (classNames != null) and (0 < classNames.length) and (classNames[0] == null)
+   * @throws IllegalArgumentException if (classNames != null) and (0 &lt; classNames.length) and (classNames[0] == null)
    * @throws IllegalArgumentException if classNames.length == 0
    */
   public static Iterable<Entrypoint> makeMainEntrypoints(final ClassLoaderReference loaderRef, final IClassHierarchy cha,
@@ -205,41 +204,38 @@ public class Util {
       throw new IllegalArgumentException("(0 < classNames.length) and (classNames[0] == null)");
     }
 
-    for (int i = 0; i < classNames.length; i++) {
-      if (classNames[i].indexOf("L") != 0) {
-        throw new IllegalArgumentException("Expected class name to start with L " + classNames[i]);
+    for (String className : classNames) {
+      if (className.indexOf('L') != 0) {
+        throw new IllegalArgumentException("Expected class name to start with L " + className);
       }
-      if (classNames[i].indexOf(".") > 0) {
-        Assertions.productionAssertion(false, "Expected class name formatted with /, not . " + classNames[i]);
+      if (className.indexOf('.') > 0) {
+        Assertions.productionAssertion(false, "Expected class name formatted with /, not . " + className);
       }
     }
 
-    return new Iterable<Entrypoint>() {
-      @Override
-      public Iterator<Entrypoint> iterator() {
-        final Atom mainMethod = Atom.findOrCreateAsciiAtom("main");
-        return new Iterator<Entrypoint>() {
-          private int index = 0;
+    return () -> {
+      final Atom mainMethod = Atom.findOrCreateAsciiAtom("main");
+      return new Iterator<Entrypoint>() {
+        private int index = 0;
 
-          @Override
-          public void remove() {
-            Assertions.UNREACHABLE();
-          }
+        @Override
+        public void remove() {
+          Assertions.UNREACHABLE();
+        }
 
-          @Override
-          public boolean hasNext() {
-            return index < classNames.length;
-          }
+        @Override
+        public boolean hasNext() {
+          return index < classNames.length;
+        }
 
-          @Override
-          public Entrypoint next() {
-            TypeReference T = TypeReference.findOrCreate(loaderRef, TypeName.string2TypeName(classNames[index++]));
-            MethodReference mainRef = MethodReference.findOrCreate(T, mainMethod, Descriptor
-                .findOrCreateUTF8("([Ljava/lang/String;)V"));
-            return new DefaultEntrypoint(mainRef, cha);
-          }
-        };
-      }
+        @Override
+        public Entrypoint next() {
+          TypeReference T = TypeReference.findOrCreate(loaderRef, TypeName.string2TypeName(classNames[index++]));
+          MethodReference mainRef = MethodReference.findOrCreate(T, mainMethod, Descriptor
+              .findOrCreateUTF8("([Ljava/lang/String;)V"));
+          return new DefaultEntrypoint(mainRef, cha);
+        }
+      };
     };
   }
 
@@ -258,8 +254,6 @@ public class Util {
   }
 
   /**
-   * @param supG
-   * @param subG
    * @throws IllegalArgumentException if subG is null
    * @throws IllegalArgumentException if supG is null
    */
@@ -278,19 +272,17 @@ public class Util {
       System.err.println("subgraph: ");
       System.err.println(subG.toString());
       System.err.println("nodeDiff: ");
-      for (Iterator it = nodeDiff.iterator(); it.hasNext();) {
-        System.err.println(it.next().toString());
+      for (T t : nodeDiff) {
+        System.err.println(t.toString());
       }
       Assertions.productionAssertion(nodeDiff.isEmpty(), "bad superset, see tracefile\n");
     }
 
-    for (Iterator<? extends T> subNodes = subG.iterator(); subNodes.hasNext();) {
-      T m = subNodes.next();
-
+    for (T m : subG) {
       Set<T> succDiff = setify(subG.getSuccNodes(m));
       succDiff.removeAll(setify(supG.getSuccNodes(m)));
       if (!succDiff.isEmpty()) {
-        Assertions.productionAssertion(succDiff.isEmpty(), "bad superset for successors of " + m + ":" + succDiff);
+        Assertions.productionAssertion(succDiff.isEmpty(), "bad superset for successors of " + m + ':' + succDiff);
       }
 
       Set<T> predDiff = setify(subG.getPredNodes(m));
@@ -301,10 +293,10 @@ public class Util {
         System.err.println("subgraph: ");
         System.err.println(subG.toString());
         System.err.println("predDiff: ");
-        for (Iterator it = predDiff.iterator(); it.hasNext();) {
-          System.err.println(it.next().toString());
+        for (T t : predDiff) {
+          System.err.println(t.toString());
         }
-        Assertions.UNREACHABLE("bad superset for predecessors of " + m + ":" + predDiff);
+        Assertions.UNREACHABLE("bad superset for predecessors of " + m + ':' + predDiff);
       }
     }
   }
@@ -316,7 +308,8 @@ public class Util {
    * @param cha governing class hierarchy
    * @param scope representation of the analysis scope
    */
-  public static CallGraphBuilder makeRTABuilder(AnalysisOptions options, AnalysisCache cache, IClassHierarchy cha,
+  public static CallGraphBuilder<InstanceKey> makeRTABuilder(
+      AnalysisOptions options, IAnalysisCacheView cache, IClassHierarchy cha,
       AnalysisScope scope) {
 
     addDefaultSelectors(options, cha);
@@ -331,9 +324,9 @@ public class Util {
    * @param scope representation of the analysis scope
    * @return a 0-CFA Call Graph Builder.
    */
-  public static SSAPropagationCallGraphBuilder makeZeroCFABuilder(AnalysisOptions options, AnalysisCache cache,
+  public static SSAPropagationCallGraphBuilder makeZeroCFABuilder(Language l, AnalysisOptions options, IAnalysisCacheView cache,
       IClassHierarchy cha, AnalysisScope scope) {
-    return makeZeroCFABuilder(options, cache, cha, scope, null, null);
+    return makeZeroCFABuilder(l, options, cache, cha, scope, null, null);
   }
 
   /**
@@ -345,7 +338,7 @@ public class Util {
    * @return a 0-CFA Call Graph Builder.
    * @throws IllegalArgumentException if options is null
    */
-  public static SSAPropagationCallGraphBuilder makeZeroCFABuilder(AnalysisOptions options, AnalysisCache cache,
+  public static SSAPropagationCallGraphBuilder makeZeroCFABuilder(Language l, AnalysisOptions options, IAnalysisCacheView cache,
       IClassHierarchy cha, AnalysisScope scope, ContextSelector customSelector, SSAContextInterpreter customInterpreter) {
 
     if (options == null) {
@@ -354,7 +347,7 @@ public class Util {
     addDefaultSelectors(options, cha);
     addDefaultBypassLogic(options, scope, Util.class.getClassLoader(), cha);
 
-    return ZeroXCFABuilder.make(cha, options, cache, customSelector, customInterpreter, ZeroXInstanceKeys.NONE);
+    return ZeroXCFABuilder.make(l, cha, options, cache, customSelector, customInterpreter, ZeroXInstanceKeys.NONE);
   }
 
   /**
@@ -364,9 +357,9 @@ public class Util {
    * @param cha governing class hierarchy
    * @param scope representation of the analysis scope
    */
-  public static SSAPropagationCallGraphBuilder makeZeroOneCFABuilder(AnalysisOptions options, AnalysisCache cache,
+  public static SSAPropagationCallGraphBuilder makeZeroOneCFABuilder(Language l, AnalysisOptions options, IAnalysisCacheView cache,
       IClassHierarchy cha, AnalysisScope scope) {
-    return makeZeroOneCFABuilder(options, cache, cha, scope, null, null);
+    return makeZeroOneCFABuilder(l, options, cache, cha, scope, null, null);
   }
 
   /**
@@ -378,7 +371,7 @@ public class Util {
    * @return a 0-1-CFA Call Graph Builder.
    * @throws IllegalArgumentException if options is null
    */
-  public static SSAPropagationCallGraphBuilder makeVanillaZeroOneCFABuilder(AnalysisOptions options, AnalysisCache cache,
+  public static SSAPropagationCallGraphBuilder makeVanillaZeroOneCFABuilder(Language l, AnalysisOptions options, IAnalysisCacheView analysisCache,
       IClassHierarchy cha, AnalysisScope scope, ContextSelector customSelector, SSAContextInterpreter customInterpreter) {
 
     if (options == null) {
@@ -387,7 +380,7 @@ public class Util {
     addDefaultSelectors(options, cha);
     addDefaultBypassLogic(options, scope, Util.class.getClassLoader(), cha);
 
-    return ZeroXCFABuilder.make(cha, options, cache, customSelector, customInterpreter, ZeroXInstanceKeys.ALLOCATIONS | ZeroXInstanceKeys.CONSTANT_SPECIFIC);
+    return ZeroXCFABuilder.make(l, cha, options, analysisCache, customSelector, customInterpreter, ZeroXInstanceKeys.ALLOCATIONS | ZeroXInstanceKeys.CONSTANT_SPECIFIC);
   }
 
   /**
@@ -397,9 +390,9 @@ public class Util {
    * @param cha governing class hierarchy
    * @param scope representation of the analysis scope
    */
-  public static SSAPropagationCallGraphBuilder makeVanillaZeroOneCFABuilder(AnalysisOptions options, AnalysisCache cache,
+  public static SSAPropagationCallGraphBuilder makeVanillaZeroOneCFABuilder(Language l, AnalysisOptions options, IAnalysisCacheView analysisCache,
       IClassHierarchy cha, AnalysisScope scope) {
-    return makeVanillaZeroOneCFABuilder(options, cache, cha, scope, null, null);
+    return makeVanillaZeroOneCFABuilder(l, options, analysisCache, cha, scope, null, null);
   }
 
   /**
@@ -411,7 +404,7 @@ public class Util {
    * @return a 0-1-CFA Call Graph Builder.
    * @throws IllegalArgumentException if options is null
    */
-  public static SSAPropagationCallGraphBuilder makeZeroOneCFABuilder(AnalysisOptions options, AnalysisCache cache,
+  public static SSAPropagationCallGraphBuilder makeZeroOneCFABuilder(Language l, AnalysisOptions options, IAnalysisCacheView cache,
       IClassHierarchy cha, AnalysisScope scope, ContextSelector customSelector, SSAContextInterpreter customInterpreter) {
 
     if (options == null) {
@@ -420,7 +413,7 @@ public class Util {
     addDefaultSelectors(options, cha);
     addDefaultBypassLogic(options, scope, Util.class.getClassLoader(), cha);
 
-    return ZeroXCFABuilder.make(cha, options, cache, customSelector, customInterpreter, ZeroXInstanceKeys.ALLOCATIONS | ZeroXInstanceKeys.SMUSH_MANY | ZeroXInstanceKeys.SMUSH_PRIMITIVE_HOLDERS
+    return ZeroXCFABuilder.make(l, cha, options, cache, customSelector, customInterpreter, ZeroXInstanceKeys.ALLOCATIONS | ZeroXInstanceKeys.SMUSH_MANY | ZeroXInstanceKeys.SMUSH_PRIMITIVE_HOLDERS
         | ZeroXInstanceKeys.SMUSH_STRINGS | ZeroXInstanceKeys.SMUSH_THROWABLES);
   }
 
@@ -431,7 +424,7 @@ public class Util {
    * @return a 0-CFA Call Graph Builder augmented with extra logic for containers
    * @throws IllegalArgumentException if options is null
    */
-  public static SSAPropagationCallGraphBuilder makeZeroContainerCFABuilder(AnalysisOptions options, AnalysisCache cache,
+  public static SSAPropagationCallGraphBuilder makeZeroContainerCFABuilder(AnalysisOptions options, IAnalysisCacheView cache,
       IClassHierarchy cha, AnalysisScope scope) {
 
     if (options == null) {
@@ -452,12 +445,12 @@ public class Util {
    * @return a 0-1-CFA Call Graph Builder augmented with extra logic for containers
    * @throws IllegalArgumentException if options is null
    */
-  public static SSAPropagationCallGraphBuilder makeZeroOneContainerCFABuilder(AnalysisOptions options, AnalysisCache cache,
+  public static SSAPropagationCallGraphBuilder makeZeroOneContainerCFABuilder(AnalysisOptions options, IAnalysisCacheView cache,
       IClassHierarchy cha, AnalysisScope scope) {
     return makeZeroOneContainerCFABuilder(options, cache, cha, scope, null, null);
   }
    
-  public static SSAPropagationCallGraphBuilder makeZeroOneContainerCFABuilder(AnalysisOptions options, AnalysisCache cache,
+  public static SSAPropagationCallGraphBuilder makeZeroOneContainerCFABuilder(AnalysisOptions options, IAnalysisCacheView cache,
       IClassHierarchy cha, AnalysisScope scope, ContextSelector appSelector, SSAContextInterpreter appInterpreter) {
 
     if (options == null) {
@@ -475,7 +468,7 @@ public class Util {
    * with call-string length limited to n, and a context-sensitive
    * allocation-site-based heap abstraction.
    */
-  public static SSAPropagationCallGraphBuilder makeNCFABuilder(int n, AnalysisOptions options, AnalysisCache cache,
+  public static SSAPropagationCallGraphBuilder makeNCFABuilder(int n, AnalysisOptions options, IAnalysisCacheView cache,
       IClassHierarchy cha, AnalysisScope scope) {
     if (options == null) {
       throw new IllegalArgumentException("options is null");
@@ -484,7 +477,7 @@ public class Util {
     addDefaultBypassLogic(options, scope, Util.class.getClassLoader(), cha);
     ContextSelector appSelector = null;
     SSAContextInterpreter appInterpreter = null;
-    SSAPropagationCallGraphBuilder result = new nCFABuilder(n, cha, options, cache, appSelector, appInterpreter);
+    SSAPropagationCallGraphBuilder result = new nCFABuilder(n, Language.JAVA.getFakeRootMethod(cha, options, cache), options, cache, appSelector, appInterpreter);
     // nCFABuilder uses type-based heap abstraction by default, but we want allocation sites
     result.setInstanceKeys(new ZeroXInstanceKeys(options, cha, result.getContextInterpreter(), ZeroXInstanceKeys.ALLOCATIONS
         | ZeroXInstanceKeys.SMUSH_MANY | ZeroXInstanceKeys.SMUSH_PRIMITIVE_HOLDERS | ZeroXInstanceKeys.SMUSH_STRINGS
@@ -498,7 +491,7 @@ public class Util {
    * allocation-site-based heap abstraction. Standard optimizations in the heap
    * abstraction like smushing of strings are disabled.
    */
-  public static SSAPropagationCallGraphBuilder makeVanillaNCFABuilder(int n, AnalysisOptions options, AnalysisCache cache,
+  public static SSAPropagationCallGraphBuilder makeVanillaNCFABuilder(int n, AnalysisOptions options, IAnalysisCacheView cache,
       IClassHierarchy cha, AnalysisScope scope) {
     if (options == null) {
       throw new IllegalArgumentException("options is null");
@@ -507,7 +500,7 @@ public class Util {
     addDefaultBypassLogic(options, scope, Util.class.getClassLoader(), cha);
     ContextSelector appSelector = null;
     SSAContextInterpreter appInterpreter = null;
-    SSAPropagationCallGraphBuilder result = new nCFABuilder(n, cha, options, cache, appSelector, appInterpreter);
+    SSAPropagationCallGraphBuilder result = new nCFABuilder(n, Language.JAVA.getFakeRootMethod(cha, options, cache), options, cache, appSelector, appInterpreter);
     // nCFABuilder uses type-based heap abstraction by default, but we want allocation sites
     result.setInstanceKeys(new ZeroXInstanceKeys(options, cha, result.getContextInterpreter(), ZeroXInstanceKeys.ALLOCATIONS | ZeroXInstanceKeys.CONSTANT_SPECIFIC));
     return result;
@@ -521,7 +514,7 @@ public class Util {
    * @return a 0-1-CFA Call Graph Builder augmented with extra logic for containers
    * @throws IllegalArgumentException if options is null
    */
-  public static SSAPropagationCallGraphBuilder makeVanillaZeroOneContainerCFABuilder(AnalysisOptions options, AnalysisCache cache,
+  public static SSAPropagationCallGraphBuilder makeVanillaZeroOneContainerCFABuilder(AnalysisOptions options, IAnalysisCacheView cache,
       IClassHierarchy cha, AnalysisScope scope) {
 
     if (options == null) {
@@ -543,13 +536,15 @@ public class Util {
       addBypassLogic(options, scope, cl, nativeSpec, cha);
     } else {
       // try to load from filesystem
-      try {
-        BufferedInputStream bIn = new BufferedInputStream(new FileInputStream(nativeSpec));
+      try (final BufferedInputStream bIn = new BufferedInputStream(new FileInputStream(nativeSpec))) {
         XMLMethodSummaryReader reader = new XMLMethodSummaryReader(bIn, scope);
         addBypassLogic(options, scope, cl, reader, cha);
       } catch (FileNotFoundException e) {
         System.err.println("Could not load natives xml file from: " + nativeSpec);
         e.printStackTrace();
+      } catch (IOException e) {
+        System.err.println("Could not close natives xml file " + nativeSpec);
+        e.printStackTrace();
       }
     }
   }
