@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.callgraph.propagation;
 
 import java.util.ArrayList;
@@ -25,12 +25,7 @@ import com.ibm.wala.fixpoint.IFixedPointSystem;
 import com.ibm.wala.fixpoint.IVariable;
 import com.ibm.wala.fixpoint.UnaryOperator;
 import com.ibm.wala.fixpoint.UnaryStatement;
-import com.ibm.wala.util.collections.CompoundIterator;
-import com.ibm.wala.util.collections.EmptyIterator;
-import com.ibm.wala.util.Predicate;
-import com.ibm.wala.util.collections.FilterIterator;
-import com.ibm.wala.util.collections.HashSetFactory;
-import com.ibm.wala.util.collections.SmallMap;
+import com.ibm.wala.util.collections.*;
 import com.ibm.wala.util.debug.Assertions;
 import com.ibm.wala.util.debug.UnimplementedError;
 import com.ibm.wala.util.graph.AbstractNumberedGraph;
@@ -61,17 +56,17 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
   /**
    * Track nodes (PointsToSet Variables and AbstractEquations)
    */
-  private final NumberedNodeManager<INodeWithNumber> nodeManager = new DelegatingNumberedNodeManager<INodeWithNumber>();
+  private final NumberedNodeManager<INodeWithNumber> nodeManager = new DelegatingNumberedNodeManager<>();
 
   /**
    * Track edges (equations) that are not represented implicitly
    */
-  private final NumberedEdgeManager<INodeWithNumber> edgeManager = new SparseNumberedEdgeManager<INodeWithNumber>(nodeManager, 2,
+  private final NumberedEdgeManager<INodeWithNumber> edgeManager = new SparseNumberedEdgeManager<>(nodeManager, 2,
       BasicNaturalRelation.SIMPLE);
 
   private final DelegateGraph delegateGraph = new DelegateGraph();
 
-  private final HashSet<AbstractStatement> delegateStatements = HashSetFactory.make();
+  private final HashSet<IFixedPointStatement<PointsToSetVariable>> delegateStatements = HashSetFactory.make();
 
   /**
    * special representation for implicitly represented unary equations. This is a map from UnaryOperator ->
@@ -80,14 +75,14 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
    * for UnaryOperator op, let R be implicitMap.get(op) then (i,j) \in R implies i op j is an equation in the graph
    * 
    */
-  private final SmallMap<UnaryOperator<PointsToSetVariable>, IBinaryNaturalRelation> implicitUnaryMap = new SmallMap<UnaryOperator<PointsToSetVariable>, IBinaryNaturalRelation>();
+  private final SmallMap<UnaryOperator<PointsToSetVariable>, IBinaryNaturalRelation> implicitUnaryMap = new SmallMap<>();
 
   /**
    * The inverse of relations in the implicit map
    * 
    * for UnaryOperator op, let R be invImplicitMap.get(op) then (i,j) \in R implies j op i is an equation in the graph
    */
-  private final SmallMap<UnaryOperator<PointsToSetVariable>, IBinaryNaturalRelation> invImplicitUnaryMap = new SmallMap<UnaryOperator<PointsToSetVariable>, IBinaryNaturalRelation>();
+  private final SmallMap<UnaryOperator<PointsToSetVariable>, IBinaryNaturalRelation> invImplicitUnaryMap = new SmallMap<>();
 
   /**
    * Number of implicit unary equations registered
@@ -97,7 +92,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
   /**
    * @return a relation in map m corresponding to a key
    */
-  private IBinaryNaturalRelation findOrCreateRelation(Map<UnaryOperator<PointsToSetVariable>, IBinaryNaturalRelation> m,
+  private static IBinaryNaturalRelation findOrCreateRelation(Map<UnaryOperator<PointsToSetVariable>, IBinaryNaturalRelation> m,
       UnaryOperator<PointsToSetVariable> key) {
     IBinaryNaturalRelation result = m.get(key);
     if (result == null) {
@@ -110,7 +105,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
   /**
    * @return a Relation object to track implicit equations using the operator
    */
-  private IBinaryNaturalRelation makeRelation(AbstractOperator op) {
+  private static IBinaryNaturalRelation makeRelation(AbstractOperator<PointsToSetVariable> op) {
     byte[] implementation = null;
     if (op instanceof AssignOperator) {
       // lots of assignments.
@@ -225,9 +220,9 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
   /**
    * @return true iff this equation should be represented implicitly in this data structure
    */
-  private boolean useImplicitRepresentation(IFixedPointStatement s) {
-    AbstractStatement eq = (AbstractStatement) s;
-    AbstractOperator op = eq.getOperator();
+  private static boolean useImplicitRepresentation(IFixedPointStatement<PointsToSetVariable> s) {
+    AbstractStatement<?, ?> eq = (AbstractStatement<?, ?>) s;
+    AbstractOperator<?> op = eq.getOperator();
     return (op instanceof AssignOperator || op instanceof PropagationCallGraphBuilder.FilterOperator);
   }
 
@@ -246,7 +241,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     int lhs = eq.getLHS().getGraphNodeId();
     int rhs = eq.getRightHandSide().getGraphNodeId();
     if (DEBUG) {
-      System.err.println(("lhs rhs " + lhs + " " + rhs));
+      System.err.println(("lhs rhs " + lhs + ' ' + rhs));
     }
     IBinaryNaturalRelation R = findOrCreateRelation(implicitUnaryMap, eq.getOperator());
     boolean b = R.add(lhs, rhs);
@@ -264,7 +259,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     int lhs = eq.getLHS().getGraphNodeId();
     int rhs = eq.getRightHandSide().getGraphNodeId();
     if (DEBUG) {
-      System.err.println(("lhs rhs " + lhs + " " + rhs));
+      System.err.println(("lhs rhs " + lhs + ' ' + rhs));
     }
     IBinaryNaturalRelation R = findOrCreateRelation(implicitUnaryMap, eq.getOperator());
     R.remove(lhs, rhs);
@@ -274,14 +269,9 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
   }
 
   @Override
-  @SuppressWarnings("unchecked")
   public Iterator<AbstractStatement> getStatements() {
-    Iterator<AbstractStatement> it = new FilterIterator(delegateGraph.iterator(), new Predicate() {
-      @Override public boolean test(Object x) {
-        return x instanceof AbstractStatement;
-      }
-    });
-    return new CompoundIterator<AbstractStatement>(it, new GlobalImplicitIterator());
+    Iterator<AbstractStatement> it = IteratorUtil.filter(delegateGraph.iterator(), AbstractStatement.class);
+    return new CompoundIterator<>(it, new GlobalImplicitIterator());
   }
 
   /**
@@ -307,13 +297,13 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     }
 
     @Override
-    public AbstractStatement next() {
+    public AbstractStatement<?, ?> next() {
       int l = defs.next();
       PointsToSetVariable lhs = (PointsToSetVariable) delegateGraph.getNode(l);
-      UnaryStatement temp = op.makeEquation(lhs, use);
+      UnaryStatement<?> temp = op.makeEquation(lhs, use);
       if (DEBUG) {
         System.err.print(("XX Return temp: " + temp));
-        System.err.println(("lhs rhs " + l + " " + use.getGraphNodeId()));
+        System.err.println(("lhs rhs " + l + ' ' + use.getGraphNodeId()));
       }
       return temp;
     }
@@ -348,10 +338,10 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     }
 
     @Override
-    public AbstractStatement next() {
+    public AbstractStatement<?, ?> next() {
       int r = uses.next();
       PointsToSetVariable rhs = (PointsToSetVariable) delegateGraph.getNode(r);
-      UnaryStatement temp = op.makeEquation(def, rhs);
+      UnaryStatement<?> temp = op.makeEquation(def, rhs);
       if (DEBUG) {
         System.err.print(("YY Return temp: " + temp));
       }
@@ -372,7 +362,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
 
     private final Iterator<UnaryOperator<PointsToSetVariable>> outerKeyDelegate = implicitUnaryMap.keySet().iterator();
 
-    private Iterator innerDelegate;
+    private Iterator<IntPair> innerDelegate;
 
     private UnaryOperator<PointsToSetVariable> currentOperator;
 
@@ -388,7 +378,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
       while (outerKeyDelegate.hasNext()) {
         currentOperator = outerKeyDelegate.next();
         IBinaryNaturalRelation R = implicitUnaryMap.get(currentOperator);
-        Iterator it = R.iterator();
+        Iterator<IntPair> it = R.iterator();
         if (it.hasNext()) {
           innerDelegate = it;
           return;
@@ -402,11 +392,11 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     }
 
     @Override
-    public AbstractStatement next() {
-      IntPair p = (IntPair) innerDelegate.next();
+    public AbstractStatement<?, ?> next() {
+      IntPair p = innerDelegate.next();
       int lhs = p.getX();
       int rhs = p.getY();
-      UnaryStatement result = currentOperator.makeEquation((PointsToSetVariable) delegateGraph.getNode(lhs),
+      UnaryStatement<?> result = currentOperator.makeEquation((PointsToSetVariable) delegateGraph.getNode(lhs),
           (PointsToSetVariable) delegateGraph.getNode(rhs));
       if (!innerDelegate.hasNext()) {
         advanceOuter();
@@ -439,20 +429,19 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
   public void reorder() {
     VariableGraphView graph = new VariableGraphView();
 
-    Iterator<PointsToSetVariable> order = Topological.makeTopologicalIter(graph);
+    Iterator<PointsToSetVariable> order = Topological.makeTopologicalIter(graph).iterator();
 
     int number = 0;
     while (order.hasNext()) {
-      Object elt = order.next();
-      if (elt instanceof IVariable) {
-        IVariable v = (IVariable) elt;
-        v.setOrderNumber(number++);
+      IVariable<?> elt = order.next();
+      if (elt != null) {
+        elt.setOrderNumber(number++);
       }
     }
   }
 
   /**
-   * A graph of just the variables in the system. v1 -> v2 iff there exists equation e s.t. e uses v1 and e defs v2.
+   * A graph of just the variables in the system. v1 -&gt; v2 iff there exists equation e s.t. e uses v1 and e defs v2.
    * 
    * Note that this graph trickily and fragilely reuses the nodeManager from the delegateGraph, above. This will work ok as long as
    * every variable is inserted in the delegateGraph.
@@ -488,8 +477,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
      */
     @Override
     public void addNode(PointsToSetVariable n) {
-      Assertions.UNREACHABLE();
-
+      assert containsNode(n);
     }
 
     /*
@@ -506,8 +494,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
      */
     @Override
     public boolean containsNode(PointsToSetVariable N) {
-      Assertions.UNREACHABLE();
-      return false;
+      return delegateGraph.containsNode(N);
     }
 
     /*
@@ -515,7 +502,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
      */
     @Override
     public Iterator<PointsToSetVariable> getPredNodes(PointsToSetVariable v) {
-      final Iterator eqs = getStatementsThatDef(v);
+      final Iterator<AbstractStatement<PointsToSetVariable, ?>> eqs = getStatementsThatDef(v);
       return new Iterator<PointsToSetVariable>() {
         Iterator<INodeWithNumber> inner;
 
@@ -533,9 +520,9 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
             }
             return result;
           } else {
-            AbstractStatement eq = (AbstractStatement) eqs.next();
+            AbstractStatement<PointsToSetVariable, ?> eq = eqs.next();
             if (useImplicitRepresentation(eq)) {
-              return (PointsToSetVariable) ((UnaryStatement) eq).getRightHandSide();
+              return (PointsToSetVariable) ((UnaryStatement<?>) eq).getRightHandSide();
             } else {
               inner = delegateGraph.getPredNodes(eq);
               return next();
@@ -554,16 +541,14 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     /*
      * @see com.ibm.wala.util.graph.EdgeManager#getPredNodeCount(java.lang.Object)
      */
-    @SuppressWarnings("unused")
-    public int getPredNodeCount(INodeWithNumber N) {
-      PointsToSetVariable v = (PointsToSetVariable) N;
+    @Override
+    public int getPredNodeCount(PointsToSetVariable v) {
       int result = 0;
-      for (Iterator eqs = getStatementsThatDef(v); eqs.hasNext();) {
-        AbstractStatement eq = (AbstractStatement) eqs.next();
+      for (AbstractStatement<PointsToSetVariable, ?> eq : Iterator2Iterable.make(getStatementsThatDef(v))) {
         if (useImplicitRepresentation(eq)) {
           result++;
         } else {
-          result += delegateGraph.getPredNodeCount(N);
+          result += delegateGraph.getPredNodeCount(v);
         }
       }
       return result;
@@ -574,7 +559,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
      */
     @Override
     public Iterator<PointsToSetVariable> getSuccNodes(PointsToSetVariable v) {
-      final Iterator eqs = getStatementsThatUse(v);
+      final Iterator<AbstractStatement> eqs = getStatementsThatUse(v);
       return new Iterator<PointsToSetVariable>() {
         PointsToSetVariable nextResult;
         {
@@ -596,7 +581,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
         private void advance() {
           nextResult = null;
           while (eqs.hasNext() && nextResult == null) {
-            AbstractStatement eq = (AbstractStatement) eqs.next();
+            AbstractStatement<?, ?> eq = eqs.next();
             nextResult = (PointsToSetVariable) eq.getLHS();
           }
         }
@@ -615,9 +600,8 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     @Override
     public int getSuccNodeCount(PointsToSetVariable v) {
       int result = 0;
-      for (Iterator eqs = getStatementsThatUse(v); eqs.hasNext();) {
-        AbstractStatement eq = (AbstractStatement) eqs.next();
-        IVariable lhs = eq.getLHS();
+      for (AbstractStatement<?, ?> eq : Iterator2Iterable.make(getStatementsThatUse(v))) {
+        IVariable<?> lhs = eq.getLHS();
         if (lhs != null) {
           result++;
         }
@@ -656,9 +640,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     @Override
     @SuppressWarnings("unchecked")
     protected NumberedEdgeManager getEdgeManager() {
-      // TODO Auto-generated method stub
-      Assertions.UNREACHABLE();
-      return null;
+      return this;
     }
 
   }
@@ -676,22 +658,22 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     Iterator<INodeWithNumber> result = delegateGraph.getSuccNodes(v);
     for (int i = 0; i < invImplicitUnaryMap.size(); i++) {
       UnaryOperator op = invImplicitUnaryMap.getKey(i);
-      IBinaryNaturalRelation R = (IBinaryNaturalRelation) invImplicitUnaryMap.getValue(i);
+      IBinaryNaturalRelation R = invImplicitUnaryMap.getValue(i);
       IntSet s = R.getRelated(number);
       if (s != null) {
-        result = new CompoundIterator<INodeWithNumber>(new ImplicitUseIterator(op, v, s), result);
+        result = new CompoundIterator<>(new ImplicitUseIterator(op, v, s), result);
       }
     }
-    List<AbstractStatement> list = new ArrayList<AbstractStatement>();
+    List<AbstractStatement> list = new ArrayList<>();
     while (result.hasNext()) {
-      list.add((AbstractStatement) result.next());
+      list.add((AbstractStatement<?, ?>) result.next());
     }
     return list.iterator();
   }
 
   @Override
   @SuppressWarnings("unchecked")
-  public Iterator<AbstractStatement> getStatementsThatDef(PointsToSetVariable v) {
+  public Iterator<AbstractStatement<PointsToSetVariable, ?>> getStatementsThatDef(PointsToSetVariable v) {
     if (v == null) {
       throw new IllegalArgumentException("v is null");
     }
@@ -702,14 +684,14 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     Iterator<INodeWithNumber> result = delegateGraph.getPredNodes(v);
     for (int i = 0; i < implicitUnaryMap.size(); i++) {
       UnaryOperator op = implicitUnaryMap.getKey(i);
-      IBinaryNaturalRelation R = (IBinaryNaturalRelation) implicitUnaryMap.getValue(i);
+      IBinaryNaturalRelation R = implicitUnaryMap.getValue(i);
       IntSet s = R.getRelated(number);
       if (s != null) {
-        result = new CompoundIterator<INodeWithNumber>(new ImplicitDefIterator(op, s, v), result);
+        result = new CompoundIterator<>(new ImplicitDefIterator(op, s, v), result);
       }
     }
 
-    List<AbstractStatement> list = new ArrayList<AbstractStatement>();
+    List<AbstractStatement<PointsToSetVariable, ?>> list = new ArrayList<>();
     while (result.hasNext()) {
       list.add((AbstractStatement) result.next());
     }
@@ -733,9 +715,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
       return 0;
     }
     int result = delegateGraph.getSuccNodeCount(v);
-    for (Iterator it = invImplicitUnaryMap.keySet().iterator(); it.hasNext();) {
-      UnaryOperator op = (UnaryOperator) it.next();
-      IBinaryNaturalRelation R = invImplicitUnaryMap.get(op);
+    for (IBinaryNaturalRelation R : invImplicitUnaryMap.values()) {
       IntSet s = R.getRelated(number);
       if (s != null) {
         result += s.size();
@@ -754,9 +734,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
       return 0;
     }
     int result = delegateGraph.getPredNodeCount(v);
-    for (Iterator it = implicitUnaryMap.keySet().iterator(); it.hasNext();) {
-      UnaryOperator op = (UnaryOperator) it.next();
-      IBinaryNaturalRelation R = implicitUnaryMap.get(op);
+    for (IBinaryNaturalRelation R : implicitUnaryMap.values()) {
       IntSet s = R.getRelated(number);
       if (s != null) {
         result += s.size();
@@ -766,14 +744,8 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
   }
 
   @Override
-  @SuppressWarnings("unchecked")
   public Iterator<PointsToSetVariable> getVariables() {
-    Iterator<PointsToSetVariable> it = new FilterIterator(delegateGraph.iterator(), new Predicate() {
-      @Override public boolean test(Object x) {
-        return x instanceof IVariable;
-      }
-    });
-    return it;
+    return IteratorUtil.filter(delegateGraph.iterator(), PointsToSetVariable.class);
   }
 
   /*
@@ -788,10 +760,10 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
       System.err.println("implicit map:");
       int count = 0;
       int totalBytes = 0;
-      for (Iterator it = implicitUnaryMap.entrySet().iterator(); it.hasNext();) {
-        count++;
-        Map.Entry e = (Map.Entry) it.next();
-        IBinaryNaturalRelation R = (IBinaryNaturalRelation) e.getValue();
+      for (Map.Entry<UnaryOperator<PointsToSetVariable>, IBinaryNaturalRelation> entry : implicitUnaryMap.entrySet()) {
+		  count++;
+        Map.Entry<?, IBinaryNaturalRelation> e = entry;
+        IBinaryNaturalRelation R = e.getValue();
         System.err.println(("entry " + count));
         R.performVerboseAction();
         HeapTracer.Result result = HeapTracer.traceHeap(Collections.singleton(R), false);
@@ -826,7 +798,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     }
     int lhs = eq.getLHS().getGraphNodeId();
     int rhs = eq.getRightHandSide().getGraphNodeId();
-    UnaryOperator op = eq.getOperator();
+    UnaryOperator<?> op = eq.getOperator();
     IBinaryNaturalRelation R = implicitUnaryMap.get(op);
     if (R != null) {
       return R.contains(lhs, rhs);
@@ -855,21 +827,21 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
   }
 
   /**
-   * A graph of just the variables in the system. v1 -> v2 iff there exists an assignment equation e s.t. e uses v1 and e defs v2.
+   * A graph of just the variables in the system. v1 -&gt; v2 iff there exists an assignment equation e s.t. e uses v1 and e defs v2.
    * 
    */
   public NumberedGraph<PointsToSetVariable> getAssignmentGraph() {
     return new FilteredConstraintGraphView() {
 
       @Override
-      boolean isInteresting(AbstractStatement eq) {
+      boolean isInteresting(AbstractStatement<?, ?> eq) {
         return eq instanceof AssignEquation;
       }
     };
   }
 
   /**
-   * A graph of just the variables in the system. v1 -> v2 iff there exists an Assingnment or Filter equation e s.t. e uses v1 and e
+   * A graph of just the variables in the system. v1 -&gt; v2 iff there exists an Assingnment or Filter equation e s.t. e uses v1 and e
    * defs v2.
    * 
    */
@@ -877,7 +849,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     return new FilteredConstraintGraphView() {
 
       @Override
-      boolean isInteresting(AbstractStatement eq) {
+      boolean isInteresting(AbstractStatement<?, ?> eq) {
         return eq instanceof AssignEquation || eq.getOperator() instanceof PropagationCallGraphBuilder.FilterOperator;
       }
     };
@@ -892,12 +864,12 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
   }
 
   /**
-   * A graph of just the variables in the system. v1 -> v2 that are related by def-use with "interesting" operators
+   * A graph of just the variables in the system. v1 -&gt; v2 that are related by def-use with "interesting" operators
    * 
    */
   private abstract class FilteredConstraintGraphView extends AbstractNumberedGraph<PointsToSetVariable> {
 
-    abstract boolean isInteresting(AbstractStatement eq);
+    abstract boolean isInteresting(AbstractStatement<?, ?> eq);
 
     /*
      * @see com.ibm.wala.util.graph.Graph#removeNodeAndEdges(java.lang.Object)
@@ -955,7 +927,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
      */
     @Override
     public Iterator<PointsToSetVariable> getPredNodes(PointsToSetVariable v) {
-      final Iterator eqs = getStatementsThatDef(v);
+      final Iterator<AbstractStatement<PointsToSetVariable, ?>> eqs = getStatementsThatDef(v);
       return new Iterator<PointsToSetVariable>() {
         PointsToSetVariable nextResult;
         {
@@ -977,9 +949,9 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
         private void advance() {
           nextResult = null;
           while (eqs.hasNext() && nextResult == null) {
-            AbstractStatement eq = (AbstractStatement) eqs.next();
+            AbstractStatement<?, ?> eq = eqs.next();
             if (isInteresting(eq)) {
-              nextResult = (PointsToSetVariable) ((UnaryStatement) eq).getRightHandSide();
+              nextResult = (PointsToSetVariable) ((UnaryStatement<?>) eq).getRightHandSide();
             }
           }
         }
@@ -997,8 +969,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     @Override
     public int getPredNodeCount(PointsToSetVariable v) {
       int result = 0;
-      for (Iterator eqs = getStatementsThatDef(v); eqs.hasNext();) {
-        AbstractStatement eq = (AbstractStatement) eqs.next();
+      for (AbstractStatement<?, ?> eq : Iterator2Iterable.make(getStatementsThatDef(v))) {
         if (isInteresting(eq)) {
           result++;
         }
@@ -1011,7 +982,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
      */
     @Override
     public Iterator<PointsToSetVariable> getSuccNodes(PointsToSetVariable v) {
-      final Iterator eqs = getStatementsThatUse(v);
+      final Iterator<AbstractStatement> eqs = getStatementsThatUse(v);
       return new Iterator<PointsToSetVariable>() {
         PointsToSetVariable nextResult;
         {
@@ -1033,9 +1004,9 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
         private void advance() {
           nextResult = null;
           while (eqs.hasNext() && nextResult == null) {
-            AbstractStatement eq = (AbstractStatement) eqs.next();
+            AbstractStatement<?, ?> eq = eqs.next();
             if (isInteresting(eq)) {
-              nextResult = (PointsToSetVariable) ((UnaryStatement) eq).getLHS();
+              nextResult = (PointsToSetVariable) ((UnaryStatement<?>) eq).getLHS();
             }
           }
         }
@@ -1054,8 +1025,7 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
     @Override
     public int getSuccNodeCount(PointsToSetVariable v) {
       int result = 0;
-      for (Iterator eqs = getStatementsThatUse(v); eqs.hasNext();) {
-        AbstractStatement eq = (AbstractStatement) eqs.next();
+      for (AbstractStatement<?, ?> eq : Iterator2Iterable.make(getStatementsThatUse(v))) {
         if (isInteresting(eq)) {
           result++;
         }
@@ -1099,22 +1069,15 @@ public class PropagationGraph implements IFixedPointSystem<PointsToSetVariable>
   }
 
   public String spaceReport() {
-    StringBuffer result = new StringBuffer("PropagationGraph\n");
-    result.append("ImplicitEdges:" + countImplicitEdges() + "\n");
     // for (Iterator it = implicitUnaryMap.values().iterator(); it.hasNext(); )
     // {
     // result.append(it.next() + "\n");
     // }
-    return result.toString();
+    return "PropagationGraph\nImplicitEdges:" + countImplicitEdges() + '\n';
   }
 
   private int countImplicitEdges() {
-    int result = 0;
-    for (Iterator it = new GlobalImplicitIterator(); it.hasNext();) {
-      it.next();
-      result++;
-    }
-    return result;
+    return IteratorUtil.count(new GlobalImplicitIterator());
   }
 
 }
