@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.callgraph.propagation;
 
 import java.util.Arrays;
@@ -32,8 +32,6 @@ import com.ibm.wala.fixpoint.UnaryOperator;
 import com.ibm.wala.fixpoint.UnaryStatement;
 import com.ibm.wala.ipa.callgraph.CallGraph;
 import com.ibm.wala.ipa.callgraph.propagation.PropagationCallGraphBuilder.FilterOperator;
-import com.ibm.wala.ipa.cha.ClassHierarchyException;
-import com.ibm.wala.ipa.cha.ClassHierarchyWarning;
 import com.ibm.wala.types.TypeReference;
 import com.ibm.wala.util.collections.HashMapFactory;
 import com.ibm.wala.util.collections.HashSetFactory;
@@ -46,12 +44,10 @@ import com.ibm.wala.util.graph.NumberedGraph;
 import com.ibm.wala.util.heapTrace.HeapTracer;
 import com.ibm.wala.util.intset.IntIterator;
 import com.ibm.wala.util.intset.IntSet;
-import com.ibm.wala.util.intset.IntSetAction;
 import com.ibm.wala.util.intset.IntSetUtil;
 import com.ibm.wala.util.intset.MutableIntSet;
 import com.ibm.wala.util.intset.MutableMapping;
 import com.ibm.wala.util.ref.ReferenceCleanser;
-import com.ibm.wala.util.warnings.Warnings;
 
 /**
  * System of constraints that define propagation for call graph construction
@@ -77,12 +73,12 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
   private final PropagationGraph flowGraph = new PropagationGraph();
 
   /**
-   * bijection from InstanceKey <=>Integer
+   * bijection from InstanceKey &lt;=&gt; Integer
    */
   protected final MutableMapping<InstanceKey> instanceKeys = MutableMapping.make();
 
   /**
-   * A mapping from IClass -> MutableSharedBitVectorIntSet The range represents the instance keys that correspond to a given class.
+   * A mapping from IClass -&gt; MutableSharedBitVectorIntSet The range represents the instance keys that correspond to a given class.
    * This mapping is used to filter sets based on declared types; e.g., in cast constraints
    */
   final private Map<IClass, MutableIntSet> class2InstanceKey = HashMapFactory.make();
@@ -105,7 +101,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
   /**
    * When doing unification, we must also updated the fixed sets in unary side effects.
    * 
-   * This maintains a map from PointsToSetVariable -> Set<UnarySideEffect>
+   * This maintains a map from PointsToSetVariable -&gt; Set&lt;UnarySideEffect&gt;
    */
   final private Map<PointsToSetVariable, Set<UnarySideEffect>> fixedSetMap = HashMapFactory.make();
 
@@ -147,8 +143,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
   protected void updateSideEffects(PointsToSetVariable p, PointsToSetVariable rep) {
     Set<UnarySideEffect> set = fixedSetMap.get(p);
     if (set != null) {
-      for (Iterator it = set.iterator(); it.hasNext();) {
-        UnarySideEffect s = (UnarySideEffect) it.next();
+      for (UnarySideEffect s : set) {
         s.replaceFixedSet(rep);
       }
       Set<UnarySideEffect> s2 = MapUtil.findOrCreateSet(fixedSetMap, rep);
@@ -214,7 +209,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
    * @return an List of instance keys corresponding to the integers in a set
    */
   List<InstanceKey> getInstances(IntSet set) {
-    LinkedList<InstanceKey> result = new LinkedList<InstanceKey>();
+    LinkedList<InstanceKey> result = new LinkedList<>();
     for (IntIterator it = set.intIterator(); it.hasNext();) {
       int j = it.next();
       result.add(getInstanceKey(j));
@@ -252,7 +247,6 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
   /**
    * If key is unified, returns the representative
    * 
-   * @param key
    * @return the dataflow variable that tracks the points-to set for key
    */
   public PointsToSetVariable findOrCreatePointsToSet(PointerKey key) {
@@ -283,12 +277,8 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
           pk = key;
         }
         FilteredPointerKey fpk = (FilteredPointerKey) pk;
-        if (fpk == null) {
-          Assertions.UNREACHABLE("fpk is null");
-        }
-        if (key == null) {
-          Assertions.UNREACHABLE("key is null");
-        }
+        assert fpk != null;
+        assert key != null;
         if (fpk.getTypeFilter() == null) {
           Assertions.UNREACHABLE("fpk.getTypeFilter() is null");
         }
@@ -307,7 +297,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
       result = instanceKeys.add(key);
     }
     if (DEBUG) {
-      System.err.println("getIndexForInstanceKey " + key + " " + result);
+      System.err.println("getIndexForInstanceKey " + key + ' ' + result);
     }
     return result;
   }
@@ -329,7 +319,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
       throw new IllegalArgumentException("rhs null");
     }
     if (DEBUG) {
-      System.err.println("Add constraint A: " + lhs + " " + op + " " + rhs);
+      System.err.println("Add constraint A: " + lhs + ' ' + op + ' ' + rhs);
     }
     PointsToSetVariable L = findOrCreatePointsToSet(lhs);
     PointsToSetVariable R = findOrCreatePointsToSet(rhs);
@@ -339,7 +329,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
       // solver if the value of L changes.
       pointsToMap.recordTransitiveRoot(L.getPointerKey());
       if (!(L.getPointerKey() instanceof FilteredPointerKey)) {
-        Assertions.UNREACHABLE("expected filtered lhs " + L.getPointerKey() + " " + L.getPointerKey().getClass() + " " + lhs + " "
+        Assertions.UNREACHABLE("expected filtered lhs " + L.getPointerKey() + ' ' + L.getPointerKey().getClass() + ' ' + lhs + ' '
             + lhs.getClass());
       }
     }
@@ -357,7 +347,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
       throw new IllegalArgumentException("rhs null");
     }
     if (DEBUG) {
-      System.err.println("Add constraint A: " + lhs + " " + op + " " + rhs);
+      System.err.println("Add constraint A: " + lhs + ' ' + op + ' ' + rhs);
     }
     assert !pointsToMap.isUnified(lhs);
     assert !pointsToMap.isUnified(rhs);
@@ -380,7 +370,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
       throw new IllegalArgumentException("null rhs2");
     }
     if (DEBUG) {
-      System.err.println("Add constraint A: " + lhs + " " + op + " " + rhs1 + ", " + rhs2);
+      System.err.println("Add constraint A: " + lhs + ' ' + op + ' ' + rhs1 + ", " + rhs2);
     }
     assert !pointsToMap.isUnified(lhs);
     assert !pointsToMap.isUnified(rhs1);
@@ -394,14 +384,14 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
   /**
    * @return true iff the system changes
    */
-  public boolean newFieldWrite(PointerKey lhs, UnaryOperator<PointsToSetVariable> op, PointerKey rhs, PointerKey container) {
+  public boolean newFieldWrite(PointerKey lhs, UnaryOperator<PointsToSetVariable> op, PointerKey rhs) {
     return newConstraint(lhs, op, rhs);
   }
 
   /**
    * @return true iff the system changes
    */
-  public boolean newFieldRead(PointerKey lhs, UnaryOperator<PointsToSetVariable> op, PointerKey rhs, PointerKey container) {
+  public boolean newFieldRead(PointerKey lhs, UnaryOperator<PointsToSetVariable> op, PointerKey rhs) {
     return newConstraint(lhs, op, rhs);
   }
 
@@ -419,11 +409,10 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
     // This works since the solver is monotonic with TOP = {}
     PointsToSetVariable L = findOrCreatePointsToSet(lhs);
     int index = findOrCreateIndexForInstanceKey(value);
-    if (L.contains(index)) {
+    if (!L.add(index)) {
       // a no-op
       return false;
     } else {
-      L.add(index);
 
       // also register that we have an instanceKey for the klass
       assert value.getConcreteType() != null;
@@ -449,29 +438,25 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
   private void registerInstanceOfClass(IClass klass, int index) {
 
     if (DEBUG) {
-      System.err.println("registerInstanceOfClass " + klass + " " + index);
+      System.err.println("registerInstanceOfClass " + klass + ' ' + index);
     }
 
     assert !klass.getReference().equals(TypeReference.JavaLangObject);
 
-    try {
-      IClass T = klass;
-      registerInstanceWithAllSuperclasses(index, T);
-      registerInstanceWithAllInterfaces(klass, index);
+    IClass T = klass;
+    registerInstanceWithAllSuperclasses(index, T);
+    registerInstanceWithAllInterfaces(klass, index);
 
-      if (klass.isArrayClass()) {
-        ArrayClass aClass = (ArrayClass) klass;
-        int dim = aClass.getDimensionality();
-        registerMultiDimArraysForArrayOfObjectTypes(dim, index, aClass);
+    if (klass.isArrayClass()) {
+      ArrayClass aClass = (ArrayClass) klass;
+      int dim = aClass.getDimensionality();
+      registerMultiDimArraysForArrayOfObjectTypes(dim, index, aClass);
 
-        IClass elementClass = aClass.getInnermostElementClass();
-        if (elementClass != null) {
-          registerArrayInstanceWithAllSuperclassesOfElement(index, elementClass, dim);
-          registerArrayInstanceWithAllInterfacesOfElement(index, elementClass, dim);
-        }
+      IClass elementClass = aClass.getInnermostElementClass();
+      if (elementClass != null) {
+        registerArrayInstanceWithAllSuperclassesOfElement(index, elementClass, dim);
+        registerArrayInstanceWithAllInterfacesOfElement(index, elementClass, dim);
       }
-    } catch (ClassHierarchyException e) {
-      Warnings.add(ClassHierarchyWarning.create(e.getMessage()));
     }
   }
 
@@ -488,22 +473,21 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
   }
 
   private void registerArrayInstanceWithAllInterfacesOfElement(int index, IClass elementClass, int dim) {
-    Collection ifaces = null;
+    Collection<IClass> ifaces = null;
     ifaces = elementClass.getAllImplementedInterfaces();
-    for (Iterator it = ifaces.iterator(); it.hasNext();) {
-      IClass I = (IClass) it.next();
+    for (IClass I : ifaces) {
       TypeReference iArrayRef = makeArray(I.getReference(), dim);
       IClass iArrayClass = null;
       iArrayClass = I.getClassLoader().lookupClass(iArrayRef.getName());
       MutableIntSet set = findOrCreateSparseSetForClass(iArrayClass);
       set.add(index);
       if (DEBUG) {
-        System.err.println("dense filter for interface " + iArrayClass + " " + set);
+        System.err.println("dense filter for interface " + iArrayClass + ' ' + set);
       }
     }
   }
 
-  private TypeReference makeArray(TypeReference element, int dim) {
+  private static TypeReference makeArray(TypeReference element, int dim) {
     TypeReference iArrayRef = element;
     for (int i = 0; i < dim; i++) {
       iArrayRef = TypeReference.findOrCreateArrayOf(iArrayRef);
@@ -511,8 +495,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
     return iArrayRef;
   }
 
-  private void registerArrayInstanceWithAllSuperclassesOfElement(int index, IClass elementClass, int dim)
-      throws ClassHierarchyException {
+  private void registerArrayInstanceWithAllSuperclassesOfElement(int index, IClass elementClass, int dim) {
     IClass T;
     // register the array with each supertype of the element class
     T = elementClass.getSuperclass();
@@ -523,40 +506,29 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
       MutableIntSet set = findOrCreateSparseSetForClass(tArrayClass);
       set.add(index);
       if (DEBUG) {
-        System.err.println("dense filter for class " + tArrayClass + " " + set);
+        System.err.println("dense filter for class " + tArrayClass + ' ' + set);
       }
       T = T.getSuperclass();
     }
   }
 
-  /**
-   * @param klass
-   * @param index
-   * @throws ClassHierarchyException
-   */
-  private void registerInstanceWithAllInterfaces(IClass klass, int index) throws ClassHierarchyException {
-    Collection ifaces = klass.getAllImplementedInterfaces();
-    for (Iterator it = ifaces.iterator(); it.hasNext();) {
-      IClass I = (IClass) it.next();
+  private void registerInstanceWithAllInterfaces(IClass klass, int index) {
+    Collection<IClass> ifaces = klass.getAllImplementedInterfaces();
+    for (IClass I : ifaces) {
       MutableIntSet set = findOrCreateSparseSetForClass(I);
       set.add(index);
       if (DEBUG) {
-        System.err.println("dense filter for interface " + I + " " + set);
+        System.err.println("dense filter for interface " + I + ' ' + set);
       }
     }
   }
 
-  /**
-   * @param index
-   * @param T
-   * @throws ClassHierarchyException
-   */
-  private void registerInstanceWithAllSuperclasses(int index, IClass T) throws ClassHierarchyException {
+  private void registerInstanceWithAllSuperclasses(int index, IClass T) {
     while (T != null && !T.getReference().equals(TypeReference.JavaLangObject)) {
       MutableIntSet set = findOrCreateSparseSetForClass(T);
       set.add(index);
       if (DEBUG) {
-        System.err.println("dense filter for class " + T + " " + set);
+        System.err.println("dense filter for class " + T + ' ' + set);
       }
       T = T.getSuperclass();
     }
@@ -567,7 +539,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
       throw new IllegalArgumentException("null arg0");
     }
     if (DEBUG) {
-      System.err.println("add constraint D: " + op + " " + arg0);
+      System.err.println("add constraint D: " + op + ' ' + arg0);
     }
     assert !pointsToMap.isUnified(arg0);
     PointsToSetVariable v1 = findOrCreatePointsToSet(arg0);
@@ -579,7 +551,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
       throw new IllegalArgumentException("null arg0");
     }
     if (DEBUG) {
-      System.err.println("add constraint D: " + op + " " + Arrays.toString(arg0));
+      System.err.println("add constraint D: " + op + ' ' + Arrays.toString(arg0));
     }
     PointsToSetVariable[] vs = new PointsToSetVariable[ arg0.length ];
     for(int i = 0; i < arg0.length; i++) {
@@ -591,7 +563,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
 
   public void newSideEffect(AbstractOperator<PointsToSetVariable> op, PointerKey arg0, PointerKey arg1) {
     if (DEBUG) {
-      System.err.println("add constraint D: " + op + " " + arg0);
+      System.err.println("add constraint D: " + op + ' ' + arg0);
     }
     assert !pointsToMap.isUnified(arg0);
     assert !pointsToMap.isUnified(arg1);
@@ -645,25 +617,20 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
 
   private String printRHSInstances(AbstractStatement s) {
     if (s instanceof UnaryStatement) {
-      UnaryStatement u = (UnaryStatement) s;
+      UnaryStatement<?> u = (UnaryStatement<?>) s;
       PointsToSetVariable rhs = (PointsToSetVariable) u.getRightHandSide();
       IntSet value = rhs.getValue();
       final int[] topFive = new int[5];
-      value.foreach(new IntSetAction() {
-        @Override
-        public void act(int x) {
-          for (int i = 0; i < 4; i++) {
-            topFive[i] = topFive[i + 1];
-          }
-          topFive[4] = x;
-        }
+      value.foreach(x -> {
+        System.arraycopy(topFive, 1, topFive, 0, 4);
+        topFive[4] = x;
       });
-      StringBuffer result = new StringBuffer();
+      StringBuilder result = new StringBuilder();
       for (int i = 0; i < 5; i++) {
         int p = topFive[i];
         if (p != 0) {
           InstanceKey ik = getInstanceKey(p);
-          result.append(p).append("  ").append(ik).append("\n");
+          result.append(p).append("  ").append(ik).append('\n');
         }
       }
       return result.toString();
@@ -702,7 +669,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
     return flowGraph.getStatementsThatUse(v);
   }
 
-  public Iterator<AbstractStatement> getStatementsThatDef(PointsToSetVariable v) {
+  public Iterator<AbstractStatement<PointsToSetVariable, ?>> getStatementsThatDef(PointsToSetVariable v) {
     return flowGraph.getStatementsThatDef(v);
   }
 
@@ -729,7 +696,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
     pointsToMap.revertToPreTransitive();
   }
 
-  public Iterator getTransitiveRoots() {
+  public Iterator<PointerKey> getTransitiveRoots() {
     return pointsToMap.getTransitiveRoots();
   }
 
@@ -760,9 +727,6 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
     return periodicMaintainInterval;
   }
 
-  /**
-   * @param periodicMaintainInteval
-   */
   public void setPeriodicMaintainInterval(int periodicMaintainInteval) {
     this.periodicMaintainInterval = periodicMaintainInteval;
   }
@@ -803,8 +767,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
    */
   private void updateSideEffectsForUnification(HashSet<PointsToSetVariable> s, int rep) {
     PointsToSetVariable pRef = pointsToMap.getPointsToSet(rep);
-    for (Iterator<PointsToSetVariable> it = s.iterator(); it.hasNext();) {
-      PointsToSetVariable p = it.next();
+    for (PointsToSetVariable p : s) {
       updateSideEffects(p, pRef);
     }
   }
@@ -818,15 +781,11 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
   @SuppressWarnings("unchecked")
   private void updateEquationsForUnification(HashSet<PointsToSetVariable> s, int rep) {
     PointsToSetVariable pRef = pointsToMap.getPointsToSet(rep);
-    for (Iterator<PointsToSetVariable> it = s.iterator(); it.hasNext();) {
-      PointsToSetVariable p = it.next();
-
+    for (PointsToSetVariable p : s) {
       if (p != pRef) {
         // pRef is the representative for p.
         // be careful: cache the defs before mucking with the underlying system
-        for (Iterator d = Iterator2Collection.toSet(getStatementsThatDef(p)).iterator(); d.hasNext();) {
-          AbstractStatement as = (AbstractStatement) d.next();
-
+        for (AbstractStatement as : Iterator2Collection.toSet(getStatementsThatDef(p))) {
           if (as instanceof AssignEquation) {
             AssignEquation assign = (AssignEquation) as;
             PointsToSetVariable rhs = assign.getRightHandSide();
@@ -841,8 +800,7 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
           }
         }
         // be careful: cache the defs before mucking with the underlying system
-        for (Iterator u = Iterator2Collection.toSet(getStatementsThatUse(p)).iterator(); u.hasNext();) {
-          AbstractStatement as = (AbstractStatement) u.next();
+        for (AbstractStatement as : Iterator2Collection.toSet(getStatementsThatUse(p))) {
           if (as instanceof AssignEquation) {
             AssignEquation assign = (AssignEquation) as;
             PointsToSetVariable lhs = assign.getLHS();
@@ -909,6 +867,10 @@ public class PropagationSystem extends DefaultFixedPointSolver<PointsToSetVariab
     return pointsToMap.isUnified(result);
   }
 
+  public boolean isImplicit(PointerKey result) {
+    return pointsToMap.isImplicit(result);
+  }
+
   public int getNumber(PointerKey p) {
     return pointsToMap.getIndex(p);
   }
