@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.callgraph.propagation;
 
 import com.ibm.wala.ipa.callgraph.CGNode;
@@ -22,7 +22,7 @@ public class ReturnValueKey extends NodeKey {
 
   @Override
   public String toString() {
-    return "[Ret-V:" + getNode() + "]";
+    return "[Ret-V:" + getNode() + ']';
   }
 
   @Override
@@ -34,4 +34,4 @@ public class ReturnValueKey extends NodeKey {
   public int hashCode() {
     return 1283 * super.internalHashCode();
   }
-}
\ No newline at end of file
+}
