@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.callgraph.propagation;
 
 import com.ibm.wala.classLoader.IField;
@@ -41,7 +41,7 @@ public final class StaticFieldKey extends AbstractPointerKey {
   }
   @Override
   public String toString() {
-    return "[" + field + "]";
+    return "[" + field + ']';
   }
   public IField getField() {
     return field;
