@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.callgraph.propagation.cfa;
 
 import com.ibm.wala.ipa.callgraph.CGNode;
@@ -23,7 +23,7 @@ public final class ExceptionReturnValueKey extends ReturnValueKey {
 
   @Override
   public String toString() {
-    return "[Exc-Ret-V:" + getNode() + "]";
+    return "[Exc-Ret-V:" + getNode() + ']';
   }
 
   @Override
@@ -38,4 +38,4 @@ public final class ExceptionReturnValueKey extends ReturnValueKey {
   public int hashCode() {
     return 1201 * super.internalHashCode();
   }
-}
\ No newline at end of file
+}
