@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,11 +7,13 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.cfg;
 
 import java.util.Iterator;
 import java.util.Set;
+import java.util.function.Function;
+import java.util.function.Predicate;
 
 import com.ibm.wala.cfg.ControlFlowGraph;
 import com.ibm.wala.cfg.IBasicBlock;
@@ -21,13 +23,12 @@ import com.ibm.wala.ipa.callgraph.CallGraph;
 import com.ibm.wala.ssa.ISSABasicBlock;
 import com.ibm.wala.ssa.SSAAbstractInvokeInstruction;
 import com.ibm.wala.ssa.SSAInstruction;
-import com.ibm.wala.util.Predicate;
 import com.ibm.wala.util.collections.FilterIterator;
 import com.ibm.wala.util.collections.IndiscriminateFilter;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.collections.MapIterator;
 import com.ibm.wala.util.debug.Assertions;
 import com.ibm.wala.util.debug.UnimplementedError;
-import com.ibm.wala.util.functions.Function;
 import com.ibm.wala.util.graph.NumberedGraph;
 import com.ibm.wala.util.graph.impl.SlowSparseNumberedGraph;
 import com.ibm.wala.util.intset.BitVector;
@@ -47,15 +48,16 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
   private static final boolean FAIL_ON_EAGER_CONSTRUCTION = false;
 
   /**
-   * Should the graph include call-to-return edges? When set to <code>false</code>, the graphs output by {@link IFDSExplorer} look
-   * incorrect
+   * Should the graph include call-to-return edges? When set to {@code false}, the graphs output by
+   * {@link com.ibm.wala.ide.ui.IFDSExplorer} look incorrect
    */
+  @SuppressWarnings({ "JavadocReference", "javadoc" })
   private final static boolean CALL_TO_RETURN_EDGES = true;
 
   /**
    * Graph implementation we delegate to.
    */
-  final private NumberedGraph<BasicBlockInContext<T>> g = new SlowSparseNumberedGraph<BasicBlockInContext<T>>(2);
+  final private NumberedGraph<BasicBlockInContext<T>> g = new SlowSparseNumberedGraph<>(2);
 
   /**
    * Governing call graph
@@ -142,9 +144,8 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
 
   /**
    * If n is relevant and its cfg has not already been added, add nodes and edges for n
-   * 
-   * @param n
    */
+  @SuppressWarnings("unused")
   private void addIntraproceduralNodesAndEdgesForCGNodeIfNeeded(CGNode n) {
     if (!cgNodesVisited.contains(cg.getNumber(n)) && relevant.test(n)) {
       if (DEBUG_LEVEL > 0) {
@@ -158,8 +159,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
         addNodeForEachBasicBlock(cfg, n);
         SSAInstruction[] instrs = cfg.getInstructions();
         // create edges for node n.
-        for (Iterator<T> bbs = cfg.iterator(); bbs.hasNext();) {
-          T bb = bbs.next();
+        for (T bb : cfg) {
           if (bb != cfg.entry())
             addEdgesToNonEntryBlock(n, cfg, instrs, bb);
         }
@@ -175,22 +175,22 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
    * @param instrs the instructions for node n
    * @param bb a basic block in the CFG
    */
+  @SuppressWarnings("unused")
   protected void addEdgesToNonEntryBlock(CGNode n, ControlFlowGraph<?, T> cfg, SSAInstruction[] instrs, T bb) {
     if (DEBUG_LEVEL > 1) {
       System.err.println("addEdgesToNonEntryBlock: " + bb);
       System.err.println("nPred: " + cfg.getPredNodeCount(bb));
     }
 
-    for (Iterator<? extends T> ps = cfg.getPredNodes(bb); ps.hasNext();) {
-      T pb = ps.next();
+    for (T pb : Iterator2Iterable.make(cfg.getPredNodes(bb))) {
       if (DEBUG_LEVEL > 1) {
         System.err.println("Consider previous block: " + pb);
       }
 
       if (pb.equals(cfg.entry())) {
         // entry block has no instructions
-        BasicBlockInContext<T> p = new BasicBlockInContext<T>(n, pb);
-        BasicBlockInContext<T> b = new BasicBlockInContext<T>(n, bb);
+        BasicBlockInContext<T> p = new BasicBlockInContext<>(n, pb);
+        BasicBlockInContext<T> b = new BasicBlockInContext<>(n, bb);
         g.addEdge(p, b);
         continue;
       }
@@ -203,14 +203,14 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
       if (inst instanceof SSAAbstractInvokeInstruction) {
         if (CALL_TO_RETURN_EDGES) {
           // Add a "normal" edge from the predecessor block to this block.
-          BasicBlockInContext<T> p = new BasicBlockInContext<T>(n, pb);
-          BasicBlockInContext<T> b = new BasicBlockInContext<T>(n, bb);
+          BasicBlockInContext<T> p = new BasicBlockInContext<>(n, pb);
+          BasicBlockInContext<T> b = new BasicBlockInContext<>(n, bb);
           g.addEdge(p, b);
         }
       } else {
         // previous instruction is not a call instruction.
-        BasicBlockInContext<T> p = new BasicBlockInContext<T>(n, pb);
-        BasicBlockInContext<T> b = new BasicBlockInContext<T>(n, bb);
+        BasicBlockInContext<T> p = new BasicBlockInContext<>(n, pb);
+        BasicBlockInContext<T> b = new BasicBlockInContext<>(n, bb);
         if (!g.containsNode(p) || !g.containsNode(b)) {
           assert g.containsNode(p) : "IPCFG does not contain " + p;
           assert g.containsNode(b) : "IPCFG does not contain " + b;
@@ -233,12 +233,13 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
    * @param returnBlock the return site for a call
    * @param targetCFG the called method
    */
+  @SuppressWarnings("unused")
   private void addEdgesFromExitToReturn(CGNode caller, T returnBlock, CGNode target,
       ControlFlowGraph<SSAInstruction, ? extends T> targetCFG) {
     T texit = targetCFG.exit();
-    BasicBlockInContext<T> exit = new BasicBlockInContext<T>(target, texit);
+    BasicBlockInContext<T> exit = new BasicBlockInContext<>(target, texit);
     addNodeForBasicBlockIfNeeded(exit);
-    BasicBlockInContext<T> ret = new BasicBlockInContext<T>(caller, returnBlock);
+    BasicBlockInContext<T> ret = new BasicBlockInContext<>(caller, returnBlock);
     if (!g.containsNode(exit) || !g.containsNode(ret)) {
       assert g.containsNode(exit) : "IPCFG does not contain " + exit;
       assert g.containsNode(ret) : "IPCFG does not contain " + ret;
@@ -255,18 +256,19 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
    * @param callBlock the return site for a call
    * @param targetCFG the called method
    */
+  @SuppressWarnings("unused")
   private void addEdgesFromCallToEntry(CGNode caller, T callBlock, CGNode target,
       ControlFlowGraph<SSAInstruction, ? extends T> targetCFG) {
     T tentry = targetCFG.entry();
-    BasicBlockInContext<T> entry = new BasicBlockInContext<T>(target, tentry);
+    BasicBlockInContext<T> entry = new BasicBlockInContext<>(target, tentry);
     addNodeForBasicBlockIfNeeded(entry);
-    BasicBlockInContext<T> call = new BasicBlockInContext<T>(caller, callBlock);
+    BasicBlockInContext<T> call = new BasicBlockInContext<>(caller, callBlock);
     if (!g.containsNode(entry) || !g.containsNode(call)) {
       assert g.containsNode(entry) : "IPCFG does not contain " + entry;
       assert g.containsNode(call) : "IPCFG does not contain " + call;
     }
     if (DEBUG_LEVEL > 1) {
-      System.err.println("addEdgeFromCallToEntry " + call + " " + entry);
+      System.err.println("addEdgeFromCallToEntry " + call + ' ' + entry);
     }
     g.addEdge(call, entry);
   }
@@ -275,8 +277,8 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
    * Add the incoming edges to the entry() block and the outgoing edges from the exit() block for a call graph node.
    * 
    * @param n a node in the call graph
-   * @param bb the entry() block for n
    */
+  @SuppressWarnings("unused")
   private void addInterproceduralEdgesForEntryAndExitBlocks(CGNode n, ControlFlowGraph<SSAInstruction, ? extends T> cfg) {
 
     T entryBlock = cfg.entry();
@@ -285,8 +287,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
       System.err.println("addInterproceduralEdgesForEntryAndExitBlocks " + n);
     }
 
-    for (Iterator callers = cg.getPredNodes(n); callers.hasNext();) {
-      CGNode caller = (CGNode) callers.next();
+    for (CGNode caller : Iterator2Iterable.make(cg.getPredNodes(n))) {
       if (DEBUG_LEVEL > 1) {
         System.err.println("got caller " + caller);
       }
@@ -296,6 +297,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
     }
   }
 
+  @SuppressWarnings("unused")
   private void addEntryAndExitEdgesToCaller(CGNode n, T entryBlock, T exitBlock, CGNode caller) {
     if (DEBUG_LEVEL > 0) {
       System.err.println("caller " + caller + "is relevant");
@@ -320,16 +322,15 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
               System.err.println("Adding edge " + ccfg.getBlockForInstruction(i) + " to " + entryBlock);
             }
             T callerBB = ccfg.getBlockForInstruction(i);
-            BasicBlockInContext<T> b1 = new BasicBlockInContext<T>(caller, callerBB);
+            BasicBlockInContext<T> b1 = new BasicBlockInContext<>(caller, callerBB);
             // need to add a node for caller basic block, in case we haven't processed caller yet
             addNodeForBasicBlockIfNeeded(b1);
-            BasicBlockInContext<T> b2 = new BasicBlockInContext<T>(n, entryBlock);
+            BasicBlockInContext<T> b2 = new BasicBlockInContext<>(n, entryBlock);
             g.addEdge(b1, b2);
             // also add edges from exit node to all return nodes (successor of call bb)
-            for (Iterator<? extends T> succIter = ccfg.getSuccNodes(callerBB); succIter.hasNext();) {
-              T returnBB = succIter.next();
-              BasicBlockInContext<T> b3 = new BasicBlockInContext<T>(n, exitBlock);
-              BasicBlockInContext<T> b4 = new BasicBlockInContext<T>(caller, returnBB);
+            for (T returnBB : Iterator2Iterable.make(ccfg.getSuccNodes(callerBB))) {
+              BasicBlockInContext<T> b3 = new BasicBlockInContext<>(n, exitBlock);
+              BasicBlockInContext<T> b4 = new BasicBlockInContext<>(caller, returnBB);
               addNodeForBasicBlockIfNeeded(b4);
               g.addEdge(b3, b4);
             }
@@ -344,13 +345,13 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
    * 
    * @param cfg a control-flow graph
    */
+  @SuppressWarnings("unused")
   private void addNodeForEachBasicBlock(ControlFlowGraph<? extends SSAInstruction, ? extends T> cfg, CGNode N) {
-    for (Iterator<? extends T> bbs = cfg.iterator(); bbs.hasNext();) {
-      T bb = bbs.next();
+    for (T bb : cfg) {
       if (DEBUG_LEVEL > 1) {
         System.err.println("IPCFG Add basic block " + bb);
       }
-      BasicBlockInContext<T> b = new BasicBlockInContext<T>(N, bb);
+      BasicBlockInContext<T> b = new BasicBlockInContext<>(N, bb);
       addNodeForBasicBlockIfNeeded(b);
     }
   }
@@ -369,7 +370,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
    * @return the original CFG from whence B came
    * @throws IllegalArgumentException if B == null
    */
-  public ControlFlowGraph<SSAInstruction, T> getCFG(BasicBlockInContext B) throws IllegalArgumentException {
+  public ControlFlowGraph<SSAInstruction, T> getCFG(BasicBlockInContext<T> B) throws IllegalArgumentException {
     if (B == null) {
       throw new IllegalArgumentException("B == null");
     }
@@ -380,7 +381,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
    * @return the original CGNode from whence B came
    * @throws IllegalArgumentException if B == null
    */
-  public CGNode getCGNode(BasicBlockInContext B) throws IllegalArgumentException {
+  public CGNode getCGNode(BasicBlockInContext<T> B) throws IllegalArgumentException {
     if (B == null) {
       throw new IllegalArgumentException("B == null");
     }
@@ -391,7 +392,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
    * @see com.ibm.wala.util.graph.Graph#removeNodeAndEdges(com.ibm.wala.util.graph.Node)
    */
   @Override
-  public void removeNodeAndEdges(BasicBlockInContext N) throws UnsupportedOperationException {
+  public void removeNodeAndEdges(BasicBlockInContext<T> N) throws UnsupportedOperationException {
     throw new UnsupportedOperationException();
   }
 
@@ -443,15 +444,12 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
 
   /**
    * add interprocedural edges to nodes in callees of n
-   * 
-   * @param n
    */
   private void addEdgesToCallees(CGNode n) {
     ControlFlowGraph<SSAInstruction, T> cfg = getCFG(n);
     if (cfg != null) {
-      for (Iterator<T> bbs = cfg.iterator(); bbs.hasNext();) {
-        T bb = bbs.next();
-        BasicBlockInContext<T> block = new BasicBlockInContext<T>(n, bb);
+      for (T bb : cfg) {
+        BasicBlockInContext<T> block = new BasicBlockInContext<>(n, bb);
         if (hasCall(block)) {
           addCalleeEdgesForCall(n, block);
         }
@@ -470,7 +468,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
       ControlFlowGraph<SSAInstruction, T> cfg = getCFG(returnBlock);
       for (Iterator<? extends T> it = cfg.getPredNodes(returnBlock.getDelegate()); it.hasNext();) {
         T b = it.next();
-        final BasicBlockInContext<T> block = new BasicBlockInContext<T>(node, b);
+        final BasicBlockInContext<T> block = new BasicBlockInContext<>(node, b);
         if (hasCall(block)) {
           addCalleeEdgesForCall(node, block);
         }
@@ -481,6 +479,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
   /**
    * add edges to callee entry for call block, and edges from callee exit to corresponding return blocks
    */
+  @SuppressWarnings("unused")
   private void addCalleeEdgesForCall(CGNode n, BasicBlockInContext<T> callBlock) {
     int num = g.getNumber(callBlock);
     if (!handledCalls.contains(num)) {
@@ -491,8 +490,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
         System.err.println("got Site: " + site);
       }
       boolean irrelevantTargets = false;
-      for (Iterator ts = cg.getPossibleTargets(n, site).iterator(); ts.hasNext();) {
-        CGNode tn = (CGNode) ts.next();
+      for (CGNode tn : cg.getPossibleTargets(n, site)) {
         if (!relevant.test(tn)) {
           if (DEBUG_LEVEL > 1) {
             System.err.println("Irrelevant target: " + tn);
@@ -515,7 +513,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
             addEdgesFromExitToReturn(n, retBlock, tn, tcfg);
             if (irrelevantTargets) {
               // Add a "normal" edge from the call block to the return block.
-              g.addEdge(callBlock, new BasicBlockInContext<T>(n, retBlock));
+              g.addEdge(callBlock, new BasicBlockInContext<>(n, retBlock));
             }
           }
         }
@@ -525,8 +523,6 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
 
   /**
    * add edges to nodes in callers of n
-   * 
-   * @param n
    */
   private void addCallerEdges(CGNode n) {
     final int num = cg.getNumber(n);
@@ -541,7 +537,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
    * @see com.ibm.wala.util.graph.NodeManager#addNode(com.ibm.wala.util.graph.Node)
    */
   @Override
-  public void addNode(BasicBlockInContext n) throws UnsupportedOperationException {
+  public void addNode(BasicBlockInContext<T> n) throws UnsupportedOperationException {
     throw new UnsupportedOperationException();
   }
 
@@ -549,7 +545,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
    * @see com.ibm.wala.util.graph.NodeManager#removeNode(com.ibm.wala.util.graph.Node)
    */
   @Override
-  public void removeNode(BasicBlockInContext n) throws UnsupportedOperationException {
+  public void removeNode(BasicBlockInContext<T> n) throws UnsupportedOperationException {
     throw new UnsupportedOperationException();
   }
 
@@ -629,12 +625,12 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
    * @see com.ibm.wala.util.graph.EdgeManager#addEdge(com.ibm.wala.util.graph.Node, com.ibm.wala.util.graph.Node)
    */
   @Override
-  public void addEdge(BasicBlockInContext src, BasicBlockInContext dst) throws UnsupportedOperationException {
+  public void addEdge(BasicBlockInContext<T> src, BasicBlockInContext<T> dst) throws UnsupportedOperationException {
     throw new UnsupportedOperationException();
   }
 
   @Override
-  public void removeEdge(BasicBlockInContext src, BasicBlockInContext dst) throws UnsupportedOperationException {
+  public void removeEdge(BasicBlockInContext<T> src, BasicBlockInContext<T> dst) throws UnsupportedOperationException {
     throw new UnsupportedOperationException();
   }
 
@@ -642,7 +638,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
    * @see com.ibm.wala.util.graph.EdgeManager#removeEdges(com.ibm.wala.util.graph.Node)
    */
   @Override
-  public void removeAllIncidentEdges(BasicBlockInContext node) throws UnsupportedOperationException {
+  public void removeAllIncidentEdges(BasicBlockInContext<T> node) throws UnsupportedOperationException {
     throw new UnsupportedOperationException();
   }
 
@@ -660,7 +656,6 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
   }
 
   /**
-   * @param B
    * @return true iff basic block B ends in a call instuction
    */
   public boolean hasCall(BasicBlockInContext<T> B) {
@@ -690,7 +685,6 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
   }
 
   /**
-   * @param B
    * @return the set of CGNodes that B may call, according to the governing call graph.
    * @throws IllegalArgumentException if B is null
    */
@@ -723,12 +717,12 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
   }
 
   @Override
-  public void removeIncomingEdges(BasicBlockInContext node) throws UnsupportedOperationException {
+  public void removeIncomingEdges(BasicBlockInContext<T> node) throws UnsupportedOperationException {
     throw new UnsupportedOperationException();
   }
 
   @Override
-  public void removeOutgoingEdges(BasicBlockInContext node) throws UnsupportedOperationException {
+  public void removeOutgoingEdges(BasicBlockInContext<T> node) throws UnsupportedOperationException {
     throw new UnsupportedOperationException();
   }
 
@@ -809,7 +803,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
     ControlFlowGraph<SSAInstruction, ? extends T> cfg = getCFG(n);
     if (cfg != null) {
       T entry = cfg.entry();
-      return new BasicBlockInContext<T>(n, entry);
+      return new BasicBlockInContext<>(n, entry);
     } else {
       return null;
     }
@@ -818,7 +812,7 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
   public BasicBlockInContext<T> getExit(CGNode n) {
     ControlFlowGraph<SSAInstruction, ? extends T> cfg = getCFG(n);
     T entry = cfg.exit();
-    return new BasicBlockInContext<T>(n, entry);
+    return new BasicBlockInContext<>(n, entry);
   }
 
   /**
@@ -834,13 +828,8 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
 
     // a successor node is a return site if it is in the same
     // procedure, and is not the entry() node.
-    Predicate isReturn = new Predicate() {
-      @Override public boolean test(Object o) {
-        BasicBlockInContext other = (BasicBlockInContext) o;
-        return !other.isEntryBlock() && node.equals(other.getNode());
-      }
-    };
-    return new FilterIterator<BasicBlockInContext<T>>(getSuccNodes(callBlock), isReturn);
+    Predicate<BasicBlockInContext<T>> isReturn = other -> !other.isEntryBlock() && node.equals(other.getNode());
+    return new FilterIterator<>(getSuccNodes(callBlock), isReturn);
   }
 
   /**
@@ -855,46 +844,36 @@ public abstract class AbstractInterproceduralCFG<T extends ISSABasicBlock> imple
     Iterator<? extends T> it = cfg.getPredNodes(returnBlock.getDelegate());
     final CGNode node = returnBlock.getNode();
 
-    Predicate<? extends T> dispatchFilter = new Predicate<T>() {
-      @Override public boolean test(T callBlock) {
-        BasicBlockInContext<T> bb = new BasicBlockInContext<T>(node, callBlock);
-        if (!hasCall(bb, cfg)) {
-          return false;
-        }
-        if (callee != null) {
-          return getCallTargets(bb).contains(callee);
-        } else {
-          return getCallTargets(bb).isEmpty();
-        }
+    Predicate<T> dispatchFilter = callBlock -> {
+      BasicBlockInContext<T> bb = new BasicBlockInContext<>(node, callBlock);
+      if (!hasCall(bb, cfg)) {
+        return false;
+      }
+      if (callee != null) {
+        return getCallTargets(bb).contains(callee);
+      } else {
+        return getCallTargets(bb).isEmpty();
       }
     };
     it = new FilterIterator<T>(it, dispatchFilter);
 
-    Function<T, BasicBlockInContext<T>> toContext = new Function<T, BasicBlockInContext<T>>() {
-      @Override
-      public BasicBlockInContext<T> apply(T object) {
-        T b = object;
-        return new BasicBlockInContext<T>(node, b);
-      }
+    Function<T, BasicBlockInContext<T>> toContext = object -> {
+      T b = object;
+      return new BasicBlockInContext<>(node, b);
     };
-    MapIterator<T, BasicBlockInContext<T>> m = new MapIterator<T, BasicBlockInContext<T>>(it, toContext);
-    return new FilterIterator<BasicBlockInContext<T>>(m, isCall);
+    MapIterator<T, BasicBlockInContext<T>> m = new MapIterator<>(it, toContext);
+    return new FilterIterator<>(m, isCall);
   }
 
-  private final Predicate<BasicBlockInContext<T>> isCall = new Predicate<BasicBlockInContext<T>>() {
-    @Override public boolean test(BasicBlockInContext<T> o) {
-      return hasCall(o);
-    }
-  };
+  private final Predicate<BasicBlockInContext<T>> isCall = this::hasCall;
 
   public boolean isReturn(BasicBlockInContext<T> bb) throws IllegalArgumentException {
     if (bb == null) {
       throw new IllegalArgumentException("bb == null");
     }
     ControlFlowGraph<SSAInstruction, T> cfg = getCFG(bb);
-    for (Iterator<? extends T> it = cfg.getPredNodes(bb.getDelegate()); it.hasNext();) {
-      T b = it.next();
-      if (hasCall(new BasicBlockInContext<T>(bb.getNode(), b))) {
+    for (T b : Iterator2Iterable.make(cfg.getPredNodes(bb.getDelegate()))) {
+      if (hasCall(new BasicBlockInContext<>(bb.getNode(), b))) {
         return true;
       }
     }
