@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2007 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.cfg;
 
 import com.ibm.wala.cfg.IBasicBlock;
@@ -15,7 +15,7 @@ import com.ibm.wala.cfg.IBasicBlock;
 /**
  * This class is used by the PrunedCFG to determine which edges in a given CFG should be kept in the pruned version.
  */
-public interface EdgeFilter<T extends IBasicBlock> {
+public interface EdgeFilter<T extends IBasicBlock<?>> {
 
   /**
    * This method must return true if and only if a normal edge from src to dst exists in the original CFG and should be kept for the
@@ -30,4 +30,4 @@ public interface EdgeFilter<T extends IBasicBlock> {
    */
   boolean hasExceptionalEdge(T src, T dst);
 
-}
\ No newline at end of file
+}
