@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2007 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.cfg;
 
 import com.ibm.wala.cfg.ControlFlowGraph;
@@ -34,10 +34,10 @@ public class ExceptionPrunedCFG {
     public boolean hasExceptionalEdge(T src, T dst) {
       return false;
     }
-  };
+  }
 
   public static <I, T extends IBasicBlock<I>> PrunedCFG<I, T> make(ControlFlowGraph<I, T> cfg) {
-    return PrunedCFG.make(cfg, new ExceptionEdgePruner<I, T>(cfg));
+    return PrunedCFG.make(cfg, new ExceptionEdgePruner<>(cfg));
   }
 }
 
