@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,9 +7,42 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.cha;
 
+import com.ibm.wala.classLoader.ArrayClass;
+import com.ibm.wala.classLoader.BytecodeClass;
+import com.ibm.wala.classLoader.ClassLoaderFactory;
+import com.ibm.wala.classLoader.IClass;
+import com.ibm.wala.classLoader.IClassLoader;
+import com.ibm.wala.classLoader.IField;
+import com.ibm.wala.classLoader.IMethod;
+import com.ibm.wala.classLoader.Language;
+import com.ibm.wala.classLoader.NoSuperclassFoundException;
+import com.ibm.wala.classLoader.PhantomClass;
+import com.ibm.wala.classLoader.ShrikeClass;
+import com.ibm.wala.ipa.callgraph.AnalysisScope;
+import com.ibm.wala.types.ClassLoaderReference;
+import com.ibm.wala.types.FieldReference;
+import com.ibm.wala.types.MethodReference;
+import com.ibm.wala.types.Selector;
+import com.ibm.wala.types.TypeName;
+import com.ibm.wala.types.TypeReference;
+import com.ibm.wala.util.MonitorUtil.IProgressMonitor;
+import com.ibm.wala.util.collections.HashMapFactory;
+import com.ibm.wala.util.collections.HashSetFactory;
+import com.ibm.wala.util.collections.Iterator2Collection;
+import com.ibm.wala.util.collections.Iterator2Iterable;
+import com.ibm.wala.util.collections.MapIterator;
+import com.ibm.wala.util.collections.MapUtil;
+import com.ibm.wala.util.debug.Assertions;
+import com.ibm.wala.util.debug.UnimplementedError;
+import com.ibm.wala.util.ref.CacheReference;
+import com.ibm.wala.util.ref.ReferenceCleanser;
+import com.ibm.wala.util.strings.Atom;
+import com.ibm.wala.util.warnings.Warning;
+import com.ibm.wala.util.warnings.Warnings;
+
 import java.io.IOException;
 import java.util.Collection;
 import java.util.Collections;
@@ -20,36 +53,7 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
-
-import com.ibm.wala.classLoader.ArrayClass;
-import com.ibm.wala.classLoader.ClassLoaderFactory;
-import com.ibm.wala.classLoader.ClassLoaderFactoryImpl;
-import com.ibm.wala.classLoader.IClass;
-import com.ibm.wala.classLoader.IClassLoader;
-import com.ibm.wala.classLoader.IField;
-import com.ibm.wala.classLoader.IMethod;
-import com.ibm.wala.classLoader.Language;
-import com.ibm.wala.classLoader.ShrikeClass;
-import com.ibm.wala.ipa.callgraph.AnalysisScope;
-import com.ibm.wala.types.ClassLoaderReference;
-import com.ibm.wala.types.FieldReference;
-import com.ibm.wala.types.MethodReference;
-import com.ibm.wala.types.Selector;
-import com.ibm.wala.types.TypeReference;
-import com.ibm.wala.util.MonitorUtil.IProgressMonitor;
-import com.ibm.wala.util.collections.HashMapFactory;
-import com.ibm.wala.util.collections.HashSetFactory;
-import com.ibm.wala.util.collections.Iterator2Collection;
-import com.ibm.wala.util.collections.MapIterator;
-import com.ibm.wala.util.collections.MapUtil;
-import com.ibm.wala.util.debug.Assertions;
-import com.ibm.wala.util.debug.UnimplementedError;
-import com.ibm.wala.util.functions.Function;
-import com.ibm.wala.util.ref.CacheReference;
-import com.ibm.wala.util.ref.ReferenceCleanser;
-import com.ibm.wala.util.strings.Atom;
-import com.ibm.wala.util.warnings.Warning;
-import com.ibm.wala.util.warnings.Warnings;
+import java.util.function.Function;
 
 /**
  * Simple implementation of a class hierarchy.
@@ -61,6 +65,9 @@ public class ClassHierarchy implements IClassHierarchy {
 
   private static final boolean DEBUG = false;
 
+  public enum MissingSuperClassHandling { NONE, ROOT, PHANTOM }
+
+
   /**
    * Languages that contribute classes to the set represented in this hierarchy. The languages may for example be related by
    * inheritance (e.g. X10 derives from Java, and shares a common type hierarchy rooted at java.lang.Object).
@@ -76,8 +83,7 @@ public class ClassHierarchy implements IClassHierarchy {
    * {@link ConcurrentModificationException}. But with a {@link ConcurrentHashMap}, at least the code merrily chugs along,
    * tolerating the race.
    */
-  final private Map<TypeReference, Node> map = new ConcurrentHashMap<TypeReference, Node>();
-
+  final private Map<TypeReference, Node> map; 
   /**
    * {@link TypeReference} for the root type
    */
@@ -99,7 +105,7 @@ public class ClassHierarchy implements IClassHierarchy {
   final private IClassLoader[] loaders;
 
   /**
-   * A mapping from IClass -> Selector -> Set of IMethod
+   * A mapping from IClass -&gt; Selector -&gt; Set of IMethod
    */
   final private HashMap<IClass, Object> targetCache = HashMapFactory.make();
 
@@ -109,7 +115,7 @@ public class ClassHierarchy implements IClassHierarchy {
   private final AnalysisScope scope;
 
   /**
-   * A mapping from IClass (representing an interface) -> Set of IClass that implement that interface
+   * A mapping from IClass (representing an interface) -&gt; Set of IClass that implement that interface
    */
   private final Map<IClass, Set<IClass>> implementors = HashMapFactory.make();
 
@@ -133,6 +139,16 @@ public class ClassHierarchy implements IClassHierarchy {
    */
   private Collection<TypeReference> runtimeExceptionTypeRefs;
 
+  /**
+   * How should we handle missing superclasses?
+   * DEFAULT: no special handling, class will be excluded from class hierarchy
+   *    ROOT: replace the missing superclass with the hierarchy root
+   * PHANTOM: create a phantom superclass and add the subclass to the hierarchy.
+   *          Note that we can only create phantom superclass when the class is a
+   *          {@link com.ibm.wala.classLoader.BytecodeClass}
+   */
+  private final MissingSuperClassHandling superClassHandling;
+
   /**
    * Return a set of {@link IClass} that holds all superclasses of klass
    * 
@@ -146,43 +162,63 @@ public class ClassHierarchy implements IClassHierarchy {
 
     Set<IClass> result = HashSetFactory.make(3);
 
-    klass = klass.getSuperclass();
-
-    while (klass != null) {
-      if (DEBUG) {
-        System.err.println("got superclass " + klass);
-      }
-      boolean added = result.add(klass);
-      if (!added) {
-        // oops.  we have A is a sub-class of B and B is a sub-class of A.  blow up.
-        throw new IllegalStateException("cycle in the extends relation for class " + klass);
-      }
+    try {
       klass = klass.getSuperclass();
-      if (klass != null && klass.getReference().getName().equals(rootTypeRef.getName())) {
-        if (!klass.getReference().getClassLoader().equals(rootTypeRef.getClassLoader())) {
-          throw new IllegalStateException("class " + klass + " is invalid, unexpected classloader");
+
+      while (klass != null) {
+        if (DEBUG) {
+          System.err.println("got superclass " + klass);
         }
+        boolean added = result.add(klass);
+        if (!added) {
+          // oops.  we have A is a sub-class of B and B is a sub-class of A.  blow up.
+          throw new IllegalStateException("cycle in the extends relation for class " + klass);
+        }
+        klass = klass.getSuperclass();
+        if (klass != null && klass.getReference().getName().equals(rootTypeRef.getName())) {
+          if (!klass.getReference().getClassLoader().equals(rootTypeRef.getClassLoader())) {
+            throw new IllegalStateException("class " + klass + " is invalid, unexpected classloader");
+          }
+        }
+      }
+    } catch (NoSuperclassFoundException e) {
+      if (!superClassHandling.equals(MissingSuperClassHandling.NONE) && klass instanceof BytecodeClass) {
+        if (superClassHandling.equals(MissingSuperClassHandling.PHANTOM)) {
+          // create a phantom superclass.  add it and the root class to the result
+          IClass phantom = getPhantomSuperclass((BytecodeClass<?>) klass);
+          result.add(phantom);
+        }
+        result.add(getRootClass());
+      } else {
+        throw e;
       }
     }
     return result;
   }
 
-  private ClassHierarchy(AnalysisScope scope, ClassLoaderFactory factory, Language language, IProgressMonitor progressMonitor)
+  ClassHierarchy(AnalysisScope scope, ClassLoaderFactory factory, Language language,
+      IProgressMonitor progressMonitor, Map<TypeReference, Node> map, MissingSuperClassHandling superClassHandling)
       throws ClassHierarchyException, IllegalArgumentException {
-    this(scope, factory, Collections.singleton(language), progressMonitor);
+    this(scope, factory, Collections.singleton(language), progressMonitor, map,
+        superClassHandling);
   }
 
-  private ClassHierarchy(AnalysisScope scope, ClassLoaderFactory factory, IProgressMonitor progressMonitor)
+  ClassHierarchy(AnalysisScope scope, ClassLoaderFactory factory, IProgressMonitor
+      progressMonitor, Map<TypeReference, Node> map, MissingSuperClassHandling superClassHandling)
       throws ClassHierarchyException, IllegalArgumentException {
-    this(scope, factory, scope.getLanguages(), progressMonitor);
+    this(scope, factory, scope.getLanguages(), progressMonitor, map, superClassHandling);
   }
 
-  private ClassHierarchy(AnalysisScope scope, ClassLoaderFactory factory, Collection<Language> languages,
-      IProgressMonitor progressMonitor) throws ClassHierarchyException, IllegalArgumentException {
+  ClassHierarchy(AnalysisScope scope, ClassLoaderFactory factory, Collection<Language> languages,
+      IProgressMonitor progressMonitor, Map<TypeReference, Node> map, MissingSuperClassHandling superClassHandling) throws
+      ClassHierarchyException, IllegalArgumentException {
     // now is a good time to clear the warnings globally.
     // TODO: think of a better way to guard against warning leaks.
     Warnings.clear();
 
+    this.map = map;
+    this.superClassHandling = superClassHandling;
+    
     if (factory == null) {
       throw new IllegalArgumentException();
     }
@@ -273,13 +309,12 @@ public class ClassHierarchy implements IClassHierarchy {
       System.err.println(("Add all classes from loader " + loader));
     }
     Collection<IClass> toRemove = HashSetFactory.make();
-    for (Iterator<IClass> it = loader.iterateAllClasses(); it.hasNext();) {
+    for (IClass klass : Iterator2Iterable.make(loader.iterateAllClasses())) {
       if (progressMonitor != null) {
         if (progressMonitor.isCanceled()) {
           throw new CancelCHAConstructionException();
         }
       }
-      IClass klass = it.next();
       boolean added = addClass(klass);
       if (!added) {
         toRemove.add(klass);
@@ -295,6 +330,7 @@ public class ClassHierarchy implements IClassHierarchy {
    */
   @Override
   public boolean addClass(IClass klass) {
+   
     if (klass == null) {
       throw new IllegalArgumentException("klass is null");
     }
@@ -306,34 +342,49 @@ public class ClassHierarchy implements IClassHierarchy {
     if (DEBUG) {
       System.err.println(("Attempt to add class " + klass));
     }
-    Set<IClass> loadedSuperclasses;
-    Collection loadedSuperInterfaces;
+    Set<IClass> loadedSuperclasses = null;
+    Collection<IClass> loadedSuperInterfaces;
     try {
       loadedSuperclasses = computeSuperclasses(klass);
       loadedSuperInterfaces = klass.getAllImplementedInterfaces();
     } catch (Exception e) {
-      // a little cleanup
-      if (klass instanceof ShrikeClass) {
-        if (DEBUG) {
-          System.err.println(("Exception.  Clearing " + klass));
+      if (!superClassHandling.equals(MissingSuperClassHandling.NONE) && e instanceof NoSuperclassFoundException) {
+        // this must have been thrown by the getAllImplementedInterfaces() call.
+        // for now, just pretend it implements no interfaces
+        loadedSuperInterfaces = Collections.emptySet();
+      } else {
+        // a little cleanup
+        if (klass instanceof ShrikeClass) {
+          if (DEBUG) {
+            System.err.println(("Exception.  Clearing " + klass));
+          }
         }
+        Warnings.add(ClassExclusion.create(klass.getReference(), e.getMessage()));
+        return false;
       }
-      Warnings.add(ClassExclusion.create(klass.getReference(), e.getMessage()));
-      return false;
     }
     Node node = findOrCreateNode(klass);
 
     if (klass.getReference().equals(this.rootTypeRef)) {
       // there is only one root
-      assert root == null;
+      assert root == null || root == node;
       root = node;
     }
 
-    Set workingSuperclasses = HashSetFactory.make(loadedSuperclasses);
+    HashSet<IClass> workingSuperclasses = HashSetFactory.make(loadedSuperclasses);
     while (node != null) {
       IClass c = node.getJavaClass();
-      IClass superclass = null;
-      superclass = c.getSuperclass();
+      IClass superclass;
+      try {
+        superclass = c.getSuperclass();
+      } catch (NoSuperclassFoundException e) {
+        assert !superClassHandling.equals(MissingSuperClassHandling.NONE);
+
+        if (superClassHandling.equals(MissingSuperClassHandling.ROOT))
+          superclass = getRootClass();
+        else
+          superclass = getPhantomSuperclass((BytecodeClass<?>) c);
+      }
       if (superclass != null) {
         workingSuperclasses.remove(superclass);
         Node supernode = findOrCreateNode(superclass);
@@ -342,6 +393,10 @@ public class ClassHierarchy implements IClassHierarchy {
         }
         supernode.addChild(node);
         if (supernode.getJavaClass().getReference().equals(rootTypeRef)) {
+          
+          assert root == null || root == supernode;
+          root = supernode;
+
           node = null;
         } else {
           node = supernode;
@@ -352,8 +407,7 @@ public class ClassHierarchy implements IClassHierarchy {
     }
 
     if (loadedSuperInterfaces != null) {
-      for (Iterator it3 = loadedSuperInterfaces.iterator(); it3.hasNext();) {
-        final IClass iface = (IClass) it3.next();
+      for (IClass iface : loadedSuperInterfaces) {
         try {
           // make sure we'll be able to load the interface!
           computeSuperclasses(iface);
@@ -377,6 +431,18 @@ public class ClassHierarchy implements IClassHierarchy {
     return true;
   }
 
+  private IClass getPhantomSuperclass(BytecodeClass<?> klass) {
+    ClassLoaderReference loader = klass.getReference().getClassLoader();
+    TypeName superName = klass.getSuperName();
+    TypeReference superRef = TypeReference.findOrCreate(loader, superName);
+    IClass superClass = lookupClass(superRef);
+    if (superClass == null) {
+      superClass = new PhantomClass(superRef, this);
+      addClass(superClass);
+    }
+    return superClass;
+  }
+
   /**
    * Record that a klass implements a particular interface
    */
@@ -454,13 +520,12 @@ public class ClassHierarchy implements IClassHierarchy {
     }
     if (declaredClass.isInterface()) {
       HashSet<IMethod> result = HashSetFactory.make(3);
-      Set impls = implementors.get(declaredClass);
+      Set<IClass> impls = implementors.get(declaredClass);
       if (impls == null) {
         // give up and return no receivers
         return Collections.emptySet();
       }
-      for (Iterator it = impls.iterator(); it.hasNext();) {
-        IClass klass = (IClass) it.next();
+      for (IClass klass : impls) {
         if (!klass.isInterface() && !klass.isAbstract()) {
           result.addAll(computeTargetsNotInterface(ref, klass));
         }
@@ -506,7 +571,6 @@ public class ClassHierarchy implements IClassHierarchy {
   /**
    * Return the unique receiver of an invocation of method on an object of type m.getDeclaredClass
    * 
-   * @param m
    * @return IMethod, or null if no appropriate receiver is found.
    * @throws IllegalArgumentException if m is null
    */
@@ -581,7 +645,7 @@ public class ClassHierarchy implements IClassHierarchy {
         return null;
       } else {
         if (DEBUG) {
-          System.err.println(("Attempt to resolve for " + receiverClass + " in superclass: " + superclass + " " + selector));
+          System.err.println(("Attempt to resolve for " + receiverClass + " in superclass: " + superclass + ' ' + selector));
         }
         return resolveMethod(superclass, selector);
       }
@@ -595,7 +659,7 @@ public class ClassHierarchy implements IClassHierarchy {
    * @param selector method selector
    * @return the method if found, else null
    */
-  private IMethod findMethod(IClass clazz, Selector selector) {
+  private static IMethod findMethod(IClass clazz, Selector selector) {
     return clazz.getMethod(selector);
   }
 
@@ -608,9 +672,7 @@ public class ClassHierarchy implements IClassHierarchy {
    */
   private Set<IMethod> computeOverriders(Node node, Selector selector) {
     HashSet<IMethod> result = HashSetFactory.make(3);
-    for (Iterator<Node> it = node.getChildren(); it.hasNext();) {
-
-      Node child = it.next();
+    for (Node child : Iterator2Iterable.make(node.getChildren())) {
       IMethod m = findMethod(child.getJavaClass(), selector);
       if (m != null) {
         result.add(m);
@@ -635,22 +697,21 @@ public class ClassHierarchy implements IClassHierarchy {
 
   @Override
   public String toString() {
-    StringBuffer result = new StringBuffer(100);
+    StringBuilder result = new StringBuilder(100);
     recursiveStringify(root, result);
     return result.toString();
   }
 
-  private void recursiveStringify(Node n, StringBuffer buffer) {
-    buffer.append(n.toString()).append("\n");
-    for (Iterator<Node> it = n.getChildren(); it.hasNext();) {
-      Node child = it.next();
+  private void recursiveStringify(Node n, StringBuilder buffer) {
+    buffer.append(n.toString()).append('\n');
+    for (Node child : Iterator2Iterable.make(n.getChildren())) {
       recursiveStringify(child, buffer);
     }
   }
 
   /**
    * Number the class hierarchy tree to support efficient subclass tests. After numbering the tree, n1 is a child of n2 iff n2.left
-   * <= n1.left ^ n1.left <= n2.right. Described as "relative numbering" by Vitek, Horspool, and Krall, OOPSLA 97
+   * &lt;= n1.left ^ n1.left &lt;= n2.right. Described as "relative numbering" by Vitek, Horspool, and Krall, OOPSLA 97
    * 
    * TODO: this implementation is recursive; un-recursify if needed
    */
@@ -663,8 +724,7 @@ public class ClassHierarchy implements IClassHierarchy {
 
   private void visitForNumbering(Node N) {
     N.left = nextNumber++;
-    for (Iterator<Node> it = N.children.iterator(); it.hasNext();) {
-      Node C = it.next();
+    for (Node C : N.children) {
       visitForNumbering(C);
     }
     N.right = nextNumber++;
@@ -673,7 +733,7 @@ public class ClassHierarchy implements IClassHierarchy {
   /**
    * internal representation of a node in the class hiearachy, representing one java class.
    */
-  private static final class Node {
+  static final class Node {
 
     private final IClass klass;
 
@@ -710,13 +770,13 @@ public class ClassHierarchy implements IClassHierarchy {
 
     @Override
     public String toString() {
-      StringBuffer result = new StringBuffer(100);
-      result.append(klass.toString()).append(":");
+      StringBuilder result = new StringBuilder(100);
+      result.append(klass.toString()).append(':');
       for (Iterator<Node> i = children.iterator(); i.hasNext();) {
         Node n = i.next();
         result.append(n.klass.toString());
         if (i.hasNext())
-          result.append(",");
+          result.append(',');
       }
       return result.toString();
     }
@@ -756,17 +816,9 @@ public class ClassHierarchy implements IClassHierarchy {
       return b;
     } else {
       Node n = map.get(b.getReference());
-      if (n == null) {
-        assert n != null : "null n for " + b;
-      }
+      assert n != null : "null n for " + b;
       Set<IClass> superB;
-      try {
-        superB = getSuperclasses(b);
-      } catch (ClassHierarchyException e1) {
-        e1.printStackTrace();
-        Assertions.UNREACHABLE();
-        superB = null;
-      }
+      superB = getSuperclasses(b);
       IClass aa = a;
       while (aa != null) {
         if (b.equals(aa) || superB.contains(aa)) {
@@ -775,19 +827,13 @@ public class ClassHierarchy implements IClassHierarchy {
         aa = aa.getSuperclass();
       }
       Set<IClass> superA;
-      try {
-        superA = getSuperclasses(a);
-      } catch (ClassHierarchyException e1) {
-        e1.printStackTrace();
-        Assertions.UNREACHABLE();
-        superA = null;
-      }
-      Assertions.UNREACHABLE("getLeastCommonSuperclass " + tempA + " " + b + ": " + superA + ", " + superB);
+      superA = getSuperclasses(a);
+      Assertions.UNREACHABLE("getLeastCommonSuperclass " + tempA + ' ' + b + ": " + superA + ", " + superB);
       return null;
     }
   }
 
-  private Set<IClass> getSuperclasses(IClass c) throws ClassHierarchyException {
+  private static Set<IClass> getSuperclasses(IClass c) {
     HashSet<IClass> result = HashSetFactory.make(3);
     while (c.getSuperclass() != null) {
       result.add(c.getSuperclass());
@@ -986,7 +1032,7 @@ public class ClassHierarchy implements IClassHierarchy {
       // arrays implement Cloneable and Serializable
       return i.equals(lookupClass(TypeReference.JavaLangCloneable)) || i.equals(lookupClass(TypeReference.JavaIoSerializable));
     }
-    Set impls = implementors.get(i);
+    Set<IClass> impls = implementors.get(i);
     if (impls != null && impls.contains(c)) {
       return true;
     }
@@ -1019,7 +1065,7 @@ public class ClassHierarchy implements IClassHierarchy {
   }
 
   /**
-   * Solely for optimization; return a Collection<TypeReference> representing the subclasses of Error
+   * Solely for optimization; return a Collection&lt;TypeReference&gt; representing the subclasses of Error
    * 
    * kind of ugly. a better scheme?
    */
@@ -1028,8 +1074,7 @@ public class ClassHierarchy implements IClassHierarchy {
     if (subTypeRefsOfError == null) {
       computeSubClasses(TypeReference.JavaLangError);
       subTypeRefsOfError = HashSetFactory.make(subclassesOfError.size());
-      for (Iterator it = subclassesOfError.iterator(); it.hasNext();) {
-        IClass klass = (IClass) it.next();
+      for (IClass klass : subclassesOfError) {
         subTypeRefsOfError.add(klass.getReference());
       }
     }
@@ -1037,7 +1082,7 @@ public class ClassHierarchy implements IClassHierarchy {
   }
 
   /**
-   * Solely for optimization; return a Collection<TypeReference> representing the subclasses of RuntimeException
+   * Solely for optimization; return a Collection&lt;TypeReference&gt; representing the subclasses of RuntimeException
    * 
    * kind of ugly. a better scheme?
    */
@@ -1046,8 +1091,7 @@ public class ClassHierarchy implements IClassHierarchy {
     if (runtimeExceptionTypeRefs == null) {
       computeSubClasses(TypeReference.JavaLangRuntimeException);
       runtimeExceptionTypeRefs = HashSetFactory.make(runtimeExceptionClasses.size());
-      for (Iterator it = runtimeExceptionClasses.iterator(); it.hasNext();) {
-        IClass klass = (IClass) it.next();
+      for (IClass klass : runtimeExceptionClasses) {
         runtimeExceptionTypeRefs.add(klass.getReference());
       }
     }
@@ -1067,8 +1111,7 @@ public class ClassHierarchy implements IClassHierarchy {
     assert node != null : "null node for class " + T;
     HashSet<IClass> result = HashSetFactory.make(3);
     result.add(T);
-    for (Iterator<Node> it = node.getChildren(); it.hasNext();) {
-      Node child = it.next();
+    for (Node child : Iterator2Iterable.make(node.getChildren())) {
       result.addAll(computeSubClasses(child.klass.getReference()));
     }
     return result;
@@ -1099,13 +1142,8 @@ public class ClassHierarchy implements IClassHierarchy {
 
   @Override
   public Iterator<IClass> iterator() {
-    Function<Node, IClass> toClass = new Function<Node, IClass>() {
-      @Override
-      public IClass apply(Node n) {
-        return n.klass;
-      }
-    };
-    return new MapIterator<Node, IClass>(map.values().iterator(), toClass);
+    Function<Node, IClass> toClass = n -> n.klass;
+    return new MapIterator<>(map.values().iterator(), toClass);
   }
 
   /**
@@ -1123,9 +1161,9 @@ public class ClassHierarchy implements IClassHierarchy {
 
   @Override
   public IClassLoader getLoader(ClassLoaderReference loaderRef) {
-    for (int i = 0; i < loaders.length; i++) {
-      if (loaders[i].getReference().equals(loaderRef)) {
-        return loaders[i];
+    for (IClassLoader loader : loaders) {
+      if (loader.getReference().equals(loaderRef)) {
+        return loader;
       }
     }
     Assertions.UNREACHABLE();
@@ -1152,7 +1190,6 @@ public class ClassHierarchy implements IClassHierarchy {
   }
 
   /**
-   * @param klass
    * @return the classes that immediately extend klass. if klass is an array class A[][]...[], we return array classes B[][]...[]
    *         (same dimensionality) where B is an immediate subclass of A. If A is primitive, we return the empty set.
    */
@@ -1161,13 +1198,8 @@ public class ClassHierarchy implements IClassHierarchy {
     if (klass.isArrayClass()) {
       return getImmediateArraySubclasses((ArrayClass)klass);
     }
-    Function<Node, IClass> node2Class = new Function<Node, IClass>() {
-      @Override
-      public IClass apply(Node n) {
-        return n.klass;
-      }
-    };
-    return Iterator2Collection.toSet(new MapIterator<Node, IClass>(findNode(klass).children.iterator(), node2Class));
+    Function<Node, IClass> node2Class = n -> n.klass;
+    return Iterator2Collection.toSet(new MapIterator<>(findNode(klass).children.iterator(), node2Class));
   }
 
   private Collection<IClass> getImmediateArraySubclasses(ArrayClass klass) {
@@ -1199,66 +1231,6 @@ public class ClassHierarchy implements IClassHierarchy {
     return result.isPrimitiveType() ? null : lookupClass(result);
   }
 
-  /**
-   * @return a ClassHierarchy object representing the analysis scope
-   * @throws ClassHierarchyException
-   */
-  public static ClassHierarchy make(AnalysisScope scope) throws ClassHierarchyException {
-    if (scope == null) {
-      throw new IllegalArgumentException("null scope");
-    }
-    return make(scope, new ClassLoaderFactoryImpl(scope.getExclusions()));
-  }
-
-  /**
-   * temporarily marking this internal to avoid infinite sleep with randomly chosen IProgressMonitor.
-   */
-  public static ClassHierarchy make(AnalysisScope scope, IProgressMonitor monitor) throws ClassHierarchyException {
-    if (scope == null) {
-      throw new IllegalArgumentException("null scope");
-    }
-    return make(scope, new ClassLoaderFactoryImpl(scope.getExclusions()), monitor);
-  }
-
-  public static ClassHierarchy make(AnalysisScope scope, ClassLoaderFactory factory) throws ClassHierarchyException {
-    if (scope == null) {
-      throw new IllegalArgumentException("null scope");
-    }
-    if (factory == null) {
-      throw new IllegalArgumentException("null factory");
-    }
-    return new ClassHierarchy(scope, factory, null);
-  }
-
-  /**
-   * temporarily marking this internal to avoid infinite sleep with randomly chosen IProgressMonitor.
-   */
-  public static ClassHierarchy make(AnalysisScope scope, ClassLoaderFactory factory, IProgressMonitor monitor)
-      throws ClassHierarchyException {
-    return new ClassHierarchy(scope, factory, monitor);
-  }
-
-  public static ClassHierarchy make(AnalysisScope scope, ClassLoaderFactory factory, Set<Language> languages)
-      throws ClassHierarchyException {
-    return new ClassHierarchy(scope, factory, languages, null);
-  }
-
-  public static ClassHierarchy make(AnalysisScope scope, ClassLoaderFactory factory, Language language)
-      throws ClassHierarchyException {
-    return new ClassHierarchy(scope, factory, language, null);
-  }
-
-  /**
-   * temporarily marking this internal to avoid infinite sleep with randomly chosen IProgressMonitor. TODO: nanny for testgen
-   */
-  public static ClassHierarchy make(AnalysisScope scope, ClassLoaderFactory factory, Language language, IProgressMonitor monitor)
-      throws ClassHierarchyException {
-    if (factory == null) {
-      throw new IllegalArgumentException("null factory");
-    }
-    return new ClassHierarchy(scope, factory, language, monitor);
-  }
-
   @Override
   public IClass getRootClass() {
     return root.getJavaClass();
@@ -1294,7 +1266,7 @@ public class ClassHierarchy implements IClassHierarchy {
 
     @Override
     public String getMsg() {
-      return getClass().toString() + " : " + klass + " " + message;
+      return getClass().toString() + " : " + klass + ' ' + message;
     }
 
     public static ClassExclusion create(TypeReference klass, String message) {
@@ -1338,4 +1310,8 @@ public class ClassHierarchy implements IClassHierarchy {
   }
 
 /** END Custom change: remember unresolved classes */
+
+  public MissingSuperClassHandling getSuperClassHandling() {
+    return superClassHandling;
+  }
 }
