@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.cha;
 
 import com.ibm.wala.classLoader.IClassLoader;
@@ -25,10 +25,10 @@ public class ClassHierarchyStats {
       throw new IllegalArgumentException("cha cannot be null");
     }
     IClassLoader[] loaders = cha.getLoaders();
-    for (int i = 0; i < loaders.length; i++) {
-      System.out.println("loader: " + loaders[i]);
-      System.out.println("  classes: " + loaders[i].getNumberOfClasses());
-      System.out.println("  methods: " + loaders[i].getNumberOfMethods());
+    for (IClassLoader loader : loaders) {
+      System.out.println("loader: " + loader);
+      System.out.println("  classes: " + loader.getNumberOfClasses());
+      System.out.println("  methods: " + loader.getNumberOfMethods());
     }
   }
 }
