@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,12 +7,13 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.slicer;
 
 import java.util.Iterator;
 
 import com.ibm.wala.ipa.callgraph.CGNode;
+import com.ibm.wala.ipa.callgraph.propagation.InstanceKey;
 import com.ibm.wala.ipa.cha.IClassHierarchyDweller;
 import com.ibm.wala.ipa.slicer.Slicer.ControlDependenceOptions;
 import com.ibm.wala.util.graph.NumberedGraph;
@@ -31,7 +32,7 @@ public interface ISDG extends NumberedGraph<Statement>, IClassHierarchyDweller {
   /**
    * Get the program dependence graph constructed for a particular node.
    */
-  PDG getPDG(CGNode node);
+  PDG<? extends InstanceKey> getPDG(CGNode node);
 
   /**
    * Iterate over the nodes which have been discovered so far, but do <em>NOT</em> eagerly construct the entire graph.
