@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.slicer;
 
 import com.ibm.wala.ipa.callgraph.CGNode;
@@ -28,19 +28,19 @@ public class NormalStatement extends StatementWithInstructionIndex {
 
   @Override
   public String toString() {
-    String name = "";
+    StringBuilder name = new StringBuilder();
     if (getInstruction().hasDef()) {
       String[] names = getNode().getIR().getLocalNames(getInstructionIndex(), getInstruction().getDef());
       if (names != null && names.length > 0) {
-        name = "[" + names[0];
+        name = new StringBuilder("[").append(names[0]);
         for (int i = 1; i < names.length; i++) {
-          name = name + ", " + names[i];
+          name.append(", ").append(names[i]);
         }
-        name = name + "]: ";
+        name.append("]: ");
       }
     }
 
-    return "NORMAL " + getNode().getMethod().getName() + ":" + name + getInstruction().toString() + " " + getNode();
+    return "NORMAL " + getNode().getMethod().getName() + ':' + name + getInstruction().toString() + ' ' + getNode();
   }
 
 }
