@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.slicer;
 
 import com.ibm.wala.ipa.callgraph.CGNode;
@@ -49,7 +49,7 @@ public class PhiStatement extends Statement {
 
   @Override
   public String toString() {
-    return "PHI " + getNode() + ":" + phi;
+    return "PHI " + getNode() + ':' + phi;
   }
 
   public SSAPhiInstruction getPhi() {
