@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2014 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 
 /*
  *  Copyright (c) 2013,
@@ -42,19 +42,18 @@
  */
 package com.ibm.wala.ipa.summaries;
 
-import com.ibm.wala.ipa.summaries.MethodSummary;
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+
+import com.ibm.wala.ssa.ConstantValue;
 import com.ibm.wala.ssa.SSAGotoInstruction;
 import com.ibm.wala.ssa.SSAInstruction;
 import com.ibm.wala.ssa.SSAInstructionFactory;
 import com.ibm.wala.ssa.SymbolTable;
-import com.ibm.wala.ssa.ConstantValue;
 import com.ibm.wala.types.MemberReference;
 import com.ibm.wala.types.TypeReference;
-
-import java.util.List;
-import java.util.ArrayList;
-import java.util.Map;
-import java.util.HashMap;
 import com.ibm.wala.util.strings.Atom;
 
 /**
@@ -71,15 +70,14 @@ import com.ibm.wala.util.strings.Atom;
  *
  *  It extends the MethodSummarys capabilities by the functions:
  *  * {@link #getStatementAt(int)}
- *  * {@link #getStatementsAfter(int)}
  *  * {@link #reserveProgramCounters(int)}
  *  * {@link #allowReserved(boolean)}
  *
- *  @see com.ibm.wala.dalvik.ssa.AndroidModelInstructionFectory
- *  @see com.ibm.wala.dalvik.ipa.callgraph.impl.DexFakeRootMethod
+ *  @see com.ibm.wala.ssa.SSAInstructionFactory
+ *  @see com.ibm.wala.ipa.callgraph.impl.FakeRootMethod
  *  @see com.ibm.wala.ipa.summaries.MethodSummary
  *
- *  @author     Tobias Blaschke <code@tobiasblaschke.de>
+ *  @author     Tobias Blaschke &lt;code@tobiasblaschke.de&gt;
  *  @since      2013-09-08
  */
 public class VolatileMethodSummary {
@@ -87,8 +85,8 @@ public class VolatileMethodSummary {
     private static final boolean DEBUG = false;
     private boolean allowReservedPC = false;
     private MethodSummary summary;
-    private List<SSAInstruction> instructions = new ArrayList<SSAInstruction>();
-    private Map<Integer, Atom> localNames = new HashMap<Integer, Atom>();
+    private List<SSAInstruction> instructions = new ArrayList<>();
+    private Map<Integer, Atom> localNames = new HashMap<>();
     private int currentProgramCounter = 0;
     private boolean locked = false;
 
@@ -97,12 +95,17 @@ public class VolatileMethodSummary {
      */
     private static final class Reserved extends SSAInstruction {
         public Reserved () { super(SSAInstruction.NO_INDEX); }
+        @Override
         public SSAInstruction copyForSSA (SSAInstructionFactory insts, int[] defs, int[] uses) {
             throw new IllegalStateException();
         }
+        @Override
         public int hashCode () { return 12384; }
+        @Override
         public boolean isFallThrough() { return true; }
+        @Override
         public String toString (SymbolTable symbolTable) { return "Reserved Slot"; }
+        @Override
         public void visit (IVisitor v) { throw new IllegalStateException(); }
     }
     private static final Reserved RESERVED = new Reserved();
@@ -216,12 +219,12 @@ public class VolatileMethodSummary {
     }
 
     /**
-     *  Not exactly dual to {@link #isFree(boolean)}.
+     *  Not exactly dual to {@link #isFree(int)}.
      *
      *  Returns whether an instruction is located at ProgramCounter. Thus it is a  shortcut
      *  to {@link #getStatementAt(int)} != null.
      *  <p>
-     *  It is not the exact dual to {@link #isFree(boolean)} as it does not consider reserved
+     *  It is not the exact dual to {@link #isFree(int)} as it does not consider reserved
      *  ProgramCounters.
      *
      *  @param programCounter   the ProgramCounter in question
@@ -240,7 +243,7 @@ public class VolatileMethodSummary {
     }
 
     /**
-     *  Like {@link addStatement(SSAInstructionWithPC <? extends SSAInstruction>) but may replace an existing one.
+     *  Like {@link #addStatement(SSAInstruction)} but may replace an existing one.
      *
      *  @param  statement    The statement to add without care of overwriting
      *  @return true if a statement has actually been overwritten 
@@ -269,7 +272,7 @@ public class VolatileMethodSummary {
 
         boolean didOverwrite = isUsed(statement.iindex);
         while (this.instructions.size() - 1 < statement.iindex) this.instructions.add(null);
-        if (DEBUG) { System.err.printf("Setting {} to {}", statement.iindex, statement); }
+        if (DEBUG) { System.err.printf("Setting %s to %s\n", statement.iindex, statement); }
         this.instructions.set(statement.iindex, statement);
         return didOverwrite;
     }
@@ -293,13 +296,13 @@ public class VolatileMethodSummary {
         for (int i = 0; i < this.instructions.size(); ++i) {
             final SSAInstruction inst = this.instructions.get(i);
             if (inst == null) {
-              if (DEBUG) { System.err.printf("No instruction at iindex {}", i); }
+              if (DEBUG) { System.err.printf("No instruction at iindex %d\n", i); }
               this.summary.addStatement(null);
             } else if (inst == RESERVED) {
               // replace reserved slots by 'goto next' statements
               this.summary.addStatement(new SSAGotoInstruction(i, i+1));
             } else {
-              if (DEBUG) { System.err.printf("Adding @{}: ", inst); }
+              if (DEBUG) { System.err.printf("Adding @%s: ", inst); }
               this.summary.addStatement(inst);
             }
         }
@@ -338,7 +341,7 @@ public class VolatileMethodSummary {
      *  @throws NullPointerException if statement is null
      *  @throws IllegalArgumentException if the statement has set an invalid ProgramCounter or
      *      if there is already a statement at the statements iindex. In this case you can use 
-     *      {@link #overwritetatement(SSAInstruction)}.
+     *      {@link #overwriteStatement(SSAInstruction)}.
      */
     public void addStatement(SSAInstruction statement) {
         if (isUsed(statement.iindex)) {
@@ -403,7 +406,7 @@ public class VolatileMethodSummary {
     /**
     *   Retrieves a mapping from SSA-Number to a constant.
     *
-    *   You can add Constants using the function {@link addConstant(java.lang.Integer, ConstantValue)}.
+    *   You can add Constants using the function {@link #addConstant(java.lang.Integer, ConstantValue)}.
     *   A call to this function gets passed directly to the internal MethodSummary.
     *
     *   @return a mapping from SSA-Number to assigned ConstantValue
@@ -429,7 +432,7 @@ public class VolatileMethodSummary {
     /**
      *  Gets you a non-reserved ProgramCounter you can write to.
      *
-     *  This function returns the next ProgramCounter for which not({@link #isUsed(ProgramCounter)})
+     *  This function returns the next ProgramCounter for which not({@link #isUsed(int)})
      *  holds. Thus it will _not_ give you a ProgramCounter which is reserved even if you enabled
      *  writing to reserved ProgramCounters using {@link #allowReserved(boolean)}! You'll have to
      *  keep track of them on your own.
@@ -570,7 +573,7 @@ public class VolatileMethodSummary {
     }
 
     /**
-     *  Set the value returned by {@link #getFactory()}
+     *  Set the value returned by {@link #isFactory()}
      *
      *  @throws IllegalStateException if summary was locked
      */
@@ -594,7 +597,7 @@ public class VolatileMethodSummary {
     }
 
     /**
-     *  Set the value returned by {@link #getStatic()}
+     *  Set the value returned by {@link #isStatic()}
      *
      *  @throws IllegalStateException if summary was locked
      */
@@ -608,6 +611,7 @@ public class VolatileMethodSummary {
     /**
      *  Generates a String-Representation of an instance of the class.
      */
+    @Override
     public java.lang.String toString() {
         return "VolatileMethodSummary of " + this.summary.toString();
     }
