@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ipa.summaries;
 
 import static com.ibm.wala.types.TypeName.ArrayMask;
@@ -20,8 +20,10 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
+import java.util.StringTokenizer;
 
 import javax.xml.parsers.ParserConfigurationException;
+import javax.xml.parsers.SAXParser;
 import javax.xml.parsers.SAXParserFactory;
 
 import org.xml.sax.Attributes;
@@ -61,7 +63,7 @@ import com.ibm.wala.util.warnings.Warning;
  * This class reads method summaries from an XML Stream.
  */
 public class XMLMethodSummaryReader implements BytecodeConstants {
-
+  
   static final boolean DEBUG = false;
 
   /**
@@ -121,22 +123,22 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
 
   private final static Map<String, Integer> elementMap = HashMapFactory.make(14);
   static {
-    elementMap.put("classloader", new Integer(E_CLASSLOADER));
-    elementMap.put("method", new Integer(E_METHOD));
-    elementMap.put("class", new Integer(E_CLASS));
-    elementMap.put("package", new Integer(E_PACKAGE));
-    elementMap.put("call", new Integer(E_CALL));
-    elementMap.put("new", new Integer(E_NEW));
-    elementMap.put("poison", new Integer(E_POISON));
-    elementMap.put("summary-spec", new Integer(E_SUMMARY_SPEC));
-    elementMap.put("return", new Integer(E_RETURN));
-    elementMap.put("putstatic", new Integer(E_PUTSTATIC));
-    elementMap.put("aastore", new Integer(E_AASTORE));
-    elementMap.put("putfield", new Integer(E_PUTFIELD));
-    elementMap.put("getfield", new Integer(E_GETFIELD));
-    elementMap.put("throw", new Integer(E_ATHROW));
-    elementMap.put("constant", new Integer(E_CONSTANT));
-    elementMap.put("aaload", new Integer(E_AALOAD));
+    elementMap.put("classloader", Integer.valueOf(E_CLASSLOADER));
+    elementMap.put("method", Integer.valueOf(E_METHOD));
+    elementMap.put("class", Integer.valueOf(E_CLASS));
+    elementMap.put("package", Integer.valueOf(E_PACKAGE));
+    elementMap.put("call", Integer.valueOf(E_CALL));
+    elementMap.put("new", Integer.valueOf(E_NEW));
+    elementMap.put("poison", Integer.valueOf(E_POISON));
+    elementMap.put("summary-spec", Integer.valueOf(E_SUMMARY_SPEC));
+    elementMap.put("return", Integer.valueOf(E_RETURN));
+    elementMap.put("putstatic", Integer.valueOf(E_PUTSTATIC));
+    elementMap.put("aastore", Integer.valueOf(E_AASTORE));
+    elementMap.put("putfield", Integer.valueOf(E_PUTFIELD));
+    elementMap.put("getfield", Integer.valueOf(E_GETFIELD));
+    elementMap.put("throw", Integer.valueOf(E_ATHROW));
+    elementMap.put("constant", Integer.valueOf(E_CONSTANT));
+    elementMap.put("aaload", Integer.valueOf(E_AALOAD));
   }
 
   //
@@ -182,10 +184,12 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
 
   private final static String A_NUM_ARGS = "numArgs";
 
+  private final static String A_PARAM_NAMES = "paramNames";
+
   private final static String V_NULL = "null";
 
   private final static String V_TRUE = "true";
-
+  
   public XMLMethodSummaryReader(InputStream xmlFile, AnalysisScope scope) {
     super();
     if (xmlFile == null) {
@@ -198,8 +202,7 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
     try {
       readXML(xmlFile);
     } catch (Exception e) {
-      e.printStackTrace();
-      Assertions.UNREACHABLE();
+      throw new Error("bad xml file", e);
     }
   }
 
@@ -208,11 +211,12 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
 
     assert xml != null : "Null xml stream";
     SAXParserFactory factory = SAXParserFactory.newInstance();
-    factory.newSAXParser().parse(new InputSource(xml), handler);
+    SAXParser parser = factory.newSAXParser();
+    parser.parse(new InputSource(xml), handler);
   }
 
   /**
-   * @return Method summaries collected for methods. Mapping Object -> MethodSummary where Object is either a
+   * @return Method summaries collected for methods. Mapping Object -&gt; MethodSummary where Object is either a
    *         <ul>
    *         <li>MethodReference
    *         <li>TypeReference
@@ -269,7 +273,7 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
     private int nextLocal = -1;
 
     /**
-     * A mapping from String (variable name) -> Integer (local number)
+     * A mapping from String (variable name) -&gt; Integer (local number)
      */
     private Map<String, Integer> symbolTable = null;
 
@@ -353,7 +357,7 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
     }
 
     private void startClass(String cname, Attributes atts) {
-      String clName = "L" + governingPackage + "/" + cname;
+      String clName = governingPackage==null? 'L' + cname: "L" + governingPackage + '/' + cname;
       governingClass = className2Ref(clName);
       String allocString = atts.getValue(A_ALLOCATABLE);
       if (allocString != null) {
@@ -409,16 +413,14 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
 
     /**
      * If a method is declared to return a value, be sure the method summary includes a return statement. Throw an assertion if not.
-     * 
-     * @param governingMethod
      */
     private void checkReturnValue(MethodSummary governingMethod) {
       Assertions.productionAssertion(governingMethod != null);
       Assertions.productionAssertion(governingMethod.getReturnType() != null);
       if (governingMethod.getReturnType().isReferenceType()) {
         SSAInstruction[] statements = governingMethod.getStatements();
-        for (int i = 0; i < statements.length; i++) {
-          if (statements[i] instanceof SSAReturnInstruction) {
+        for (SSAInstruction statement : statements) {
+          if (statement instanceof SSAReturnInstruction) {
             return;
           }
         }
@@ -429,8 +431,6 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
 
     /**
      * Process an element indicating a call instruction
-     * 
-     * @param atts
      */
     private void processCallSite(Attributes atts) {
       String typeString = atts.getValue(A_TYPE);
@@ -445,28 +445,44 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
       MethodReference ref = MethodReference.findOrCreate(type, nm, D);
       CallSiteReference site = null;
       int nParams = ref.getNumberOfParameters();
-      if (typeString.equals("virtual")) {
-        site = CallSiteReference.make(governingMethod.getNextProgramCounter(), ref, IInvokeInstruction.Dispatch.VIRTUAL);
-        nParams++;
-      } else if (typeString.equals("special")) {
-        site = CallSiteReference.make(governingMethod.getNextProgramCounter(), ref, IInvokeInstruction.Dispatch.SPECIAL);
-        nParams++;
-      } else if (typeString.equals("interface")) {
-        site = CallSiteReference.make(governingMethod.getNextProgramCounter(), ref, IInvokeInstruction.Dispatch.INTERFACE);
-        nParams++;
-      } else if (typeString.equals("static")) {
-        site = CallSiteReference.make(governingMethod.getNextProgramCounter(), ref, IInvokeInstruction.Dispatch.STATIC);
-      } else {
-        Assertions.UNREACHABLE("Invalid call type " + typeString);
+      switch (typeString) {
+        case "virtual":
+          site = CallSiteReference.make(governingMethod.getNextProgramCounter(), ref, IInvokeInstruction.Dispatch.VIRTUAL);
+          nParams++;
+          break;
+        case "special":
+          site = CallSiteReference.make(governingMethod.getNextProgramCounter(), ref, IInvokeInstruction.Dispatch.SPECIAL);
+          nParams++;
+          break;
+        case "interface":
+          site = CallSiteReference.make(governingMethod.getNextProgramCounter(), ref, IInvokeInstruction.Dispatch.INTERFACE);
+          nParams++;
+          break;
+        case "static":
+          site = CallSiteReference.make(governingMethod.getNextProgramCounter(), ref, IInvokeInstruction.Dispatch.STATIC);
+          break;
+        default:
+          Assertions.UNREACHABLE("Invalid call type " + typeString);
+          break;
       }
+
+      String paramCount = atts.getValue(A_NUM_ARGS);
+      if (paramCount != null) {
+        nParams = Integer.parseInt(paramCount);
+      }
+      
       int[] params = new int[nParams];
 
       for (int i = 0; i < params.length; i++) {
         String argString = atts.getValue(A_ARG + i);
-        Assertions.productionAssertion(argString != null, "unspecified arg in method " + governingMethod + " " + site);
+        Assertions.productionAssertion(argString != null, "unspecified arg in method " + governingMethod + ' ' + site);
         Integer valueNumber = symbolTable.get(argString);
         if (valueNumber == null) {
-          Assertions.UNREACHABLE("Cannot lookup value: " + argString);
+          if (argString.equals(V_NULL)) {
+            valueNumber = getValueNumberForNull();
+          } else {
+            valueNumber = Integer.parseInt(argString);
+          }
         }
         params[i] = valueNumber.intValue();
       }
@@ -483,7 +499,7 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
         }
 
         int defNum = nextLocal;
-        symbolTable.put(defVar, new Integer(nextLocal++));
+        symbolTable.put(defVar, Integer.valueOf(nextLocal++));
 
         governingMethod.addStatement(insts.InvokeInstruction(governingMethod.getNumberOfStatements(), defNum, params, exceptionValue, site, null));
       } else {
@@ -494,8 +510,6 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
 
     /**
      * Process an element indicating a new allocation site.
-     * 
-     * @param atts
      */
     private void processAllocation(Attributes atts) {
       Language lang = scope.getLanguage(governingLoader.getLanguage());
@@ -516,7 +530,7 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
         defVar = "L" + nextLocal;
       }
       int defNum = nextLocal;
-      symbolTable.put(defVar, new Integer(nextLocal++));
+      symbolTable.put(defVar, Integer.valueOf(nextLocal++));
 
       // create the allocation statement and add it to the method summary
       NewSiteReference ref = NewSiteReference.make(governingMethod.getNextProgramCounter(), type);
@@ -541,8 +555,6 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
 
     /**
      * Process an element indicating an Athrow
-     * 
-     * @param atts
      */
     private void processAthrow(Attributes atts) {
       Language lang = scope.getLanguage(governingLoader.getLanguage());
@@ -564,8 +576,6 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
 
     /**
      * Process an element indicating a putfield.
-     * 
-     * @param atts
      */
     private void processGetField(Attributes atts) {
       Language lang = scope.getLanguage(governingLoader.getLanguage());
@@ -592,7 +602,7 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
         Assertions.UNREACHABLE("Must specify def for getfield " + governingMethod);
       }
       int defNum = nextLocal;
-      symbolTable.put(defVar, new Integer(nextLocal++));
+      symbolTable.put(defVar, Integer.valueOf(nextLocal++));
 
       // get the ref read from
       String R = atts.getValue(A_REF);
@@ -610,8 +620,6 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
 
     /**
      * Process an element indicating a putfield.
-     * 
-     * @param atts
      */
     private void processPutField(Attributes atts) {
       Language lang = scope.getLanguage(governingLoader.getLanguage());
@@ -634,10 +642,7 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
       if (V == null) {
         Assertions.UNREACHABLE("Must specify value for putfield " + governingMethod);
       }
-      Integer valueNumber = symbolTable.get(V);
-      if (valueNumber == null) {
-        Assertions.UNREACHABLE("Cannot lookup value: " + V);
-      }
+      Integer valueNumber = symbolTable.containsKey(V)? symbolTable.get(V): Integer.parseInt(V);
 
       // get the ref stored to
       String R = atts.getValue(A_REF);
@@ -655,8 +660,6 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
 
     /**
      * Process an element indicating a putstatic.
-     * 
-     * @param atts
      */
     private void processPutStatic(Attributes atts) {
       Language lang = scope.getLanguage(governingLoader.getLanguage());
@@ -689,8 +692,6 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
 
     /**
      * Process an element indicating an Aastore
-     * 
-     * @param atts
      */
     private void processAastore(Attributes atts) {
       Language lang = scope.getLanguage(governingLoader.getLanguage());
@@ -734,8 +735,6 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
 
     /**
      * Process an element indicating an Aaload
-     * 
-     * @param atts
      */
     private void processAaload(Attributes atts) {
       //<aaload def="foo" ref="arg1" index="the-answer" />
@@ -750,11 +749,14 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
       if (refNumber == null) {
         Assertions.UNREACHABLE("Cannot lookup value: " + R);
       }
-      // N.B: we currently ignore the index
       String I = atts.getValue(A_INDEX);
       if (I == null) {
         Assertions.UNREACHABLE("Must specify index for aaload " + governingMethod);
       }
+      Integer idxNumber = symbolTable.get(I);
+      if (idxNumber == null) {
+        Assertions.UNREACHABLE("Cannot lookup value: " + I);
+      }
       String strType = atts.getValue(A_TYPE);
       TypeReference type;
       if (strType == null) {
@@ -771,16 +773,13 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
         Assertions.UNREACHABLE("Must specify def for getfield " + governingMethod);
       }
       int defNum = nextLocal;
-      symbolTable.put(defVar, new Integer(nextLocal++));
-      SSAArrayLoadInstruction S = insts.ArrayLoadInstruction(governingMethod.getNumberOfStatements(), defNum, refNumber.intValue(), 0,
-          type);
+      symbolTable.put(defVar, Integer.valueOf(nextLocal++));
+      SSAArrayLoadInstruction S = insts.ArrayLoadInstruction(governingMethod.getNumberOfStatements(), defNum, refNumber, idxNumber, type);
       governingMethod.addStatement(S);
     }
 
     /**
      * Process an element indicating a return statement.
-     * 
-     * @param atts
      */
     private void processReturn(Attributes atts) {
       Language lang = scope.getLanguage(governingLoader.getLanguage());
@@ -797,11 +796,7 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
             if (!retV.equals(V_NULL)) {
               Assertions.UNREACHABLE("Cannot return value with no def: " + retV);
             } else {
-              valueNumber = symbolTable.get(V_NULL);
-              if (valueNumber == null) {
-                valueNumber = new Integer(nextLocal++);
-                symbolTable.put(V_NULL, valueNumber);
-              }
+              valueNumber = getValueNumberForNull();
             }
           }
           boolean isPrimitive = governingMethod.getReturnType().isPrimitiveType();
@@ -811,50 +806,58 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
       }
     }
 
-    /**
-     * @param atts
-     */
+    private Integer getValueNumberForNull() {
+      Integer valueNumber;
+      valueNumber = symbolTable.get(V_NULL);
+      if (valueNumber == null) {
+        valueNumber = Integer.valueOf(nextLocal++);
+        symbolTable.put(V_NULL, valueNumber);
+      }
+      return valueNumber;
+    }
+
     private void processConstant(Attributes atts) {
       String var = atts.getValue(A_NAME);
       if (var == null)
         Assertions.UNREACHABLE("Must give name for constant");
-      Integer valueNumber = new Integer(nextLocal++);
+      Integer valueNumber = Integer.valueOf(nextLocal++);
       symbolTable.put(var, valueNumber);
 
       String typeString = atts.getValue(A_TYPE);
       String valueString = atts.getValue(A_VALUE);
 
-      governingMethod.addConstant(valueNumber, (typeString.equals("int")) ? new ConstantValue(new Integer(valueString))
-          : (typeString.equals("long")) ? new ConstantValue(new Long(valueString))
-              : (typeString.equals("short")) ? new ConstantValue(new Short(valueString))
-                  : (typeString.equals("float")) ? new ConstantValue(new Float(valueString))
-                      : (typeString.equals("double")) ? new ConstantValue(new Double(valueString)) : null);
+      governingMethod.addConstant(valueNumber, (typeString.equals("int")) ? new ConstantValue(Integer.valueOf(valueString))
+          : (typeString.equals("long")) ? new ConstantValue(Long.valueOf(valueString))
+              : (typeString.equals("short")) ? new ConstantValue(Short.valueOf(valueString))
+                  : (typeString.equals("float")) ? new ConstantValue(Float.valueOf(valueString))
+                      : (typeString.equals("double")) ? new ConstantValue(Double.valueOf(valueString)) : null);
     }
 
     /**
      * Process an element which indicates this method is "poison"
-     * 
-     * @param atts
      */
     private void processPoison(Attributes atts) {
       String reason = atts.getValue(A_REASON);
       governingMethod.addPoison(reason);
       String level = atts.getValue(A_LEVEL);
-      if (level.equals("severe")) {
-        governingMethod.setPoisonLevel(Warning.SEVERE);
-      } else if (level.equals("moderate")) {
-        governingMethod.setPoisonLevel(Warning.MODERATE);
-      } else if (level.equals("mild")) {
-        governingMethod.setPoisonLevel(Warning.MILD);
-      } else {
-        Assertions.UNREACHABLE("Unexpected level: " + level);
+      switch (level) {
+        case "severe":
+          governingMethod.setPoisonLevel(Warning.SEVERE);
+          break;
+        case "moderate":
+          governingMethod.setPoisonLevel(Warning.MODERATE);
+          break;
+        case "mild":
+          governingMethod.setPoisonLevel(Warning.MILD);
+          break;
+        default:
+          Assertions.UNREACHABLE("Unexpected level: " + level);
+          break;
       }
     }
 
     /**
      * Begin processing of a method. 1. Set the governing method. 2. Initialize the nextLocal variable
-     * 
-     * @param atts
      */
     private void startMethod(Attributes atts) {
 
@@ -876,25 +879,33 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
       boolean isStatic = false;
       String staticString = atts.getValue(A_STATIC);
       if (staticString != null) {
-        if (staticString.equals("true")) {
-          isStatic = true;
-          governingMethod.setStatic(true);
-        } else if (staticString.equals("false")) {
-          isStatic = false;
-          governingMethod.setStatic(false);
-        } else {
-          Assertions.UNREACHABLE("Invalid attribute value " + A_STATIC + ": " + staticString);
+        switch (staticString) {
+          case "true":
+            isStatic = true;
+            governingMethod.setStatic(true);
+            break;
+          case "false":
+            isStatic = false;
+            governingMethod.setStatic(false);
+            break;
+          default:
+            Assertions.UNREACHABLE("Invalid attribute value " + A_STATIC + ": " + staticString);
+            break;
         }
       }
 
       String factoryString = atts.getValue(A_FACTORY);
       if (factoryString != null) {
-        if (factoryString.equals("true")) {
-          governingMethod.setFactory(true);
-        } else if (factoryString.equals("false")) {
-          governingMethod.setFactory(false);
-        } else {
-          Assertions.UNREACHABLE("Invalid attribute value " + A_FACTORY + ": " + factoryString);
+        switch (factoryString) {
+          case "true":
+            governingMethod.setFactory(true);
+            break;
+          case "false":
+            governingMethod.setFactory(false);
+            break;
+          default:
+            Assertions.UNREACHABLE("Invalid attribute value " + A_FACTORY + ": " + factoryString);
+            break;
         }
       }
 
@@ -918,14 +929,31 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
       symbolTable = HashMapFactory.make(5);
       // create symbols for the parameters
       for (int i = 0; i < nParams; i++) {
-        symbolTable.put("arg" + i, new Integer(i + 1));
+        symbolTable.put("arg" + i, Integer.valueOf(i + 1));
       }
+      
+      int pn = 1;
+      String paramDescString = atts.getValue(A_PARAM_NAMES);
+      if (paramDescString != null) {
+        StringTokenizer paramNames = new StringTokenizer(paramDescString);
+        while (paramNames.hasMoreTokens()) {
+          symbolTable.put(paramNames.nextToken(), pn++);
+        }
+      }
+       
+      Map<Integer,Atom> nameTable = HashMapFactory.make();
+      for(Map.Entry<String, Integer> x : symbolTable.entrySet()) {
+        if (! x.getKey().startsWith("arg")) {
+          nameTable.put(x.getValue(), Atom.findOrCreateUnicodeAtom(x.getKey()));
+        }
+      }
+      
+      governingMethod.setValueNames(nameTable);
     }
 
     /**
      * Method classLoaderName2Ref.
      * 
-     * @param clName
      * @return ClassLoaderReference
      */
     private ClassLoaderReference classLoaderName2Ref(String clName) {
@@ -935,7 +963,6 @@ public class XMLMethodSummaryReader implements BytecodeConstants {
     /**
      * Method classLoaderName2Ref.
      * 
-     * @param clName
      * @return ClassLoaderReference
      */
     private TypeReference className2Ref(String clName) {
