@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ssa;
 
 
@@ -27,7 +27,7 @@ public abstract class ReflectiveMemberAccess extends SSAInstruction {
 
   @Override
   public String toString(SymbolTable symbolTable) {
-    return "fieldref " + getValueString(symbolTable, objectRef) + "." + getValueString(symbolTable, memberRef);
+    return "fieldref " + getValueString(symbolTable, objectRef) + '.' + getValueString(symbolTable, memberRef);
   }
 
   /*
@@ -60,4 +60,4 @@ public abstract class ReflectiveMemberAccess extends SSAInstruction {
     return true;
   }
 
-}
\ No newline at end of file
+}
