@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,11 +7,9 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ssa;
 
-import java.util.Iterator;
-
 import com.ibm.wala.analysis.stackMachine.AbstractIntStackMachine;
 import com.ibm.wala.cfg.IBasicBlock;
 import com.ibm.wala.cfg.ShrikeCFG;
@@ -61,6 +59,8 @@ import com.ibm.wala.util.graph.dominators.Dominators;
 import com.ibm.wala.util.intset.IntPair;
 import com.ibm.wala.util.shrike.ShrikeUtil;
 
+import java.util.Arrays;
+
 /**
  * This class constructs an SSA {@link IR} from a backing ShrikeBT instruction stream.
  * 
@@ -70,7 +70,7 @@ import com.ibm.wala.util.shrike.ShrikeUtil;
  */
 public class SSABuilder extends AbstractIntStackMachine {
 
-  public static SSABuilder make(IBytecodeMethod method, SSACFG cfg, ShrikeCFG scfg, SSAInstruction[] instructions,
+  public static SSABuilder make(IBytecodeMethod<?> method, SSACFG cfg, ShrikeCFG scfg, SSAInstruction[] instructions,
       SymbolTable symbolTable, boolean buildLocalMap, SSAPiNodePolicy piNodePolicy) throws IllegalArgumentException {
     if (scfg == null) {
       throw new IllegalArgumentException("scfg == null");
@@ -81,7 +81,7 @@ public class SSABuilder extends AbstractIntStackMachine {
   /**
    * A wrapper around the method being analyzed.
    */
-  final private IBytecodeMethod method;
+  final private IBytecodeMethod<?> method;
 
   /**
    * Governing symbol table
@@ -89,7 +89,7 @@ public class SSABuilder extends AbstractIntStackMachine {
   final private SymbolTable symbolTable;
 
   /**
-   * A logical mapping from <bcIndex, valueNumber> -> local number if null, don't build it.
+   * A logical mapping from &lt;bcIndex, valueNumber&gt; -&gt; local number if null, don't build it.
    */
   private final SSA2LocalMap localMap;
 
@@ -105,7 +105,7 @@ public class SSABuilder extends AbstractIntStackMachine {
   
   private final ShrikeIndirectionData ssaIndirections;
   
-  private SSABuilder(IBytecodeMethod method, SSACFG cfg, ShrikeCFG scfg, SSAInstruction[] instructions, SymbolTable symbolTable,
+  private SSABuilder(IBytecodeMethod<?> method, SSACFG cfg, ShrikeCFG scfg, SSAInstruction[] instructions, SymbolTable symbolTable,
       boolean buildLocalMap, SSAPiNodePolicy piNodePolicy) {
     super(scfg);
     localMap = buildLocalMap ? new SSA2LocalMap(scfg, instructions.length, cfg.getNumberOfNodes()) : null;
@@ -144,9 +144,9 @@ public class SSABuilder extends AbstractIntStackMachine {
       }
 
       if (allTheSame(rhs)) {
-        for (int i = 0; i < rhs.length; i++) {
-          if (rhs[i] != TOP) {
-            return rhs[i];
+        for (int rh : rhs) {
+          if (rh != TOP) {
+            return rh;
           }
         }
         // didn't find anything but TOP
@@ -172,15 +172,12 @@ public class SSABuilder extends AbstractIntStackMachine {
       }
     }
 
-    /**
-     * @see com.ibm.wala.analysis.stackMachine.AbstractIntStackMachine.Meeter#meetLocal(int, int[], BasicBlock)
-     */
     @Override
     public int meetLocal(int n, int[] rhs, BasicBlock bb) {
       if (allTheSame(rhs)) {
-        for (int i = 0; i < rhs.length; i++) {
-          if (rhs[i] != TOP) {
-            return rhs[i];
+        for (int rh : rhs) {
+          if (rh != TOP) {
+            return rh;
           }
         }
         // didn't find anything but TOP
@@ -212,8 +209,7 @@ public class SSABuilder extends AbstractIntStackMachine {
 
     /**
      * Are all rhs values all the same? Note, we consider TOP (-1) to be same as everything else.
-     * 
-     * @param rhs
+     *
      * @return boolean
      */
     private boolean allTheSame(int[] rhs) {
@@ -234,9 +230,6 @@ public class SSABuilder extends AbstractIntStackMachine {
       return true;
     }
 
-    /**
-     * @see com.ibm.wala.analysis.stackMachine.AbstractIntStackMachine.Meeter#meetStackAtCatchBlock(BasicBlock)
-     */
     @Override
     public int meetStackAtCatchBlock(BasicBlock bb) {
       int bbNumber = shrikeCFG.getNumber(bb);
@@ -331,9 +324,7 @@ public class SSABuilder extends AbstractIntStackMachine {
         instructions[getCurrentInstructionIndex()] = s;
         for (int i = 0; i < s.getNumberOfDefs(); i++) {
           if (creators.length < (s.getDef(i) + 1)) {
-            SSAInstruction[] arr = new SSAInstruction[2 * s.getDef(i)];
-            System.arraycopy(creators, 0, arr, 0, creators.length);
-            creators = arr;
+            creators = Arrays.copyOf(creators, 2 * s.getDef(i));
           }
 
           assert s.getDef(i) != -1 : "invalid def " + i + " for " + s;
@@ -550,6 +541,7 @@ public class SSABuilder extends AbstractIntStackMachine {
           int ref = workingState.pop();
           emitInstruction(insts.GetInstruction(getCurrentInstructionIndex(), result, ref, f));
         }
+        assert result != -1;
         workingState.push(result);
       }
 
@@ -781,8 +773,8 @@ public class SSABuilder extends AbstractIntStackMachine {
       }
 
       private void doIndirectReads(int[] locals) {
-        for(int i = 0; i < locals.length; i++) {
-          ssaIndirections.setUse(getCurrentInstructionIndex(), new ShrikeLocalName(locals[i]), workingState.getLocal(locals[i]));
+        for (int local : locals) {
+          ssaIndirections.setUse(getCurrentInstructionIndex(), new ShrikeLocalName(local), workingState.getLocal(local));
         }
       }
       
@@ -797,13 +789,13 @@ public class SSABuilder extends AbstractIntStackMachine {
       }
 
       private void doIndirectWrites(int[] locals, int rval) {
-        for(int i = 0; i < locals.length; i++) {
-          ShrikeLocalName name = new ShrikeLocalName(locals[i]);
+        for (int local : locals) {
+          ShrikeLocalName name = new ShrikeLocalName(local);
           int idx = getCurrentInstructionIndex();
           if (ssaIndirections.getDef(idx, name) == -1) {
             ssaIndirections.setDef(idx, name, rval==-1? symbolTable.newSymbol(): rval);
           }
-          workingState.setLocal(locals[i], ssaIndirections.getDef(idx, name));
+          workingState.setLocal(local, ssaIndirections.getDef(idx, name));
         }        
       }
       
@@ -818,10 +810,6 @@ public class SSABuilder extends AbstractIntStackMachine {
 
     }
 
-    /**
-     * @param piCause
-     * @param ref
-     */
     private void reuseOrCreatePi(SSAInstruction piCause, int ref) {
       int n = getCurrentInstructionIndex();
       SSACFG.BasicBlock bb = cfg.getBlockForInstruction(n);
@@ -863,9 +851,11 @@ public class SSABuilder extends AbstractIntStackMachine {
 
     private void maybeInsertPi(SSAConditionalBranchInstruction cond) {
       if (piNodePolicy != null) {
-        Pair<Integer, SSAInstruction> pi = piNodePolicy.getPi(cond, getDef(cond.getUse(0)), getDef(cond.getUse(1)), symbolTable);
-        if (pi != null) {
-          reuseOrCreatePi(pi.snd, pi.fst);
+        for (Pair<Integer, SSAInstruction> pi : piNodePolicy.getPis(cond, getDef(cond.getUse(0)), getDef(cond.getUse(1)),
+            symbolTable)) {
+          if (pi != null) {
+            reuseOrCreatePi(pi.snd, pi.fst);
+          }
         }
       }
     }
@@ -922,7 +912,7 @@ public class SSABuilder extends AbstractIntStackMachine {
   }
   
   /**
-   * A logical mapping from <pc, valueNumber> -> local number Note: make sure this class remains static: this persists as part of
+   * A logical mapping from &lt;pc, valueNumber&gt; -&gt; local number Note: make sure this class remains static: this persists as part of
    * the IR!!
    */
   private static class SSA2LocalMap implements com.ibm.wala.ssa.IR.SSA2LocalMap {
@@ -930,7 +920,7 @@ public class SSABuilder extends AbstractIntStackMachine {
     private final ShrikeCFG shrikeCFG;
 
     /**
-     * Mapping Integer -> IntPair where p maps to (vn,L) iff we've started a range at pc p where value number vn corresponds to
+     * Mapping Integer -&gt; IntPair where p maps to (vn,L) iff we've started a range at pc p where value number vn corresponds to
      * local L
      */
     private final IntPair[] localStoreMap;
@@ -962,8 +952,7 @@ public class SSABuilder extends AbstractIntStackMachine {
      * Finish populating the map of local variable information
      */
     private void finishLocalMap(SSABuilder builder) {
-      for (Iterator it = shrikeCFG.iterator(); it.hasNext();) {
-        ShrikeCFG.BasicBlock bb = (ShrikeCFG.BasicBlock) it.next();
+      for (BasicBlock bb : shrikeCFG) {
         MachineState S = builder.getIn(bb);
         int number = bb.getNumber();
         block2LocalState[number] = S.getLocals();
@@ -984,7 +973,7 @@ public class SSABuilder extends AbstractIntStackMachine {
           if (localNumbers == null) {
             return null;
           } else {
-            IBytecodeMethod m = shrikeCFG.getMethod();
+            IBytecodeMethod<?> m = shrikeCFG.getMethod();
             String[] result = new String[localNumbers.length];
             for (int i = 0; i < localNumbers.length; i++) {
               result[i] = m.getLocalVariableName(m.getBytecodeIndex(index), localNumbers[i]);
@@ -1030,7 +1019,7 @@ public class SSABuilder extends AbstractIntStackMachine {
       if (vn < 0) {
         return null;
       }
-      IBasicBlock bb = shrikeCFG.getBlockForInstruction(pc);
+      IBasicBlock<?> bb = shrikeCFG.getBlockForInstruction(pc);
       int firstInstruction = bb.getFirstInstructionIndex();
       // walk forward from the first instruction to reconstruct the
       // state of the locals at this pc
@@ -1047,11 +1036,11 @@ public class SSABuilder extends AbstractIntStackMachine {
     /**
      * @return the indices i s.t. x[i] == y, or null if none found.
      */
-    private int[] extractIndices(int[] x, int y) {
+    private static int[] extractIndices(int[] x, int y) {
       assert x != null;
       int count = 0;
-      for (int i = 0; i < x.length; i++) {
-        if (x[i] == y) {
+      for (int element : x) {
+        if (element == y) {
           count++;
         }
       }
