@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,35 +7,39 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ssa;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.function.Function;
 
 import com.ibm.wala.cfg.AbstractCFG;
 import com.ibm.wala.cfg.BytecodeCFG;
 import com.ibm.wala.cfg.ControlFlowGraph;
 import com.ibm.wala.cfg.IBasicBlock;
 import com.ibm.wala.cfg.InducedCFG;
+import com.ibm.wala.cfg.MinimalCFG;
 import com.ibm.wala.classLoader.IClass;
 import com.ibm.wala.classLoader.IClassLoader;
 import com.ibm.wala.classLoader.IMethod;
 import com.ibm.wala.shrikeBT.ExceptionHandler;
 import com.ibm.wala.shrikeBT.IInstruction;
+import com.ibm.wala.types.ClassLoaderReference;
 import com.ibm.wala.types.TypeReference;
 import com.ibm.wala.util.collections.EmptyIterator;
 import com.ibm.wala.util.collections.HashMapFactory;
 import com.ibm.wala.util.collections.Iterator2Collection;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.collections.MapIterator;
 import com.ibm.wala.util.debug.Assertions;
 import com.ibm.wala.util.debug.UnimplementedError;
-import com.ibm.wala.util.functions.Function;
 import com.ibm.wala.util.graph.impl.NumberedNodeIterator;
 import com.ibm.wala.util.intset.BitVector;
 import com.ibm.wala.util.intset.IntSet;
@@ -55,7 +59,7 @@ import com.ibm.wala.util.warnings.Warnings;
  * As the current implementation stands, the delegate graph stores the graph structure, and this class additionally stores
  * {@link BasicBlock}s and the {@link SSAInstruction} array.
  */
-public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock> {
+public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>, MinimalCFG<ISSABasicBlock> {
 
   private static final boolean DEBUG = false;
 
@@ -96,7 +100,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
     }
     this.delegate = cfg;
     if (DEBUG) {
-      System.err.println(("Incoming CFG for " + method + ":"));
+      System.err.println(("Incoming CFG for " + method + ':'));
       System.err.println(cfg.toString());
     }
 
@@ -119,8 +123,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
    * SSABasicBlocks
    */
   private void addPisFromInducedCFG(InducedCFG cfg) {
-    for (Iterator<? extends InducedCFG.BasicBlock> it = cfg.iterator(); it.hasNext();) {
-      InducedCFG.BasicBlock ib = it.next();
+    for (com.ibm.wala.cfg.InducedCFG.BasicBlock ib : cfg) {
       // we rely on the invariant that basic blocks in this cfg are numbered identically as in the source
       // InducedCFG
       BasicBlock b = getBasicBlock(ib.getNumber());
@@ -136,8 +139,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
    * SSABasicBlocks
    */
   private void addPhisFromInducedCFG(InducedCFG cfg) {
-    for (Iterator<? extends InducedCFG.BasicBlock> it = cfg.iterator(); it.hasNext();) {
-      InducedCFG.BasicBlock ib = it.next();
+    for (com.ibm.wala.cfg.InducedCFG.BasicBlock ib : cfg) {
       // we rely on the invariant that basic blocks in this cfg are numbered identically as in the source
       // InducedCFG
       BasicBlock b = getBasicBlock(ib.getNumber());
@@ -163,12 +165,13 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
   }
 
   private void recordExceptionTypes(Set<ExceptionHandler> set, IClassLoader loader) {
-    for (Iterator<ExceptionHandler> it = set.iterator(); it.hasNext();) {
-      ExceptionHandler handler = it.next();
+    for (ExceptionHandler handler : set) {
       TypeReference t = null;
       if (handler.getCatchClass() == null) {
         // by convention, in ShrikeCT this means catch everything
         t = TypeReference.JavaLangThrowable;
+      } else if (handler.getCatchClassLoader() instanceof ClassLoaderReference) {
+        t = ShrikeUtil.makeTypeReference((ClassLoaderReference)handler.getCatchClassLoader(), handler.getCatchClass());
       } else {
         TypeReference exceptionType = ShrikeUtil.makeTypeReference(loader.getReference(), handler.getCatchClass());
         IClass klass = null;
@@ -181,16 +184,14 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
         }
       }
       int instructionIndex = handler.getHandler();
-      IBasicBlock b = getBlockForInstruction(instructionIndex);
-      if (!(b instanceof ExceptionHandlerBasicBlock)) {
-        assert b instanceof ExceptionHandlerBasicBlock : "not exception handler " + b + " index " + instructionIndex;
-      }
+      IBasicBlock<?> b = getBlockForInstruction(instructionIndex);
+      assert b instanceof ExceptionHandlerBasicBlock : "not exception handler " + b + " index " + instructionIndex;
       ExceptionHandlerBasicBlock bb = (ExceptionHandlerBasicBlock) getBlockForInstruction(instructionIndex);
       bb.addCaughtExceptionType(t);
     }
   }
 
-  private void createBasicBlocks(AbstractCFG G) {
+  private void createBasicBlocks(AbstractCFG<?, ?> G) {
     basicBlocks = new BasicBlock[G.getNumberOfNodes()];
     for (int i = 0; i <= G.getMaxNumber(); i++) {
       if (G.getCatchBlocks().get(i)) {
@@ -284,7 +285,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
      */
     @Override
     public int getFirstInstructionIndex() {
-      IBasicBlock B = delegate.getNode(number);
+      IBasicBlock<?> B = delegate.getNode(number);
       return B.getFirstInstructionIndex();
     }
 
@@ -298,7 +299,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
 
     @Override
     public int getLastInstructionIndex() {
-      IBasicBlock B = delegate.getNode(number);
+      IBasicBlock<?> B = delegate.getNode(number);
       return B.getLastInstructionIndex();
     }
 
@@ -312,7 +313,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
         if (localPhis == null) {
           return EmptyIterator.instance();
         } else {
-          LinkedList<SSAPhiInstruction> result = new LinkedList<SSAPhiInstruction>();
+          LinkedList<SSAPhiInstruction> result = new LinkedList<>();
           for (SSAPhiInstruction phi : localPhis) {
             if (phi != null) {
               result.add(phi);
@@ -322,7 +323,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
         }
       } else {
         // stackSlotPhis != null
-        LinkedList<SSAPhiInstruction> result = new LinkedList<SSAPhiInstruction>();
+        LinkedList<SSAPhiInstruction> result = new LinkedList<>();
         for (SSAPhiInstruction phi : stackSlotPhis) {
           if (phi != null) {
             result.add(phi);
@@ -376,9 +377,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
         stackSlotPhis = new SSAPhiInstruction[initialCapacity];
       }
       if (slot >= stackSlotPhis.length) {
-        SSAPhiInstruction[] temp = stackSlotPhis;
-        stackSlotPhis = new SSAPhiInstruction[slot * 2];
-        System.arraycopy(temp, 0, stackSlotPhis, 0, temp.length);
+        stackSlotPhis = Arrays.copyOf(stackSlotPhis, slot * 2);
       }
       stackSlotPhis[slot] = phi;
     }
@@ -388,9 +387,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
         localPhis = new SSAPhiInstruction[initialCapacity];
       }
       if (n >= localPhis.length) {
-        SSAPhiInstruction[] temp = localPhis;
-        localPhis = new SSAPhiInstruction[n * 2];
-        System.arraycopy(temp, 0, localPhis, 0, temp.length);
+        localPhis = Arrays.copyOf(localPhis, n * 2);
       }
       localPhis[n] = phi;
     }
@@ -416,9 +413,9 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
           SSAPhiInstruction[] old = stackSlotPhis;
           stackSlotPhis = new SSAPhiInstruction[newLength];
           int j = 0;
-          for (int i = 0; i < old.length; i++) {
-            if (old[i] != null) {
-              stackSlotPhis[j++] = old[i];
+          for (SSAPhiInstruction element : old) {
+            if (element != null) {
+              stackSlotPhis[j++] = element;
             }
           }
         }
@@ -440,9 +437,9 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
           SSAPhiInstruction[] old = localPhis;
           localPhis = new SSAPhiInstruction[newLength];
           int j = 0;
-          for (int i = 0; i < old.length; i++) {
-            if (old[i] != null) {
-              localPhis[j++] = old[i];
+          for (SSAPhiInstruction element : old) {
+            if (element != null) {
+              localPhis[j++] = element;
             }
           }
         }
@@ -453,13 +450,12 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
       return piInstructions.get(new RefPathKey(n, this, path));
     }
 
-    private final LinkedList<SSAPiInstruction> blockPiInstructions = new LinkedList<SSAPiInstruction>();
+    private final LinkedList<SSAPiInstruction> blockPiInstructions = new LinkedList<>();
 
     /**
      * 
      * @param n can be the val in the pi instruction
      * @param path can be the successor block in the pi instruction
-     * @param pi
      */
     public void addPiForRefAndPath(int n, Object path, SSAPiInstruction pi) {
       piInstructions.put(new RefPathKey(n, this, path), pi);
@@ -510,9 +506,9 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
     public List<SSAInstruction> getAllInstructions() {
       compressPhis();
 
-      ArrayList<SSAInstruction> result = new ArrayList<SSAInstruction>();
-      for (Iterator<? extends SSAInstruction> it = iteratePhis(); it.hasNext();) {
-        result.add(it.next());
+      ArrayList<SSAInstruction> result = new ArrayList<>();
+      for (SSAInstruction inst : Iterator2Iterable.make(iteratePhis())) {
+        result.add(inst);
       }
 
       for (int i = getFirstInstructionIndex(); i <= getLastInstructionIndex(); i++) {
@@ -522,8 +518,8 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
         }
       }
 
-      for (Iterator<? extends SSAInstruction> it = iteratePis(); it.hasNext();) {
-        result.add(it.next());
+      for (SSAInstruction inst : Iterator2Iterable.make(iteratePis())) {
+        result.add(inst);
       }
       return result;
     }
@@ -540,9 +536,9 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
           SSAPhiInstruction[] old = stackSlotPhis;
           stackSlotPhis = new SSAPhiInstruction[size];
           int j = 0;
-          for (int i = 0; i < old.length; i++) {
-            if (old[i] != null) {
-              stackSlotPhis[j++] = old[i];
+          for (SSAPhiInstruction element : old) {
+            if (element != null) {
+              stackSlotPhis[j++] = element;
             }
           }
         }
@@ -555,9 +551,9 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
           SSAPhiInstruction[] old = localPhis;
           localPhis = new SSAPhiInstruction[size];
           int j = 0;
-          for (int i = 0; i < old.length; i++) {
-            if (old[i] != null) {
-              localPhis[j++] = old[i];
+          for (SSAPhiInstruction element : old) {
+            if (element != null) {
+              localPhis[j++] = element;
             }
           }
         }
@@ -566,8 +562,8 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
 
     private int countNonNull(SSAPhiInstruction[] a) {
       int result = 0;
-      for (int i = 0; i < a.length; i++) {
-        if (a[i] != null) {
+      for (SSAPhiInstruction element : a) {
+        if (element != null) {
           result++;
         }
       }
@@ -602,12 +598,9 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
       // TODO Auto-generated method stub
     }
 
-    /**
-     * @see java.lang.Object#toString()
-     */
     @Override
     public String toString() {
-      return "BB[SSA:" + getFirstInstructionIndex() + ".." + getLastInstructionIndex() + "]" + getNumber() + " - "
+      return "BB[SSA:" + getFirstInstructionIndex() + ".." + getLastInstructionIndex() + ']' + getNumber() + " - "
           + method.getSignature();
     }
 
@@ -666,8 +659,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
 
     /**
      * The {@link ExceptionHandlerBasicBlock} subclass will override this.
-     * 
-     * @see com.ibm.wala.ssa.ISSABasicBlock#getCaughtExceptionTypes()
+     *
      */
     @Override
     public Iterator<TypeReference> getCaughtExceptionTypes() {
@@ -736,9 +728,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
       }
       nExceptionTypes++;
       if (nExceptionTypes > exceptionTypes.length) {
-        TypeReference[] temp = exceptionTypes;
-        exceptionTypes = new TypeReference[nExceptionTypes * 2];
-        System.arraycopy(temp, 0, exceptionTypes, 0, temp.length);
+        exceptionTypes = Arrays.copyOf(exceptionTypes, nExceptionTypes * 2);
       }
       exceptionTypes[nExceptionTypes - 1] = exceptionType;
     }
@@ -760,15 +750,15 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
 
   @Override
   public String toString() {
-    StringBuffer s = new StringBuffer("");
+    StringBuilder s = new StringBuilder();
     for (int i = 0; i <= getNumber(exit()); i++) {
       BasicBlock bb = getNode(i);
-      s.append("BB").append(i).append("[").append(bb.getFirstInstructionIndex()).append("..").append(bb.getLastInstructionIndex())
+      s.append("BB").append(i).append('[').append(bb.getFirstInstructionIndex()).append("..").append(bb.getLastInstructionIndex())
           .append("]\n");
 
-      Iterator succNodes = getSuccNodes(bb);
+      Iterator<ISSABasicBlock> succNodes = getSuccNodes(bb);
       while (succNodes.hasNext()) {
-        s.append("    -> BB").append(((BasicBlock) succNodes.next()).getNumber()).append("\n");
+        s.append("    -> BB").append(((BasicBlock) succNodes.next()).getNumber()).append('\n');
       }
     }
     return s.toString();
@@ -836,11 +826,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
    */
   @Override
   public Iterator<ISSABasicBlock> iterator() {
-    ArrayList<ISSABasicBlock> list = new ArrayList<ISSABasicBlock>();
-    for (BasicBlock b : basicBlocks) {
-      list.add(b);
-    }
-    return list.iterator();
+    return Arrays.<ISSABasicBlock>asList(basicBlocks).iterator();
   }
 
   /*
@@ -860,7 +846,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
       throw new IllegalArgumentException("b == null");
     }
     IBasicBlock<IInstruction> n = delegate.getNode(b.getNumber());
-    final Iterator i = delegate.getPredNodes(n);
+    final Iterator<IBasicBlock<IInstruction>> i = delegate.getPredNodes(n);
     return new Iterator<ISSABasicBlock>() {
       @Override
       public boolean hasNext() {
@@ -869,7 +855,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
 
       @Override
       public BasicBlock next() {
-        IBasicBlock n = (IBasicBlock) i.next();
+        IBasicBlock<?> n = i.next();
         int number = n.getNumber();
         return basicBlocks[number];
       }
@@ -902,7 +888,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
       throw new IllegalArgumentException("b == null");
     }
     IBasicBlock<IInstruction> n = delegate.getNode(b.getNumber());
-    final Iterator i = delegate.getSuccNodes(n);
+    final Iterator<IBasicBlock<IInstruction>> i = delegate.getSuccNodes(n);
     return new Iterator<ISSABasicBlock>() {
       @Override
       public boolean hasNext() {
@@ -911,7 +897,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
 
       @Override
       public ISSABasicBlock next() {
-        IBasicBlock n = (IBasicBlock) i.next();
+        IBasicBlock<?> n = i.next();
         int number = n.getNumber();
         return basicBlocks[number];
       }
@@ -1015,10 +1001,9 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
       throw new IllegalArgumentException("b is null");
     }
     final IBasicBlock<IInstruction> n = delegate.getNode(b.getNumber());
-    final Iterator<IBasicBlock<IInstruction>> i = delegate.getExceptionalSuccessors(n).iterator();
-    final List<ISSABasicBlock> c = new ArrayList<ISSABasicBlock>(getSuccNodeCount(b));
-    for (; i.hasNext();) {
-      final IBasicBlock<IInstruction> s = i.next();
+    final Collection<IBasicBlock<IInstruction>> ss = delegate.getExceptionalSuccessors(n);
+    final List<ISSABasicBlock> c = new ArrayList<>(getSuccNodeCount(b));
+    for (final IBasicBlock<IInstruction> s : ss) {
       c.add(basicBlocks[delegate.getNumber(s)]);
     }
     return c;
@@ -1033,13 +1018,8 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
       throw new IllegalArgumentException("b is null");
     }
     IBasicBlock<IInstruction> n = delegate.getNode(b.getNumber());
-    Function<IBasicBlock<IInstruction>, ISSABasicBlock> f = new Function<IBasicBlock<IInstruction>, ISSABasicBlock>() {
-      @Override
-      public ISSABasicBlock apply(IBasicBlock<IInstruction> object) {
-        return basicBlocks[delegate.getNumber(object)];
-      }
-    };
-    return Iterator2Collection.toSet(new MapIterator<IBasicBlock<IInstruction>, ISSABasicBlock>(delegate
+    Function<IBasicBlock<IInstruction>, ISSABasicBlock> f = object -> basicBlocks[delegate.getNumber(object)];
+    return Iterator2Collection.toSet(new MapIterator<>(delegate
         .getExceptionalPredecessors(n).iterator(), f));
   }
 
@@ -1048,7 +1028,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
   }
 
   /**
-   * has exceptional edge src -> dest
+   * has exceptional edge src -&gt; dest
    * 
    * @throws IllegalArgumentException if dest is null
    */
@@ -1064,7 +1044,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
   }
 
   /**
-   * has normal edge src -> dest
+   * has normal edge src -&gt; dest
    * 
    * @throws IllegalArgumentException if dest is null
    */
@@ -1088,10 +1068,9 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
       throw new IllegalArgumentException("b is null");
     }
     IBasicBlock<IInstruction> n = delegate.getNode(b.getNumber());
-    final Iterator<IBasicBlock<IInstruction>> i = delegate.getNormalSuccessors(n).iterator();
-    Collection<ISSABasicBlock> c = new ArrayList<ISSABasicBlock>(getSuccNodeCount(b));
-    for (; i.hasNext();) {
-      IBasicBlock<IInstruction> s = i.next();
+    final Collection<IBasicBlock<IInstruction>> ss = delegate.getNormalSuccessors(n);
+    Collection<ISSABasicBlock> c = new ArrayList<>(getSuccNodeCount(b));
+    for (IBasicBlock<IInstruction> s : ss) {
       c.add(basicBlocks[delegate.getNumber(s)]);
     }
     return c;
@@ -1106,10 +1085,9 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
       throw new IllegalArgumentException("b is null");
     }
     IBasicBlock<IInstruction> n = delegate.getNode(b.getNumber());
-    final Iterator<IBasicBlock<IInstruction>> i = delegate.getNormalPredecessors(n).iterator();
-    Collection<ISSABasicBlock> c = new ArrayList<ISSABasicBlock>(getPredNodeCount(b));
-    for (; i.hasNext();) {
-      IBasicBlock<IInstruction> s = i.next();
+    final Collection<IBasicBlock<IInstruction>> ss = delegate.getNormalPredecessors(n);
+    Collection<ISSABasicBlock> c = new ArrayList<>(getPredNodeCount(b));
+    for (IBasicBlock<IInstruction> s : ss) {
       c.add(basicBlocks[delegate.getNumber(s)]);
     }
     return c;
@@ -1120,7 +1098,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
    */
   @Override
   public Iterator<ISSABasicBlock> iterateNodes(IntSet s) {
-    return new NumberedNodeIterator<ISSABasicBlock>(s, this);
+    return new NumberedNodeIterator<>(s, this);
   }
 
   @Override
@@ -1170,7 +1148,7 @@ public class SSACFG implements ControlFlowGraph<SSAInstruction, ISSABasicBlock>
 
     @Override
     public String getMsg() {
-      return getClass().toString() + " : " + type + " " + method;
+      return getClass().toString() + " : " + type + ' ' + method;
     }
 
     public static ExceptionLoadFailure create(TypeReference type, IMethod method) {
