@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 
 package com.ibm.wala.ssa.analysis;
 
@@ -30,6 +30,7 @@ import com.ibm.wala.types.TypeReference;
 import com.ibm.wala.util.collections.EmptyIterator;
 import com.ibm.wala.util.collections.HashSetFactory;
 import com.ibm.wala.util.collections.Iterator2Collection;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.collections.NonNullSingletonIterator;
 import com.ibm.wala.util.collections.SimpleVector;
 import com.ibm.wala.util.debug.Assertions;
@@ -40,7 +41,7 @@ import com.ibm.wala.util.intset.MutableSparseIntSet;
 
 /**
  * A view of a control flow graph where each basic block corresponds to exactly one SSA instruction index.
- * 
+ *
  * Prototype: Not terribly efficient.
  */
 public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction, IExplodedBasicBlock> {
@@ -54,7 +55,7 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
   /**
    * The ith element of this vector is the basic block holding instruction i. this basic block has number i+1.
    */
-  private final SimpleVector<IExplodedBasicBlock> normalNodes = new SimpleVector<IExplodedBasicBlock>();
+  private final SimpleVector<IExplodedBasicBlock> normalNodes = new SimpleVector<>();
 
   private final Collection<IExplodedBasicBlock> allNodes = HashSetFactory.make();
 
@@ -127,7 +128,7 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
       return Collections.emptySet();
     }
     if (eb.isExitBlock() || eb.instructionIndex == eb.original.getFirstInstructionIndex()) {
-      List<IExplodedBasicBlock> result = new ArrayList<IExplodedBasicBlock>();
+      List<IExplodedBasicBlock> result = new ArrayList<>();
       for (ISSABasicBlock s : ir.getControlFlowGraph().getExceptionalPredecessors(eb.original)) {
         assert normalNodes.get(s.getLastInstructionIndex()) != null;
         result.add(normalNodes.get(s.getLastInstructionIndex()));
@@ -140,18 +141,18 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
 
   @Override
   public List<IExplodedBasicBlock> getExceptionalSuccessors(IExplodedBasicBlock bb) {
-    ExplodedBasicBlock eb = (ExplodedBasicBlock) bb;    
+    ExplodedBasicBlock eb = (ExplodedBasicBlock) bb;
     assert eb != null;
     if (eb.equals(exit)) {
       return Collections.emptyList();
     }
     if (eb.isEntryBlock() || eb.instructionIndex == eb.original.getLastInstructionIndex()) {
-      List<IExplodedBasicBlock> result = new ArrayList<IExplodedBasicBlock>();
+      List<IExplodedBasicBlock> result = new ArrayList<>();
       ISSABasicBlock orig = eb.original;
       if (eb.isEntryBlock() && orig == null) {
         orig = ir.getControlFlowGraph().entry();
       }
-      
+
       for (ISSABasicBlock s : ir.getControlFlowGraph().getExceptionalSuccessors(orig)) {
         if (s.equals(ir.getControlFlowGraph().exit())) {
           result.add(exit());
@@ -184,7 +185,7 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
       return Collections.emptySet();
     }
     if (eb.isExitBlock() || eb.instructionIndex == eb.original.getFirstInstructionIndex()) {
-      List<IExplodedBasicBlock> result = new ArrayList<IExplodedBasicBlock>();
+      List<IExplodedBasicBlock> result = new ArrayList<>();
       for (ISSABasicBlock s : ir.getControlFlowGraph().getNormalPredecessors(eb.original)) {
         if (s.equals(ir.getControlFlowGraph().entry())) {
           if (s.getLastInstructionIndex() >= 0) {
@@ -216,7 +217,7 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
       return Collections.singleton(normalNodes.get(0));
     }
     if (eb.instructionIndex == eb.original.getLastInstructionIndex()) {
-      List<IExplodedBasicBlock> result = new ArrayList<IExplodedBasicBlock>();
+      List<IExplodedBasicBlock> result = new ArrayList<>();
       for (ISSABasicBlock s : ir.getControlFlowGraph().getNormalSuccessors(eb.original)) {
         if (s.equals(ir.getControlFlowGraph().exit())) {
           result.add(exit());
@@ -277,7 +278,7 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
 
   @Override
   public int getPredNodeCount(IExplodedBasicBlock bb) throws IllegalArgumentException {
-    ExplodedBasicBlock eb = (ExplodedBasicBlock) bb;    
+    ExplodedBasicBlock eb = (ExplodedBasicBlock) bb;
     if (eb == null) {
       throw new IllegalArgumentException("eb == null");
     }
@@ -309,12 +310,11 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
     }
     ISSABasicBlock original = eb.isExitBlock() ? ir.getControlFlowGraph().exit() : eb.original;
     if (eb.isExitBlock() || eb.instructionIndex == eb.original.getFirstInstructionIndex()) {
-      List<IExplodedBasicBlock> result = new ArrayList<IExplodedBasicBlock>();
+      List<IExplodedBasicBlock> result = new ArrayList<>();
       if (eb.original != null && eb.original.isEntryBlock()) {
         result.add(entry);
       }
-      for (Iterator<ISSABasicBlock> it = ir.getControlFlowGraph().getPredNodes(original); it.hasNext();) {
-        ISSABasicBlock s = it.next();
+      for (ISSABasicBlock s : Iterator2Iterable.make(ir.getControlFlowGraph().getPredNodes(original))) {
         if (s.isEntryBlock()) {
           // it's possible for an entry block to have instructions; in this case, add
           // the exploded basic block for the last instruction in the entry block
@@ -355,9 +355,8 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
       return z == null ? EmptyIterator.<IExplodedBasicBlock> instance() : NonNullSingletonIterator.make(z);
     }
     if (eb.instructionIndex == eb.original.getLastInstructionIndex()) {
-      List<IExplodedBasicBlock> result = new ArrayList<IExplodedBasicBlock>();
-      for (Iterator<ISSABasicBlock> it = ir.getControlFlowGraph().getSuccNodes(eb.original); it.hasNext();) {
-        ISSABasicBlock s = it.next();
+      List<IExplodedBasicBlock> result = new ArrayList<>();
+      for (ISSABasicBlock s : Iterator2Iterable.make(ir.getControlFlowGraph().getSuccNodes(eb.original))) {
         if (s.equals(ir.getControlFlowGraph().exit())) {
           result.add(exit());
         } else {
@@ -379,13 +378,12 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
 
   @Override
   public boolean hasEdge(IExplodedBasicBlock src, IExplodedBasicBlock dst) throws UnimplementedError {
-    for (Iterator<IExplodedBasicBlock> it = getSuccNodes(src); it.hasNext();) {
-      IExplodedBasicBlock succ = it.next();
+    for (IExplodedBasicBlock succ : Iterator2Iterable.make(getSuccNodes(src))) {
       if (succ == dst) {
         return true;
       }
     }
-    
+
     return false;
   }
 
@@ -443,8 +441,8 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
   @Override
   public IntSet getPredNodeNumbers(IExplodedBasicBlock node) {
     MutableSparseIntSet result = MutableSparseIntSet.makeEmpty();
-    for (Iterator<? extends IExplodedBasicBlock> it = getPredNodes(node); it.hasNext();) {
-      result.add(getNumber(it.next()));
+    for (IExplodedBasicBlock ebb : Iterator2Iterable.make(getPredNodes(node))) {
+      result.add(getNumber(ebb));
     }
     return result;
   }
@@ -458,7 +456,7 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
   /**
    * A basic block with exactly one normal instruction (which may be null), corresponding to a single instruction index in the SSA
    * instruction array.
-   * 
+   *
    * The block may also have phis.
    */
   private class ExplodedBasicBlock implements IExplodedBasicBlock {
@@ -627,25 +625,29 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
     @Override
     public String toString() {
       if (isEntryBlock()) {
-        return "ExplodedBlock[" + getNumber() + "](entry:" + getMethod() + ")";
+        return "ExplodedBlock[" + getNumber() + "](entry:" + getMethod() + ')';
       }
       if (isExitBlock()) {
-        return "ExplodedBlock[" + getNumber() + "](exit:" + getMethod() + ")";
+        return "ExplodedBlock[" + getNumber() + "](exit:" + getMethod() + ')';
       }
-      return "ExplodedBlock[" + getNumber() + "](original:" + original + ")";
+      return "ExplodedBlock[" + getNumber() + "](original:" + original + ')';
+    }
+
+    @Override
+    public int getOriginalNumber() {
+      return original.getNumber();
     }
   }
 
   @Override
   public String toString() {
-    StringBuffer s = new StringBuffer("");
-    for (Iterator<IExplodedBasicBlock> it = iterator(); it.hasNext();) {
-      IExplodedBasicBlock bb = it.next();
-      s.append("BB").append(getNumber(bb)).append("\n");
+    StringBuilder s = new StringBuilder();
+    for (IExplodedBasicBlock bb : this) {
+      s.append("BB").append(getNumber(bb)).append('\n');
 
       Iterator<? extends IExplodedBasicBlock> succNodes = getSuccNodes(bb);
       while (succNodes.hasNext()) {
-        s.append("    -> BB").append(getNumber(succNodes.next())).append("\n");
+        s.append("    -> BB").append(getNumber(succNodes.next())).append('\n');
       }
     }
     return s.toString();
@@ -655,4 +657,4 @@ public class ExplodedControlFlowGraph implements ControlFlowGraph<SSAInstruction
     return ir;
   }
 
-}
\ No newline at end of file
+}
