@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2007 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ssa.analysis;
 
 import com.ibm.wala.ssa.ISSABasicBlock;
@@ -17,7 +17,7 @@ import com.ibm.wala.ssa.SSAInstruction;
 /**
  * A basic block with exactly one normal instruction (which may be null), corresponding to a single instruction index in the SSA
  * instruction array.
- * 
+ *
  * The block may also have phis.
  */
 public interface IExplodedBasicBlock extends ISSABasicBlock {
@@ -29,9 +29,15 @@ public interface IExplodedBasicBlock extends ISSABasicBlock {
 
   /**
    * if this represents an exception handler block, return the corresponding {@link SSAGetCaughtExceptionInstruction}
-   * 
+   *
    * @throws IllegalArgumentException if this does not represent an exception handler block
    */
   public SSAGetCaughtExceptionInstruction getCatchInstruction();
 
+  /**
+   * get the number of the original basic block containing the instruction of
+   * this exploded block
+   */
+  public int getOriginalNumber();
+
 }
