@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.types;
 
 import static com.ibm.wala.types.TypeName.ArrayMask;
@@ -50,9 +50,9 @@ public final class TypeReference implements Serializable {
    */
   private final static Map<Key, TypeReference> dictionary = HashMapFactory.make();
 
-  /*********************************************************************************************************************
+  /*
    * Primitive Dispatch *
-   ********************************************************************************************************************/
+   */
 
   public final static TypeName BooleanName = TypeName.string2TypeName("Z");
 
@@ -110,9 +110,9 @@ public final class TypeReference implements Serializable {
 
   public final static byte OtherPrimitiveTypeCode = 'P';
   
-  /*********************************************************************************************************************
+  /*
    * Primitive Array Dispatch *
-   ********************************************************************************************************************/
+   */
 
   public final static TypeReference BooleanArray = findOrCreateArrayOf(Boolean);
 
@@ -130,9 +130,9 @@ public final class TypeReference implements Serializable {
 
   public final static TypeReference ShortArray = findOrCreateArrayOf(Short);
 
-  /*********************************************************************************************************************
+  /*
    * Special object types *
-   ********************************************************************************************************************/
+   */
 
   private final static TypeName JavaLangArithmeticExceptionName = TypeName.string2TypeName("Ljava/lang/ArithmeticException");
 
@@ -158,6 +158,10 @@ public final class TypeReference implements Serializable {
 
   public final static TypeReference JavaLangInvokeMethodHandle = findOrCreate(ClassLoaderReference.Primordial, JavaLangInvokeMethodHandleName);
 
+  private final static TypeName JavaLangInvokeMethodHandlesLookupName = TypeName.string2TypeName("Ljava/lang/invoke/MethodHandles$Lookup");
+
+  public final static TypeReference JavaLangInvokeMethodHandlesLookup = findOrCreate(ClassLoaderReference.Primordial, JavaLangInvokeMethodHandlesLookupName);
+
   private final static TypeName JavaLangInvokeMethodTypeName = TypeName.string2TypeName("Ljava/lang/invoke/MethodType");
 
   public final static TypeReference JavaLangInvokeMethodType = findOrCreate(ClassLoaderReference.Primordial, JavaLangInvokeMethodTypeName);
@@ -579,9 +583,9 @@ public final class TypeReference implements Serializable {
    * TypeReferences are canonical. However, note that two TypeReferences can be non-equal, yet still represent the same
    * IClass.
    * 
-   * For example, the there can be two TypeReferences <Application,java.lang.Object> and <Primordial,java.lang.Object>.
-   * These two TypeReference are <bf>NOT</bf> equal(), but they both represent the IClass which is named
-   * <Primordial,java.lang.Object>
+   * For example, the there can be two TypeReferences &lt;Application,java.lang.Object&gt; and &lt;Primordial,java.lang.Object&gt;.
+   * These two TypeReference are <b>NOT</b> equal(), but they both represent the IClass which is named
+   * &lt;Primordial,java.lang.Object&gt;
    */
   @Override
   public final boolean equals(Object other) {
@@ -590,7 +594,7 @@ public final class TypeReference implements Serializable {
 
   @Override
   public final String toString() {
-    return "<" + classloader.getName() + "," + name + ">";
+    return "<" + classloader.getName() + ',' + name + '>';
   }
 
   public static TypeReference findOrCreateClass(ClassLoaderReference loader, String packageName, String className) {
