@@ -1,4 +1,4 @@
-/******************************************************************************
+/*
  * Copyright (c) 2002 - 2014 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *****************************************************************************/
+ */
 
 /*
  *  Copyright (c) 2013,
@@ -77,7 +77,7 @@ import com.ibm.wala.util.ssa.SSAValue.WeaklyNamedKey;
  *  If you want to alter the values of the incoming parameters you may also want to use the ParameterManager
  *  which tracks the changes.
  *
- *  @author Tobias Blaschke <code@tobiasblaschke.de>
+ *  @author Tobias Blaschke &lt;code@tobiasblaschke.de&gt;
  *  @since  2013-10-19
  */
 public class ParameterAccessor {
@@ -142,12 +142,10 @@ public class ParameterAccessor {
      *
      *  Use .getNumber() to access the associated SSA-Value.
      *
-     *  @author Tobias Blaschke <code@tobiasblaschke.de>
+     *  @author Tobias Blaschke &lt;code@tobiasblaschke.de&gt;
      *  @since  2013-10-19
      */
     public static class Parameter extends SSAValue {
-        /** Is Accessor constructed with IMethod or MethodReference */
-        private final BasedOn basedOn;      
         /** Implicit this or regular parameter? */
         private final ParamerterDisposition disp;   
         /** Add to number to get position in descriptor */
@@ -189,7 +187,7 @@ public class ParameterAccessor {
             if ((disp == ParamerterDisposition.PARAM) && (number + descriptorOffset > mRef.getNumberOfParameters())) {
                 throw new IllegalArgumentException("The SSA-Value " + number + " (with added offset " + descriptorOffset + 
                         ") is beyond the number of Arguments (" + mRef.getNumberOfParameters() + ") of the Method " +
-                        mRef.getName() + "\n" + mRef.getSignature());
+                        mRef.getName() + '\n' + mRef.getSignature());
             }
             if ((disp == ParamerterDisposition.THIS) && (basedOn == BasedOn.METHOD_REFERENCE) && (number != 1)) {
                 throw new IllegalArgumentException("The implicit this-pointer of a MethodReference is located at SSA-Value 1. " +
@@ -205,7 +203,6 @@ public class ParameterAccessor {
             }
 
             this.disp = disp;
-            this.basedOn = basedOn;
             this.descriptorOffset = descriptorOffset;
             super.isAssigned();
         }
@@ -294,7 +291,7 @@ public class ParameterAccessor {
      *
      *  Using this Constructor influences the SSA-Values returned later. The cha is needed to
      *  determine whether mRef is static. If this is already known one should prefer the faster
-     *  {@link #ParameterAccessor(ParameterAccessor, boolean)}.
+     *  {@link #ParameterAccessor(MethodReference, boolean)}.
      *
      *  @param  mRef    The method to read the parameters from.
      */
@@ -313,10 +310,10 @@ public class ParameterAccessor {
         if (targets.size() < 1) {
             warn("Unable to look up the method {} starting extensive search...", mRef);
 
-            targets = new HashSet<IMethod>();
+            targets = new HashSet<>();
             final TypeReference mClass = mRef.getDeclaringClass();
             final Selector mSel = mRef.getSelector();
-            final Set<IClass> testClasses = new HashSet<IClass>();
+            final Set<IClass> testClasses = new HashSet<>();
 
             // Look up all classes matching exactly
             for (IClassLoader loader : cha.getLoaders()) {
@@ -393,7 +390,7 @@ public class ParameterAccessor {
      *
      *  Do _not_ use ParameterAceesor(IMethod.getReference()), but ParameterAceesor(IMehod)!
      *
-     *  This constructor is faster than {@link #ParameterAccessor(MethodReference, IClassHierarchy}.
+     *  This constructor is faster than {@link #ParameterAccessor(MethodReference, IClassHierarchy)}.
      *
      *  @param  mRef    The method to read the parameters from.
      */
@@ -457,7 +454,7 @@ public class ParameterAccessor {
      *
      *  @param  no  the number in the Selector
      *  @return new Parameter-Object for no
-     *  @throws IllegalArgumentExceptions if the parameter is zero
+     *  @throws IllegalArgumentException if the parameter is zero
      *  @throws ArrayIndexOutOfBoundsException if no is not within bounds [1 to numberOfParameters]
      */
     public Parameter getParameter(final int no) {
@@ -534,7 +531,7 @@ public class ParameterAccessor {
      */
     public List<Parameter> all() {
         // TODO: Cache!
-        List<Parameter> all = new ArrayList<Parameter>(this.getNumberOfParameters());
+        List<Parameter> all = new ArrayList<>(this.getNumberOfParameters());
 
         if (this.getNumberOfParameters() == 0) {
             return all;
@@ -542,7 +539,7 @@ public class ParameterAccessor {
             switch (this.base) {
                 case IMETHOD:
                     {
-                        final int firstInSelector = firstInSelector();
+                        // final int firstInSelector = firstInSelector();
                         for (int i = ((hasImplicitThis())?1:0); i < this.method.getNumberOfParameters(); ++i) {   
                             debug("all() adding: Parameter({}, {}, {}, {}, {})", (i + 1), this.method.getParameterType(i),
                                     this.base,  this.method, this.descriptorOffset);
@@ -839,7 +836,7 @@ public class ParameterAccessor {
         }
 
         final List<Parameter> all = all();
-        final List<Parameter> allExctends = new ArrayList();
+        final List<Parameter> allExctends = new ArrayList<>();
         IClass searchType = null;
         final IClassLoader[] allLoaders = cha.getLoaders();
 
@@ -908,7 +905,7 @@ public class ParameterAccessor {
 
         final IClass searchType = cha.lookupClass(tRef);
         final List<Parameter> all = all();
-        final List<Parameter> allExctends = new ArrayList();
+        final List<Parameter> allExctends = new ArrayList<>();
             
         if (searchType == null) {
             throw new IllegalStateException("Could not find the IClass of " + tRef);
@@ -1281,10 +1278,10 @@ public class ParameterAccessor {
             defaults = Collections.EMPTY_SET;
         }
         if (callee.getNumberOfParameters() == 0) {
-            return new ArrayList<SSAValue>(0);
+            return new ArrayList<>(0);
         }
         
-        final List<SSAValue> assigned = new ArrayList<SSAValue>(); // TODO: Set initial size
+        final List<SSAValue> assigned = new ArrayList<>(); // TODO: Set initial size
         final List<Parameter> calleeParams = callee.all();
         final List<Parameter> thisParams = all();
 
@@ -1585,7 +1582,7 @@ public class ParameterAccessor {
     }
 
     /**
-     *  Shorthand for forInvokeStatic(final List<? extends Parameter> args, final ParameterAccessor target, final IClassHierarchy cha).
+     *  Shorthand for forInvokeStatic(final List&lt;? extends Parameter&gt; args, final ParameterAccessor target, final IClassHierarchy cha).
      *
      *  Generates a new ParameterAccessor for target and hands the call through.
      */
@@ -1594,7 +1591,7 @@ public class ParameterAccessor {
     }
 
     /**
-     *  Shorthand for forInvokeVirtual(final int self, final List<? extends Parameter> args, final ParameterAccessor target, final IClassHierarchy cha).
+     *  Shorthand for forInvokeVirtual(final int self, final List&lt;? extends Parameter&gt; args, final ParameterAccessor target, final IClassHierarchy cha).
      *
      *  Generates a new ParameterAccessor for target and hands the call through.
      */
@@ -1653,8 +1650,10 @@ public class ParameterAccessor {
      *  Extensive output for debugging purposes.
      */
     public String dump() {
-        String ret = "Parameter Accessor for " + ((this.mRef!=null)?"mRef:" + this.mRef.toString():"IMethod: " + this.method.toString()) +
-            "\nContains " + this.numberOfParameters + " Parameters " + this.base + "\n";
+        final StringBuilder ret = new StringBuilder().append("Parameter Accessor for ")
+                .append((this.mRef != null) ? "mRef:" + this.mRef.toString() : "IMethod: " + this.method.toString())
+                .append("\nContains ").append(this.numberOfParameters).append(" Parameters ").append(this.base)
+                .append('\n');
         /*for (int i = 1; i <= this.numberOfParameters; ++i) {
             try {
                 ret += "\t" + getParameter(i).toString() + "\n";
@@ -1662,18 +1661,19 @@ public class ParameterAccessor {
                 ret += "\tNone at " + i + "\n";
             }
         }*/
-        ret += "\nAnd all is:\n";
+        ret.append("\nAnd all is:\n");
         for (Parameter p : all()) {
-            ret += "\t" + p + "\n";
+            ret.append('\t').append(p).append('\n');
         }
         if (hasImplicitThis ()) {
-            ret +="This: " + getThis();
+            ret.append("This: ").append(getThis());
         } else {
-            ret +="Is static";
+            ret.append("Is static");
         }
-        return ret;
+        return ret.toString();
     }
 
+    @Override
     public String toString() {
         return "<ParamAccessor forMethod=" + this.forMethod() + " />";
     }
