@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.strings;
 
 import static com.ibm.wala.types.TypeName.ArrayMask;
@@ -49,13 +49,13 @@ public class StringStuff {
     primitiveClassNames.put("void", "V");
   }
 
-  public static void padWithSpaces(StringBuffer b, int length) {
+  public static void padWithSpaces(StringBuilder b, int length) {
     if (b == null) {
       throw new IllegalArgumentException("b is null");
     }
     if (b.length() < length) {
       for (int i = b.length(); i < length; i++) {
-        b.append(" ");
+        b.append(' ');
       }
     }
   }
@@ -77,9 +77,9 @@ public class StringStuff {
       String baseType = dString.substring(0, arrayIndex);
       int dim = (dString.length() - arrayIndex) / 2;
       baseType = deployment2CanonicalTypeString(baseType);
-      StringBuffer result = new StringBuffer("[");
+      StringBuilder result = new StringBuilder("[");
       for (int i = 1; i < dim; i++) {
-        result.append("[");
+        result.append('[');
       }
       result.append(baseType);
       return result.toString();
@@ -87,7 +87,7 @@ public class StringStuff {
       if (primitiveClassNames.get(dString) != null) {
         return primitiveClassNames.get(dString);
       } else {
-        return "L" + dString;
+        return 'L' + dString;
       }
     }
   }
@@ -109,9 +109,9 @@ public class StringStuff {
       String baseType = dString.substring(0, arrayIndex);
       int dim = (dString.length() - arrayIndex) / 2;
       baseType = deployment2CanonicalDescriptorTypeString(baseType);
-      StringBuffer result = new StringBuffer("[");
+      StringBuilder result = new StringBuilder("[");
       for (int i = 1; i < dim; i++) {
-        result.append("[");
+        result.append('[');
       }
       result.append(baseType);
       return result.toString();
@@ -119,7 +119,7 @@ public class StringStuff {
       if (primitiveClassNames.get(dString) != null) {
         return primitiveClassNames.get(dString);
       } else {
-        return "L" + dString + ";";
+        return 'L' + dString + ';';
       }
     }
   }
@@ -223,7 +223,7 @@ public class StringStuff {
       throw new IllegalArgumentException("invalid descriptor: " + b);
     }
 
-    ArrayList<TypeName> sigs = new ArrayList<TypeName>(10);
+    ArrayList<TypeName> sigs = new ArrayList<>(10);
 
     int i = 1;
     while (true) {
@@ -340,7 +340,7 @@ public class StringStuff {
       }
       return new ImmutableByteArray(name.b, start + 1 + dim, lastSlash - start - 1 - dim);
     } catch (ArrayIndexOutOfBoundsException e) {
-      throw new IllegalArgumentException("invalid name " + name + " start: " + start + " length: " + length);
+      throw new IllegalArgumentException("invalid name " + name + " start: " + start + " length: " + length, e);
     }
   }
 
@@ -394,7 +394,7 @@ public class StringStuff {
         return new ImmutableByteArray(name.b, lastSlash + 1, L);
       }
     } catch (ArrayIndexOutOfBoundsException e) {
-      throw new IllegalArgumentException("Malformed name: " + name + " " + start + " " + length);
+      throw new IllegalArgumentException("Malformed name: " + name + ' ' + start + ' ' + length, e);
     }
   }
 
@@ -443,7 +443,7 @@ public class StringStuff {
       }
       return code;
     } catch (ArrayIndexOutOfBoundsException e) {
-      throw new IllegalArgumentException("ill-formed array descriptor " + b);
+      throw new IllegalArgumentException("ill-formed array descriptor " + b, e);
     }
   }
 
@@ -468,7 +468,7 @@ public class StringStuff {
       }
       return new ImmutableByteArray(b.b, i, length - (i - start));
     } catch (ArrayIndexOutOfBoundsException e) {
-      throw new IllegalArgumentException("invalid element desciptor: " + b);
+      throw new IllegalArgumentException("invalid element desciptor: " + b, e);
     }
   }
 
@@ -506,7 +506,7 @@ public class StringStuff {
 
       return name.b[start] != 'L';
     } catch (ArrayIndexOutOfBoundsException e) {
-      throw new IllegalArgumentException(name.toString());
+      throw new IllegalArgumentException(name.toString(), e);
     }
   }
 
@@ -546,7 +546,7 @@ public class StringStuff {
     if (jvmType == null) {
       throw new IllegalArgumentException("jvmType is null");
     }
-    StringBuffer readable = new StringBuffer(); // human readable version
+    StringBuilder readable = new StringBuilder(); // human readable version
     int numberOfDimensions = 0; // the number of array dimensions
 
     if (jvmType.length() == 0) {
@@ -559,35 +559,46 @@ public class StringStuff {
       numberOfDimensions++;
       prefix = jvmType.charAt(numberOfDimensions);
     }
-    if (prefix == 'V') {
-      readable.append("void");
-    } else if (prefix == 'B') {
-      readable.append("byte");
-    } else if (prefix == 'C') {
-      readable.append("char");
-    } else if (prefix == 'D') {
-      readable.append("double");
-    } else if (prefix == 'F') {
-      readable.append("float");
-    } else if (prefix == 'I') {
-      readable.append("int");
-    } else if (prefix == 'J') {
-      readable.append("long");
-    } else if (prefix == 'S') {
-      readable.append("short");
-    } else if (prefix == 'Z') {
-      readable.append("boolean");
-    } else if (prefix == 'L') {
-      readable.append(jvmType.substring(numberOfDimensions + 1, // strip
-          // all
-          // leading
-          // '[' &
-          // 'L'
-          jvmType.length()) // Trim off the trailing ';'
-          );
-      // Convert to standard Java dot-notation
-      readable = new StringBuffer(slashToDot(readable.toString()));
-      readable = new StringBuffer(dollarToDot(readable.toString()));
+    switch (prefix) {
+      case 'V':
+        readable.append("void");
+        break;
+      case 'B':
+        readable.append("byte");
+        break;
+      case 'C':
+        readable.append("char");
+        break;
+      case 'D':
+        readable.append("double");
+        break;
+      case 'F':
+        readable.append("float");
+        break;
+      case 'I':
+        readable.append("int");
+        break;
+      case 'J':
+        readable.append("long");
+        break;
+      case 'S':
+        readable.append("short");
+        break;
+      case 'Z':
+        readable.append("boolean");
+        break;
+      case 'L':
+        readable.append(jvmType.substring(numberOfDimensions + 1, // strip
+                // all
+                // leading
+                // '[' &
+                // 'L'
+                jvmType.length()) // Trim off the trailing ';'
+        );
+        // Convert to standard Java dot-notation
+        readable = new StringBuilder(slashToDot(readable.toString()));
+        readable = new StringBuilder(dollarToDot(readable.toString()));
+        break;
     }
     // append trailing "[]" for each array dimension
     for (int i = 0; i < numberOfDimensions; ++i) {
@@ -607,7 +618,7 @@ public class StringStuff {
     if (jvmType == null) {
       throw new IllegalArgumentException("jvmType is null");
     }
-    StringBuffer readable = new StringBuffer(); // human readable version
+    StringBuilder readable = new StringBuilder(); // human readable version
     int numberOfDimensions = 0; // the number of array dimensions
 
     if (jvmType.length() == 0) {
@@ -620,34 +631,45 @@ public class StringStuff {
       numberOfDimensions++;
       prefix = jvmType.charAt(numberOfDimensions);
     }
-    if (prefix == 'V') {
-      readable.append("void");
-    } else if (prefix == 'B') {
-      readable.append("byte");
-    } else if (prefix == 'C') {
-      readable.append("char");
-    } else if (prefix == 'D') {
-      readable.append("double");
-    } else if (prefix == 'F') {
-      readable.append("float");
-    } else if (prefix == 'I') {
-      readable.append("int");
-    } else if (prefix == 'J') {
-      readable.append("long");
-    } else if (prefix == 'S') {
-      readable.append("short");
-    } else if (prefix == 'Z') {
-      readable.append("boolean");
-    } else if (prefix == 'L') {
-      readable.append(jvmType.substring(numberOfDimensions + 1, // strip
-          // all
-          // leading
-          // '[' &
-          // 'L'
-          jvmType.length()) // Trim off the trailing ';'
-          );
-      // Convert to standard Java dot-notation
-      readable = new StringBuffer(slashToDot(readable.toString()));
+    switch (prefix) {
+      case 'V':
+        readable.append("void");
+        break;
+      case 'B':
+        readable.append("byte");
+        break;
+      case 'C':
+        readable.append("char");
+        break;
+      case 'D':
+        readable.append("double");
+        break;
+      case 'F':
+        readable.append("float");
+        break;
+      case 'I':
+        readable.append("int");
+        break;
+      case 'J':
+        readable.append("long");
+        break;
+      case 'S':
+        readable.append("short");
+        break;
+      case 'Z':
+        readable.append("boolean");
+        break;
+      case 'L':
+        readable.append(jvmType.substring(numberOfDimensions + 1, // strip
+                // all
+                // leading
+                // '[' &
+                // 'L'
+                jvmType.length()) // Trim off the trailing ';'
+        );
+        // Convert to standard Java dot-notation
+        readable = new StringBuilder(slashToDot(readable.toString()));
+        break;
     }
     // append trailing "[]" for each array dimension
     for (int i = 0; i < numberOfDimensions; ++i) {
@@ -666,7 +688,7 @@ public class StringStuff {
     if (path == null) {
       throw new IllegalArgumentException("path is null");
     }
-    StringBuffer dotForm = new StringBuffer(path);
+    StringBuilder dotForm = new StringBuilder(path);
     // replace all '/' in the path with '.'
     for (int i = 0; i < dotForm.length(); ++i) {
       if (dotForm.charAt(i) == '/') {
@@ -687,7 +709,7 @@ public class StringStuff {
     if (path == null) {
       throw new IllegalArgumentException("path is null");
     }
-    StringBuffer dotForm = new StringBuffer(path);
+    StringBuilder dotForm = new StringBuilder(path);
     // replace all '$' in the path with '.'
     for (int i = 0; i < dotForm.length(); ++i) {
       if (dotForm.charAt(i) == '$') {
@@ -708,7 +730,7 @@ public class StringStuff {
     if (path == null) {
       throw new IllegalArgumentException("path is null");
     }
-    StringBuffer dotForm = new StringBuffer(path);
+    StringBuilder dotForm = new StringBuilder(path);
     // replace all '.' in the path with '$'
     for (int i = 0; i < dotForm.length(); ++i) {
       if (dotForm.charAt(i) == '.') {
@@ -726,9 +748,9 @@ public class StringStuff {
       int stop = typeName.length() - 1;
 
       if (typeName.contains(".")) {
-        start = typeName.lastIndexOf(".");
+        start = typeName.lastIndexOf('.');
       } else if (typeName.contains("/")) {
-        start = typeName.lastIndexOf("/");
+        start = typeName.lastIndexOf('/');
       }
 
       if (typeName.endsWith(";")) {
