@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.warnings;
 
 import java.util.Collection;
@@ -32,14 +32,13 @@ public class Warnings {
   }
 
   public static synchronized String asString() {
-    TreeSet<Warning> T = new TreeSet<Warning>();
-    T.addAll(warnings);
+    TreeSet<Warning> T = new TreeSet<>(warnings);
     Iterator<Warning> it = T.iterator();
-    StringBuffer result = new StringBuffer();
+    StringBuilder result = new StringBuilder();
     for (int i = 1; i <= T.size(); i++) {
       result.append(i).append(". ");
       result.append(it.next());
-      result.append("\n");
+      result.append('\n');
     }
     return result.toString();
   }
@@ -47,4 +46,4 @@ public class Warnings {
   public static synchronized Iterator<Warning> iterator() {
     return warnings.iterator();
   }
-}
\ No newline at end of file
+}
