@@ -69,10 +69,9 @@ import com.ibm.wala.util.ssa.TypeSafeInstructionFactory;
  *  which aids in keeping track of SSA-Variables and adding Phi-Functions.
  *
  *  @see        com.ibm.wala.dalvik.ipa.callgraph.impl.AndroidEntryPoint.ExecutionOrder
- *  @see        com.ibm.wala.dalvik.ipa.callgraph.impl.DexFakeRootMethod
  *  @see        com.ibm.wala.dalvik.ipa.callgraph.androidModel.parameters.AndroidModelParameterManager
  *
- *  @author     Tobias Blaschke <code@tobiasblaschke.de>
+ *  @author     Tobias Blaschke &lt;code@tobiasblaschke.de&gt;
  *  @since      2013-09-07
  */
 public abstract class AbstractAndroidModel  {
@@ -99,7 +98,7 @@ public abstract class AbstractAndroidModel  {
         assert (start != null) : "The argument start was null";
         assert (end != null) : "The argument end was null";
 
-        List<TypeReference> returnTypes = new ArrayList<TypeReference>();
+        List<TypeReference> returnTypes = new ArrayList<>();
         for (Entrypoint ep : this.entryPoints) {
             if (ep instanceof AndroidEntryPoint) {
                 AndroidEntryPoint aep = (AndroidEntryPoint)ep;
@@ -160,7 +159,7 @@ public abstract class AbstractAndroidModel  {
      *
      *  This function is expected to be called on entrypoints in ascending order.
      *
-     *  You are expected to call {@link #enter(ExecutionOrder, int)} iff a
+     *  You are expected to call {@link #enter(com.ibm.wala.dalvik.ipa.callgraph.impl.AndroidEntryPoint.ExecutionOrder, int)} iff a
      *  Label got skipped over.
      *
      *  @param  order       The entrypoint in question
@@ -197,7 +196,7 @@ public abstract class AbstractAndroidModel  {
      *  Gets called when Label ExecutionOrder.AT_FIRST got stepped over.
      *
      *  In most cases you don't want to invoke this function directly but to use 
-     *  {@link #enter(ExecutionOrder.AT_FIRST, int)} instead.
+     *  {@code enter(ExecutionOrder.AT_FIRST, int)} instead.
      *
      *  Sideeffects: currentSection is updated, instructions are inserted into the body
      *
@@ -205,13 +204,13 @@ public abstract class AbstractAndroidModel  {
      *      you'll simply pass body.getNextProgramCounter()
      *  @return             Program Counter after insertion of the code
      */
-    protected int enterAT_FIRST(int PC) { return PC; };
+    protected int enterAT_FIRST(int PC) { return PC; }
 
      /**
      *  Gets called when Label ExecutionOrder.BEFORE_LOOP got stepped over.
      *
      *  In most cases you don't want to invoke this function directly but to use 
-     *  {@link #enter(ExecutionOrder.BEFORE_LOOP, int)} instead
+     *  {@code enter(ExecutionOrder.BEFORE_LOOP, int)} instead
      *
      *  Sideeffects: currentSection is updated, instructions are inserted into the body
      *
@@ -219,13 +218,13 @@ public abstract class AbstractAndroidModel  {
      *      you'll simply pass body.getNextProgramCounter()
      *  @return             Program Counter after insertion of the code
      */
-    protected int enterBEFORE_LOOP (int PC) { return PC; };
+    protected int enterBEFORE_LOOP (int PC) { return PC; }
 
     /**
      *  Gets called when Label ExecutionOrder.START_OF_LOOP got stepped over.
      *
      *  In most cases you don't want to invoke this function directly but to use 
-     *  {@link #enter(ExecutionOrder.START_OF_LOOP, int)} instead
+     *  {@code enter(ExecutionOrder.START_OF_LOOP, int)} instead
      *
      *  Sideeffects: currentSection is updated, instructions are inserted into the body
      *
@@ -233,13 +232,13 @@ public abstract class AbstractAndroidModel  {
      *      you'll simply pass body.getNextProgramCounter()
      *  @return             Program Counter after insertion of the code
      */
-    protected int enterSTART_OF_LOOP (int PC) { return PC; };
+    protected int enterSTART_OF_LOOP (int PC) { return PC; }
 
     /**
      *  Gets called when Label ExecutionOrder.MIDDLE_OF_LOOP got stepped over.
      *
      *  In most cases you don't want to invoke this function directly but to use 
-     *  {@link #enter(ExecutionOrder.MIDDLE_OF_LOOP, int)} instead
+     *  {@code enter(ExecutionOrder.MIDDLE_OF_LOOP, int)} instead
      *
      *  Sideeffects: currentSection is updated, instructions are inserted into the body
      *
@@ -247,13 +246,13 @@ public abstract class AbstractAndroidModel  {
      *      you'll simply pass body.getNextProgramCounter()
      *  @return             Program Counter after insertion of the code
      */
-    protected int enterMIDDLE_OF_LOOP (int PC) { return PC; };
+    protected int enterMIDDLE_OF_LOOP (int PC) { return PC; }
     
     /**
      *  Gets called when Label ExecutionOrder.MULTIPLE_TIMES_IN_LOOP got stepped over.
      *
      *  In most cases you don't want to invoke this function directly but to use 
-     *  {@link #enter(ExecutionOrder.MULTIPLE_TIMES_IN_LOOP, int)} instead
+     *  {@code enter(ExecutionOrder.MULTIPLE_TIMES_IN_LOOP, int)} instead
      *
      *  Sideeffects: currentSection is updated, instructions are inserted into the body
      *
@@ -261,13 +260,13 @@ public abstract class AbstractAndroidModel  {
      *      you'll simply pass body.getNextProgramCounter()
      *  @return             Program Counter after insertion of the code
      */
-    protected int enterMULTIPLE_TIMES_IN_LOOP (int PC) { return PC; };
+    protected int enterMULTIPLE_TIMES_IN_LOOP (int PC) { return PC; }
 
     /**
      *  Gets called when Label ExecutionOrder.END_OF_LOOP got stepped over.
      *
      *  In most cases you don't want to invoke this function directly but to use 
-     *  {@link #enter(ExecutionOrder.END_OF_LOOP, int)} instead
+     *  {@code enter(ExecutionOrder.END_OF_LOOP, int)} instead
      *
      *  Sideeffects: currentSection is updated, instructions are inserted into the body
      *
@@ -275,13 +274,13 @@ public abstract class AbstractAndroidModel  {
      *      you'll simply pass body.getNextProgramCounter()
      *  @return             Program Counter after insertion of the code
      */
-    protected int enterEND_OF_LOOP (int PC) { return PC; };
+    protected int enterEND_OF_LOOP (int PC) { return PC; }
 
     /**
      *  Gets called when Label ExecutionOrder.AFTER_LOOP got stepped over.
      *
      *  In most cases you don't want to invoke this function directly but to use 
-     *  {@link #enter(ExecutionOrder.AFTER_LOOP, int)} instead
+     *  {@code enter(ExecutionOrder.AFTER_LOOP, int)} instead
      *
      *  Sideeffects: currentSection is updated, instructions are inserted into the body
      *
@@ -289,13 +288,13 @@ public abstract class AbstractAndroidModel  {
      *      you'll simply pass body.getNextProgramCounter()
      *  @return             Program Counter after insertion of the code
      */
-    protected int enterAFTER_LOOP (int PC) { return PC; };
+    protected int enterAFTER_LOOP (int PC) { return PC; }
 
     /**
      *  Gets called when Label ExecutionOrder.AT_LAST got stepped over.
      *
      *  In most cases you don't want to invoke this function directly but to use 
-     *  {@link #enter(ExecutionOrder.AT_LAST, int)} instead
+     *  {@code enter(ExecutionOrder.AT_LAST, int)} instead
      *  
      *  Sideeffects: currentSection is updated, instructions are inserted into the body
      *
@@ -303,7 +302,7 @@ public abstract class AbstractAndroidModel  {
      *      you'll simply pass body.getNextProgramCounter()
      *  @return             Program Counter after insertion of the code
      */
-    protected int enterAT_LAST (int PC) { return PC; };
+    protected int enterAT_LAST (int PC) { return PC; }
 
     /**
      *  Gets called when the model gets finished.
@@ -317,7 +316,7 @@ public abstract class AbstractAndroidModel  {
      *      you'll simply pass body.getNextProgramCounter()
      *  @return             Program Counter after insertion of the code
      */
-    protected int leaveAT_LAST (int PC) { return PC; };
+    protected int leaveAT_LAST (int PC) { return PC; }
 
     /**
      *  Dispatches to the enterLABEL-functions. Does also call functions to any labels that
