@@ -59,7 +59,7 @@ import com.ibm.wala.util.strings.Atom;
  *
  *  @see    com.ibm.wala.dalvik.util.AndroidEntryPointLocator
  *
- *  @author  Tobias Blaschke <code@toiasblaschke.de>
+ *  @author  Tobias Blaschke &lt;code@toiasblaschke.de&gt;
  *  @since   2013-09-01
  */
 public class AndroidEntryPoint extends DexEntryPoint {
@@ -163,17 +163,16 @@ public class AndroidEntryPoint extends DexEntryPoint {
      * @return the section of this entrypoint
      */
     public ExecutionOrder getSection() {
-        if (this.order.compareTo(ExecutionOrder.BEFORE_LOOP) == -1) return ExecutionOrder.AT_FIRST;
-        if (this.order.compareTo(ExecutionOrder.START_OF_LOOP) == -1) return ExecutionOrder.BEFORE_LOOP;
-        if (this.order.compareTo(ExecutionOrder.MIDDLE_OF_LOOP) == -1) return ExecutionOrder.START_OF_LOOP;
-        if (this.order.compareTo(ExecutionOrder.MULTIPLE_TIMES_IN_LOOP) == -1) return ExecutionOrder.MIDDLE_OF_LOOP;
-        if (this.order.compareTo(ExecutionOrder.END_OF_LOOP) == -1) return ExecutionOrder.MULTIPLE_TIMES_IN_LOOP;
-        if (this.order.compareTo(ExecutionOrder.AFTER_LOOP) == -1) return ExecutionOrder.END_OF_LOOP;
-        if (this.order.compareTo(ExecutionOrder.AT_LAST) == -1) return ExecutionOrder.AFTER_LOOP;
+        if (this.order.compareTo(ExecutionOrder.BEFORE_LOOP) < 0) return ExecutionOrder.AT_FIRST;
+        if (this.order.compareTo(ExecutionOrder.START_OF_LOOP) < 0) return ExecutionOrder.BEFORE_LOOP;
+        if (this.order.compareTo(ExecutionOrder.MIDDLE_OF_LOOP) < 0) return ExecutionOrder.START_OF_LOOP;
+        if (this.order.compareTo(ExecutionOrder.MULTIPLE_TIMES_IN_LOOP) < 0) return ExecutionOrder.MIDDLE_OF_LOOP;
+        if (this.order.compareTo(ExecutionOrder.END_OF_LOOP) < 0) return ExecutionOrder.MULTIPLE_TIMES_IN_LOOP;
+        if (this.order.compareTo(ExecutionOrder.AFTER_LOOP) < 0) return ExecutionOrder.END_OF_LOOP;
+        if (this.order.compareTo(ExecutionOrder.AT_LAST) < 0) return ExecutionOrder.AFTER_LOOP;
         return ExecutionOrder.AT_LAST;
     }
 
-    /** {@inheritDoc} */
     public int getOrderValue() { return order.getOrderValue(); }
     public int compareTo(AndroidEntryPoint.IExecutionOrder o) {
         return this.order.compareTo(o);
@@ -189,7 +188,7 @@ public class AndroidEntryPoint extends DexEntryPoint {
      * Before building the model a list of AdroidEntryPoints is to be sorted by that criterion. 
      * You can use AndroidEntryPoint.ExecutionOrderComperator for that task.
      */
-    public static class ExecutionOrder implements Comparable<IExecutionOrder>, IExecutionOrder {
+    public static class ExecutionOrder implements IExecutionOrder {
         // This is an Enum-Style class
         /** Visit the EntryPoint once at the beginning of the model use that for initialization stuff  */
         public final static ExecutionOrder AT_FIRST = new ExecutionOrder(0);
@@ -215,7 +214,7 @@ public class AndroidEntryPoint extends DexEntryPoint {
          *  Unrecommended way to generate the Order based on an Integer.
          *
          *  This method is handy when reading back files. In your code you should prefer the methods
-         *  {@link #after(IExecutionOrder)} and {@link #between(IExecutionOrder, IExecutionOrder)}.
+         *  {@link #after(com.ibm.wala.dalvik.ipa.callgraph.impl.AndroidEntryPoint.IExecutionOrder)} and {@link #between(com.ibm.wala.dalvik.ipa.callgraph.impl.AndroidEntryPoint.IExecutionOrder, com.ibm.wala.dalvik.ipa.callgraph.impl.AndroidEntryPoint.IExecutionOrder)}.
          */
         public ExecutionOrder(int val) { 
             this.value=val; 
@@ -237,7 +236,8 @@ public class AndroidEntryPoint extends DexEntryPoint {
             if (label.equals("AT_LAST")) { this.value = ExecutionOrder.AT_LAST.getOrderValue(); return; }
             throw new IllegalArgumentException("ExecutionOrder was constructed from an illegal label: " + label);
         }
-        /** {@inheritDoc} */
+
+        @Override
         public int getOrderValue() { return this.value; }
 
         /**
@@ -264,7 +264,7 @@ public class AndroidEntryPoint extends DexEntryPoint {
          *  Use this to place a call to an EntryPoint between two other EntryPoint calls or ExecutionOrder "labels".
          *  between() does not care about section-boundaries by itself! 
          *
-         *  Use {@link between(IExecutionOrder[], IExecutionOrder[])} and use labels as additional placement-information 
+         *  Use {@link #between(com.ibm.wala.dalvik.ipa.callgraph.impl.AndroidEntryPoint.IExecutionOrder[], com.ibm.wala.dalvik.ipa.callgraph.impl.AndroidEntryPoint.IExecutionOrder[])} and use labels as additional placement-information 
          *  to prevent unexpected misplacement.
          *
          *  @param  after   the call or "label" to be executed before this one
@@ -299,7 +299,7 @@ public class AndroidEntryPoint extends DexEntryPoint {
          *  This method is intended to be more robust when changing the position-information of referred-to
          *  ExecutionOrders.
          *
-         *  In any other means it behaves exactly like {@link #between(IExecutionOrder, IExecutionOrder)}.
+         *  In any other means it behaves exactly like {@link #between(com.ibm.wala.dalvik.ipa.callgraph.impl.AndroidEntryPoint.IExecutionOrder, com.ibm.wala.dalvik.ipa.callgraph.impl.AndroidEntryPoint.IExecutionOrder)}.
          *
          *  @param  after   the calls or "labels"  to be executed before this one
          *  @param  before  the calls or "labels" to be executed after this one (inclusive)
@@ -359,7 +359,7 @@ public class AndroidEntryPoint extends DexEntryPoint {
         }
 
         /**
-         *  Prefer {@link #after(IExecutionOrder)} whenever possible.
+         *  Prefer {@link #after(com.ibm.wala.dalvik.ipa.callgraph.impl.AndroidEntryPoint.IExecutionOrder)} whenever possible.
          */
         public static ExecutionOrder after (int after) {
             return between(after, ((after / (Integer.MAX_VALUE / 8)) + 1) * (Integer.MAX_VALUE / 8));
@@ -393,26 +393,22 @@ public class AndroidEntryPoint extends DexEntryPoint {
             return new ExecutionOrder(before.getOrderValue() + 1);
         }
 
-        /**
-         * {@inheritDoc}
-         */
+        @Override
         public ExecutionOrder getSection() {
-            if (this.compareTo(ExecutionOrder.BEFORE_LOOP) == -1) return ExecutionOrder.AT_FIRST;
-            if (this.compareTo(ExecutionOrder.START_OF_LOOP) == -1) return ExecutionOrder.BEFORE_LOOP;
-            if (this.compareTo(ExecutionOrder.MIDDLE_OF_LOOP) == -1) return ExecutionOrder.START_OF_LOOP;
-            if (this.compareTo(ExecutionOrder.MULTIPLE_TIMES_IN_LOOP) == -1) return ExecutionOrder.MIDDLE_OF_LOOP;
-            if (this.compareTo(ExecutionOrder.END_OF_LOOP) == -1) return ExecutionOrder.MULTIPLE_TIMES_IN_LOOP;
-            if (this.compareTo(ExecutionOrder.AFTER_LOOP) == -1) return ExecutionOrder.END_OF_LOOP;
-            if (this.compareTo(ExecutionOrder.AT_LAST) == -1) return ExecutionOrder.AFTER_LOOP;
+            if (this.compareTo(ExecutionOrder.BEFORE_LOOP) < 0) return ExecutionOrder.AT_FIRST;
+            if (this.compareTo(ExecutionOrder.START_OF_LOOP) < 0) return ExecutionOrder.BEFORE_LOOP;
+            if (this.compareTo(ExecutionOrder.MIDDLE_OF_LOOP) < 0) return ExecutionOrder.START_OF_LOOP;
+            if (this.compareTo(ExecutionOrder.MULTIPLE_TIMES_IN_LOOP) < 0) return ExecutionOrder.MIDDLE_OF_LOOP;
+            if (this.compareTo(ExecutionOrder.END_OF_LOOP) < 0) return ExecutionOrder.MULTIPLE_TIMES_IN_LOOP;
+            if (this.compareTo(ExecutionOrder.AFTER_LOOP) < 0) return ExecutionOrder.END_OF_LOOP;
+            if (this.compareTo(ExecutionOrder.AT_LAST) < 0) return ExecutionOrder.AFTER_LOOP;
             return ExecutionOrder.AT_LAST;
         }
 
 
         @Override
         public int compareTo(IExecutionOrder o) {
-            if (this.value == o.getOrderValue()) return 0;
-            if (this.value > o.getOrderValue()) return 1;
-            return -1;
+            return this.value - o.getOrderValue();
         }
 
         @Override
@@ -426,13 +422,13 @@ public class AndroidEntryPoint extends DexEntryPoint {
             if (this.compareTo(ExecutionOrder.AFTER_LOOP) == 0) return "ExecutionOrder.AFTER_LOOP";
             if (this.compareTo(ExecutionOrder.AT_LAST) == 0) return "ExecutionOrder.AT_LAST";
 
-            if (this.compareTo(ExecutionOrder.BEFORE_LOOP) == -1) return "in section ExecutionOrder.AT_FIRST";
-            if (this.compareTo(ExecutionOrder.START_OF_LOOP) == -1) return "in section ExecutionOrder.BEFORE_LOOP";
-            if (this.compareTo(ExecutionOrder.MIDDLE_OF_LOOP) == -1) return "in section ExecutionOrder.START_OF_LOOP";
-            if (this.compareTo(ExecutionOrder.MULTIPLE_TIMES_IN_LOOP) == -1) return "in section ExecutionOrder.MIDDLE_OF_LOOP";
-            if (this.compareTo(ExecutionOrder.END_OF_LOOP) == -1) return "in section ExecutionOrder.MULTIPLE_TIMES_IN_LOOP";
-            if (this.compareTo(ExecutionOrder.AFTER_LOOP) == -1) return "in section ExecutionOrder.END_OF_LOOP";
-            if (this.compareTo(ExecutionOrder.AT_LAST) == -1) return "in section ExecutionOrder.AFTER_LOOP";
+            if (this.compareTo(ExecutionOrder.BEFORE_LOOP) < 0) return "in section ExecutionOrder.AT_FIRST";
+            if (this.compareTo(ExecutionOrder.START_OF_LOOP) < 0) return "in section ExecutionOrder.BEFORE_LOOP";
+            if (this.compareTo(ExecutionOrder.MIDDLE_OF_LOOP) < 0) return "in section ExecutionOrder.START_OF_LOOP";
+            if (this.compareTo(ExecutionOrder.MULTIPLE_TIMES_IN_LOOP) < 0) return "in section ExecutionOrder.MIDDLE_OF_LOOP";
+            if (this.compareTo(ExecutionOrder.END_OF_LOOP) < 0) return "in section ExecutionOrder.MULTIPLE_TIMES_IN_LOOP";
+            if (this.compareTo(ExecutionOrder.AFTER_LOOP) < 0) return "in section ExecutionOrder.END_OF_LOOP";
+            if (this.compareTo(ExecutionOrder.AT_LAST) < 0) return "in section ExecutionOrder.AFTER_LOOP";
             return "in section ExecutionOrder.AT_LAST";
         }
     }
