@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -8,12 +8,9 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Adam Fuchs, Avik Chaudhuri, Steve Suh - Modified from stack to registers
- *******************************************************************************/
+ */
 package com.ibm.wala.dalvik.ssa;
 
-import java.util.Iterator;
-import java.util.logging.Logger;
-
 import com.ibm.wala.dalvik.classLoader.DexCFG;
 import com.ibm.wala.dalvik.classLoader.DexCFG.BasicBlock;
 import com.ibm.wala.dalvik.classLoader.DexConstants;
@@ -54,14 +51,15 @@ import com.ibm.wala.shrikeBT.IGetInstruction;
 import com.ibm.wala.shrikeBT.IInvokeInstruction;
 import com.ibm.wala.shrikeBT.IPutInstruction;
 import com.ibm.wala.shrikeBT.IUnaryOpInstruction;
-import com.ibm.wala.shrikeBT.InstanceofInstruction;
 import com.ibm.wala.shrikeBT.MonitorInstruction;
 import com.ibm.wala.shrikeBT.NewInstruction;
 import com.ibm.wala.shrikeBT.SwitchInstruction;
 import com.ibm.wala.shrikeBT.ThrowInstruction;
 import com.ibm.wala.util.CancelException;
 import com.ibm.wala.util.CancelRuntimeException;
+import com.ibm.wala.util.collections.Iterator2Iterable;
 import com.ibm.wala.util.debug.UnimplementedError;
+import com.ibm.wala.util.graph.INodeWithNumber;
 
 /**
  * Skeleton of functionality to propagate information through the Java bytecode stack machine using ShrikeBT.
@@ -119,14 +117,17 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
     protected void init(Meeter meeter, final FlowProvider flow) {
         final MeetOperator meet = new MeetOperator(meeter);
         ITransferFunctionProvider<BasicBlock, MachineState> xferFunctions = new ITransferFunctionProvider<BasicBlock, MachineState>() {
+            @Override
             public boolean hasNodeTransferFunctions() {
                 return flow.needsNodeFlow();
             }
 
+            @Override
             public boolean hasEdgeTransferFunctions() {
                 return flow.needsEdgeFlow();
             }
 
+            @Override
             public UnaryOperator<MachineState> getNodeTransferFunction(final BasicBlock node) {
                 return new UnaryOperator<MachineState>() {
                     @Override
@@ -161,6 +162,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
                 };
             }
 
+            @Override
             public UnaryOperator<MachineState> getEdgeTransferFunction(final BasicBlock from, final BasicBlock to) {
                 return new UnaryOperator<MachineState>() {
                     @Override
@@ -195,12 +197,13 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
                 };
             }
 
+            @Override
             public AbstractMeetOperator<MachineState> getMeetOperator() {
                 return meet;
             }
         };
 
-        IKilldallFramework<BasicBlock, MachineState> problem = new BasicFramework<BasicBlock, MachineState>(cfg, xferFunctions);
+        IKilldallFramework<BasicBlock, MachineState> problem = new BasicFramework<>(cfg, xferFunctions);
         solver = new DataflowSolver<BasicBlock, MachineState>(problem) {
             private MachineState entry;
 
@@ -229,8 +232,8 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
                 /*
                  * Add only the entry variable to the work list.
                  */
-                 for (Iterator it = getFixedPointSystem().getStatementsThatUse(entry); it.hasNext();) {
-                     AbstractStatement s = (AbstractStatement) it.next();
+                 for (INodeWithNumber inn : Iterator2Iterable.make(getFixedPointSystem().getStatementsThatUse(entry))) {
+                     AbstractStatement s = (AbstractStatement) inn;
                      addToWorkList(s);
                  }
             }
@@ -349,7 +352,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
      * @param bb the basic block at whose entry the meet occurs
      * @return true if the lhs value changes. false otherwise.
      */
-    private boolean meet(IVariable lhs, IVariable[] rhs, BasicBlock bb, Meeter meeter) {
+    private static boolean meet(IVariable lhs, IVariable[] rhs, BasicBlock bb, Meeter meeter) {
 
 //      boolean changed = meetStacks(lhs, rhs, bb, meeter);
 
@@ -365,7 +368,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
      * @param bb the basic block at whose entry the meet occurs
      * @return true if the lhs value changes. false otherwise.
      */
-    private boolean meetForCatchBlock(IVariable lhs, IVariable[] rhs, BasicBlock bb, Meeter meeter) {
+    private static boolean meetForCatchBlock(IVariable lhs, IVariable[] rhs, BasicBlock bb, Meeter meeter) {
 
         boolean changed = meetLocals(lhs, rhs, bb, meeter);
 
@@ -470,7 +473,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
      * @param bb the basic block at whose entry the meet occurs
      * @return true if the lhs value changes. false otherwise.
      */
-    private boolean meetLocals(IVariable lhs, IVariable[] rhs, BasicBlock bb, Meeter meeter) {
+    private static boolean meetLocals(IVariable lhs, IVariable[] rhs, BasicBlock bb, Meeter meeter) {
 
         boolean changed = false;
         MachineState L = (MachineState) lhs;
@@ -618,9 +621,6 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
 
         /**
          * set the value of local i to symbol j
-         *
-         * @param i
-         * @param j
          */
         public void setLocal(int i, int j) {
             if (locals == null) {
@@ -634,7 +634,6 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
         }
 
         /**
-         * @param i
          * @return the number of the symbol corresponding to local i
          */
         public int getLocal(int i) {
@@ -682,7 +681,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
 //          if (isTOP()) {
 //              return "<TOP>@" + System.identityHashCode(this);
 //          }
-//          StringBuffer result = new StringBuffer("<");
+//          StringBuffer result = new StringBuilder("<");
 //          result.append("S");
 //          if (stackHeight == 0) {
 //              result.append("[empty]");
@@ -696,7 +695,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
         }
 
 //      private StringBuffer array2StringBuffer(int[] array, int n) {
-//          StringBuffer result = new StringBuffer("[");
+//          StringBuffer result = new StringBuilder("[");
 //          if (array == null) {
 //              result.append(OPTIMISTIC ? "TOP" : "BOTTOM");
 //          } else {
@@ -709,19 +708,10 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
 //          return result;
 //      }
 
+        @Override
         public void copyState(MachineState other) {
-            if (other.stack == null) {
-                stack = null;
-            } else {
-                stack = new int[other.stack.length];
-                System.arraycopy(other.stack, 0, stack, 0, other.stack.length);
-            }
-            if (other.locals == null) {
-                locals = null;
-            } else {
-                locals = new int[other.locals.length];
-                System.arraycopy(other.locals, 0, locals, 0, other.locals.length);
-            }
+            stack = other.stack == null ? null : other.stack.clone();
+            locals = other.locals == null ? null : other.locals.clone();
             stackHeight = other.stackHeight;
         }
 
@@ -834,21 +824,24 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             this.edgeVisitor = ev;
         }
 
+        @Override
         public boolean needsNodeFlow() {
             return true;
         }
 
+        @Override
         public boolean needsEdgeFlow() {
             return false;
         }
 
+        @Override
         public MachineState flow(MachineState entry, BasicBlock basicBlock) {
             workingState = entry.duplicate();
             currentBlock = basicBlock;
             currentSuccessorBlock = null;
             Instruction[] instructions = getInstructions();
             if (DEBUG) {
-                System.err.println("Entry to BB" + cfg.getNumber(basicBlock) + " " + workingState);
+                System.err.println("Entry to BB" + cfg.getNumber(basicBlock) + ' ' + workingState);
             }
             for (int i = basicBlock.getFirstInstructionIndex(); i <= basicBlock.getLastInstructionIndex(); i++) {
                 currentInstructionIndex = i;
@@ -861,13 +854,14 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             return workingState;
         }
 
+        @Override
         public MachineState flow(MachineState entry, BasicBlock from, BasicBlock to) {
             workingState = entry.duplicate();
             currentBlock = from;
             currentSuccessorBlock = to;
             Instruction[] instructions = getInstructions();
             if (DEBUG) {
-                System.err.println("Entry to BB" + cfg.getNumber(from) + " " + workingState);
+                System.err.println("Entry to BB" + cfg.getNumber(from) + ' ' + workingState);
             }
             for (int i = from.getFirstInstructionIndex(); i <= from.getLastInstructionIndex(); i++) {
                 currentInstructionIndex = i;
@@ -903,7 +897,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
         protected class BasicRegisterMachineVisitor extends Visitor {
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitArrayLength(ArrayLengthInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitArrayLength(ArrayLengthInstruction)
              */
             @Override
             public void visitArrayLength(ArrayLength instruction) {
@@ -915,7 +909,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitArrayLoad(IArrayLoadInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitArrayLoad(IArrayLoadInstruction)
              */
             @Override
             public void visitArrayGet(ArrayGet instruction) {
@@ -928,7 +922,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitArrayStore(IArrayStoreInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitArrayStore(IArrayStoreInstruction)
              */
             @Override
             public void visitArrayPut(ArrayPut instruction) {
@@ -940,7 +934,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitBinaryOp(IBinaryOpInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitBinaryOp(IBinaryOpInstruction)
              */
             @Override
             public void visitBinaryOperation(BinaryOperation instruction) {
@@ -950,7 +944,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitComparison(IComparisonInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitComparison(IComparisonInstruction)
              */
 //          @Override
 //          public void visitComparison(IComparisonInstruction instruction) {
@@ -960,7 +954,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
 //          }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitConditionalBranch(IConditionalBranchInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitConditionalBranch(IConditionalBranchInstruction)
              */
             @Override
             public void visitBranch(Branch instruction) {
@@ -971,7 +965,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitConstant(ConstantInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitConstant(ConstantInstruction)
              */
             @Override
             public void visitConstant(Constant instruction) {
@@ -981,7 +975,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitConversion(IConversionInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitConversion(IConversionInstruction)
              */
 //          @Override
 //          public void visitConversion(IConversionInstruction instruction) {
@@ -990,7 +984,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
 //          }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitDup(DupInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitDup(DupInstruction)
              */
 //          @Override
 //          public void visitDup(DupInstruction instruction) {
@@ -1023,7 +1017,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
 //          }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitGet(IGetInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitGet(IGetInstruction)
              */
             @Override
             public void visitGetField(GetField instruction) {
@@ -1040,7 +1034,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
 //          }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitInstanceof(InstanceofInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitInstanceof
              */
             @Override
             public void visitInstanceof(InstanceOf instruction) {
@@ -1051,7 +1045,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitInvoke(IInvokeInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitInvoke(IInvokeInstruction)
              */
             @Override
             public void visitInvoke(Invoke instruction) {
@@ -1066,7 +1060,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitMonitor(MonitorInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitMonitor(MonitorInstruction)
              */
             @Override
             public void visitMonitor(Monitor instruction) {
@@ -1076,7 +1070,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitLocalLoad(ILoadInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitLocalLoad(ILoadInstruction)
              */
 //          @Override
 //          public void visitLocalLoad(ILoadInstruction instruction) {
@@ -1085,7 +1079,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
 //          }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitLocalStore(IStoreInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitLocalStore(IStoreInstruction)
              */
 //          @Override
 //          public void visitLocalStore(IStoreInstruction instruction) {
@@ -1094,7 +1088,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
 //          }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitNew(NewInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitNew(NewInstruction)
              */
             @Override
             public void visitNew(New instruction) {
@@ -1105,7 +1099,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitPop(PopInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitPop(PopInstruction)
              */
 //          @Override
 //          public void visitPop(PopInstruction instruction) {
@@ -1115,7 +1109,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
 //          }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitPut(IPutInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitPut(IPutInstruction)
              */
             @Override
             public void visitPutField(PutField instruction) {
@@ -1125,7 +1119,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitShift(IShiftInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitShift(IShiftInstruction)
              */
 //          @Override
 //          public void visitShift(IShiftInstruction instruction) {
@@ -1133,7 +1127,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
 //          }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitSwap(SwapInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitSwap(SwapInstruction)
              */
 //          @Override
 //          public void visitSwap(SwapInstruction instruction) {
@@ -1141,7 +1135,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
 //          }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitSwitch(SwitchInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitSwitch(SwitchInstruction)
              */
             @Override
             public void visitSwitch(Switch instruction) {
@@ -1151,7 +1145,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitThrow(ThrowInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitThrow(ThrowInstruction)
              */
             @Override
             public void visitThrow(Throw instruction) {
@@ -1163,7 +1157,7 @@ public abstract class AbstractIntRegisterMachine implements FixedPointConstants
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitUnaryOp(IUnaryOpInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitUnaryOp(IUnaryOpInstruction)
              */
             @Override
             public void visitUnaryOperation(UnaryOperation instruction) {
