@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -8,14 +8,11 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Adam Fuchs, Avik Chaudhuri, Steve Suh - Modified from stack to registers
- *******************************************************************************/
+ */
 package com.ibm.wala.dalvik.ssa;
 
-import java.nio.ByteBuffer;
+import java.util.Arrays;
 import java.util.Iterator;
-import java.util.logging.Logger;
-
-import org.jf.dexlib.Code.Format.ArrayDataPseudoInstruction.ArrayElement;
 
 import com.ibm.wala.cfg.IBasicBlock;
 import com.ibm.wala.classLoader.CallSiteReference;
@@ -49,7 +46,6 @@ import com.ibm.wala.dalvik.dex.instructions.Switch;
 import com.ibm.wala.dalvik.dex.instructions.Throw;
 import com.ibm.wala.dalvik.dex.instructions.UnaryOperation;
 import com.ibm.wala.shrikeBT.ArrayLengthInstruction;
-import com.ibm.wala.shrikeBT.CheckCastInstruction;
 import com.ibm.wala.shrikeBT.ConstantInstruction;
 import com.ibm.wala.shrikeBT.GotoInstruction;
 import com.ibm.wala.shrikeBT.IArrayLoadInstruction;
@@ -59,7 +55,6 @@ import com.ibm.wala.shrikeBT.IConditionalBranchInstruction;
 import com.ibm.wala.shrikeBT.IGetInstruction;
 import com.ibm.wala.shrikeBT.IInvokeInstruction;
 import com.ibm.wala.shrikeBT.IUnaryOpInstruction;
-import com.ibm.wala.shrikeBT.InstanceofInstruction;
 import com.ibm.wala.shrikeBT.MonitorInstruction;
 import com.ibm.wala.shrikeBT.NewInstruction;
 import com.ibm.wala.shrikeBT.ReturnInstruction;
@@ -119,7 +114,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
     final private SymbolTable symbolTable;
 
     /**
-     * A logical mapping from <bcIndex, valueNumber> -> local number if null, don't build it.
+     * A logical mapping from &lt;bcIndex, valueNumber&gt; -&gt; local number if null, don't build it.
      */
     private final SSA2LocalMap localMap;
 
@@ -139,8 +134,8 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             boolean buildLocalMap, SSAPiNodePolicy piNodePolicy) {
         super(scfg);
         localMap = buildLocalMap ? new SSA2LocalMap(scfg, instructions.length, cfg.getNumberOfNodes(), method.getMaxLocals()) : null;
-        init(new SymbolTableMeeter(cfg, instructions, scfg), new SymbolicPropagator(scfg, instructions,
-                localMap, cfg, piNodePolicy));
+        init(new SymbolTableMeeter(cfg, scfg), new SymbolicPropagator(scfg, instructions,
+                cfg, piNodePolicy));
         this.method = method;
         this.symbolTable = symbolTable;
         this.insts = method.getDeclaringClass().getClassLoader().getInstructionFactory();
@@ -155,7 +150,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 
         final DexCFG dexCFG;
 
-        SymbolTableMeeter(SSACFG cfg, SSAInstruction[] instructions, DexCFG dexCFG) {
+        SymbolTableMeeter(SSACFG cfg, DexCFG dexCFG) {
             this.cfg = cfg;
 //            this.instructions = instructions;
             this.dexCFG = dexCFG;
@@ -198,11 +193,12 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 //          }
 //      }
 
+        @Override
         public int meetLocal(int n, int[] rhs, DexCFG.BasicBlock bb) {
             if (allTheSame(rhs)) {
-                for (int i = 0; i < rhs.length; i++) {
-                    if (rhs[i] != TOP) {
-                        return rhs[i];
+                for (int rh : rhs) {
+                    if (rh != TOP) {
+                        return rh;
                     }
                 }
                 // didn't find anything but TOP
@@ -235,7 +231,6 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
         /**
          * Are all rhs values all the same? Note, we consider TOP (-1) to be same as everything else.
          *
-         * @param rhs
          * @return boolean
          */
         private boolean allTheSame(int[] rhs) {
@@ -348,10 +343,10 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 
         final SSAPiNodePolicy piNodePolicy;
 
-        public SymbolicPropagator(DexCFG dexCFG, SSAInstruction[] instructions, SSA2LocalMap localMap,
-                SSACFG cfg, SSAPiNodePolicy piNodePolicy) {
+        public SymbolicPropagator(DexCFG dexCFG, SSAInstruction[] instructions, SSACFG cfg,
+                SSAPiNodePolicy piNodePolicy) {
             super(dexCFG);
-            this.piNodePolicy = null;// piNodePolicy;
+            this.piNodePolicy = piNodePolicy;
             this.cfg = cfg;
             this.creators = new SSAInstruction[0];
             this.dexCFG = dexCFG;
@@ -370,9 +365,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             instructions[getCurrentInstructionIndex()] = s;
             for (int i = 0; i < s.getNumberOfDefs(); i++) {
                 if (creators.length < (s.getDef(i) + 1)) {
-                    SSAInstruction[] arr = new SSAInstruction[2 * s.getDef(i)];
-                    System.arraycopy(creators, 0, arr, 0, creators.length);
-                    creators = arr;
+                    creators = Arrays.copyOf(creators, 2 * s.getDef(i));
                 }
 
                 assert s.getDef(i) != -1 : "invalid def " + i + " for " + s;
@@ -429,7 +422,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 			// TODO: make sure all visit functions are overridden
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitArrayLength(ArrayLengthInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitArrayLength(ArrayLengthInstruction)
              */
             @Override
             public void visitArrayLength(ArrayLength instruction) {
@@ -442,7 +435,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitArrayLoad(IArrayLoadInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitArrayLoad(IArrayLoadInstruction)
              */
             @Override
             public void visitArrayGet(ArrayGet instruction) {
@@ -463,7 +456,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitArrayStore(IArrayStoreInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitArrayStore(IArrayStoreInstruction)
              */
             @Override
             public void visitArrayPut(ArrayPut instruction) {
@@ -482,46 +475,37 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 
             @Override
             public void visitArrayFill(ArrayFill instruction) {
-
-                Iterator<ArrayElement> iae = instruction.getTable().getElements();
+                Iterator<Number> iae = instruction.getTable().getArrayElements().iterator();
                 int i = 0;
                 while (iae.hasNext())
                 {
-                    ArrayElement ae = (ArrayElement)iae.next();
-                    int ElementWidth = ae.elementWidth;
-
+                    Number ae = iae.next();                    
                     int index = symbolTable.getConstant(i);
                     int arrayRef = workingState.getLocal(instruction.array);
                     TypeReference t = instruction.getType();
 //                  System.out.println(t.getName().toString());
                     int value;
-
-                    //fetch the byte[] array for the element
-                    byte[] temp_byte = new byte[ElementWidth];
-                    for (int j = 0; j < ElementWidth; j++)
-                        temp_byte[j] = ae.buffer[ae.bufferIndex+(ElementWidth-1)-j];
-                    ByteBuffer byte_buffer = ByteBuffer.wrap(temp_byte);
 //
 //                      System.out.println("Index: " + ae.bufferIndex + ", Width: " + ae.elementWidth + ", Value: " +  byte_buffer.getSomethingDependingonType );
 
 
                     //okay to call the getConstant(String) for a char?
                     if (t.equals(TypeReference.Char))
-                        value = symbolTable.getConstant(Character.toString(byte_buffer.getChar()));
+                        value = symbolTable.getConstant((char) ae.intValue());
                     else if (t.equals(TypeReference.Byte))
-                        value = symbolTable.getConstant((int)byte_buffer.get());
+                        value = symbolTable.getConstant(ae.byteValue());
                     else if (t.equals(TypeReference.Short))
-                        value = symbolTable.getConstant((int)byte_buffer.getShort());
+                        value = symbolTable.getConstant(ae.shortValue());
                     else if (t.equals(TypeReference.Int))
-                        value = symbolTable.getConstant(byte_buffer.getInt());
+                        value = symbolTable.getConstant(ae.intValue());
                     else if (t.equals(TypeReference.Long))
-                        value = symbolTable.getConstant(byte_buffer.getLong());
+                        value = symbolTable.getConstant(ae.longValue());
                     else if (t.equals(TypeReference.Float))
-                        value = symbolTable.getConstant(byte_buffer.getFloat());
+                        value = symbolTable.getConstant(ae.floatValue());
                     else if (t.equals(TypeReference.Double))
-                        value = symbolTable.getConstant(byte_buffer.getDouble());
+                        value = symbolTable.getConstant(ae.doubleValue());
                     else if (t.equals(TypeReference.Boolean))
-                        value = symbolTable.getConstant((byte_buffer.get() == 1)?true:false);
+                        value = symbolTable.getConstant(ae.intValue() != 0);
                     else
                     {
                         
@@ -537,7 +521,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitBinaryOp(IBinaryOpInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitBinaryOp(IBinaryOpInstruction)
              */
             @Override
             public void visitBinaryOperation(BinaryOperation instruction) {
@@ -554,7 +538,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitBinaryOp(IBinaryOpInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitBinaryOp(IBinaryOpInstruction)
              */
             @Override
             public void visitBinaryLiteral(BinaryLiteralOperation instruction) {
@@ -598,7 +582,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 			}
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitCheckCast(CheckCastInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitCheckCast
              */
             @Override
             public void visitCheckCast(CheckCast instruction) {
@@ -613,7 +597,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitConditionalBranch(IConditionalBranchInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitConditionalBranch(IConditionalBranchInstruction)
              */
             @Override
             public void visitBranch(Branch instruction) {
@@ -643,7 +627,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitConstant(ConstantInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitConstant(ConstantInstruction)
              */
             @Override
             public void visitConstant(Constant instruction) {
@@ -710,7 +694,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitConversion(IConversionInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitConversion(IConversionInstruction)
              */
             // TODO: is this just a unary operation?
 //          @Override
@@ -727,7 +711,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 //          }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitGet(IGetInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitGet(IGetInstruction)
              */
             @Override
             public void visitGetField(GetField instruction) {
@@ -763,7 +747,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitGoto(GotoInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitGoto(GotoInstruction)
              */
             @Override
             public void visitGoto(Goto instruction) {
@@ -771,7 +755,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitInstanceof(InstanceofInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitInstanceof
              */
             @Override
             public void visitInstanceof(InstanceOf instruction) {
@@ -786,7 +770,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitInvoke(IInvokeInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitInvoke(IInvokeInstruction)
              */
             @Override
             public void visitInvoke(Invoke instruction) {
@@ -802,7 +786,6 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 
                 Language lang = dexCFG.getMethod().getDeclaringClass().getClassLoader().getLanguage();
                 // TODO: check that the signature needed by findOrCreate can use the descriptor
-                
                 MethodReference m = MethodReference.findOrCreate(lang, loader, instruction.clazzName, instruction.methodName, instruction.descriptor);
 
 
@@ -904,7 +887,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 //          }
 //
 //          /*
-//           * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitLocalStore(com.ibm.wala.shrikeBT.StoreInstruction)
+//           * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitLocalStore(com.ibm.wala.shrikeBT.StoreInstruction)
 //           */
 //          @Override
 //          public void visitLocalStore(IStoreInstruction instruction) {
@@ -915,7 +898,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 //          }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitMonitor(MonitorInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitMonitor(MonitorInstruction)
              */
             @Override
             public void visitMonitor(Monitor instruction) {
@@ -925,7 +908,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitNew(NewInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitNew(NewInstruction)
              */
             @Override
             public void visitNew(New instruction) {
@@ -991,7 +974,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitGet(IGetInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitGet(IGetInstruction)
              */
             @Override
             public void visitPutField(PutField instruction) {
@@ -1012,7 +995,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitReturn(ReturnInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitReturn(ReturnInstruction)
              */
             @Override
             public void visitReturn(Return instruction) {
@@ -1047,7 +1030,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitShift(IShiftInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitShift(IShiftInstruction)
              */
             // TODO: this is just a binary operation
 //          @Override
@@ -1061,7 +1044,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 //          }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitSwitch(SwitchInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitSwitch(SwitchInstruction)
              */
             @Override
             public void visitSwitch(Switch instruction) {
@@ -1105,7 +1088,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitThrow(ThrowInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitThrow(ThrowInstruction)
              */
             @Override
             public void visitThrow(Throw instruction) {
@@ -1124,7 +1107,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
             }
 
             /**
-             * @see com.ibm.wala.shrikeBT.Instruction.Visitor#visitUnaryOp(IUnaryOpInstruction)
+             * @see com.ibm.wala.shrikeBT.IInstruction.Visitor#visitUnaryOp(IUnaryOpInstruction)
              */
             @Override
             public void visitUnaryOperation(UnaryOperation instruction) {
@@ -1288,10 +1271,6 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 
         }
 
-        /**
-         * @param piCause
-         * @param ref
-         */
         private void reuseOrCreatePi(SSAInstruction piCause, int ref) {
             int n = getCurrentInstructionIndex();
             SSACFG.BasicBlock bb = cfg.getBlockForInstruction(n);
@@ -1392,7 +1371,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
     }
 
     /**
-     * A logical mapping from <pc, valueNumber> -> local number Note: make sure this class remains static: this persists as part of
+     * A logical mapping from &lt;pc, valueNumber&gt; -&gt; local number Note: make sure this class remains static: this persists as part of
      * the IR!!
      */
     private static class SSA2LocalMap implements com.ibm.wala.ssa.IR.SSA2LocalMap {
@@ -1400,7 +1379,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
         private final DexCFG dexCFG;
 
         /**
-         * Mapping Integer -> IntPair where p maps to (vn,L) iff we've started a range at pc p where value number vn corresponds to
+         * Mapping Integer -&gt; IntPair where p maps to (vn,L) iff we've started a range at pc p where value number vn corresponds to
          * local L
          */
         private final IntPair[] localStoreMap;
@@ -1434,7 +1413,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
 		void startRange(int pc, int localNumber, int valueNumber) {
             int max = ((DexIMethod)dexCFG.getMethod()).getMaxLocals();
             if (localNumber >= max) {
-                assert false : "invalid local " + localNumber + ">" + max;
+                assert false : "invalid local " + localNumber + '>' + max;
             }
 
             localStoreMap[pc] = new IntPair(valueNumber, localNumber);
@@ -1444,8 +1423,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
          * Finish populating the map of local variable information
          */
         private void finishLocalMap(DexSSABuilder builder) {
-            for (Iterator<BasicBlock> it = dexCFG.iterator(); it.hasNext();) {
-                BasicBlock bb = it.next();
+            for (BasicBlock bb : dexCFG) {
                 MachineState S = builder.getIn(bb);
                 int number = bb.getNumber();
                 block2LocalState[number] = S.getLocals();
@@ -1456,6 +1434,7 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
          * @param index - index into IR instruction array
          * @param vn - value number
          */
+        @Override
         public String[] getLocalNames(int index, int vn) {
             try {
                 if (!dexCFG.getMethod().hasLocalVariableTable()) {
@@ -1516,10 +1495,10 @@ public class DexSSABuilder extends AbstractIntRegisterMachine {
         /**
          * @return the indices i s.t. x[i] == y, or null if none found.
          */
-        private int[] extractIndices(int[] x, int y) {
+        private static int[] extractIndices(int[] x, int y) {
             int count = 0;
-            for (int i = 0; i < x.length; i++) {
-                if (x[i] == y) {
+            for (int element : x) {
+                if (element == y) {
                     count++;
                 }
             }
