@@ -78,7 +78,7 @@ import com.ibm.wala.util.config.SetOfClasses;
  *  Iterates the ClassHierarchy matching its elements to a set of hardcoded entrypoint-specifications.
  *  Then optionally uses heuristics to select further entrypoints.
  *
- *  @author     Tobias Blaschke <code@tobiasblaschke.de>
+ *  @author     Tobias Blaschke &lt;code@tobiasblaschke.de&gt;
  */
 public final class AndroidEntryPointLocator {
     private static final Logger logger = LoggerFactory.getLogger(AndroidEntryPointLocator.class);
@@ -118,7 +118,7 @@ public final class AndroidEntryPointLocator {
         WITH_ANDROID
     }
 
-    private final static List<AndroidPossibleEntryPoint> possibleEntryPoints = new ArrayList<AndroidPossibleEntryPoint>();
+    private final static List<AndroidPossibleEntryPoint> possibleEntryPoints = new ArrayList<>();
     protected final Set<LocatorFlags> flags;
 
     public AndroidEntryPointLocator(final Set<LocatorFlags> flags) {
@@ -146,16 +146,26 @@ public final class AndroidEntryPointLocator {
             throw new IllegalArgumentException("I need a ClassHierarchy to search");
         }
 
-        Set<AndroidEntryPoint> entryPoints = new HashSet<AndroidEntryPoint>();
+        Set<AndroidEntryPoint> entryPoints = new HashSet<>();
 
         mon.beginTask("Locating Entrypoints", IProgressMonitor.UNKNOWN);
         int dummy = 0;  // for the progress monitor
         for (IClass cls : cha) {
             mon.worked(dummy++);
+            if (cls.getName().toString().contains("MainActivity")) {
+            	System.err.println("got here");
+            }
             if (isExcluded(cls)) continue;
-            if (!cls.isInterface() && !cls.isAbstract() && cls.getClassLoader().getName().equals(AnalysisScope.APPLICATION)) {
+            if (!cls.isInterface() && 
+            	!cls.isAbstract() && 
+            	!( cls.getClassLoader().getName().equals(AnalysisScope.PRIMORDIAL) ||
+            	   cls.getClassLoader().getName().equals(AnalysisScope.EXTENSION)
+            	 )) {
 nextMethod:
                 for (final IMethod m : cls.getDeclaredMethods()) {
+                    if (cls.getName().toString().contains("MainActivity")) {
+                    	System.err.println("got here: " + m);
+                    }
                 	// If there is a Method signature in the possible entry points use thatone
                     for (AndroidPossibleEntryPoint e: possibleEntryPoints) {
                         if (e.name.equals(m.getName().toString()) ) {
@@ -173,7 +183,7 @@ nextMethod:
         } // for IClass : cha
 
         if (this.flags.contains(LocatorFlags.EP_HEURISTIC) || this.flags.contains(LocatorFlags.CB_HEURISTIC)) {
-            final Set<TypeReference> bases = new HashSet<TypeReference>();
+            final Set<TypeReference> bases = new HashSet<>();
 
             if (this.flags.contains(LocatorFlags.EP_HEURISTIC)) {
                 // Add bases for EP-Heuristic
@@ -191,7 +201,7 @@ nextMethod:
                     // Restrict the set
                     bases.add(AndroidTypes.Application);
                     bases.add(AndroidTypes.Activity);
-                    /** @todo TODO: add Fragments in getEntryPoints */
+                    /** TODO: TODO: add Fragments in getEntryPoints */
                     //bases.add(AndroidTypes.Fragment);
                     bases.add(AndroidTypes.Service);
                     bases.add(AndroidTypes.ContentProvider);
@@ -206,7 +216,7 @@ nextMethod:
         }
 
 
-        List<AndroidEntryPoint> ret = new ArrayList<AndroidEntryPoint>(entryPoints);
+        List<AndroidEntryPoint> ret = new ArrayList<>(entryPoints);
         Collections.sort(ret, new AndroidEntryPoint.ExecutionOrderComperator());
         mon.done();
         return ret;
@@ -238,7 +248,7 @@ nextMethod:
                     // Don't consider internal overrides
                     continue;
                 }
-                final Collection<IMethod> methods = candid.getDeclaredMethods();
+                final Collection<? extends IMethod> methods = candid.getDeclaredMethods();
                 for (final IMethod method : methods) {
 
 
@@ -249,10 +259,8 @@ nextMethod:
                     if (baseClass.getMethod(method.getSelector()) != null) {
                         final AndroidEntryPoint ep = makeEntryPointForHeuristic(method, cha);
                        
-                        if (! eps.contains(ep)) {  // Just to be sure that a previous element stays as-is
-                            if (eps.add(ep)) {
-                                logger.debug("Heuristic 1: selecting {} for base {}", method, base);
-                            }
+                        if (eps.add(ep)) {  // Just to be sure that a previous element stays as-is
+                            logger.debug("Heuristic 1: selecting {} for base {}", method, base);
                         }
                     }
                 }
@@ -264,7 +272,7 @@ nextMethod:
 //        return test.getName().toString().contains("$"); // PRETTY!
 //    }
 
-    private AndroidEntryPoint makeEntryPointForHeuristic(final IMethod method, final IClassHierarchy cha) {
+    private static AndroidEntryPoint makeEntryPointForHeuristic(final IMethod method, final IClassHierarchy cha) {
         AndroidComponent compo;
         { // Guess component
             compo = AndroidComponent.from(method, cha);
@@ -272,7 +280,7 @@ nextMethod:
 
             }
         }
-        final AndroidEntryPoint ep = new AndroidEntryPoint(selectPositionForHeuristic(method), method, cha, compo);
+        final AndroidEntryPoint ep = new AndroidEntryPoint(selectPositionForHeuristic(), method, cha, compo);
 
         return ep;
     }
@@ -319,7 +327,7 @@ nextMethod:
             { // Overridden methods
                 if (isAPIComponent(appClass)) continue;
                 if (isExcluded(appClass)) continue;
-                final Collection<IMethod> methods = appClass.getDeclaredMethods();
+                final Collection<? extends IMethod> methods = appClass.getDeclaredMethods();
                 for (final IMethod method : methods) {
                     if ((method.isInit() || method.isClinit()) && (! this.flags.contains(LocatorFlags.WITH_CTOR))) {
                         logger.debug("Skipping constructor of {}", method); 
@@ -330,10 +338,9 @@ nextMethod:
                     if (androidClass.getMethod(method.getSelector()) != null) {
                         final AndroidEntryPoint ep = makeEntryPointForHeuristic(method, cha);
 
-                        if (! eps.contains(ep)) {  // Just to be sure that a previous element stays as-is
-                        if (eps.add(ep)) {
+                        if (eps.add(ep)) {  // Just to be sure that a previous element stays as-is
                             logger.debug("Heuristic 2a: selecting {}", method);
-                        }} else {
+                        } else {
                             logger.debug("Heuristic 2a: already selected {}", method);
                         }
                     }
@@ -349,18 +356,17 @@ nextMethod:
                     }
                     if (isExcluded(iFace)) continue;
                     logger.debug("Searching Interface {}", iFace);
-                    final Collection<IMethod> ifMethods = iFace.getDeclaredMethods();
+                    final Collection<? extends IMethod> ifMethods = iFace.getDeclaredMethods();
                     for (final IMethod ifMethod : ifMethods) {
                         final IMethod method = appClass.getMethod(ifMethod.getSelector());
                         if (method != null && method.getDeclaringClass().getClassLoader().getReference().equals(ClassLoaderReference.Application)) {
                             // The function is overridden
-                            final AndroidEntryPoint ep = new AndroidEntryPoint(selectPositionForHeuristic(method), method, cha);
+                            final AndroidEntryPoint ep = new AndroidEntryPoint(selectPositionForHeuristic(), method, cha);
 
-                            if (! eps.contains(ep)) {  // Just to be sure that a previous element stays as-is
-                            if (eps.add(ep)) {
+                            if (eps.add(ep)) {  // Just to be sure that a previous element stays as-is
                                 logger.debug("Heuristic 2b: selecting {}", method);
-                            }}
-                        } else {
+                            }
+                        } else if (method != null) {
                             // The function is taken from the super-class
                             if (this.flags.contains(LocatorFlags.WITH_SUPER)) {
                                 final AndroidEntryPoint ep = makeEntryPointForHeuristic(method, cha);
@@ -370,8 +376,7 @@ nextMethod:
                                     for (final AndroidEntryPoint eps_ep : eps) {
                                         if (eps_ep.equals(ep)) {
                                             final TypeReference[] oldTypes = eps_ep.getParameterTypes(0);
-                                            final TypeReference[] newTypes = new TypeReference[oldTypes.length + 1];
-                                            System.arraycopy(oldTypes, 0, newTypes, 0, oldTypes.length);
+                                            final TypeReference[] newTypes = Arrays.copyOf(oldTypes, oldTypes.length + 1);
                                             newTypes[oldTypes.length] = appClass.getReference();
                                             eps_ep.setParameterTypes(0, newTypes);
                                             logger.debug("New This-Types for {} are {}", method.getSelector(), Arrays.toString(newTypes));
@@ -394,12 +399,13 @@ nextMethod:
         }
     }
 
-    private boolean isAPIComponent(final IMethod method) {
+    private static boolean isAPIComponent(final IMethod method) {
         return isAPIComponent(method.getDeclaringClass());
     }
 
-    private boolean isAPIComponent(final IClass cls) {
-        if (cls.getClassLoader().getReference().equals(ClassLoaderReference.Application)) {
+    private static boolean isAPIComponent(final IClass cls) {
+        ClassLoaderReference clr = cls.getClassLoader().getReference();
+		if (! (clr.equals(ClassLoaderReference.Primordial) || clr.equals(ClassLoaderReference.Extension))) {
             if (cls.getName().toString().startsWith("Landroid/")) {
                 return true;
             }
@@ -409,7 +415,7 @@ nextMethod:
         }
     }
 
-    private boolean isExcluded(final IClass cls) {
+    private static boolean isExcluded(final IClass cls) {
     	final SetOfClasses set = cls.getClassHierarchy().getScope().getExclusions();
     	if (set == null) {
     		return false; // exclusions null ==> no exclusions ==> no class is excluded
@@ -424,7 +430,7 @@ nextMethod:
      *
      *  Currently all methods are placed at ExecutionOrder.MULTIPLE_TIMES_IN_LOOP.
      */
-    private ExecutionOrder selectPositionForHeuristic(IMethod method) {
+    private static ExecutionOrder selectPositionForHeuristic() {
         return ExecutionOrder.MULTIPLE_TIMES_IN_LOOP;
     }
 
@@ -443,21 +449,22 @@ nextMethod:
         private final String name;
         public final AndroidEntryPoint.ExecutionOrder order;
 
-        public AndroidPossibleEntryPoint(AndroidComponent c, String n, ExecutionOrder o) { 
+        public AndroidPossibleEntryPoint(String n, ExecutionOrder o) {
 //            cls = c; 
             name = n; 
             order = o; 
         }
  
-        public AndroidPossibleEntryPoint(AndroidComponent c, String n, AndroidPossibleEntryPoint o) { 
+        public AndroidPossibleEntryPoint(String n, AndroidPossibleEntryPoint o) {
 //            cls = c; 
             name = n; 
             order = o.order; 
         }
        
-        public int getOrderValue() { return order.getOrderValue(); }
-        public int compareTo(AndroidEntryPoint.IExecutionOrder o) { return order.compareTo(o); }
-        public AndroidEntryPoint.ExecutionOrder getSection() { return order.getSection(); }
+        @Override public int getOrderValue() { return order.getOrderValue(); }
+        @Override public int compareTo(AndroidEntryPoint.IExecutionOrder o) { return order.compareTo(o); }
+        @Override public AndroidEntryPoint.ExecutionOrder getSection() { return order.getSection(); }
+
         public static class ExecutionOrderComperator implements Comparator<AndroidPossibleEntryPoint> {
             @Override public int compare(AndroidPossibleEntryPoint a, AndroidPossibleEntryPoint b) {
                 return a.order.compareTo(b.order);
