@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2013 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ide.util;
 
 import static com.ibm.wala.ide.util.JdtUtil.getAST;
@@ -28,7 +28,7 @@ public class ASTNodeFinder {
 	public ASTNode getASTNode(JdtPosition pos) {
 		IFile sourceFile = pos.getEclipseFile();
 		if (!fileASTs.containsKey(sourceFile) || fileASTs.get(sourceFile).get() == null) {
-			fileASTs.put(sourceFile, new SoftReference<ASTNode>(getAST(sourceFile)));
+			fileASTs.put(sourceFile, new SoftReference<>(getAST(sourceFile)));
 		}
 		
 		return getOriginalNode(fileASTs.get(sourceFile).get(), pos);
