@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,10 +7,11 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ide.util;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
@@ -97,7 +98,7 @@ public class JdtUtil {
     ICompilationUnit cu = (ICompilationUnit) type.getParent();
     String packageName = getPackageName(cu);
     String className = type.getElementName();
-    String fullyQName = packageName + "." + className;
+    String fullyQName = packageName + '.' + className;
     return fullyQName;
   }
 
@@ -114,9 +115,8 @@ public class JdtUtil {
    * used as a handle to create JavaElement by 'JavaCore.create(String)'
    * 
    * For example, suppose we have the method 'fooPackage.barPackage.FooClass.fooMethod(int)' which is in the 'FooProject' and source
-   * folder 'src' the handle would be '=FooProject/src<fooPackage.barPackage{FooClass.java[FooClass~fooMethod~I'
+   * folder 'src' the handle would be '=FooProject/src&lt;fooPackage.barPackage{FooClass.java[FooClass~fooMethod~I'
    * 
-   * @param javaElt
    * @throws IllegalArgumentException if javaElt is null
    */
   public static String getJdtHandleString(IJavaElement javaElt) {
@@ -311,7 +311,7 @@ public class JdtUtil {
       // and failed. implementing a miserable hack instead.
       // Need to consult a guru to figure out how to do this.
       try {
-        List<IMethod> matches = new ArrayList<IMethod>();
+        List<IMethod> matches = new ArrayList<>();
         Collection<String> typeParameterNames = getTypeParameterNames(type);
         METHODS: for (IMethod x : type.getMethods()) {
           if (x.getElementName().equals(name)) {
@@ -370,7 +370,7 @@ public class JdtUtil {
         return result;
       }
     } catch (StringIndexOutOfBoundsException e) {
-      throw new IllegalArgumentException("invalid selector: " + selector);
+      throw new IllegalArgumentException("invalid selector: " + selector, e);
     }
   }
 
@@ -389,7 +389,7 @@ public class JdtUtil {
         throw new IllegalArgumentException("invalid descriptor: " + d);
       }
 
-      ArrayList<String> sigs = new ArrayList<String>(10);
+      ArrayList<String> sigs = new ArrayList<>(10);
 
       int i = 1;
       while (true) {
@@ -444,7 +444,7 @@ public class JdtUtil {
           do {
             c = d.charAt(i++);
           } while (c != ',' && c != ')');
-          sigs.add("L" + d.substring(off, i - 1) + ";");
+          sigs.add('L' + d.substring(off, i - 1) + ';');
 
           if (c == ')') {
             return toArray(sigs);
@@ -455,7 +455,7 @@ public class JdtUtil {
         }
       }
     } catch (StringIndexOutOfBoundsException e) {
-      throw new IllegalArgumentException("error parsing selector " + selector);
+      throw new IllegalArgumentException("error parsing selector " + selector, e);
     }
   }
 
@@ -505,7 +505,7 @@ public class JdtUtil {
     if (kludge.size() == 1) {
       return (IMethod) kludge.iterator().next();
     } else {
-      System.err.println("RETURNED " + kludge.size() + " " + kludge);
+      System.err.println("RETURNED " + kludge.size() + ' ' + kludge);
       return null;
     }
   }
@@ -519,9 +519,7 @@ public class JdtUtil {
       Collection<IMethod> result = HashSetFactory.make();
       for (IType type : getClasses((ICompilationUnit) elt)) {
         try {
-          for (IMethod m : type.getMethods()) {
-            result.add(m);
-          }
+          result.addAll(Arrays.asList(type.getMethods()));
         } catch (JavaModelException e) {
           e.printStackTrace();
         }
@@ -578,7 +576,7 @@ public class JdtUtil {
   }
 
   public static ASTNode getAST(IFile javaSourceFile) {
-	  ASTParser parser = ASTParser.newParser(AST.JLS3);
+	  @SuppressWarnings("deprecation") ASTParser parser = ASTParser.newParser(AST.JLS3);
 	  parser.setSource(JavaCore.createCompilationUnitFrom(javaSourceFile));
 	  parser.setProject(JavaCore.create(javaSourceFile.getProject()));
 	  parser.setResolveBindings(true);
