@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.ide.ui;
 
 import org.eclipse.jface.window.ApplicationWindow;
@@ -46,12 +46,6 @@ public abstract class AbstractJFaceRunner  {
 
   @Override
   public String toString() {
-    StringBuffer result = new StringBuffer(super.toString());
-    result.append(" (applicationWindow: ");
-    result.append(applicationWindow);
-    result.append(", blockInput: ");
-    result.append(blockInput);
-    result.append(')');
-    return result.toString();
+    return super.toString() + " (applicationWindow: " + applicationWindow + ", blockInput: " + blockInput + ')';
   }
 } 
