@@ -76,7 +76,6 @@ import org.scandroid.util.CGAnalysisContext;
 
 import com.ibm.wala.classLoader.IMethod;
 import com.ibm.wala.dataflow.IFDS.ICFGSupergraph;
-import com.ibm.wala.dataflow.IFDS.ISupergraph;
 import com.ibm.wala.dataflow.IFDS.TabulationResult;
 import com.ibm.wala.ipa.callgraph.CGNode;
 import com.ibm.wala.ipa.callgraph.CallGraph;
@@ -122,13 +121,13 @@ public class OutflowAnalysis {
 		this.specs = specs;
 	}
 
-	private void addEdge(
+	private static void addEdge(
 			Map<FlowType<IExplodedBasicBlock>, Set<FlowType<IExplodedBasicBlock>>> graph,
 			FlowType<IExplodedBasicBlock> source,
 			FlowType<IExplodedBasicBlock> dest) {
 		Set<FlowType<IExplodedBasicBlock>> dests = graph.get(source);
 		if (dests == null) {
-			dests = new HashSet<FlowType<IExplodedBasicBlock>>();
+			dests = new HashSet<>();
 			graph.put(source, dests);
 		}
 		dests.add(dest);
@@ -141,7 +140,7 @@ public class OutflowAnalysis {
 			IFDSTaintDomain<IExplodedBasicBlock> domain,
 			Map<FlowType<IExplodedBasicBlock>, Set<FlowType<IExplodedBasicBlock>>> flowGraph,
 			List<SinkSpec> sinkSpecs) {
-		List<Collection<IMethod>> targetList = new ArrayList<Collection<IMethod>>();
+		List<Collection<IMethod>> targetList = new ArrayList<>();
 
 		for (int i = 0; i < sinkSpecs.size(); i++) {
 			Collection<IMethod> tempList = sinkSpecs.get(i).getNamePattern()
@@ -186,13 +185,13 @@ public class OutflowAnalysis {
 						CGNode node = block.getNode();
 
 						IntSet resultSet = flowResult.getResult(block);
-						for (int j = 0; j < argNums.length; j++) {
+						for (int argNum : argNums) {
 
 							// The set of flow types we're looking for:
 							Set<FlowType<IExplodedBasicBlock>> taintTypeSet = HashSetFactory.make();
 
 							LocalElement le = new LocalElement(
-									invInst.getUse(argNums[j]));
+									invInst.getUse(argNum));
 							Set<DomainElement> elements = domain
 									.getPossibleElements(le);
 							if (elements != null) {
@@ -205,7 +204,7 @@ public class OutflowAnalysis {
 							}
 
 							LocalPointerKey lpkey = new LocalPointerKey(node,
-									invInst.getUse(argNums[j]));
+									invInst.getUse(argNum));
 							for (InstanceKey ik : pa.getPointsToSet(lpkey)) {
 								for (DomainElement de : domain
 										.getPossibleElements(new InstanceKeyElement(
@@ -276,12 +275,12 @@ public class OutflowAnalysis {
 			//
 			// }
 			// }
-			for (int i = 0; i < newArgNums.length; i++) {
+			for (int newArgNum : newArgNums) {
 
 				// see if anything flowed into the args as sinks:
 				for (DomainElement de : domain
 						.getPossibleElements(new LocalElement(node.getIR()
-								.getParameter(newArgNums[i])))) {
+								.getParameter(newArgNum)))) {
 
 					for (BasicBlockInContext<IExplodedBasicBlock> block : graph
 							.getExitsForProcedure(node)) {
@@ -289,29 +288,29 @@ public class OutflowAnalysis {
 						int mappedIndex = domain.getMappedIndex(de);
 						if (flowResult.getResult(block).contains(mappedIndex)) {
 							addEdge(flowGraph, de.taintSource,
-									new ParameterFlow<IExplodedBasicBlock>(
-											entryBlock, newArgNums[i], false));
+									new ParameterFlow<>(
+											entryBlock, newArgNum, false));
 						}
 					}
 
 					int mappedIndex = domain.getMappedIndex(de);
 					if (flowResult.getResult(entryBlock).contains(mappedIndex)) {
 						addEdge(flowGraph, de.taintSource,
-								new ParameterFlow<IExplodedBasicBlock>(
-										entryBlock, newArgNums[i], false));
+								new ParameterFlow<>(
+										entryBlock, newArgNum, false));
 					}
 
 				}
 				for (InstanceKey ik : pa.getPointsToSet(new LocalPointerKey(
-						node, node.getIR().getParameter(newArgNums[i])))) {
+						node, node.getIR().getParameter(newArgNum)))) {
 					for (DomainElement de : domain
 							.getPossibleElements(new InstanceKeyElement(ik))) {
 						if (flowResult.getResult(entryBlock).contains(
 								domain.getMappedIndex(de))) {
 							
 							addEdge(flowGraph, de.taintSource,
-									new ParameterFlow<IExplodedBasicBlock>(
-											entryBlock, newArgNums[i], false));
+									new ParameterFlow<>(
+											entryBlock, newArgNum, false));
 						}
 					}
 				}
@@ -352,7 +351,7 @@ public class OutflowAnalysis {
 							domain.getMappedIndex(de))) {
 						
 						addEdge(flowGraph, de.taintSource,
-								new ReturnFlow<IExplodedBasicBlock>(block,
+								new ReturnFlow<>(block,
 										false));
 					}
 					// Iterator<BasicBlockInContext<E>> it =
@@ -395,7 +394,7 @@ public class OutflowAnalysis {
 										domain.getMappedIndex(ikElement))) {
 									addEdge(flowGraph,
 											ikElement.taintSource,
-											new ReturnFlow<IExplodedBasicBlock>(
+											new ReturnFlow<>(
 													realBlock, false));
 								}
 							}
@@ -409,17 +408,13 @@ public class OutflowAnalysis {
 	public Map<FlowType<IExplodedBasicBlock>, Set<FlowType<IExplodedBasicBlock>>> analyze(
 			TabulationResult<BasicBlockInContext<IExplodedBasicBlock>, CGNode, DomainElement> flowResult,
 			IFDSTaintDomain<IExplodedBasicBlock> domain) {
-		return analyze(ctx.cg, ctx.getClassHierarchy(), ctx.graph, ctx.pa,
-				flowResult, domain, specs);
+		return analyze(flowResult, domain, specs);
 	}
 
 	public Map<FlowType<IExplodedBasicBlock>, Set<FlowType<IExplodedBasicBlock>>> analyze(
-			CallGraph cg,
-			ClassHierarchy cha,
-			ISupergraph<BasicBlockInContext<IExplodedBasicBlock>, CGNode> graph,
-			PointerAnalysis<InstanceKey> pa,
 			TabulationResult<BasicBlockInContext<IExplodedBasicBlock>, CGNode, DomainElement> flowResult,
-			IFDSTaintDomain<IExplodedBasicBlock> domain, ISpecs s) {
+			IFDSTaintDomain<IExplodedBasicBlock> domain,
+			ISpecs s) {
 
 		
 		
@@ -430,15 +425,15 @@ public class OutflowAnalysis {
 		SinkSpec[] ss = s.getSinkSpecs();
 		
 
-		for (int i = 0; i < ss.length; i++) {
-			if (ss[i] instanceof EntryArgSinkSpec)
-				processSinkSpec(flowResult, domain, taintFlow, ss[i]);
-			else if (ss[i] instanceof CallArgSinkSpec)
-				processSinkSpec(flowResult, domain, taintFlow, ss[i]);
-			else if (ss[i] instanceof EntryRetSinkSpec)
-				processSinkSpec(flowResult, domain, taintFlow, ss[i]);
-			else if (ss[i] instanceof StaticFieldSinkSpec)
-				processSinkSpec(flowResult, domain, taintFlow, ss[i]);
+		for (SinkSpec element : ss) {
+			if (element instanceof EntryArgSinkSpec)
+				processSinkSpec(flowResult, domain, taintFlow, element);
+			else if (element instanceof CallArgSinkSpec)
+				processSinkSpec(flowResult, domain, taintFlow, element);
+			else if (element instanceof EntryRetSinkSpec)
+				processSinkSpec(flowResult, domain, taintFlow, element);
+			else if (element instanceof StaticFieldSinkSpec)
+				processSinkSpec(flowResult, domain, taintFlow, element);
 			else
 				throw new UnsupportedOperationException(
 						"SinkSpec not yet Implemented");
@@ -526,7 +521,7 @@ public class OutflowAnalysis {
 						.getICFG().getExit(node);
 				for (int argNum : sinkSpec.getArgNums()) {
 					final int ssaVal = node.getIR().getParameter(argNum);
-					final ParameterFlow<IExplodedBasicBlock> sinkFlow = new ParameterFlow<IExplodedBasicBlock>(
+					final ParameterFlow<IExplodedBasicBlock> sinkFlow = new ParameterFlow<>(
 							entryBlock, argNum, false);
 					final LocalSinkPoint sinkPoint = new LocalSinkPoint(
 							exitBlock, ssaVal, sinkFlow);
@@ -588,13 +583,13 @@ public class OutflowAnalysis {
 							final IExplodedBasicBlock block = graph.getICFG()
 									.getCFG(caller)
 									.getBlockForInstruction(invokeIndex);
-							BasicBlockInContext<IExplodedBasicBlock> callBlock = new BasicBlockInContext<IExplodedBasicBlock>(
+							BasicBlockInContext<IExplodedBasicBlock> callBlock = new BasicBlockInContext<>(
 									caller, block);
 
 							for (int argNum : sinkSpec.getArgNums()) {
 								// and add a sink point for each arg num
 								final int ssaVal = invokeInst.getUse(argNum);
-								final ParameterFlow<IExplodedBasicBlock> sinkFlow = new ParameterFlow<IExplodedBasicBlock>(
+								final ParameterFlow<IExplodedBasicBlock> sinkFlow = new ParameterFlow<>(
 										callBlock, argNum, false);
 								final LocalSinkPoint sinkPoint = new LocalSinkPoint(
 										callBlock, ssaVal, sinkFlow);
@@ -639,7 +634,7 @@ public class OutflowAnalysis {
 						SSAReturnInstruction returnInst = (SSAReturnInstruction) inst;
 						if (!returnInst.returnsVoid()) {
 							final int ssaVal = returnInst.getResult();
-							final ReturnFlow<IExplodedBasicBlock> sinkFlow = new ReturnFlow<IExplodedBasicBlock>(
+							final ReturnFlow<IExplodedBasicBlock> sinkFlow = new ReturnFlow<>(
 									exitBlock, false);
 							final LocalSinkPoint sinkPoint = new LocalSinkPoint(
 									exitBlock, ssaVal, sinkFlow);
