@@ -104,7 +104,7 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
     /**
      * XML elements that represent the ssa instructions
      */
-    private final List<Element> summary = new ArrayList<Element>();
+    private final List<Element> summary = new ArrayList<>();
 
     public SSAtoXMLVisitor(Document doc, int argCount) {
         this.doc = doc;
@@ -119,9 +119,9 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
     }
 
     /**
-     * Load from an array ref, at specified index, and store in def.
+     * <p>Load from an array ref, at specified index, and store in def.</p>
      * 
-     *   <aaload ref="x" index="0" def="y" />
+     *   {@code <aaload ref="x" index="0" def="y" />}
      */
     @Override
     public void visitArrayLoad(SSAArrayLoadInstruction instruction) {
@@ -134,7 +134,7 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
             String defStr = getLocalName(instruction.getDef());
             elt.setAttribute(XMLSummaryWriter.A_VALUE, defStr);
             
-            elt.setAttribute(XMLSummaryWriter.A_INDEX, ""+instruction.getIndex());
+            elt.setAttribute(XMLSummaryWriter.A_INDEX, String.valueOf(instruction.getIndex()));
             summary.add(elt);
         } catch (Exception e) {
             throw new SSASerializationException(e);
@@ -142,7 +142,7 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
     }
 
     /**
-     *    <aastore ref="x" value="y" index="0" />
+     *    {@code <aastore ref="x" value="y" index="0" />}
      */
     @Override
     public void visitArrayStore(SSAArrayStoreInstruction instruction) {
@@ -155,7 +155,7 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
             String valueStr = getLocalName(instruction.getValue());
             elt.setAttribute(XMLSummaryWriter.A_VALUE, valueStr);
             
-            elt.setAttribute(XMLSummaryWriter.A_INDEX, ""+instruction.getIndex());
+            elt.setAttribute(XMLSummaryWriter.A_INDEX, String.valueOf(instruction.getIndex()));
             summary.add(elt);
         } catch (Exception e) {
             throw new SSASerializationException(e);
@@ -208,15 +208,15 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
     }
 
     /**
-     * eg:
+     * <p>eg:</p>
      * 
-     * <getfield class="Ljava/lang/Thread" field="runnable"
-     * fieldType="Ljava/lang/Runnable" def="x" ref="arg0" />
+     * {@code <getfield class="Ljava/lang/Thread" field="runnable"
+     * fieldType="Ljava/lang/Runnable" def="x" ref="arg0" />}
      * 
-     * I think the get statics look like this:
-     * 1007g 9.1g  12m S 237.9  0.9   4:27.32 java
-     * <getstatic class="Ljava/lang/Thread" field="runnable"
-     * fieldType="Ljava/lang/Runnable" def="x" />
+     * <p>I think the get statics look like this:</p>
+     * <p>1007g 9.1g  12m S 237.9  0.9   4:27.32 java</p>
+     * {@code <getstatic class="Ljava/lang/Thread" field="runnable"
+     * fieldType="Ljava/lang/Runnable" def="x" />}
      */
     @Override
     public void visitGet(SSAGetInstruction instruction) {
@@ -256,11 +256,11 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
     }
 
     /**
-     * <putstatic class="Ljava/lang/System" field="security"
-     * fieldType="Ljava/lang/SecurityManager" value="secure" />
+     * <p>{@code <putstatic class="Ljava/lang/System" field="security"
+     * fieldType="Ljava/lang/SecurityManager" value="secure" />}</p>
      * 
-     * <putfield class="Ljava/lang/Thread" field="runnable"
-     * fieldType="Ljava/lang/Runnable" ref="arg0" value="arg0" />
+     * <p>{@code <putfield class="Ljava/lang/Thread" field="runnable"
+     * fieldType="Ljava/lang/Runnable" ref="arg0" value="arg0" />}</p>
      * 
      */
     @Override
@@ -302,10 +302,10 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
     }
 
     /**
-     * 	  <call type="virtual" name="put"
+     * 	  {@code <call type="virtual" name="put"
 	 *          class="Ljava/util/Hashtable"
 	 *          descriptor="(Ljava/lang/Object;Ljava/lang/Object;)Ljava/lang/Object;"
-	 *          arg0="x" arg1="key" arg2="value" def="local_def" />
+	 *          arg0="x" arg1="key" arg2="value" def="local_def" />}
      */
     @Override
     public void visitInvoke(SSAInvokeInstruction instruction) {
@@ -333,7 +333,7 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
                 elt.setAttribute(XMLSummaryWriter.A_DEF, localName);
             }
 
-            int paramCount = instruction.getNumberOfParameters();
+            int paramCount = instruction.getNumberOfPositionalParameters();
             for (int i=0; i < paramCount; i++) {
             	String argName = getLocalName(instruction.getUse(i));
             	elt.setAttribute(XMLSummaryWriter.A_ARG+i, argName);
@@ -384,11 +384,11 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
     }
 
     /**
-     * Serialiaze a throw to XML.
+     * <p>Serialiaze a throw to XML.</p>
      * 
-     * Something like this?
+     * <p>Something like this?</p>
      * 
-     * <throw value="val_localDef" /> 
+     * {@code <throw value="val_localDef" />}
      */
     @Override
     public void visitThrow(SSAThrowInstruction instruction) {
@@ -443,8 +443,6 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
 
     /**
      * Add a new defNum, creating a name for that defnum.
-     * 
-     * @param defNum
      */
     private String newLocalDef(int defNum) {
         String newName = "localdef_" + defCounter;
@@ -461,12 +459,7 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
      * local name associated with it) then this will throw an illegal state
      * exception.
      *
-     * TODO needs to return 'arg0' -> 'argN' for those value numbers...
-     *
-     * @param defNum
-     *
-     * @return
-     * @throws IllegalStateException
+     * TODO needs to return 'arg0' -&gt; 'argN' for those value numbers...
      */
     private String getLocalName(int defNum) throws IllegalStateException {
     	if (0 == defNum) {
@@ -486,7 +479,7 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
     }
 
     @SuppressWarnings("unused")
-	private String typeRefToStr(TypeReference fieldType)
+	private static String typeRefToStr(TypeReference fieldType)
             throws UTFDataFormatException {
         Atom className = fieldType.getName().getClassName();
         Atom pkgName = fieldType.getName().getPackage();
@@ -499,7 +492,7 @@ public class SSAtoXMLVisitor implements SSAInstruction.IVisitor {
         	
         }
         
-        return pkgName.toUnicodeString() + "/" + className.toUnicodeString();
+        return pkgName.toUnicodeString() + '/' + className.toUnicodeString();
     }
 
 }
