@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002,2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.shrikeBT;
 
 import com.ibm.wala.shrikeCT.BootstrapMethodsReader.BootstrapMethod;
@@ -318,7 +318,7 @@ public abstract class ConstantInstruction extends Instruction {
 
     @Override
     final public Object getValue() {
-      return new Float(getFloatValue());
+      return Float.valueOf(getFloatValue());
     }
 
     @Override
@@ -390,7 +390,7 @@ public abstract class ConstantInstruction extends Instruction {
 
     @Override
     final public Object getValue() {
-      return new Double(getDoubleValue());
+      return Double.valueOf(getDoubleValue());
     }
 
     @Override
@@ -845,7 +845,7 @@ public abstract class ConstantInstruction extends Instruction {
   private static String quote(Object o) {
     if (o instanceof String) {
       String s = (String) o;
-      StringBuffer buf = new StringBuffer("\"");
+      StringBuilder buf = new StringBuilder("\"");
       int len = s.length();
       for (int i = 0; i < len; i++) {
         char ch = s.charAt(i);
@@ -864,7 +864,7 @@ public abstract class ConstantInstruction extends Instruction {
           buf.append(ch);
         }
       }
-      buf.append("\"");
+      buf.append('\"');
       return buf.toString();
     } else if (o == null) {
       return "null";
@@ -875,7 +875,7 @@ public abstract class ConstantInstruction extends Instruction {
 
   @Override
   final public String toString() {
-    return "Constant(" + getType() + "," + quote(getValue()) + ")";
+    return "Constant(" + getType() + ',' + quote(getValue()) + ')';
   }
 
   @Override
