@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002,2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,10 +7,11 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.shrikeBT;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.IdentityHashMap;
 
 /**
@@ -145,7 +146,7 @@ public final class MethodEditor {
     }
   }
 
-  private String getStateMessage(int state) {
+  private static String getStateMessage(int state) {
     switch (state) {
     case BEFORE_PASS:
       return "This operation can only be performed before or after an editing pass";
@@ -190,8 +191,7 @@ public final class MethodEditor {
     } else if (h2.length == 0) {
       return h1;
     } else {
-      ExceptionHandler[] r = new ExceptionHandler[h1.length + h2.length];
-      System.arraycopy(h1, 0, r, 0, h1.length);
+      ExceptionHandler[] r = Arrays.copyOf(h1, h1.length + h2.length);
       System.arraycopy(h2, 0, r, h1.length, h2.length);
       return r;
     }
@@ -201,9 +201,9 @@ public final class MethodEditor {
    * Output is the interface that patches use to emit their code into a method body.
    */
   public final static class Output {
-    final ArrayList<IInstruction> newInstructions = new ArrayList<IInstruction>();
+    final ArrayList<IInstruction> newInstructions = new ArrayList<>();
 
-    final ArrayList<ExceptionHandler[]> newInstructionHandlers = new ArrayList<ExceptionHandler[]>();
+    final ArrayList<ExceptionHandler[]> newInstructionHandlers = new ArrayList<>();
 
     int[] instructionsToBytecodes = new int[10];
 
@@ -243,9 +243,7 @@ public final class MethodEditor {
 
       int s = newInstructions.size();
       if (s + 1 > instructionsToBytecodes.length) {
-        int[] t = new int[instructionsToBytecodes.length * 2];
-        System.arraycopy(instructionsToBytecodes, 0, t, 0, instructionsToBytecodes.length);
-        instructionsToBytecodes = t;
+        instructionsToBytecodes = Arrays.copyOf(instructionsToBytecodes, instructionsToBytecodes.length * 2);
       }
 
       instructionsToBytecodes[s] = originalBytecode;
@@ -256,9 +254,7 @@ public final class MethodEditor {
     void internalEmitInstruction(IInstruction i) {
       int s = newInstructions.size();
       if (s + 1 > instructionsToBytecodes.length) {
-        int[] t = new int[instructionsToBytecodes.length * 2];
-        System.arraycopy(instructionsToBytecodes, 0, t, 0, instructionsToBytecodes.length);
-        instructionsToBytecodes = t;
+        instructionsToBytecodes = Arrays.copyOf(instructionsToBytecodes, instructionsToBytecodes.length * 2);
       }
 
       instructionsToBytecodes[s] = originalBytecode;
@@ -285,9 +281,7 @@ public final class MethodEditor {
 
       int s = newInstructions.size();
       if (s + instrs.length > instructionsToBytecodes.length) {
-        int[] t = new int[instructionsToBytecodes.length * 2 + instrs.length];
-        System.arraycopy(instructionsToBytecodes, 0, t, 0, instructionsToBytecodes.length);
-        instructionsToBytecodes = t;
+        instructionsToBytecodes = Arrays.copyOf(instructionsToBytecodes, instructionsToBytecodes.length * 2 + instrs.length);
       }
 
       ExceptionHandler[] hs = mergeHandlers(handlers, additionalHandlers);
@@ -415,7 +409,7 @@ public final class MethodEditor {
       }
       patchCount++;
     } catch (ArrayIndexOutOfBoundsException e) {
-      throw new IllegalArgumentException("invalid i");
+      throw new IllegalArgumentException("invalid i", e);
     }
   }
 
@@ -454,7 +448,7 @@ public final class MethodEditor {
       instructionHandlerPatches[i] = new HandlerPatch(instructionHandlerPatches[i], catchClass, allocateLabel(), p);
       patchCount++;
     } catch (ArrayIndexOutOfBoundsException e) {
-      throw new IllegalArgumentException("invalid i: " + i);
+      throw new IllegalArgumentException("invalid i: " + i, e);
     }
   }
 
@@ -640,11 +634,11 @@ public final class MethodEditor {
       ExceptionHandler[] hs = handlers[i];
       if (hs.length > 0 && (i == 0 || hs != handlers[i - 1])) {
         if (adjustedHandlers == null) {
-          adjustedHandlers = new IdentityHashMap<ExceptionHandler, Object>();
+          adjustedHandlers = new IdentityHashMap<>();
         }
 
-        for (int j = 0; j < hs.length; j++) {
-          ExceptionHandler h = hs[j];
+        for (ExceptionHandler element : hs) {
+          ExceptionHandler h = element;
           if (!adjustedHandlers.containsKey(h)) {
             adjustedHandlers.put(h, null);
             h.handler = labelDefs[h.handler]; // breaks invariant of ExceptionHandler: immutable!
@@ -732,4 +726,4 @@ public final class MethodEditor {
       editor.addInstructionExceptionHandler(index, catchClass, p);
     }
   }
-}
\ No newline at end of file
+}
