@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002,2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.shrikeBT;
 
 import java.io.IOException;
@@ -19,7 +19,6 @@ import java.util.Arrays;
 import java.util.HashMap;
 
 import com.ibm.wala.shrikeBT.IInvokeInstruction.Dispatch;
-import com.ibm.wala.shrikeCT.BootstrapMethodsReader.BootstrapMethod;
 import com.ibm.wala.util.collections.Pair;
 
 /**
@@ -110,7 +109,7 @@ public final class Util {
     if (c.startsWith("[")) {
       return c.replace('.', '/');
     } else if (!c.endsWith(";")) {
-      return "L" + c.replace('.', '/') + ";";
+      return 'L' + c.replace('.', '/') + ';';
     } else {
       return c;
     }
@@ -169,8 +168,8 @@ public final class Util {
   }
 
   static {
-    typeAliases = new HashMap<String, String>();
-    classAliases = new HashMap<String, String>();
+    typeAliases = new HashMap<>();
+    classAliases = new HashMap<>();
     addAlias("void", "V");
     addAlias("int", "I");
     addAlias("long", "J");
@@ -206,7 +205,7 @@ public final class Util {
    * 
    * @throws IllegalArgumentException if type == null
    */
-  static int getParamsCount(String type) throws IllegalArgumentException {
+  public static int getParamsCount(String type) throws IllegalArgumentException {
     if (type == null || type.length() < 2) {
       throw new IllegalArgumentException("invalid type: " + type);
     }
@@ -220,7 +219,7 @@ public final class Util {
       }
       return count;
     } catch (StringIndexOutOfBoundsException e) {
-      throw new IllegalArgumentException("invalid type: " + type);
+      throw new IllegalArgumentException("invalid type: " + type, e);
     }
   }
 
@@ -306,7 +305,7 @@ public final class Util {
    * Compute the type "array of t".
    */
   public static String makeArray(String t) {
-    return ("[" + t).intern();
+    return ('[' + t).intern();
   }
 
   /**
@@ -371,12 +370,12 @@ public final class Util {
     if (params == null) {
       throw new IllegalArgumentException("params == null");
     }
-    StringBuffer buf = new StringBuffer();
-    buf.append("(");
-    for (int i = 0; i < params.length; i++) {
-      buf.append(makeType(params[i]));
+    StringBuilder buf = new StringBuilder();
+    buf.append('(');
+    for (Class<?> param : params) {
+      buf.append(makeType(param));
     }
-    buf.append(")");
+    buf.append(')');
     buf.append(makeType(result));
     return buf.toString();
   }
@@ -425,15 +424,15 @@ public final class Util {
     if (paramTypes == null) {
       return name;
     } else {
-      StringBuffer buf = new StringBuffer(name);
-      buf.append("(");
+      StringBuilder buf = new StringBuilder(name);
+      buf.append('(');
       for (int i = 0; i < paramTypes.length; i++) {
         if (i > 0) {
-          buf.append(",");
+          buf.append(',');
         }
         buf.append(paramTypes[i].getName());
       }
-      buf.append(")");
+      buf.append(')');
       return buf.toString();
     }
   }
@@ -448,8 +447,7 @@ public final class Util {
     }
     Method[] methods = c.getMethods();
     Method result = null;
-    for (int i = 0; i < methods.length; i++) {
-      Method m = methods[i];
+    for (Method m : methods) {
       if (m.getName().equals(name) && (paramTypes == null || Arrays.equals(m.getParameterTypes(), paramTypes))) {
         if (result != null) {
           throw new IllegalArgumentException("Method " + makeName(name, paramTypes) + " is ambiguous in class " + c);
@@ -474,8 +472,7 @@ public final class Util {
 
     if (name.equals("<init>")) {
       Constructor<?>[] cs = c.getConstructors();
-      for (int i = 0; i < cs.length; i++) {
-        Constructor<?> con = cs[i];
+      for (Constructor<?> con : cs) {
         if (paramTypes == null || Arrays.equals(con.getParameterTypes(), paramTypes)) {
           if (result != null) {
             throw new IllegalArgumentException("Constructor " + makeName(name, paramTypes) + " is ambiguous in class " + c);
@@ -593,8 +590,7 @@ public final class Util {
     if (b < 0) {
       return bytes;
     } else {
-      byte[] big = new byte[bytes.length * 2 + 1];
-      System.arraycopy(bytes, 0, big, 0, bytes.length);
+      byte[] big = Arrays.copyOf(bytes, bytes.length * 2 + 1);
       big[bytes.length] = (byte) b;
       int offset = bytes.length + 1;
       do {
@@ -660,4 +656,4 @@ public final class Util {
 
     return Pair.make(r, catchers);
   }
-}
\ No newline at end of file
+}
