@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002,2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.shrikeCT;
 
 /**
@@ -65,7 +65,7 @@ public final class ClassReader implements ClassConstants {
       throw new InvalidClassFileException(offset, "bad magic number: " + magic);
     }
     if (majorVersion < 45 || majorVersion > 52) {
-      throw new InvalidClassFileException(offset, "unknown class file version: " + majorVersion + "." + minorVersion);
+      throw new InvalidClassFileException(offset, "unknown class file version: " + majorVersion + '.' + minorVersion);
     }
     
     cpParser = new ConstantPoolParser(bytes, offset, constantPoolCount);
@@ -325,6 +325,13 @@ public final class ClassReader implements ClassConstants {
   public byte getByte(int i) {
     return bytes[i];
   }
+  
+  /**
+   * @return the unsigned 8-bit value at offset i in the class data
+   */
+  public int getUnsignedByte(int i) {
+    return bytes[i] & 0xff;
+  }
 
   /**
    * @return the number of fields in the class
