@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002,2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.shrikeCT;
 
 import com.ibm.wala.shrikeCT.BootstrapMethodsReader.BootstrapMethod;
@@ -119,7 +119,6 @@ public final class ConstantPoolParser implements ClassConstants {
    * @param bytes the raw class file data
    * @param offset the start of the constant pool data
    * @param itemCount the number of items in the pool
-   * @param classReader 
    */
   public ConstantPoolParser(byte[] bytes, int offset, int itemCount) throws InvalidClassFileException {
     this.bytes = bytes;
@@ -438,7 +437,7 @@ public final class ConstantPoolParser implements ClassConstants {
   /**
    * @return the value of the Integer at constant pool item i
    */
-  public int getCPInt(int i) throws InvalidClassFileException, IllegalArgumentException {
+  public int getCPInt(int i) throws IllegalArgumentException {
     if (i < 1 || i >= cpItems.length) {
       throw new IllegalArgumentException("Constant pool item #" + i + " out of range");
     }
@@ -452,7 +451,7 @@ public final class ConstantPoolParser implements ClassConstants {
   /**
    * @return the value of the Float at constant pool item i
    */
-  public float getCPFloat(int i) throws InvalidClassFileException, IllegalArgumentException {
+  public float getCPFloat(int i) throws IllegalArgumentException {
     if (i < 1 || i >= cpItems.length) {
       throw new IllegalArgumentException("Constant pool item #" + i + " out of range");
     }
@@ -466,7 +465,7 @@ public final class ConstantPoolParser implements ClassConstants {
   /**
    * @return the value of the Long at constant pool item i
    */
-  public long getCPLong(int i) throws InvalidClassFileException, IllegalArgumentException {
+  public long getCPLong(int i) throws IllegalArgumentException {
     if (i < 1 || i >= cpItems.length) {
       throw new IllegalArgumentException("Constant pool item #" + i + " out of range");
     }
@@ -480,7 +479,7 @@ public final class ConstantPoolParser implements ClassConstants {
   /**
    * @return the value of the Double at constant pool item i
    */
-  public double getCPDouble(int i) throws InvalidClassFileException, IllegalArgumentException {
+  public double getCPDouble(int i) throws IllegalArgumentException {
     if (i < 1 || i >= cpItems.length) {
       throw new IllegalArgumentException("Constant pool item #" + i + " out of range");
     }
@@ -543,7 +542,7 @@ public final class ConstantPoolParser implements ClassConstants {
 
   private InvalidClassFileException invalidUtf8(int item, int offset) {
     return new InvalidClassFileException(offset, "Constant pool item #" + item + " starting at " + cpOffsets[item]
-        + ", is an invalid Java Utf8 string (byte is " + getByte(offset) + ")");
+        + ", is an invalid Java Utf8 string (byte is " + getByte(offset) + ')');
   }
 
   /**
@@ -561,7 +560,7 @@ public final class ConstantPoolParser implements ClassConstants {
     if (s == null) {
       int count = getUShort(offset + 1);
       int end = count + offset + 3;
-      StringBuffer buf = new StringBuffer(count);
+      StringBuilder buf = new StringBuilder(count);
       offset += 3;
       while (offset < end) {
         byte x = getByte(offset);
@@ -676,4 +675,4 @@ public final class ConstantPoolParser implements ClassConstants {
   private double getDouble(int i) {
     return Double.longBitsToDouble(getLong(i));
   }
-}
\ No newline at end of file
+}
