@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002,2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.shrikeCT;
 
 /**
@@ -29,4 +29,8 @@ public final class SourceFileReader extends AttributeReader {
   public int getSourceFileCPIndex() {
     return cr.getUShort(attr + 6);
   }
-}
\ No newline at end of file
+  
+  public String getSourceFile() throws IllegalArgumentException, InvalidClassFileException {
+    return cr.getCP().getCPUtf8(getSourceFileCPIndex());
+  }
+}
