@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.dataflow.graph;
 
 import com.ibm.wala.fixpoint.AbstractOperator;
@@ -16,8 +16,7 @@ import com.ibm.wala.fixpoint.IVariable;
 /**
  * Abstract superclass for meet operators
  */
-@SuppressWarnings("rawtypes")
-public abstract class AbstractMeetOperator<T extends IVariable> extends AbstractOperator<T> {
+public abstract class AbstractMeetOperator<T extends IVariable<T>> extends AbstractOperator<T> {
 
   /**
    * subclasses can override if needed
