@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.dataflow.graph;
 
 import com.ibm.wala.fixpoint.IVariable;
@@ -16,8 +16,7 @@ import com.ibm.wala.util.graph.Graph;
 /**
  * a basic implementation of the dataflow framework
  */
-@SuppressWarnings("rawtypes")
-public class BasicFramework<T, V extends IVariable> implements IKilldallFramework<T, V> {
+public class BasicFramework<T, V extends IVariable<V>> implements IKilldallFramework<T, V> {
 
   private final Graph<T> flowGraph;
   private final ITransferFunctionProvider<T, V> transferFunctionProvider;
@@ -42,4 +41,4 @@ public class BasicFramework<T, V extends IVariable> implements IKilldallFramewor
   public ITransferFunctionProvider<T, V> getTransferFunctionProvider() {
     return transferFunctionProvider;
   }
-}
\ No newline at end of file
+}
