@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,16 +7,15 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.dataflow.graph;
 
 import com.ibm.wala.fixpoint.BooleanVariable;
-import com.ibm.wala.fixpoint.FixedPointConstants;
 
 /**
  * Operator U(n) = U(n) U U(j)
  */
-public class BooleanUnion extends AbstractMeetOperator<BooleanVariable> implements FixedPointConstants {
+public class BooleanUnion extends AbstractMeetOperator<BooleanVariable> {
 
   private final static BooleanUnion SINGLETON = new BooleanUnion();
 
@@ -52,8 +51,7 @@ public class BooleanUnion extends AbstractMeetOperator<BooleanVariable> implemen
     }
     BooleanVariable U = new BooleanVariable();
     U.copyState(lhs);
-    for (int i = 0; i < rhs.length; i++) {
-      BooleanVariable R = rhs[i];
+    for (BooleanVariable R : rhs) {
       if (R != null) {
         U.or(R);
       }
@@ -65,4 +63,4 @@ public class BooleanUnion extends AbstractMeetOperator<BooleanVariable> implemen
       return NOT_CHANGED;
     }
   }
-}
\ No newline at end of file
+}
