@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.dataflow.graph;
 
 import com.ibm.wala.fixpoint.IVariable;
@@ -19,8 +19,7 @@ import com.ibm.wala.util.graph.Graph;
  * 
  * @param <T> type of nodes in the graph
  */
-@SuppressWarnings("rawtypes")
-public interface IKilldallFramework<T,V extends IVariable> {
+public interface IKilldallFramework<T,V extends IVariable<V>> {
 
   /**
    * @return the flow graph which induces this dataflow problem
