@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.fixedpoint.impl;
 
 import com.ibm.wala.fixpoint.IVariable;
@@ -15,8 +15,7 @@ import com.ibm.wala.fixpoint.IVariable;
 /**
  * An implementation of NullaryStep that carries its operator explicitly
  */
-@SuppressWarnings("rawtypes")
-public class BasicNullaryStatement<T extends IVariable> extends NullaryStatement<T> {
+public class BasicNullaryStatement<T extends IVariable<T>> extends NullaryStatement<T> {
 
   /**
    * The operator in the equation
