@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.fixedpoint.impl;
 
 import com.ibm.wala.fixpoint.IFixedPointSystem;
@@ -17,7 +17,7 @@ import com.ibm.wala.fixpoint.IVariable;
 /**
  * Default implementation of a fixed point solver.
  */
-public abstract class DefaultFixedPointSolver<T extends IVariable<?>> extends AbstractFixedPointSolver<T> {
+public abstract class DefaultFixedPointSolver<T extends IVariable<T>> extends AbstractFixedPointSolver<T> {
 
   private final DefaultFixedPointSystem<T> graph;
   
@@ -27,16 +27,16 @@ public abstract class DefaultFixedPointSolver<T extends IVariable<?>> extends Ab
    */
   public DefaultFixedPointSolver(int expectedOut) {
     super();
-    graph = new DefaultFixedPointSystem<T>(expectedOut);
+    graph = new DefaultFixedPointSystem<>(expectedOut);
   }
   
   public DefaultFixedPointSolver() {
     super();
-    graph = new DefaultFixedPointSystem<T>();
+    graph = new DefaultFixedPointSystem<>();
   }
   
   @Override
   public IFixedPointSystem<T> getFixedPointSystem() {
     return graph;
   }
-}
\ No newline at end of file
+}
