@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.fixedpoint.impl;
 
 import java.util.HashSet;
@@ -41,10 +41,9 @@ public class Worklist extends Heap<AbstractStatement> {
   }
   
   public void insertStatement(AbstractStatement eq) {
-    if (!contents.contains(eq)) {
-      contents.add(eq);
+    if (contents.add(eq)) {
       super.insert(eq);
     }
   }
 
-}
\ No newline at end of file
+}
