@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.fixpoint;
 
 
@@ -16,8 +16,7 @@ package com.ibm.wala.fixpoint;
  * 
  * This is an abstract class and not an interface in order to force subclasses to re-implement equals(), hashCode(), and toString()
  */
-@SuppressWarnings("rawtypes")
-public abstract class AbstractOperator<T extends IVariable> implements FixedPointConstants {
+public abstract class AbstractOperator<T extends IVariable<T>> implements FixedPointConstants {
 
   /**
    * Evaluate this equation, setting a new value for the left-hand side.
