@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,15 +7,14 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.fixpoint;
 
 
 /**
  * An implementation of UnaryStatement that carries its operator explicitly
  */
-@SuppressWarnings("rawtypes")
-public class BasicUnaryStatement<T extends IVariable> extends UnaryStatement<T> {
+public class BasicUnaryStatement<T extends IVariable<T>> extends UnaryStatement<T> {
 
   private final UnaryOperator<T> operator;
 
