@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.fixpoint;
 
 
@@ -18,7 +18,7 @@ import com.ibm.wala.util.MonitorUtil.IProgressMonitor;
 /**
  * Solves a set of constraints
  */
-public interface IFixedPointSolver<T extends IVariable>  {
+public interface IFixedPointSolver<T extends IVariable<T>>  {
 
   /**
    * @return the set of statements solved by this {@link IFixedPointSolver}
@@ -34,4 +34,4 @@ public interface IFixedPointSolver<T extends IVariable>  {
    *         value of some variable.
    */
   public boolean solve(IProgressMonitor monitor) throws CancelException;
-}
\ No newline at end of file
+}
