@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.fixpoint;
 
 import com.ibm.wala.util.graph.INodeWithNumber;
@@ -16,8 +16,7 @@ import com.ibm.wala.util.graph.INodeWithNumber;
 /**
  * Represents a single variable in a fixed-point iterative system.
  */
-@SuppressWarnings("rawtypes")
-public interface IVariable<T extends IVariable> extends INodeWithNumber {
+public interface IVariable<T extends IVariable<T>> extends INodeWithNumber {
   
   /**
    * Variables must allow the solver implementation to get/set an order number,
@@ -44,4 +43,4 @@ public interface IVariable<T extends IVariable> extends INodeWithNumber {
     */
   public void copyState(T v);
 
-}
\ No newline at end of file
+}
