@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.fixpoint;
 
 import com.ibm.wala.util.debug.Assertions;
@@ -16,8 +16,7 @@ import com.ibm.wala.util.debug.UnimplementedError;
 /**
  * An operator of the form lhs = op (rhs)
  */
-@SuppressWarnings("rawtypes")
-public abstract class UnaryOperator<T extends IVariable> extends AbstractOperator<T> implements FixedPointConstants {
+public abstract class UnaryOperator<T extends IVariable<T>> extends AbstractOperator<T> {
 
   /**
    * Evaluate this equation, setting a new value for the left-hand side.
@@ -31,7 +30,7 @@ public abstract class UnaryOperator<T extends IVariable> extends AbstractOperato
    * efficiency.
    */
   public UnaryStatement<T> makeEquation(T lhs, T rhs) {
-    return new BasicUnaryStatement<T>(lhs, this, rhs);
+    return new BasicUnaryStatement<>(lhs, this, rhs);
   }
 
   public boolean isIdentity() {
