@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,17 +7,16 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 
 package com.ibm.wala.util.collections;
 
 import java.util.Collection;
-import com.ibm.wala.util.Predicate;
-
+import java.util.function.Predicate;
 /**
  * A filter defined by set membership
  */
-public class CollectionFilter<T> extends Predicate<T> {
+public class CollectionFilter<T> implements Predicate<T> {
 
   private final Collection<? extends T> S;
 
