@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.collections;
 
 import java.util.Iterator;
@@ -22,7 +22,6 @@ public final class EmptyIterator<T> implements Iterator<T> {
   @SuppressWarnings("rawtypes")
   private static final EmptyIterator EMPTY = new EmptyIterator();
 
-  @SuppressWarnings("unchecked")
   public static <T> EmptyIterator<T> instance() {
     return EMPTY;
   }
