@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,15 +7,15 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.collections;
 
-import com.ibm.wala.util.Predicate;
+import java.util.function.Predicate;
 
 /**
  * intersection of two filters
  */
-public class Filtersection<T> extends Predicate<T> {
+public class Filtersection<T> implements Predicate<T> {
 
   final private Predicate<T> a;
   final private Predicate<T> b;
