@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,16 +7,16 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.collections;
 
 import java.util.Iterator;
+import java.util.function.IntFunction;
 
-import com.ibm.wala.util.functions.IntFunction;
 import com.ibm.wala.util.intset.IntIterator;
 
 /**
- * An <code>IntMapIterator</code> maps an <code>Iterator</code> contents to produce a new Iterator
+ * An {@code IntMapIterator} maps an {@code Iterator} contents to produce a new Iterator
  */
 public class IntMapIterator<T> implements Iterator<T> {
   final IntIterator i;
@@ -54,4 +54,4 @@ public class IntMapIterator<T> implements Iterator<T> {
     return "map: " + f + " of " + i;
   }
 
-}
\ No newline at end of file
+}
