@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2007 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.collections;
 
 import java.util.Iterator;
@@ -20,7 +20,7 @@ public class Iterator2Iterable<T> implements Iterable<T> {
   private final Iterator<T> iter;
 
   public static <T> Iterator2Iterable<T> make(Iterator<T> iter) {
-    return new Iterator2Iterable<T>(iter);
+    return new Iterator2Iterable<>(iter);
   }
 
   public Iterator2Iterable(Iterator<T> iter) {
