@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.collections;
 
 import java.util.Iterator;
@@ -20,7 +20,7 @@ public class IteratorPlusOne<T> implements Iterator<T> {
     if (it == null) {
       throw new IllegalArgumentException("null it");
     }
-    return new IteratorPlusOne<T>(it, xtra);
+    return new IteratorPlusOne<>(it, xtra);
   }
 
   private final Iterator<? extends T> it;
