@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,13 +7,10 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.collections;
 
 import java.util.Iterator;
-
-import com.ibm.wala.util.functions.Function;
-import com.ibm.wala.util.Predicate;
 /**
  * utilities dealing with Iterators
  */
@@ -46,20 +43,7 @@ public class IteratorUtil {
     return count;
   }
 
-  @SuppressWarnings("deprecation")
   public static <T, S extends T> Iterator<S> filter(Iterator<T> iterator, final Class<S> cls) {
-    return new MapIterator<T,S>(
-        new FilterIterator<T>(iterator, new Predicate<T>() {
-          @Override public boolean test(T o) {
-            return cls.isInstance(o);
-          }
-        }), 
-        new Function<T,S>() {
-          @SuppressWarnings("unchecked")
-          @Override
-          public S apply(T object) {
-            return (S) object;
-          }
-        });
+    return new MapIterator<>(new FilterIterator<>(iterator, cls::isInstance), cls::cast);
   }
 }
