@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.collections;
 
 import java.util.Iterator;
@@ -53,7 +53,7 @@ public class NonNullSingletonIterator<T> implements Iterator<T> {
   }
 
   public static <T> NonNullSingletonIterator<T> make(T item) {
-    return new NonNullSingletonIterator<T>(item);
+    return new NonNullSingletonIterator<>(item);
   }
 
 }
