@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.collections;
 
 import java.util.Comparator;
@@ -36,7 +36,6 @@ public class ToStringComparator<T> implements Comparator<T> {
     return o1.toString().compareTo(o2.toString());
   }
   
-  @SuppressWarnings("unchecked")
   public static <T> ToStringComparator<T> instance() {
     return INSTANCE;
   }
