@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2007 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.graph;
 
 import com.ibm.wala.util.collections.SimpleVector;
@@ -18,7 +18,7 @@ import com.ibm.wala.util.collections.SimpleVector;
 public class BasicTree<T> {
 
   private final T value;
-  final private SimpleVector<BasicTree<T>> children = new SimpleVector<BasicTree<T>>();
+  final private SimpleVector<BasicTree<T>> children = new SimpleVector<>();
 
   protected BasicTree(T value) {
     this.value = value;
@@ -28,7 +28,7 @@ public class BasicTree<T> {
     if (value == null) {
       throw new IllegalArgumentException("null value");
     }
-    return new BasicTree<T>(value);
+    return new BasicTree<>(value);
   }
   
   public T getRootValue() {
