@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,12 +7,11 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.graph;
 
-import java.util.Collection;
 import java.util.HashSet;
-import java.util.Iterator;
+import java.util.Set;
 
 import com.ibm.wala.util.collections.HashSetFactory;
 
@@ -21,13 +20,12 @@ import com.ibm.wala.util.collections.HashSetFactory;
  */
 public class InferGraphRoots {
 
-  public static <T> Collection<T> inferRoots(Graph<T> g){
+  public static <T> Set<T> inferRoots(Graph<T> g){
     if (g == null) {
       throw new IllegalArgumentException("g is null");
     }
     HashSet<T> s = HashSetFactory.make();
-    for (Iterator<? extends T> it = g.iterator(); it.hasNext();) {
-      T node = it.next();
+    for (T node : g) {
       if (g.getPredNodeCount(node) == 0) {
         s.add(node);
       }
