@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.graph.dominators;
 
 import com.ibm.wala.util.graph.NumberedGraph;
@@ -34,11 +34,6 @@ public class NumberedDominators<T> extends Dominators<T> {
     analyze();
   }
 
-  @Override
-  public NumberedGraph<T> getGraph() {
-    return (NumberedGraph<T>) G;
-  }
-
   /*
    * Look-aside table for DominatorInfo objects
    */
@@ -48,7 +43,7 @@ public class NumberedDominators<T> extends Dominators<T> {
   @Override
   protected final DominatorInfo getInfo(T node) {
     assert node != null;
-    return (DominatorInfo) infoMap[getGraph().getNumber(node)];
+    return (DominatorInfo) infoMap[((NumberedGraph<T>)G).getNumber(node)];
   }
 
 }
