@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.graph.impl;
 
 import com.ibm.wala.util.graph.AbstractNumberedGraph;
@@ -21,9 +21,9 @@ import com.ibm.wala.util.graph.NumberedNodeManager;
  */
 public class DelegatingNumberedGraph<T extends INodeWithNumberedEdges> extends AbstractNumberedGraph<T> {
 
-  final private DelegatingNumberedNodeManager<T> nodeManager = new DelegatingNumberedNodeManager<T>();
+  final private DelegatingNumberedNodeManager<T> nodeManager = new DelegatingNumberedNodeManager<>();
 
-  final private DelegatingNumberedEdgeManager<T> edgeManager = new DelegatingNumberedEdgeManager<T>(nodeManager);
+  final private DelegatingNumberedEdgeManager<T> edgeManager = new DelegatingNumberedEdgeManager<>(nodeManager);
 
   /*
    * @see com.ibm.wala.util.graph.AbstractGraph#getNodeManager()
@@ -40,4 +40,4 @@ public class DelegatingNumberedGraph<T extends INodeWithNumberedEdges> extends A
   protected NumberedEdgeManager<T> getEdgeManager() {
     return edgeManager;
   }
-}
\ No newline at end of file
+}
