@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.graph.impl;
 
 import com.ibm.wala.util.graph.Graph;
@@ -19,18 +19,17 @@ import com.ibm.wala.util.graph.NumberedGraph;
 public class GraphInverter {
 
   public static <T> NumberedGraph<T> invert(final NumberedGraph<T> G) {
-    return new InvertedNumberedGraph<T>(G);
+    return new InvertedNumberedGraph<>(G);
   }
   
-      /**
-   * @param G
+  /**
    * @return A graph view that reverses the edges in G
    */
   public static <T> Graph<T> invert(final Graph<T> G) {
     if (G instanceof NumberedGraph) {
-      return new InvertedNumberedGraph<T>((NumberedGraph<T>) G);
+      return new InvertedNumberedGraph<>((NumberedGraph<T>) G);
     } else {
-      return new InvertedGraph<T>(G);
+      return new InvertedGraph<>(G);
     }
   }
 
