@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.graph.impl;
 
 import com.ibm.wala.util.graph.AbstractGraph;
@@ -36,7 +36,7 @@ public class InvertedGraph<T> extends AbstractGraph<T> {
 
   public InvertedGraph(Graph<T> G) {
     nodes = G;
-    edges = new InvertingEdgeManager<T>(G);
+    edges = new InvertingEdgeManager<>(G);
   }
 
 }
