@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.graph.impl;
 
 import com.ibm.wala.util.graph.AbstractNumberedGraph;
@@ -35,7 +35,7 @@ public class InvertedNumberedGraph<T> extends AbstractNumberedGraph<T> {
 
   InvertedNumberedGraph(NumberedGraph<T> G) {
     nodes = G;
-    edges = new InvertingNumberedEdgeManager<T>(G);
+    edges = new InvertingNumberedEdgeManager<>(G);
   }
 
 }
