@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.heapTrace;
 
 import java.io.File;
@@ -51,12 +51,12 @@ public class HeapTracer {
     /**
      * Stack of instance objects discovered but not yet traced.
      */
-    private final Stack<Object> scalarWorkList = new Stack<Object>();
+    private final Stack<Object> scalarWorkList = new Stack<>();
 
     /**
      * Stack of array objects discovered but not yet traced.
      */
-    private final Stack<Object> arrayWorkList = new Stack<Object>();
+    private final Stack<Object> arrayWorkList = new Stack<>();
 
     /**
      * How many bytes do we assume the JVM wastes on each instance?
@@ -69,7 +69,7 @@ public class HeapTracer {
     private final boolean traceStatics;
 
     /**
-     * Map: Class -> Integer, the size of each class
+     * Map: Class -&gt; Integer, the size of each class
      */
     private final HashMap<Class<?>, Integer> sizeMap = HashMapFactory.make();
 
@@ -129,18 +129,11 @@ public class HeapTracer {
 	this.traceStatics = traceStatics;
     }
 
-    /**
-     * @param c
-     * @param traceStatics
-     */
     public HeapTracer(Collection<?> c, boolean traceStatics) {
 	rootInstances = c;
 	this.traceStatics = traceStatics;
     }
 
-    /**
-     * @param args
-     */
     public static void main(String[] args) {
 	try {
 	    Result r = (new HeapTracer(true)).perform();
@@ -157,8 +150,8 @@ public class HeapTracer {
 	String classpath = System.getProperty("java.class.path");
 	Object[] binDirectories = extractBinDirectories(classpath);
 	HashSet<String> classFileNames = HashSetFactory.make();
-	for (int i = 0; i < binDirectories.length; i++) {
-	    String dir = (String) binDirectories[i];
+	for (Object binDirectorie : binDirectories) {
+	    String dir = (String) binDirectorie;
 	    File fdir = new File(dir);
 	    classFileNames.addAll(findClassNames(dir, fdir));
 	}
@@ -172,7 +165,7 @@ public class HeapTracer {
 
     /**
      * @param fdir
-     * @return Collection <String>representing the class names in a particular
+     * @return {@link Collection}&lt;{@link String}&gt; representing the class names in a particular
      *         file
      */
     /**
@@ -180,14 +173,14 @@ public class HeapTracer {
      *            root of the classpath governing file f
      * @param f
      *            a File or directory
-     * @return Collection <String>representing the class names in f
+     * @return {@link Collection}&lt;{@link String}&gt; representing the class names in f
      */
     private static Collection<String> findClassNames(String rootDir, File f) {
 	HashSet<String> result = HashSetFactory.make();
 	if (f.isDirectory()) {
 	    File[] files = f.listFiles();
-	    for (int i = 0; i < files.length; i++) {
-		result.addAll(findClassNames(rootDir, files[i]));
+	    for (File file : files) {
+		result.addAll(findClassNames(rootDir, file));
 	    }
 	} else {
 	    if (f.getName().indexOf(".class") > 0) {
@@ -203,7 +196,6 @@ public class HeapTracer {
     }
 
     /**
-     * @param classpath
      * @return set of strings that are names of directories that contain "bin"
      */
     private static Object[] extractBinDirectories(String classpath) {
@@ -224,24 +216,22 @@ public class HeapTracer {
     public Result perform() throws ClassNotFoundException,
 	    IllegalArgumentException, IllegalAccessException {
 	Result result = new Result();
-	IdentityHashMap<Object, Object> objectsVisited = new IdentityHashMap<Object, Object>();
+	IdentityHashMap<Object, Object> objectsVisited = new IdentityHashMap<>();
 	if (traceStatics) {
-	    for (int i = 0; i < rootClasses.length; i++) {
-		Class<?> c = Class.forName(rootClasses[i]);
+	    for (String rootClasse : rootClasses) {
+		Class<?> c = Class.forName(rootClasse);
 		Field[] fields = c.getDeclaredFields();
-		for (int j = 0; j < fields.length; j++) {
-		    if (isStatic(fields[j])) {
-			traverse(fields[j], result, objectsVisited);
+		for (Field field : fields) {
+		    if (isStatic(field)) {
+			traverse(field, result, objectsVisited);
 		    }
 		}
 	    }
 	}
-	for (Iterator<?> it = rootInstances.iterator(); it.hasNext();) {
-	    Object instance = it.next();
+	for (Object instance : rootInstances) {
 	    Class<?> c = instance.getClass();
 	    Set<Field> fields = getAllInstanceFields(c);
-	    for (Iterator<Field> it2 = fields.iterator(); it2.hasNext();) {
-		Field f = it2.next();
+	    for (Field f : fields) {
 		traverse(f, instance, result, objectsVisited);
 	    }
 	}
@@ -250,7 +240,6 @@ public class HeapTracer {
     }
 
     /**
-     * @param o
      * @return the estimated size of the object
      */
     private static int computeSizeOf(Object o) {
@@ -264,8 +253,7 @@ public class HeapTracer {
 	    throw new Error();
 	} else {
 	    Collection<Field> fields = getAllInstanceFields(c);
-	    for (Iterator<Field> it = fields.iterator(); it.hasNext();) {
-		Field f = it.next();
+	    for (Field f : fields) {
 		result += sizeOfSlot(f.getType());
 	    }
 	}
@@ -273,7 +261,6 @@ public class HeapTracer {
     }
 
     /**
-     * @param o
      * @return the estimated size of the object
      */
     private int sizeOf(Object o) {
@@ -283,7 +270,7 @@ public class HeapTracer {
 	} else {
 	    Integer S = sizeMap.get(c);
 	    if (S == null) {
-		S = new Integer(computeSizeOf(o));
+		S = Integer.valueOf(computeSizeOf(o));
 		sizeMap.put(c, S);
 	    }
 	    return S.intValue();
@@ -291,7 +278,6 @@ public class HeapTracer {
     }
 
     /**
-     * @param c
      * @return size of a field of type c, in bytes
      */
     private static int sizeOfSlot(Class<?> c) {
@@ -315,10 +301,6 @@ public class HeapTracer {
 
     /**
      * Traverse the heap starting at a static field
-     * 
-     * @param result
-     * @throws IllegalAccessException
-     * @throws IllegalArgumentException
      */
     private void traverse(Field root, Result result,
 	    IdentityHashMap<Object, Object> objectsVisited)
@@ -416,8 +398,8 @@ public class HeapTracer {
 	    System.err.println(("traverse scalar " + c));
 	}
 	Field[] fields = getAllReferenceInstanceFields(c);
-	for (int i = 0; i < fields.length; i++) {
-	    traverseFieldOfScalar(root, fields[i], scalar, container,
+	for (Field field : fields) {
+	    traverseFieldOfScalar(root, field, scalar, container,
 		    objectsVisited, result);
 	}
     }
@@ -456,16 +438,6 @@ public class HeapTracer {
 	}
     }
 
-    /**
-     * @param root
-     * @param f
-     * @param scalar
-     * @param container
-     * @param objectsVisited
-     * @param result
-     * @throws IllegalArgumentException
-     * @throws IllegalAccessException
-     */
     private void traverseFieldOfScalar(Field root, Field f, Object scalar,
 	    Object container, IdentityHashMap<Object, Object> objectsVisited,
 	    Result result) throws IllegalArgumentException,
@@ -630,13 +602,13 @@ public class HeapTracer {
      */
     class Demographics {
 	/**
-	 * mapping: Object (key) -> Integer (number of instances in a partition)
+	 * mapping: Object (key) -&gt; Integer (number of instances in a partition)
 	 */
 	private final HashMap<Object, Integer> instanceCount = HashMapFactory
 		.make();
 
 	/**
-	 * mapping: Object (key) -> Integer (bytes)
+	 * mapping: Object (key) -&gt; Integer (bytes)
 	 */
 	private final HashMap<Object, Integer> sizeCount = HashMapFactory
 		.make();
@@ -660,31 +632,30 @@ public class HeapTracer {
 	public void registerObject(Object key, Object o) {
 	    Integer I = instanceCount.get(key);
 	    int newCount = (I == null) ? 1 : I.intValue() + 1;
-	    instanceCount.put(key, new Integer(newCount));
+	    instanceCount.put(key, Integer.valueOf(newCount));
 	    totalInstances++;
 
 	    I = sizeCount.get(key);
 	    int s = sizeOf(o);
 	    int newSizeCount = (I == null) ? s : I.intValue() + s;
-	    sizeCount.put(key, new Integer(newSizeCount));
+	    sizeCount.put(key, Integer.valueOf(newSizeCount));
 	    totalSize += s;
 	}
 
 	@Override
 	public String toString() {
-	    StringBuffer result = new StringBuffer();
-	    result.append("Totals: " + totalInstances + " " + totalSize + "\n");
-	    TreeSet<Object> sorted = new TreeSet<Object>(new SizeComparator());
+	    StringBuilder result = new StringBuilder();
+	    result.append("Totals: ").append(totalInstances).append(' ').append(totalSize).append('\n');
+	    TreeSet<Object> sorted = new TreeSet<>(new SizeComparator());
 	    sorted.addAll(instanceCount.keySet());
-	    for (Iterator<Object> it = sorted.iterator(); it.hasNext();) {
-		Object key = it.next();
+	    for (Object key : sorted) {
 		Integer I = instanceCount.get(key);
 		Integer bytes = sizeCount.get(key);
 		result.append("  ").append(I).append("   ").append(bytes)
 			.append("   ");
 		result.append(bytes.intValue() / I.intValue()).append("   ");
 		result.append(key);
-		result.append("\n");
+		result.append('\n');
 	    }
 	    return result.toString();
 	}
@@ -729,13 +700,12 @@ public class HeapTracer {
     public class Result {
 
 	/**
-	 * a mapping from Field (static field roots) -> Demographics object
+	 * a mapping from Field (static field roots) -&gt; Demographics object
 	 */
 	private final HashMap<Field, Demographics> roots = HashMapFactory
 		.make();
 
 	/**
-	 * @param root
 	 * @return the Demographics object tracking objects traced from that
 	 *         root
 	 */
@@ -757,37 +727,33 @@ public class HeapTracer {
 
 	public int getTotalSize() {
 	    int totalSize = 0;
-	    for (Iterator<Demographics> it = roots.values().iterator(); it
-		    .hasNext();) {
-		Demographics d = it.next();
-		totalSize += d.getTotalSize();
-	    }
+	    for (Demographics d : roots.values()) {
+totalSize += d.getTotalSize();
+  }
 	    return totalSize;
 	}
 
 	@Override
 	public String toString() {
-	    StringBuffer result = new StringBuffer();
+	    StringBuilder result = new StringBuilder();
 	    result.append("Assuming " + BYTES_IN_HEADER
 		    + " header bytes per object\n");
 	    int totalInstances = 0;
 	    int totalSize = 0;
-	    for (Iterator<Demographics> it = roots.values().iterator(); it
-		    .hasNext();) {
-		Demographics d = it.next();
-		totalInstances += d.getTotalInstances();
-		totalSize += d.getTotalSize();
-	    }
-	    result.append("Total instances: " + totalInstances + "\n");
-	    result.append("Total size(bytes): " + totalSize + "\n");
+	    for (Demographics d : roots.values()) {
+totalInstances += d.getTotalInstances();
+totalSize += d.getTotalSize();
+  }
+	    result.append("Total instances: ").append(totalInstances).append('\n');
+	    result.append("Total size(bytes): ").append(totalSize).append('\n');
 
-	    TreeSet<Field> sortedDemo = new TreeSet<Field>(new SizeComparator());
+	    TreeSet<Field> sortedDemo = new TreeSet<>(new SizeComparator());
 	    sortedDemo.addAll(roots.keySet());
-	    for (Iterator<Field> it = sortedDemo.iterator(); it.hasNext();) {
-		Object root = it.next();
+	    for (Field field : sortedDemo) {
+		Object root = field;
 		Demographics d = roots.get(root);
 		if (d.getTotalSize() > 10000) {
-		    result.append(" root: ").append(root).append("\n");
+		    result.append(" root: ").append(root).append('\n');
 		    result.append(d);
 		}
 	    }
