@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.intset;
 
 /**
@@ -57,7 +57,7 @@ public class IntPair {
 
   @Override
   public String toString() {
-    return "[" + x + "," + y + "]";
+    return "[" + x + ',' + y + ']';
   }
 
   public static IntPair make(int x, int y) {
