@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,13 +7,15 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.intset;
 
 import com.ibm.wala.util.collections.CompoundIntIterator;
 import com.ibm.wala.util.collections.EmptyIntIterator;
 
 public class SemiSparseMutableIntSet implements MutableIntSet {
+  private static final long serialVersionUID = 8647721176321526013L;
+
   private static final boolean DEBUG = true;
 
   private static final double FIX_SPARSE_MOD = 12;
@@ -234,7 +236,6 @@ public class SemiSparseMutableIntSet implements MutableIntSet {
   }
   
   /**
-   * @param i
    * @return true iff this set contains integer i
    */
   @Override
@@ -339,7 +340,6 @@ public class SemiSparseMutableIntSet implements MutableIntSet {
         return next;
       }
     }
-    ;
 
     if (sparsePart.isEmpty()) {
       if (densePart == null || densePart.isZero()) {
@@ -374,8 +374,6 @@ public class SemiSparseMutableIntSet implements MutableIntSet {
 
   /**
    * Invoke an action on each element of the Set, excluding elements of Set X
-   * 
-   * @param action
    */
   @Override
   public void foreachExcluding(IntSet X, IntSetAction action) {
@@ -402,7 +400,7 @@ public class SemiSparseMutableIntSet implements MutableIntSet {
   }
 
   /**
-   * @return true iff <code>this</code> has the same value as <code>that</code>.
+   * @return true iff {@code this} has the same value as {@code that}.
    * @throws IllegalArgumentException if that is null
    */
   @Override
@@ -429,7 +427,7 @@ public class SemiSparseMutableIntSet implements MutableIntSet {
   }
 
   /**
-   * @return true iff <code>this</code> is a subset of <code>that</code>.
+   * @return true iff {@code this} is a subset of {@code that}.
    * @throws IllegalArgumentException if that is null
    */
   @Override
@@ -615,8 +613,6 @@ public class SemiSparseMutableIntSet implements MutableIntSet {
 
   /**
    * Interset this with another set.
-   * 
-   * @param set
    */
   @Override
   public void intersectWith(IntSet set) {
@@ -654,11 +650,11 @@ public class SemiSparseMutableIntSet implements MutableIntSet {
 
   @Override
   public String toString() {
-    StringBuffer sb = new StringBuffer("[");
+    StringBuilder sb = new StringBuilder("[");
     if (densePart != null) {
-      sb.append("densePart: ").append(densePart.toString()).append(" ");
+      sb.append("densePart: ").append(densePart.toString()).append(' ');
     }
-    sb.append("sparsePart: ").append(sparsePart.toString()).append("]");
+    sb.append("sparsePart: ").append(sparsePart.toString()).append(']');
     return sb.toString();
   }
 
