@@ -1,4 +1,4 @@
-/*******************************************************************************
+/*
  * Copyright (c) 2002 - 2006 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -7,7 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *******************************************************************************/
+ */
 package com.ibm.wala.util.perf;
 
 /**
@@ -53,12 +53,12 @@ public class Stopwatch {
   
   @Override
   public String toString() {
-    StringBuffer sb = new StringBuffer();
-    sb.append("total: " + getElapsedMillis());
+    StringBuilder sb = new StringBuilder();
+    sb.append("total: ").append(getElapsedMillis());
     if (count > 0){
-      sb.append(", inv: " + count);
-      sb.append(", avg: " + getElapsedMillis()/count);
+      sb.append(", inv: ").append(count);
+      sb.append(", avg: ").append(getElapsedMillis() / count);
     }
     return sb.toString();
   }
-}
\ No newline at end of file
+}
